### -*-fundamental-*-
###
### NB: Use fundamental-mode, rather than awk-mode, to avoid very long
### delays in insertion of commas and parentheses, sigh...
###
### /u/sy/beebe/bibnet/journal.awk, Mon May  2 14:13:56 1994
### Edit by Nelson H. F. Beebe <beebe@sunrise>
### ====================================================================
### Substitute journal names with standard abbreviations in a BibTeX file.
### The output is stored in a temporary file so that the abbreviations
### that are actually used can be merged back in before the first entry,
### with the final result sent to stdout.
###
### As of 06-Feb-1996, this program also provides support for insertion of
### ISSN and CODEN data, where possible, and for the checking of existing
### ISSN and CODEN data.
###
### Periodicals can be looked up at the ISSN registry at:
###
###	http://www.ulrichsweb.com/ulrichsweb/
###
### I have yet to find a definitive online CODEN directory for the printed
### version
###
###	International CODEN Directory: Introduction International CODEN
###	Service, Chemical Abstracts Service, 2540 Olentangy River Road,
###	Columbus, OH 43210, USA
###
### but this index for the SPIRES Journals Database may be helpful:
###
###	http://www-library.desy.de/spires/coden/
###
### The Chemical Abstracts service maintains this useful online site
### for journal searches by name, by CODEN, and by ISSN:
###
###	http://cassi.cas.org/
###
### For at least some journals listed at that site, there are links to
### the journal home page or issue archive.
###
### From
###
###	http://www.cas.org/PRINTED/coden.html
###
### I quote: ``CODEN are unique, six-character codes that identify
### serial and nonserial publications produced worldwide. CODEN are
### assigned not only to chemistry-related literature but to
### publications in all subject areas.''
###
### [27-Oct-2010] I found today a useful list of almost 11,000 entries
### with CODEN/ISSN/journal-name/publisher data at
###
###    http://lib.asust.edu.cn/info_sear/ess/EISOURCE.htm
###
### We assume that the input has already been prettyprinted so that
### simpler pattern matching suffices.  For maximum substitutions, the
### input should have value strings on a single line, such as when output
### by bibclean -max-width 0.
###
### This program contains a large number of journal strings (about 2360
### unique journals, with about 5300 variant names) collected from
### various sources, together with their abbreviations.  Any journal
### values that cannot be replaced by an abbreviation are flagged on
### stderr.
###
### As of 02-May-1996, all included journals that were previously
### missing CODEN and/or ISSN values have been looked up manually in
### Ulrich's International Periodical Directory (34th edition, 1996,
### ISBN 0-8352-3676-5, ISSN 0000-0175) which lists all periodicals
### currently published throughout the world.  Those for which no ISSN
### or CODEN data can be found are suspect; they may be
###
###	(a) incorrectly named journals;
###	(b) journals that have not been published since 1972 when the ISSN
###	    and ISBN systems were introduced;
###	(c) bogus journal names.
###
### Future additions to this program should always include CODEN and
### ISSN values, because journal names that lack an ISSN are likely to
### be suspect (misspelled, wrongly named, or simply, non-existant).
### CODEN values are assigned by Chemical Abstracts, so they are not
### usually available for journals outside the fields of chemistry and
### physics.  The OCLC Article1st and PapersFirst databases usually
### include both ISSN and CODEN values, which oclc-to-bibtex.awk will
### preserve.
###
### When official abbreviations of journal names are available, the BibTeX
### abbreviation is created by converting the official abbreviation to
### upper-case, converting consecutive space and period to a single
### hyphen, discarding non-letters, and finally, prefixing that result
### with "j-".  Thus, "Review of Modern Physics" is conventionally
### abbreviated "Rev. Mod. Phys.", and is assigned a BibTeX string name of
### j-REV-MOD-PHYS.  Although this sometimes makes for long BibTeX string
### names, they are much more readable in a large collection than more
### cryptic ones, like "j-RMP", would be.
###
### Because wide inconsistency in journal abbreviations leads to
### ambiguities and uncertainties, the default action of this program is
### to supply full, rather than abbreviated, journal names in the BibTeX
### @String{j-xxx="..."} output.  A future edition may offer an option
### to produce `standard' abbreviations from library catalogs and
### Mathematical Reviews Abbreviations of Names of Serials, and for
### rewriting existing bibliographies to use the standardized j-xxx
### BibTeX strings that reflect those standardized abbreviations.  The
### is-xxx extended bibliography styles will produce ISSN and CODEN
### values in bibliographic entries written to the .bbl file.
###
### Usage:
###	nawk -f journal.awk [-v CHECK=1] [-v MAPFILE=filename] \
###		[-v PRINT_MISSING=1] [-v PRINT_TABLE=1] old.bib >new.bib
###
### If CHECK is nonzero, the internal CODEN and ISSN values are
### validated from their respective checksum algorithms, and any
### invalid ones are reported on stderr.  No additional processing of
### command-line arguments is done.
###
### If MAPFILE is set, the specified file is expected to contain
### whitespace-separated pairs of CODENs and ISSNs; any additional
### data on the line is ignored.  Question marks in either CODEN or
### ISSN value cause the line to be ignored.  Otherwise, the pairs are
### checked against internal data in this file, and discrepancies are
### reported on stdout.  No additional processing of command-line
### arguments is done.
###
### If the PRINT_MISSING variable is set, the output will contain sorted
### lists of statements for insertion in initialize_CODEN() and
### initialize_ISSN() after missing values have been supplied for them.
###
### If the PRINT_TABLE variable is set, the output will contain a
### sorted list of triples ISSN<tab>CODEN<tab>journal-abbreviation,
### followed by additional code to set CODEN values for any missing
### ones, when correct CODEN data are available from ISSN-to-CODEN.txt,
### and execution will terminate on completion of that output.
###
### [17-Feb-2016] -- Add new code in initialize() to create new map
###		     array Full_ISSN[] to convert 9-character ISSN
###		     to longer string (e.g., "0009-3696" to
###		     "0009-3696 (print), 2327-5804 (electronic)".  Add
###		     new code to print_ISSN() to replace 9-character
###		     ISSN value by longer form, when available.  That
###		     will allow updating bibliographies to always use
###		     the longer form, when it exists.
### [04-Jan-2006] -- Add new code for MAPFILE processing.
### [18-Nov-2005] -- Add new code in PRINT_TABLE handling to output
###		     new initialization code for previously-missing
###		     CODEN data.
### [25-Jun-2005] -- Add new initialize_quad() and set_quad() functions
###		     to allow compact initializations.  The companion
###		     journal-abbrev.el file supplies a function to
###		     construct BibTeX string abbreviations from journal
###		     abbreviations.
### [27-Jan-2004] -- Add PRINT_TABLE support, and fix error in
###		     while(getline...){...} loops.  Add 36 new CODEN
###		     values previously marked as unknown, from tables
###		     at http://www.lib.nccu.edu.tw/ref/list/ei-*.htm
### [23-Jan-2001] -- Add getpid() and use it in forming Temp_File.
### [27-Jan-1999] -- Original version.
### ====================================================================

BEGIN					{ initialize() }

/^@[A-Za-z][-A-Za-z0-9_]*\{/ 		{ new_entry() }

/^ *fjournal *=/			{ Have_Full_Journal = 1 }

/^ *[Ii][Ss][Ss][Nn] *=/		{ Have_ISSN = 1 }

/^ *[Ii][Ss][Ss][Nn]-[Ll] *= *"[0-9][0-9][0-9][0-9]-[0-9][0-9][0-9][0-9X]" *, *$/	{ Have_ISSN_L = 1 }

/^ *journal-URL *=/			{ Have_Journal_URL = 1 }

/^ *[Cc][Oo][Dd][Ee][Nn] *= *".*", *$/	{ print_CODEN($0); next }

/^ *[Ii][Ss][Ss][Nn] *= *".*", *$/	{ print_ISSN($0); next }

/^ *journal *= *".*", *$/		{ print_journal($0); next }

/^ *journal *= *[a-zA-Z]/		{ print_and_save_journal($0); next }

/^ *} *$/				{ print_saved_data($0); next }

# Just copy everything else
					{ write_tmp($0) }

END   {
    close(Temp_File)
    close(SED_File)
    while ((getline x <Temp_File) > 0)	# copy preamble
    {
	if (x ~ /^@[Pp][Rr][Ee][Aa][Mm][Bb][Ll][Ee]/)
	{
	    print x
	    continue
	}
	else if (x ~ /^@[Ss][Tt][Rr][Ii][Nn][Gg]/)
	{
	    print x
	    continue
	}
	else if (x ~ /^@/)		# then found first entry
	{
	    print_abbrevs()
	    print x
	    break
	}
	print x
    }
    while ((getline x <Temp_File) > 0)	# copy remainder of file
	print x
    close(Temp_File)
    system("/bin/rm -f " Temp_File)
    close("/dev/stderr")
}

#=======================================================================


function checksum_CODEN(the_CODEN,    checksum)
{
    ## CODEN values are 6-character strings from the set [A-Z0-9],
    ## with a check digit stored in the 6th position given by
    ##
    ##     (11*N1 + 7*N2 + 5*N3 + 3*N4 + 1*N5) mod 34 == X
    ##
    ## where the Nk are 1..26 for A..Z, and 27..36 for 1..9..0.
    ## However, the checksum X (in 0..33) is represented by the
    ## corresponding character in the different 34-character range
    ## [9A-Z2-8], which excludes digits 0 and 1 to avoid confusion
    ## with letters O and I.

    checksum = 0
    checksum += 11 * CODEN_Digit(the_CODEN, 1)
    checksum +=  7 * CODEN_Digit(the_CODEN, 2)
    checksum +=  5 * CODEN_Digit(the_CODEN, 3)
    checksum +=  3 * CODEN_Digit(the_CODEN, 4)
    checksum +=  1 * CODEN_Digit(the_CODEN, 5)

    return (checksum)
}


function check_CODEN(the_CODEN,    checksum)
{
    if (int(checksum_CODEN(the_CODEN) % 34) != CODEN_Check_Digit(the_CODEN, 6))
	warning("invalid CODEN: [" the_CODEN "]: expected " fix_CODEN(the_CODEN))
}


function check_CODEN_list(CODEN_list,    k,n,parts)
{
    CODEN_list = toupper(CODEN_list)
    n = split(CODEN_list, parts, "[,; ]+")
    for (k = 1; k <= n; ++k)
	check_CODEN(parts[k])
}


function check_ISSN(the_ISSN,    checksum,issn,k)
{
    ## ISSN numbers are 8-character values from the set [0-9Xx], with
    ## a checksum given by
    ##
    ##	(sum(k=1:7) digit(k) * (k+2)) mod 11 == digit(8)
    ##
    ## where digits have their normal value, X (or x) as a digit has
    ## value 10, and spaces and hyphens are ignored.  The sum is
    ## bounded from above by 10*(3 + 4 + ... + 9) = 420.

    sub("-", "", the_ISSN)
    issn = toupper(the_ISSN)

    checksum = 0
    for (k = 1; k <= 7; ++k)
	checksum += ISSN_Digit(issn, k) * (k + 2)

    if (int(checksum % 11) != ISSN_Digit(issn, 8))
	warning("invalid ISSN: [" the_ISSN "]")
}


function check_ISSN_list(ISSN_list,    k,n,parts)
{
    ISSN_list = toupper(ISSN_list)
    n = split(ISSN_list, parts, "[,; ]+")
    for (k = 1; k <= n; ++k)
    {
	if ( (parts[k] != "(PRINT)") && (parts[k] != "(ELECTRONIC)") )
	    check_ISSN(parts[k])
    }
}


function CODEN_Check_Digit(the_CODEN,n)
{
    return (index("9ABCDEFGHIJKLMNOPQRSTUVWXYZ2345678", substr(the_CODEN, n, 1)) - 1)
}


function CODEN_Digit(the_CODEN,n)
{
    return (index("ABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890", substr(the_CODEN, n, 1)))
}


function CODEN_to_Journal(the_CODEN)
{
    the_CODEN = tolower(the_CODEN)
    return ((the_CODEN in CODEN_to_journal) ? CODEN_to_journal[the_CODEN] : "")
}


function define(short,long, t)
{
    # Check for missing second argument
    if (long == "")
	warning("No expansion for abbreviation [" short "]")

    if (!(short in Expansion))	# save only the first long form
	Expansion[short] = long

    if ((long in Abbrev) && (Abbrev[long] != short)) # error in define() calls: should never happen!
	warning("Long journal name has two abbreviations: " Abbrev[long] " " short)
    else
    {
	Abbrev[long] = short
	t = squeeze(long)
	if ((t in Squeezed_Abbrev) && \
	    (tolower(Squeezed_Abbrev[t]) != tolower(short))) # should never happen
	    warning("Squeezed name " t " has two abbreviations: " Squeezed_Abbrev[t] " " short)
	else
	    Squeezed_Abbrev[t] = short
    }
}


function fix_CODEN(the_CODEN)
{
    return (substr(the_CODEN, 1, 5) \
    	    substr("9ABCDEFGHIJKLMNOPQRSTUVWXYZ2345678", \
		   int(checksum_CODEN(the_CODEN) % 34) + 1, 1))
}


function getpid( pid)
{
    if (("pid" in PROCINFO) && ((0 + PROCINFO["pid"]) > 0)) # recent gawk extension
	pid = PROCINFO["pid"]
    else if ((getline pid < "/dev/pid") > 0) # use gawk extension when available
	close("/dev/pid")
    else
    {
	srand()			# seed with time-of-day
	pid = (10000 * int(int(rand()*100000000)/10000))
    }
    return (pid)
}


function initialize(    coden,issn,journal,pid,s,sortpipe)
{
    ### This file is site-dependent, and requires data that may be
    ### proprietary to issn.org (although the data are available
    ### without charge on request).  If the file does not exist,
    ### the provision of ISSN-L values is simply disabled.
    ISSN_L_TO_ISSN_MAP_FILE = "/u/sy/beebe/tex/bib/ISSN-L_to_ISSN.map"

    TYPE_ABBREV  = 10003
    TYPE_COMPLEX = 10004
    TYPE_QUOTED  = 10005
    TYPE_UNKNOWN = 10007

    ## initialize global variables to keep gawk --lint happy
    Citation_Tag = ""
    CODEN = ""
    Have_Full_Journal = 0
    Have_ISSN = 0
    Have_ISSN_L = 0
    Have_Journal_URL = 0
    ISSN = ""
    ISSN_L = ""
    Journal = ""

    "date" | getline Current_Date_and_Time
    close("date")
    pid = getpid()
    Temp_File = ("/tmp/journal.tmp." pid)
    SED_File = ("/tmp/fix-CODEN.sed." pid)

    initialize_CODEN()
    initialize_ISSN()
    initialize_ISSN_L()
    initialize_strings()
    initialize_quad()
    initialize_URL()

    for (issn in ISSN_to_journal)
    {
	if (length(issn) > 9)
	    Full_ISSN[toupper(substr(issn,1,9))] = issn
    }

    if (CHECK)
    {
	for (coden in CODEN_to_journal)
	    check_CODEN_list(toupper(coden))
	for (issn in ISSN_to_journal)
	    check_ISSN_list(toupper(issn))
	exit(0)
    }

    if (MAPFILE != "")
    {
	sortpipe = "sort -t'\t' -k1"
	while ((getline < MAPFILE) > 0)
	{	# expected data format: CODEN ISSN arbitrary-following-text
	    if ( ($1 ~ "[?]") || ($2 ~ "[?]") ) continue
	    if ((length($1) != 6) || (length($2) != 9)) continue

	    check_CODEN_list($1)
	    check_ISSN_list($2)

	    journal = CODEN_to_Journal($1)
	    if (journal != "")
	    {
		issn = Journal_to_ISSN(journal)
		if (index(issn,$2) == 0)
		    printf("%-63s\t%-9s\t%s\n", journal, issn, $2) | sortpipe
	    }

	    journal = ISSN_to_Journal($2)
	    if (journal != "")
	    {
		coden = Journal_to_CODEN(journal)
		if (index(coden,$1) == 0)
		    printf("%-63s\t%-9s\t%s\n", journal, coden, $1) | sortpipe
	    }
	}
	close(MAPFILE)
	close(sortpipe)
	exit(0)
    }

    # Enable these statements to find journals missing ISSN or CODEN data
    if (PRINT_MISSING)
    {
	SORTPIPE = "unexpand -a | sort" # for PRINT_MISSING output
	SORTPIPE2 = "sort -f -u -t'\t' +4 | unexpand -a" # for PRINT_MISSING output
	print_missing_CODEN()
	print_missing_ISSN()
	close (SORTPIPE)
	close (SORTPIPE2)
    }
    if (PRINT_TABLE)
    {
	sortpipe = "sort -t'\t' -k1"
	for (issn in ISSN_to_journal)
	{
	    journal = ISSN_to_journal[issn]
	    coden = Journal_to_CODEN(journal)
	    coden = (coden == "") ? "????" : coden
	    printf("%9s\t%6s\t%s\n", toupper(substr(issn,1,9)), substr(coden,1,6), journal) | sortpipe
	}
	close(sortpipe)

	## Search the ISSN-to-CODEN.txt data (extracted from the Union
	## List of Periodicals) for missing CODEN data, and output new
	## code.

	sortpipe = "sort | unexpand"
	while ((getline < "ISSN-to-CODEN.txt") > 0)
	{
	    if (NF == 2)
	    {
		issn = tolower($1)
		coden = tolower($2)
		if (issn in ISSN_to_journal)
		{
		    journal = ISSN_to_journal[issn]
		    s = Journal_to_CODEN(journal)
		    s = (s == "") ? "????" : s
		    if (s == "????")
			printf("    set_CODEN(%-42s\"%s\")\n", ("\"" journal "\","), toupper(coden))
		}
	    }
	}
	close(sortpipe)

	exit(0)
    }
}


function initialize_CODEN(    coden)
{
    # CODEN values are Chemical Abstracts journal abbreviations.
    # They appear to have been originally 5-character strings,
    # and some have since been expanded to 6-character strings.

    # NB: A field value of "????" means that the journal has been
    # checked, and apparently has no CODEN.  An empty field value
    # means that library checks still need to be done.

    set_CODEN("j-16TH-CENT",				"????")
    set_CODEN("j-3X-400-SYST-MANAG",			"????")
    set_CODEN("j-A-PLUS",				"AAAAE6")
    set_CODEN("j-AAICA",				"AAICAE")
    set_CODEN("j-AAPG-EXPLOR",				"????")
    set_CODEN("j-AAUP-BULL",				"????")
    set_CODEN("j-ABACUS",				"ABACEJ")
    set_CODEN("j-ABERDEEN-UNIV-REV",			"????")
    set_CODEN("j-ABH-MATH-SEMIN-UNIV-HAMBG",		"AMHAAJ")
    set_CODEN("j-ABSTR-APPL-ANAL",			"????")
    set_CODEN("j-ABSTR-PAP-AM-CHEM-SOC",		"ACSRAL")
    set_CODEN("j-ACAD-COMPUT",				"????")
    set_CODEN("j-ACAPA",				"ACRABY")
    set_CODEN("j-ACCOUNTANCY",				"ACTYAD")
    set_CODEN("j-ACCOUNT-HIST-J",			"????")
    set_CODEN("j-ACCOUNT-RES",				"ARQAEZ")
    set_CODEN("j-ACCOUNT-REV",				"ACRVAS")
    set_CODEN("j-ACM-COMM-COMP-ALGEBRA",		"????")
    set_CODEN("j-ACM-J-EXP-ALGORITHMICS",		"????")
    set_CODEN("j-ACM-SIGCAS-COMPUT-SOC",		"CMSCD3")
    set_CODEN("j-ACM-SIGMOBILE-MOBILE-COMPUT-COMMUN-REV",	"MCCRFA")
    set_CODEN("j-ACM-SIGSOFT",				"SFENDP")
    set_CODEN("j-ACOUSTICS-AUSTRALIA",			"ACAUEC")
    set_CODEN("j-ACT-CONG-INT-MATH",			"????")
    set_CODEN("j-ACTA-ANAT",				"ACATA5")
    set_CODEN("j-ACTA-APPL-MATH",			"AAMADV")
    set_CODEN("j-ACTA-ARITHMETICA",			"AARIA9")
    set_CODEN("j-ACTA-ASTRONAUT",			"AASTCF")
    set_CODEN("j-ACTA-BIOTHEOR",			"ABIOAN")
    set_CODEN("j-ACTA-CRYSTALLOGR",			"ACCRA9")
    set_CODEN("j-ACTA-CRYSTAL-A",			"ACACBN")
    set_CODEN("j-ACTA-CRYSTAL-A-FOUND-CRYST",		"ACACEQ")
    set_CODEN("j-ACTA-CYBER",				"ACCYDX")
    set_CODEN("j-ACTA-GEOD-GEOPHYS-HU",			"AGGHFW")
    set_CODEN("j-ACTA-HISTOCHEM-SUPPL",			"AHSUAV")
    set_CODEN("j-ACTA-INFO",				"AINFA2")
    set_CODEN("j-ACTA-LITT-SCI-SZEGED",			"ALSHAK")
    set_CODEN("j-ACTA-MATER",				"ACMAFD")
    set_CODEN("j-ACTA-MATH",				"ACMAA8")
    set_CODEN("j-ACTA-MATH-HUNG",			"ACMTAV")
    set_CODEN("j-ACTA-MATH-SINICA",			"????")
    set_CODEN("j-ACTA-MECH",				"AMHCAP")
    set_CODEN("j-ACTA-MED-SCAND",			"AMSVAZ")
    set_CODEN("j-ACTA-METALL",				"AMETAR")
    set_CODEN("j-ACTA-METALL-MATER",			"AMATEB")
    set_CODEN("j-ACTA-NUMERICA",			"ANUMFU")
    set_CODEN("j-ACTA-ONCOL",				"ACTOEL")
    set_CODEN("j-ACTA-OPHTHALMOL",			"????")
    set_CODEN("j-ACTA-PADIATR-SCAND",			"APSVAM")
    set_CODEN("j-ACTA-PHYS-ACAD-SCI-HUNG",		"APAHAQ")
    set_CODEN("j-ACTA-PHYS-AUSTRIACA",			"APASAP")
    set_CODEN("j-ACTA-PHYS-HUNG-A",			"APHAC8")
    set_CODEN("j-ACTA-PHYS-HUNG-NEW-SERIES-HEAVY-ION-PHYS",	"APHPFM")
    set_CODEN("j-ACTA-PHYS-POL",			"APPOAK")
    set_CODEN("j-ACTA-PHYS-POL-A",			"ATPLB6")
    set_CODEN("j-ACTA-PHYS-POL-B",			"APOBBB")
    set_CODEN("j-ACTA-POLYTECH-HUNG",			"????")
    set_CODEN("j-ACTA-POLYTECH-SCAND-ELECTR-ENG-SER",	"APSEA5")
    set_CODEN("j-ACTA-PROTOZOO",			"ACPZAU")
    ## BAD: set_CODEN("j-ACTA-SOC-BOT-POL",			"ASBNA2, ASPN2")
    set_CODEN("j-ACTA-SCI-MATH-SZEGED",			"")
    set_CODEN("j-ACTA-SCI-NATUR-UNIV-SUNYATSENI",	"CHTHAJ")
    set_CODEN("j-ACTA-SOC-BOT-POL",			"ASBNA2")	# [04-Jan-2006] corrected
    set_CODEN("j-ACTA-SOCIOL",				"ASOGAC")
    set_CODEN("j-ADA-USER",				"ADUSEB")
    set_CODEN("j-ADA-USER-J",				"AUJOET")
    set_CODEN("j-ADV-APPL-MATH",			"????")
    set_CODEN("j-ADV-APPL-MECH",			"AAMCAY")
    set_CODEN("j-ADV-APPL-PROB",			"AAPBBD")
    set_CODEN("j-ADV-APPL-STAT",			"????")
    set_CODEN("j-ADV-APPL-STAT-SCI",			"????")
    set_CODEN("j-ADV-BIOPHYS",				"ADVBAT")
    set_CODEN("j-ADV-CARDIOL",				"ACDYB2")
    set_CODEN("j-ADV-CHEM-PHYS",			"ADCPAA")
    set_CODEN("j-ADV-COMPLEX-SYST",			"????")
    set_CODEN("j-ADV-COMPUT-MATH",			"ACMHEX")
    set_CODEN("j-ADV-CYCLIC-NUCLEOTIDE-RES",		"ACNRCW")
    set_CODEN("j-ADV-DIFFERENCE-EQU",			"????")
    set_CODEN("j-ADV-ENG-SOFTWARE",			"AESODT")
    set_CODEN("j-ADV-ENG-SOFTWARE-WORKSTATIONS",	"AESWEK")
    set_CODEN("j-ADV-ENZYMOL",				"AERAAD")
    set_CODEN("j-ADV-EXP-MED-BIO",                      "AEMBAP")
    set_CODEN("j-ADV-GEOPHYS",				"ADGOAR")
    set_CODEN("j-ADV-HIST-STUD",			"????")
    set_CODEN("j-ADV-IMAGING",				"ADIMEZ")
    set_CODEN("j-ADV-MATER",				"ADVMEW")
    set_CODEN("j-ADV-MATH",				"ADMTA4")
    set_CODEN("j-ADV-MORPHOGENESIS",			"ADMOAN")
    set_CODEN("j-ADV-NEURAL-INF-PROCESS-SYST",		"????")
    set_CODEN("j-ADV-NONLINEAR-ANAL",			"")
    set_CODEN("j-ADV-PHYS",				"ADPHAH")
    set_CODEN("j-ADV-PROTEIN-PHOSPHATASES",		"APPHE3")
    set_CODEN("j-ADV-PURE-APPL-MATH",			"????")
    set_CODEN("j-ADV-QUANTUM-CHEM",			"AQCHA9")
    set_CODEN("j-ADV-SCI",				"ADSCAH")
    set_CODEN("j-ADV-SCI-LETT",				"ASLDAM")
    set_CODEN("j-ADV-SOFT-SCI-TECH",			"????")
    set_CODEN("j-ADV-SPACE-RES",			"ASRSDW")
    set_CODEN("j-ADV-THEORY-SIMUL",			"ATSDCW")
    set_CODEN("j-ADV-WATER-RESOURCES",			"AWREDI")
    set_CODEN("j-AEDS-J",				"AEDSAV")
    set_CODEN("j-AEQUATIONES-MATHEMATICAE",		"AEMABN")
    set_CODEN("j-AEROBIOLOGIA",				"AROBFT")
    set_CODEN("j-AEROSPACE-AMERICA",			"AEAME2")
    set_CODEN("j-AEU",					"AEUTAH")
    set_CODEN("j-AFTERIMAGES",                          "")
    set_CODEN("j-AGAINST-GRAIN",			"????")
    set_CODEN("j-AGRIC-EDUC-MAG",			"????")
    set_CODEN("j-AI-EXPERT",				"????")
    set_CODEN("j-AI-MAGAZINE",				"AIMAEK")
    set_CODEN("j-AI-SOC",				"AISCEM")
    set_CODEN("j-AIAA-ASME-ASCE-AHS-STRUCT-STRUCT-DYN-MAT-CONF","CPSCDO")
    set_CODEN("j-AIAA-J",				"AIAJAH")
    set_CODEN("j-AIAA-PAPER",				"AAPRAQ")
    set_CODEN("j-AICHE-SYMP-SER",			"ACSSCQ")
    set_CODEN("j-AIP-ADV",				"AAIDBI")
    set_CODEN("j-AIP-CONF-PROC",			"APCPCS")
    set_CODEN("j-AIR-FORCE-MAG",			"AFORCO")
    set_CODEN("j-AIR-TRANSP-WORLD",			"????")
    set_CODEN("j-AISB-Q",				"AISBEJ")
    set_CODEN("j-AIXTRA",				"????")
    set_CODEN("j-ALGEBRA-LOGIC",			"ALL0A6")
    set_CODEN("j-ALGOL-BULLETIN",			"ALGOBG")
    set_CODEN("j-ALGORITHMICA",				"ALGOEJ")
    set_CODEN("j-ALGORITHMS-BASEL",			"ALGOCH")
    set_CODEN("j-ALLC-BULL",				"ALLCB5")
    set_CODEN("j-ALMAGEST",				"????")
    set_CODEN("j-ALTA-FREQ",				"ALFRAJ")
    set_CODEN("j-ALTERNATIVES",                         "")
    set_CODEN("j-AM-ANTHROPOL",				"AMATA7")
    set_CODEN("j-AM-BIOL-TEACH",			"????")
    set_CODEN("j-AM-CRAFT",				"????")
    set_CODEN("j-AM-DOC",				"AMDOA7")
    set_CODEN("j-AM-EDUC",				"????")
    set_CODEN("j-AM-HEART-J",				"AHJOA2")
    set_CODEN("j-AM-HIST-REV",				"????")
    set_CODEN("j-AM-J-ANAT",				"AJANA2")
    set_CODEN("j-AM-J-APPL-SCI",			"AJASCJ")
    set_CODEN("j-AM-J-ARCHAEOL",			"AJARAE")
    set_CODEN("j-AM-J-CARDIOL",				"AJCDAG")
    set_CODEN("j-AM-J-ECON-SOCIOL",			"AJESA3")
    set_CODEN("j-AM-J-HUM-GENET",			"AJHGAG")
    set_CODEN("j-AM-J-MATH",				"AJMAAN")
    set_CODEN("j-AM-J-MATH-MANAGE-SCI",			"AMMSDX")
    set_CODEN("j-AM-J-MED",				"AJMEAZ")
    set_CODEN("j-AM-J-MED-SCI",				"AJMSA9")
    set_CODEN("j-AM-J-OPHTHALMOL",			"AJOPAA")
    set_CODEN("j-AM-J-PHYS-ANTHROPOL",			"AJPNA9")
    set_CODEN("j-AM-J-PHYSIOL",				"AJPHAP")
    set_CODEN("j-AM-J-PSYCHIATRY",			"AJPSAO")
    set_CODEN("j-AM-J-SCI",				"AJSCAP")
    set_CODEN("j-AM-J-SOCIOL",				"AJSOAR")
    set_CODEN("j-AM-NAT",				"AMNTA4")
    set_CODEN("j-AM-PHOTO",				"????")
    set_CODEN("j-AM-PROG",				"AMPRFD")
    set_CODEN("j-AM-PROSPECT",				"APROEY")
    set_CODEN("j-AM-Q",					"????")
    set_CODEN("j-AM-SCH",				"????")
    set_CODEN("j-AM-SCI",				"AMSCAC")
    set_CODEN("j-AM-STUD",				"????")
    set_CODEN("j-AMBIX",				"AMBXAO")
    set_CODEN("j-AMER-AGR-ECON",			"AJAEBA")
    set_CODEN("j-AMER-J-CLIN-PATH",			"AJCPAI")
    set_CODEN("j-AMER-J-PHYSICS",			"AJPIAS")
    set_CODEN("j-AMER-J-PSYCHOLOGY",			"AJPCAA")
    set_CODEN("j-AMER-LIBRARIES",			"????")
    set_CODEN("j-AMER-MATH-MONTHLY",			"AMMYAE")
    set_CODEN("j-AMER-MATH-MONTHLY-SLAUGHT",		"????")
    set_CODEN("j-AMER-PSYCHOLOGIST",			"AMPSAB")
    set_CODEN("j-AMER-SOC-MECH-ENG-AESD",		"AMEAE8")
    set_CODEN("j-AMER-STAT",				"ASTAAJ")
    set_CODEN("j-AMERICAS-NETWORK",			"ANETE4")
    set_CODEN("j-AMERIKASTUDIEN",			"????")
    set_CODEN("j-AMS-COLL-PUB",				"????")
    set_CODEN("j-AN-R-ACAD-NAC-MED-MADR",               "ARANAO")
    set_CODEN("j-ANAESTHESIA",				"ANASAB")
    set_CODEN("j-ANAL-CHEM",				"ANCHAM")
    set_CODEN("j-ANAL-MATH-PHYS",			"????")
    set_CODEN("j-ANALYST",				"ANALAO")
    set_CODEN("j-ANALYT-BIOCHEM",			"ANBCA2")
    set_CODEN("j-ANAT-EMBRYOL",				"ANEMDG")
    set_CODEN("j-ANESTHESIA-ANALGESIA-CURR-RESEARCHES", "AACRAT")
    set_CODEN("j-ANESTHESIOL-HAGERSTOWN",		"????")
    set_CODEN("j-ANG-INFO-ELEK-DATEN",			"AWIFA7")
    set_CODEN("j-ANGEW-CHEM-INT-ED",			"ACIEF5")
    set_CODEN("j-ANGEW-CHEM-INT-ED-ENGL",		"ACIEAY")
    set_CODEN("j-ANIM-BEHAV",				"ANBEA8")
    set_CODEN("j-ANN-ACAD-REGIAE-SCI-UPS",		"ARUPAS")
    set_CODEN("j-ANN-AM-ACAD-POLIT-SOC-SCI",		"????")
    set_CODEN("j-ANN-APPL-BIOL",			"AABIAV")
    set_CODEN("j-ANN-APPL-PROBAB",			"????")
    set_CODEN("j-ANN-APPL-STAT",			"????")
    set_CODEN("j-ANN-BIOMED-ENG",			"ABMECF")
    set_CODEN("j-ANN-CHIM-PHYS",			"ACPHAA")
    set_CODEN("j-ANN-EUGENICS",				"????")
    set_CODEN("j-ANN-FAC-SCI-UNIV-CLERMONT",		"AFUCA7")
    set_CODEN("j-ANN-FINANCE",				"????")
    set_CODEN("j-ANN-FOURIER",				"AIFUA7")
    set_CODEN("j-ANN-FOND-LOUIS-DE-BROGLIE",		"????")
    set_CODEN("j-ANN-FUNCT-ANAL",			"????")
    set_CODEN("j-ANN-HIST-COMPUT",			"AHCOE5")
    set_CODEN("j-ANN-HUM-GENET",			"ANHGAA")
    set_CODEN("j-ANN-INST-HENRI-POINCARE-ANAL-NON-LINEAIRE", "????")
    set_CODEN("j-ANN-INST-HENRI-POINCARE",		"AIHPA2")
    set_CODEN("j-ANN-INST-HENRI-POINCARE-A",		"AHPAAO")
    set_CODEN("j-ANN-INST-HENRI-POINCARE-B",		"AHPBAR")
    set_CODEN("j-ANN-INST-HENRI-POINCARE-PROBAB-STATIST",	"AHPBAR")
    set_CODEN("j-ANN-INST-STAT-MATH-TOKYO",		"AISXAD")
    set_CODEN("j-ANN-INTERN-MED",			"AIMEAS")
    set_CODEN("j-ANN-MAT-PURA-APPL-4",			"ANLMAE")
    set_CODEN("j-ANN-MATH",				"ANMAAH")
    set_CODEN("j-ANN-MATH-2",				"ANMAAH", 1)
    set_CODEN("j-ANN-MATH-ARTIF-INTELL",		"AMAIEC")
    set_CODEN("j-ANN-MATH-STAT",			"AASTAD")
    set_CODEN("j-ANN-MATH-STUDIES",			"ANMAAH", 1)
    set_CODEN("j-ANN-NUCL-ENERGY",			"ANENDJ")
    set_CODEN("j-ANN-NUM-MATH",				"????")
    set_CODEN("j-ANN-NY-ACAD-SCI",			"ANYAA9")
    set_CODEN("j-ANN-OPER-RESEARCH",			"AOREEV")
    set_CODEN("j-ANN-PHYS",				"APNYA6")
    set_CODEN("j-ANN-PHYS-1900",			"????")
    set_CODEN("j-ANN-PHYS-1900-4",			"????")
    set_CODEN("j-ANN-PHYS-5",				"ANPYA2")
    set_CODEN("j-ANN-PHYS-6",				"ANPYA2")
    set_CODEN("j-ANN-PHYS-8",				"ANPYA2")
    set_CODEN("j-ANN-PHYS-BERLIN",			"ANPYA2")
    set_CODEN("j-ANN-PHYS-CHEM",			"ANPYA2")
    set_CODEN("j-ANN-PHYS-PHYS-CHEM",			"ANPYA2")
    set_CODEN("j-ANN-PROBAB",				"APBYAE")
    set_CODEN("j-ANN-REG-SCI",				"ARGSB2")
    set_CODEN("j-ANN-REV-BIOCHEM",			"ARBOAW")
    set_CODEN("j-ANN-REV-BIOPHYS-BIOPHYS-CHEM",		"ARBCEY")
    set_CODEN("j-ANN-REV-CELL-BIOL",			"ARCBE2")
    set_CODEN("j-ANN-REV-ECOLOG-SYST",			"ARECBC")
    set_CODEN("j-ANN-REV-FLUID-MECH",			"ARVFA3")
    set_CODEN("j-ANN-REV-GENET",			"ARVGB7")
    set_CODEN("j-ANN-REV-MATERIAL-SCI",			"ARMSCX")
    set_CODEN("j-ANN-REV-NEURO",			"ARNSD5")
    set_CODEN("j-ANN-REV-PHYS-CHEM",			"ARPLAP")
    set_CODEN("j-ANN-REV-PHYSIOL",			"ARPHAD")
    set_CODEN("j-ANN-SC-NORM-SUPER-PISA-CL-SCI",	"PSNAAI")
    set_CODEN("j-ANN-SCI-MATH-QUEBEC",			"????")
    set_CODEN("j-ANN-SCIENCE",				"ANNSA8")
    set_CODEN("j-ANN-SENS",				"????")
    set_CODEN("j-ANN-STAT",				"ASTSC7")
    set_CODEN("j-ANN-SYMP-FOCS",			"ASFPDV")
    set_CODEN("j-ANN-TELECOMMUN",			"ANTEAU")
    set_CODEN("j-ANN-THEOR-PSYCHOL",			"????")
    set_CODEN("j-ANNALES-ACAD-SCIENT-FENNICAE-A-I",	"AAFMAT")
    set_CODEN("j-ANNU-REP-PROG-CHEM",			"ARPCAW")
    set_CODEN("j-ANNU-REV-ASTRON-ASTROPHYS",		"ARAAAJ")
    set_CODEN("j-ANNU-REV-AUTOM-PROGRAM",		"ARVAAM")
    set_CODEN("j-ANNU-REV-NUCL-PART-SCI",		"ARPSDF")
    set_CODEN("j-ANNU-REV-NUCL-SCI",			"ARNUA8")
    set_CODEN("j-ANNUAL-ACM-SYMP-PAR-ALG-ARCH",		"AASAES")
    set_CODEN("j-ANRITSU-TECHNICAL-BULL",		"ANTKAE")
    set_CODEN("j-ANTIMICROB-AGENTS-CHEMOTHER",		"AMACCQ")
    set_CODEN("j-ANTIOCH-REV",				"????")
    set_CODEN("j-ANTISENSE-RES-DEV",			"AREDEI")
    set_CODEN("j-ANZIAM-J",				"AJNOA2")
    set_CODEN("j-ANZJS",				"????")
    set_CODEN("j-AP",					"????")
    set_CODEN("j-APL-MAT",				"APMTAK")
    set_CODEN("j-APL-QUOTE-QUAD",			"APLQD9")
    set_CODEN("j-APPL-ALGEBRA-ENG-COMMUN-COMPUT",	"AAECEW")
    set_CODEN("j-APPL-ANAL",				"APANCC")
    set_CODEN("j-APPL-COMPUT-HARMON-ANAL",		"")
    set_CODEN("j-APPL-ECON-LETT",			"????")
    set_CODEN("j-APPL-ENV-MICROBIOL",			"AEMIDF")
    set_CODEN("j-APPL-FINANC-ECON",			"????")
    set_CODEN("j-APPL-INTELL",				"APITE4")
    set_CODEN("j-APPL-MATH",				"APMTEO")
    set_CODEN("j-APPL-MATH-COMP-SCI",			"AMCPE9")
    set_CODEN("j-APPL-MATH-COMP",			"AMHCBQ")
    set_CODEN("j-APPL-MATH-LETT",			"AMLEEL")
    set_CODEN("j-APPL-MATH-MECH-ENGL-ED",		"AMMEEQ")
    set_CODEN("j-APPL-MATH-MODEL",			"AMMODL")
    set_CODEN("j-APPL-MATH-NOTES",			"")
    set_CODEN("j-APPL-MATH-OPTIM",			"AMOMBN")
    set_CODEN("j-APPL-MATH-SCI-RUSE",			"????")
    set_CODEN("j-APPL-MATH-SER-NBS",			"")
    set_CODEN("j-APPL-MECH-REV",			"AMREAD")
    set_CODEN("j-APPL-MICROBIOL-BIOTECHNOL",		"EJABDD")
    set_CODEN("j-APPL-NUM-ANA",				"????")
    set_CODEN("j-APPL-NUM-ANAL-COMPUT-MATH",		"")
    set_CODEN("j-APPL-NUM-MATH",			"ANMAEL")
    set_CODEN("j-APPL-OPTICS",				"APOPAI")
    set_CODEN("j-APPL-PHYS-A",				"APAMFC")
    set_CODEN("j-APPL-PHYS-LET",			"APPLAB")
    set_CODEN("j-APPL-PHYS-EXPRESS",			"APEPC4")
    set_CODEN("j-APPL-PSYCH-MEASUREMENT",		"????")
    set_CODEN("j-APPL-SCI-RES",				"ASRHAU")
    set_CODEN("j-APPL-SCI-RES-SECT-B",			"ASRBAC")
    set_CODEN("j-APPL-STAT",				"APSTAG")
    set_CODEN("j-APPL-SURF-SCI",			"ASUSEE")
    set_CODEN("j-APPL-SURF-SCI-1977-1985",		"ASUSDD")
    set_CODEN("j-APPROX-THEORY-APPL",			"????")
    set_CODEN("j-AQUAC-FISH-FISH",			"????")
    set_CODEN("j-AQUAT-BOT",				"AQBODS")
    set_CODEN("j-AQUAT-TOXICOL",			"AQTODG")
    set_CODEN("j-ARCH-APPL-MECH",			"AAMEEA")
    set_CODEN("j-ARCH-BIOCHEM-BIOPHYS",			"ABBIA4")
    set_CODEN("j-ARCH-ENTWICKLUNGSMECH",		"AREOAD")
    set_CODEN("j-ARCH-HIST-EXACT-SCI",			"AHESAN")
    set_CODEN("j-ARCH-INEQUAL-APPL",			"????")
    set_CODEN("j-ARCH-MATH",				"ACVMAL")
    set_CODEN("j-ARCH-MECH",				"AVMHBR")
    set_CODEN("j-ARCH-MED-RES",				"AEDEER")
    set_CODEN("j-ARCH-MICROBIOL",			"AMICCW")
    set_CODEN("j-ARCH-NEERL-SCI-EXACTES-NAT",		"ANSNAI")
    set_CODEN("j-ARCH-NEUROL",				"ARNEAS")
    set_CODEN("j-ARCH-NUM-SOFT",			"????")
    set_CODEN("j-ARCH-PHARM-WEINHEIM",			"ARPMAS")
    set_CODEN("j-ARCH-PHILOS",				"????")
    set_CODEN("j-ARCH-RAT-MECH-ANAL",			"AVRMAW")
    set_CODEN("j-ARCH-SCI-PHYS-NAT",			"ASPNA4")
    set_CODEN("j-ARCHIMEDE",				"????")
    set_CODEN("j-ARITH-TEACHER",			"ARITBF")
    set_CODEN("j-ARKHIMEDES",				"AKMDA5")
    set_CODEN("j-ARKIV-MAT-ASTRON-FYSIK",		"AMAFAX")
    set_CODEN("j-ARKIV-MATH",				"AKMTAJ")
    set_CODEN("j-ARKIV-MATH-NATUR",			"????")
    set_CODEN("j-ARKIV-FYSIK",				"AFYSA7")
    set_CODEN("j-ARM-J-PHYS",				"AJPRCN")
    set_CODEN("j-ARMS",					"????")
    set_CODEN("j-ARMS-CONTROL-TODAY",			"????")
    set_CODEN("j-ARS-COMB",				"????")
    set_CODEN("j-ARSP-ARCH-RECHTS-SOZIALPHILOS",	"????")
    set_CODEN("j-ART-BULL",				"????")
    set_CODEN("j-ART-INTELL",				"AINTBB")
    set_CODEN("j-ART-LIFE-ROBOT",			"????")
    set_CODEN("j-ARTIF-LIFE",				"ARLIEY")
    set_CODEN("j-ARTISTS-MAG",				"????")
    set_CODEN("j-ASEAN-PROPRINT",			"????")
    set_CODEN("j-ASIAWEEK",				"????")
    set_CODEN("j-ASIA-PAC-MATH-NEWSL",			"????")
    set_CODEN("j-ASLIB-PROC",				"ASLPAO")
    set_CODEN("j-ASPECTS-APPL-BIOL",			"????")
    set_CODEN("j-ASTA-ADV-STAT-ANAL",			"????")
    set_CODEN("j-ASTERISK",				"ASTRF7")
    set_CODEN("j-ASTM-SPEC-TECH-PUB",			"ASTTA8")
    set_CODEN("j-ASTRO-NACHR",				"ASNAAN")
    set_CODEN("j-ASTROBIOLOGY",				"ASTRC4")
    set_CODEN("j-ASTRON-ASTROPHYS",			"AAEJAF")
    set_CODEN("j-ASTRON-ASTROPHYS-REV",			"AASREB")
    set_CODEN("j-ASTRON-ASTROPHYS-SUPPL-SER",		"AAESB9")
    set_CODEN("j-ASTRON-ASTROPHYS-TRANS",		"AATREG")
    set_CODEN("j-ASTRON-GEOPHYS",			"ASGEF5")
    set_CODEN("j-ASTRON-J",				"ANJOAA")
    set_CODEN("j-ASTRON-Q",				"ASTQD2")
    set_CODEN("j-ASTROPART-PHYS",			"APHYEE")
    set_CODEN("j-ASTROPHYS-LETT",			"ASTLAI")
    set_CODEN("j-ASTROPHYS-SPACE-SCI",			"APSSBE")
    set_CODEN("j-ASTROPHYSICAL-J",			"ASJOAB")
    set_CODEN("j-ASTROPHYSICAL-J-SUPPL-SER",		"APJSA2")
    set_CODEN("j-ASYMP-STAT",				"????")
    set_CODEN("j-ASYMPTOT-ANAL",			"ASANEZ")
    set_CODEN("j-AT-DATA-NUCL-DATA-TABLES",		"ADNDAT")
    set_CODEN("j-ATLANTIC-MONTHLY",			"????")
    set_CODEN("j-ATMOS-ENV",				"ATENBP")
    set_CODEN("j-ATMOS-SCI-LETT",			"????")
    set_CODEN("j-ATOMS",				"ATOMC5")
    set_CODEN("j-ATT-BELL-LABORATORIES-RECORD",		"????")
    set_CODEN("j-ATT-BELL-LAB-TECH-J",			"ABLJER")
    set_CODEN("j-ATT-TECH-J",				"ATJOEM")
    set_CODEN("j-ATTEN-PERCEPT-PSYCHOPHYS",		"????")
    set_CODEN("j-AUDIO-VISUAL",				"????")
    set_CODEN("j-AUDITING",				"????")
    set_CODEN("j-AUST-J-AGRIC-RES",			"AJAEA9")
    set_CODEN("j-AUST-J-MATH-ANAL-APPL",		"????")
    set_CODEN("j-AUST-J-STAT",				"AUJSA3")
    set_CODEN("j-AUSTRALIAN-COMP-J",			"ACMJB2")
    set_CODEN("j-AUSTRALIAN-COMP-SCI-COMM",		"ACSCDD")
    set_CODEN("j-AUSTRALIAN-J-PHYS",			"AUJPAS")
    set_CODEN("j-AUSTRALIAN-J-STAT",			"AUJSA3")
    set_CODEN("j-AUSTRALIAN-LIBR-REV",			"ALIRE4")
    set_CODEN("j-AUSTRALIAN-MATH-SOC-GAZ",		"")
    set_CODEN("j-AUSTRALIAN-MATH-SOC-SERIES-A",		"????")
    set_CODEN("j-AUSTRALIAN-MATH-TEACHER",		"????")
    set_CODEN("j-AUSTRALIAN-PERSONAL-COMP",		"????")
    set_CODEN("j-AUTO-CTL-COMP-SCI",			"ACCSCE")
    set_CODEN("j-AUTOM-REMOTE-CONTROL",			"AURCAT")
    set_CODEN("j-AUTOMATIC-REMOTE-CTL",			"????")
    set_CODEN("j-AUTOMATICA",				"ATCAA9")
    set_CODEN("j-AUTOMATION-REMOTE-CTL",		"AURCAT")
    set_CODEN("j-AUTOMOTIVE-ENG",			"????")
    set_CODEN("j-AV-VIDEO",				"????")
    set_CODEN("j-AVIAT-WEEK-SPACE-TECHNOL",		"AWSTAV")
    set_CODEN("j-AXIOMS-BASEL",				"????")
    set_CODEN("j-AXIS",					"AXISE")
    set_CODEN("j-BANK-SYST-TECHNOL",			"BSYTEE")
    set_CODEN("j-BANKING-TECH",                         "BATEEM")
    set_CODEN("j-BASIC-LIFE-SCI",			"BLFSBY")
    set_CODEN("j-BASIC-RES-CARDIOL",			"BRCAB7")
    set_CODEN("j-BAYESIAN-ANAL",			"????")
    set_CODEN("j-BEHAV-BRAIN-SCI",			"BBSCDH")
    set_CODEN("j-BEHAV-INF-TECH",			"BEITD5")
    set_CODEN("j-BEHAV-RES-METH-INSTR",			"BRMIAC")
    set_CODEN("j-BEHAV-RES-METH-INSTR-COMP",		"BRMCEW")
    set_CODEN("j-BEHAV-SCI",				"BEHSAS")
    set_CODEN("j-BEHAVIOUR",				"BEHAA8")
    set_CODEN("j-BEIBL-ANN-PHYS",			"BEAPAI")
    set_CODEN("j-BEITRAGE-NUMER-MATH",			"????")
    set_CODEN("j-BELL-LABS-RECORD",			"BLRCAB")
    set_CODEN("j-BELL-LABS-TECH-J",			"BLTJFD")
    set_CODEN("j-BELL-SYST-TECH-J",			"BSTJAN")
    set_CODEN("j-BELLCORE-EXCHANGE",			"????")
    set_CODEN("j-BER-BUNSENGES-PHYS-CHEM",		"BBPCAX")
    set_CODEN("j-BER-DTSCH-CHEM-GES",			"BDCGAS")
    set_CODEN("j-BER-DTSCH-CHEM-GES-A",			"BDCAAA")
    set_CODEN("j-BER-DTSCH-CHEM-GES-B",			"")
    set_CODEN("j-BER-DTSCH-CHEM-GES-ABT-A-B",		"BDCBAD")
    set_CODEN("j-BER-WISSENSCHAFTGESCH",		"BEWID8")
    set_CODEN("j-BERICHTE-GMD-BONN",			"????")
    set_CODEN("j-BERNOULLI",				"????")
    set_CODEN("j-BESTS-REV-LIFE-HEALTH-INSUR-ED",	"BRLHB5")
    set_CODEN("j-BIO-CHEM-HOPPE-SEYLER",		"BCHSEI")
    set_CODEN("j-BIOCHEM",				"BICHAW")
    set_CODEN("j-BIOCHEM-BIOKHIM",			"BIORAK")
    set_CODEN("j-BIOCHEM-BIOPHYS-RES-COMMUN",		"BBRCA9")
    set_CODEN("j-BIOCHEM-CELL-BIOL",			"BCBIEQ")
    set_CODEN("j-BIOCHEM-INT",				"BIINDF")
    set_CODEN("j-BIOCHEM-J",				"BIJOAK")
    set_CODEN("j-BIOCHEM-MOL-BIOL-INT",			"BMBIES")
    set_CODEN("j-BIOCHEM-PHARM",			"BCPCA6")
    set_CODEN("j-BIOCHEM-SER-MONOGR",			"????")
    set_CODEN("j-BIOCHEM-SOC-SYMP",			"BSSYAT")
    set_CODEN("j-BIOCHEM-SOC-TRANS",			"BCSTB5")
    set_CODEN("j-BIOCHEM-SYS-ECO",			"BSECBU")
    set_CODEN("j-BIOCHEM-Z",				"BIZBAR")
    set_CODEN("j-BIOCHIM-BIOPHYS-ACTA",			"BBACAQ")
    ## set_CODEN("j-BIOCHIM-BIOPHYS-ACTA",			"ABBPAP")
    set_CODEN("j-BIOCHIM-BIOPHYS-ACTA-HUNG",		"")
    set_CODEN("j-BIOCHIM-BIOPHYS-ACTA-GENE-STRUCT-EXPRESS", "BBGSD5")
    set_CODEN("j-BIOCHIM-BIOPHYS-ACTA-MOL-CELL-RES",	"BBAMCO")
    set_CODEN("j-BIOCHIMIE",				"BICMBE")
    set_CODEN("j-BIOELECTROCHEM-BIOENERG",		"BEBEBP")
    set_CODEN("j-BIOENERGETICS",			"????")
    set_CODEN("j-BIOESSAYS",				"BIOEEJ")
    set_CODEN("j-BIOFIZIKA",				"BIOFAI")
    set_CODEN("j-BIOGR-MEM-NAT-ACAD-SCI",		"BMNSAC")
    set_CODEN("j-BIOGRAPH-MEMOIRS-FELLOWS-ROY-SOC",	"BMFRA3")
    set_CODEN("j-BIOGRAPHY-HONOLULU",			"BGPYE2")
    set_CODEN("j-BIOINFORMATICS",			"????")
    set_CODEN("j-BIOL-BULL",				"BIBUBX")
    set_CODEN("j-BIOL-CYBERN",				"BICYAF")
    set_CODEN("j-BIOL-J-LINNEAN-SOC",			"BJLSBG")
    set_CODEN("j-BIOL-REPROD",                          "BIREBV")
    set_CODEN("j-BIOL-REV-CAMB-PHIL-SOC",		"BRCPAH")
    set_CODEN("j-BIOMED-BIOCHIM-ACTA",			"BBIADT")
    set_CODEN("j-BIOMEMBRANES",				"BOMBB5")
    set_CODEN("j-BIOMETRIC-BULL",			"BIOMB6")
    set_CODEN("j-BIOMETRICAL-J",			"BIJODN")
    set_CODEN("j-BIOMETRICS",				"BIOMB6", 1)
    set_CODEN("j-BIOMETRIKA",				"BIOKAX")
    set_CODEN("j-BIOMETRISCHE-Z",			"BIZEB3")
    set_CODEN("j-BIOPHYS",				"BIOPAE")
    set_CODEN("j-BIOPHYS-CHEM",				"BICIAZ")
    set_CODEN("j-BIOPHYS-J",				"BIOJAU")
    set_CODEN("j-BIOPHYS-STRUCT-MECH",			"BSMHBH")
    set_CODEN("j-BIOPOLYMERS-SYMPOSIA",			"")
    set_CODEN("j-BIORHEOLOGY",				"BRHLAU")
    set_CODEN("j-BIOSCI",				"BISNAS")
    set_CODEN("j-BIOSCI-REP",				"BRPTDT")
    set_CODEN("j-BIOSYSTEMS",				"BSYMBO")
    set_CODEN("j-BIOTECH",				"BTCHDA")
    set_CODEN("j-BIT",					"BITTEL, NBITAB")
    set_CODEN("j-BLOOD",				"BLOOAW")
    set_CODEN("j-BLOOD-CELLS",				"BLCEDD")
    set_CODEN("j-BLOOD-REV",				"BLOREB")
    set_CODEN("j-BLUT",					"BLUTA9")
    set_CODEN("j-BMC-BIOINFORMATICS",			"BBMIC4")
    set_CODEN("j-BOL-MAT-SAO-PAULO",			"BSMSAF")
    set_CODEN("j-BOL-SOC-PORT-MAT",			"????")
    set_CODEN("j-BOLL-STOR-SCI-MAT",			"????")
    set_CODEN("j-BOLL-UNIONE-MAT-ITAL",			"BLUMAM")
    set_CODEN("j-BOLL-UNIONE-MAT-ITAL-A",		"BLUMAM", 1)
    set_CODEN("j-BONE-MINERAL",				"BOMIET")
    set_CODEN("j-BOSTON-GLOBE",				"????")
    set_CODEN("j-BOSTON-PHOENIX",			"????")
    set_CODEN("j-BOUND-VALUE-PROBL",			"????")
    set_CODEN("j-BOUNDARY-LAYER-METEOROL",		"BLMEBR")
    set_CODEN("j-BR-ASSOC-ADV-SCI-REP",			"BAASAX")
    set_CODEN("j-BR-J-APPL-PHYS",			"BJAPAJ")
    set_CODEN("j-BR-J-HAEMATOL",			"BJHEAL")
    set_CODEN("j-BR-J-NEUROSURG",			"BJNEEL")
    set_CODEN("j-BR-J-PHOTOGR",				"BRJFAM")
    set_CODEN("j-BR-MED-J",				"BMJOAE")
    set_CODEN("j-BRAIN-COGN",				"????")
    set_CODEN("j-BRAIN-RES",                            "BRREAP")
    set_CODEN("j-BRAIN-RES-REV",                        "BRERD2")
    set_CODEN("j-BRAZ-J-PHYS",				"BJPHE6")
    set_CODEN("j-BRAZILIAN-J-MED-BIOL-RES",		"BJMRDK")
    set_CODEN("j-BRITISH-DENTAL-J",			"BDJOHQ")
    set_CODEN("j-BRITISH-HEART-J",			"BHJUAV")
    set_CODEN("j-BRITISH-J-CANCER",			"BJCAAI")
    set_CODEN("j-BRITISH-J-HIST-MATH",			"????")
    set_CODEN("j-BRITISH-J-HIST-SCI",			"BJHSAT")
    set_CODEN("j-BRITISH-J-MATH-STATIST-PSYCHOL",	"BJMSAK")
    set_CODEN("j-BRITISH-J-PHILOS-SCI",			"BJPIA5")
    set_CODEN("j-BRITISH-LIBRARY-RDR",			"BLRRDP")
    set_CODEN("j-BRITISH-PRINTER",			"????")
    set_CODEN("j-BROADCAST-CABLE",			"????")
    set_CODEN("j-BSHM-BULL",				"????")
    set_CODEN("j-BSHM-NEWSLETTER",			"????")
    set_CODEN("j-BT-TECH-J",				"BTJUEH")
    set_CODEN("j-BUL-ACAD-STIINTE-REPUB-MOD-MAT",	"")
    set_CODEN("j-BULL-ACAD-POL-SCI-CL-3",		"BPSMA6")
    set_CODEN("j-BULL-ACAD-POL-SCI-SER-SCI-MATH-ASTRON-PHYS",	"BAPMAM")
    set_CODEN("j-BULL-AM-SOC-INF-SCI",			"BASICR")
    set_CODEN("j-BULL-AMER-PHYS-SOC",			"BAPSA6")
    set_CODEN("j-BULL-AMS",				"BAMOAD")
    set_CODEN("j-BULL-AMS-N-S",				"BAMOAD", 1)
    set_CODEN("j-BULL-ASSOC-SUISE-ELECTRICIENS",	"BUSEAH")
    set_CODEN("j-BULL-ASTRON-SOC-INDIA",		"BANID3")
    set_CODEN("j-BULL-AT-SCI",				"BASIAP")
    set_CODEN("j-BULL-AUSTRAL-MATH-SOC",		"ALNBAB")
    set_CODEN("j-BULL-CALCUTTA-MATH-SOC",		"BCMSA5")
    set_CODEN("j-BULL-EATCS",				"BEASDU")
    set_CODEN("j-BULL-ENV-CONTAM-TOXIC",		"BECTA6")
    set_CODEN("j-BULL-GEODESIQUE",			"BGDQAG")
    set_CODEN("j-BULL-HIST-CHEM",			"BHCHET")
    set_CODEN("j-BULL-INFO-CYBER",			"????")
    set_CODEN("j-BULL-INST-MATH-APPL",			"IMTABW")
    set_CODEN("j-BULL-INST-MATH-STAT",			"SMBCVA")
    set_CODEN("j-BULL-KNOB",				"????")
    set_CODEN("j-BULL-LOND-MATH-SOC",			"LMSBBT")
    set_CODEN("j-BULL-MATH-BIOL",			"BMTBAP")
    set_CODEN("j-BULL-MATH-BIOPHYS",			"BMTIAO")
    set_CODEN("j-BULL-MATH-SOC-SCI-MATH-ROUMANIE",	"BMSSB4")
    set_CODEN("j-BULL-PLANKTON-SOC-JAPAN",		"PSJBAZ")
    set_CODEN("j-BULL-SANTA-FE-INST",			"????")
    set_CODEN("j-BULL-SCHWEIZ-ELEKTROTECH",		"BEVEDP")
    set_CODEN("j-BULL-SCI-ASSOC-INGEN-ELECTRICIENS-MONTEFIORE","BURMA2")
    set_CODEN("j-BULL-SOC-MATH-FRANCE",			"BSMFAA")
    set_CODEN("j-BULL-SOC-R-SCI-LIEGE",			"BSRSA6")
    set_CODEN("j-BULL-SYMB-LOG",			"BSLOF3")
    set_CODEN("j-BUS-AM",				"")
    set_CODEN("j-BUS-COMMUN-REV",			"BCORBD")
    set_CODEN("j-BUS-INDIA",				"")
    set_CODEN("j-BUSINESS-INFO-REV",                    "BIREEY")
    set_CODEN("j-BUSINESS-MARKETING",                   "BUMAED")
    set_CODEN("j-BUSINESS-PUBLISHING",			"????")
    set_CODEN("j-BUSINESS-REVIEW-WEEKLY",		"????")
    set_CODEN("j-BUSINESS-WEEK",			"BUWEA3")
    set_CODEN("j-BYTE",					"BYTEDJ")
    set_CODEN("j-C-JET",				"????")
    set_CODEN("j-C-PLUS-PLUS-REPORT",			"CRPTE7")
    set_CODEN("j-C-R-ACAD-BULGARE-SCI",			"DBANAD")
    set_CODEN("j-C-R-ACAD-BULGARE-SCI-SCI-MATH-NAT",	"DBANAD", 1)
    set_CODEN("j-C-R-ACAD-SCI",				"????")
    set_CODEN("j-C-R-ACAD-SCI-CANADA",			"????")
    set_CODEN("j-C-R-ACAD-SCI-I",			"CASMEI")
    set_CODEN("j-C-R-ACAD-SCI-III",			"CRASEV")
    set_CODEN("j-C-R-ACAD-SCI-PARIS",			"????")
    set_CODEN("j-C-R-ACAD-SCI-PARIS-SER-A"		"CHASAP")
    set_CODEN("j-C-R-ACAD-SCI-PARIS-SER-B"		"CHDBAN")
    set_CODEN("j-C-R-ACAD-SCI-PARIS-SER-AB",		"CHASAP")
    set_CODEN("j-C-R-ACAD-SCI-PARIS-SER-I-MATH",	"CASMEI")
    set_CODEN("j-C-R-ACAD-SCI-SER-GEN-VIE-SCI",		"CRAGET")
    set_CODEN("j-C-R-ACAD-SCI-URSS",			"DANKAS")
    set_CODEN("j-C-R-BIOL",				"CRBOCM")
    set_CODEN("j-C-R-DAS-URSS",				"????")
    set_CODEN("j-C-R-HEBD-SEANCES-ACAD-SCI",		"COREAF")
    ## set_CODEN("j-C-R-MATH-I",			"CHASAP")
    set_CODEN("j-C-R-MATH-ACAD-SCI-PARIS",		"")
    set_CODEN("j-C-R-MEC",				"CRMOC9")
    set_CODEN("j-C-R-PHYS",				"CRPOBN")
    set_CODEN("j-CABLE-TRANS",				"CTRAA4")
    set_CODEN("j-CACM",					"CACMA2")
    ## set_CODEN("j-CAD",					"CAIDA5")
    set_CODEN("j-CADALYST",				"????")
    set_CODEN("j-CAGD",					"CAGDEX")
    set_CODEN("j-CAH-PHYS",				"CAPHAI")
    set_CODEN("j-CAHIERS-CENTRE-ETUDES-RECH-OPER",	"CCROAT")
    set_CODEN("j-CALCOLO",				"CALOBK")
    set_CODEN("j-CALIF-MANAGE-REV",			"")
    set_CODEN("j-CALPHAD",				"CCCTD6")
    set_CODEN("j-CAMBRIDGE-STUDIES-ADV-MATH",		"????")
    set_CODEN("j-CAMPUS-WIDE-INF-SYST",			"CISYF9")
    set_CODEN("j-CAN-APPL-MATH-Q",			"????")
    set_CODEN("j-CAN-ELECTR-ENG-J",			"CEEJDY")
    set_CODEN("j-CAN-J-ARCHAEO",			"????")
    set_CODEN("j-CAN-J-BIOCHEM-CELL-BIOL",		"CJBBDU")
    set_CODEN("j-CAN-J-CARDIOL",			"CJCAEX")
    set_CODEN("j-CAN-J-CHEM",				"0008-4042")
    set_CODEN("j-CAN-J-EARTH-SCI",			"CJESAP")
    set_CODEN("j-CAN-J-ELECT-COMP-ENG",			"CJEEEL")
    set_CODEN("j-CAN-J-FOR-RES",			"CJFRAR")
    set_CODEN("j-CAN-J-INFO-SCIENCE",			"CJISDE")
    set_CODEN("j-CAN-J-FISH-AQUAT-SCI",			"CJFSDX")
    set_CODEN("j-CAN-J-HIGHER-ED",			"????")
    set_CODEN("j-CAN-J-MATH",				"CJMAAB")
    set_CODEN("j-CAN-J-MICROBIOL",			"CJMIAZ")
    set_CODEN("j-CAN-J-PHYS",				"CJPHAD")
    set_CODEN("j-CAN-J-PHYSIOL-PHARMACOL",		"CJPPA3")
    set_CODEN("j-CAN-J-RES-SECT-A",			"CNRAAU")
    set_CODEN("j-CAN-J-STAT",				"????")
    set_CODEN("j-CAN-MATH-BULL",			"CMBUA3")
    set_CODEN("j-CANCER-METASTASIS-REV",		"CMRED4")
    set_CODEN("j-CAPACITY-MANAGEMENT-REVIEW",		"CAMRE3")
    set_CODEN("j-CARBOHYDR-RES",			"CRBRAT")
    set_CODEN("j-CARBON",				"CRBNAH")
    set_CODEN("j-CARDIOSCIENCE",                        "CRDIEG")
    set_CODEN("j-CARDIOVASC-RES",			"CVREAU")
    set_CODEN("j-CART-GIS",				"CGISES")
    set_CODEN("j-CARTOGRAPHICA",			"????")
    set_CODEN("j-CAS-PEST-MAT",				"CPMTA8")
    set_CODEN("j-CAT-CLASSIF-Q",			"CCQUDB")
    set_CODEN("j-CCCUJ",				"CCUJEX")
    set_CODEN("j-CCPE",					"CCPEBO")
    set_CODEN("j-CD-ROM-PROF",				"CRPFEX")
    set_CODEN("j-CD-ROM-WORLD",				"CDWOEV")
    set_CODEN("j-CEE",					"CHEDAY")
    set_CODEN("j-CELEST-MECH",				"CLMCAV")
    set_CODEN("j-CELEST-MECH-DYN-ASTR",			"CLMCAV", 1)
    set_CODEN("j-CELL",					"CELLB5")
    set_CODEN("j-CELL-BIOL-INT",			"CBIIEV")
    set_CODEN("j-CELL-BIOL-INT-REP",			"CBRPDS")
    set_CODEN("j-CELL-BIOPHYS",				"CBIODE")
    set_CODEN("j-CELL-CALCIUM",				"CECADV")
    set_CODEN("j-CELL-DIFFER",				"CLDFAT")
    set_CODEN("j-CELL-DIFFER-DEV",			"CDDEE8")
    set_CODEN("j-CELL-MOTIL",				"CMOTDY")
    set_CODEN("j-CELL-MOTIL-CYTOSKEL",			"CMCYEO")
    set_CODEN("j-CELL-REGUL",				"CELREQ")
    set_CODEN("j-CELL-SIGNAL",				"CESIEY")
    set_CODEN("j-CELL-STRUCT-FUNCT",			"CSFUDY")
    set_CODEN("j-CELL-SYST",				"????")
    set_CODEN("j-CELL-TISSUE-RES",                      "CTSRCS")
    set_CODEN("j-CELL-TISSUE-KINET",			"CTKIAR")
    set_CODEN("j-CENTAURUS",				"CENTA4")
    set_CODEN("j-CERN-COURIER",				"CECOA2")
    set_CODEN("j-CESK-CAS-FYZ",				"CKCFAH")
    set_CODEN("j-CESK-CAS-FYZ-SEK-A",			"CKCFAH")
    set_CODEN("j-CG-WORLD",				"CGWODH")
    set_CODEN("j-CGF",					"CGFODY")
    set_CODEN("j-CGIP",					"CGIPBG")
    set_CODEN("j-CHANCE",				"CNDCE4")
    set_CODEN("j-CHAOS",				"CHAOEH")
    set_CODEN("j-CHAOS-SOLITONS-FRACTALS",		"CSFOEH")
    set_CODEN("j-CHEM-BRITAIN",				"CHMBAY")
    set_CODEN("j-CHEM-ENG",				"CMERA9")
    set_CODEN("j-CHEM-ENG-COMMUN",			"CEGCAK")
    set_CODEN("j-CHEM-ENG-NEWS",			"CENEAR")
    set_CODEN("j-CHEM-ENG-NEWS-ARCHIVE",		"????")
    set_CODEN("j-CHEM-ENG-PROG",			"CEPRA8")
    set_CODEN("j-CHEM-ENG-SCI",				"CESCAC")
    set_CODEN("j-CHEM-IND-CHICHESTER-UK",		"CHINAG")
    set_CODEN("j-CHEM-INTELL",				"CHEIFK")
    set_CODEN("j-CHEM-MATER",				"CMATEX")
    set_CODEN("j-CHEM-NEWS-J-IND-SCI",			"????")
    set_CODEN("j-CHEM-NEWS-J-PHYS-SCI",			"CHNWAY")
    set_CODEN("j-CHEM-PHARM-BULL",			"CPBTAL")
    set_CODEN("j-CHEM-PHYS",				"CMPHC2")
    set_CODEN("j-CHEM-PHYS-LETT",			"CHPLBC")
    set_CODEN("j-CHEM-REV",				"CHREAY")
    set_CODEN("j-CHEMINFORM",				"????")
    set_CODEN("j-CHEMO-INTELL-LAB",			"CILSEN")
    set_CODEN("j-CHEMOSPHERE",				"CMSHAF")
    set_CODEN("j-CHEMPHYSCHEM",				"CPCHFT")
    set_CODEN("j-CHEMTECH",				"CHTEDD")
    set_CODEN("j-CHIC-J-THEOR-COMPUT-SCI",		"")
    set_CODEN("j-CHIC-REV",				"????")
    set_CODEN("j-CHIFFRES",				"????")
    set_CODEN("j-CHILTONS-AUTOMOT-IND",			"CAUIEG")
    set_CODEN("j-CHIN-J-COMPUTERS",			"JIXUDT")
    set_CODEN("j-CHIN-J-LASERS",			"ZHJIDO")
    set_CODEN("j-CHIN-PHYS-LETT",			"CPLEEU")
    set_CODEN("j-CHIRALITY",				"CHRLEP")
    set_CODEN("j-CHR-SCI-MON",				"????")
    set_CODEN("j-CHRON-HIGHER-ED",			"????")
    set_CODEN("j-CHYMIA",				"CHYMAP")
    set_CODEN("j-CIBA-FOUND-SYMP",                      "CIBSB4")
    set_CODEN("j-CIEL-TERRE",				"CIELAV")
    set_CODEN("j-CIENC-INVEST",				"CIBAAH")
    set_CODEN("j-CIRC-ARRHYTHM-ELECTROPHYSIOL",		"CIRCC3")
    set_CODEN("j-CIRC-RES",				"CIRUAL")
    set_CODEN("j-CIRCULATION",				"CIRCAZ")
    set_CODEN("j-CISCO-WORLD",				"????")
    set_CODEN("j-CIVILIZ",				"????")
    set_CODEN("j-CLASS-COMP-LEARN",			"CCOLD8")
    set_CODEN("j-CLASS-QUANTUM-GRAV",			"CQGRDG")
    set_CODEN("j-CLIENT-SERVER-ECONOMICS-LETT",         "CSELF4")
    set_CODEN("j-CLIN-EXP-IMMUNOL",			"CEXIAL")
    set_CODEN("j-CLIN-HAEMATOL",			"CLHMB3")
    set_CODEN("j-CLIN-LAB-HAEMOTOLOGY",			"CLHAD3")
    set_CODEN("j-CLIN-PHARMACOL-THER",			"CLPTAT")
    set_CODEN("j-CLIN-PLAST-SURG",			"CPSUDA")
    set_CODEN("j-CLIN-SCI",				"CSCIAE")
    set_CODEN("j-CLNET",				"????")
    set_CODEN("j-CMCM",					"????")
    set_CODEN("j-CMG-PROC",				"CMPREY")
    set_CODEN("j-CMS-NOTES",				"????")
    set_CODEN("j-COAL-NEWSLETTER",			"????")
    set_CODEN("j-COASTAL-ZONE",				"COZODK")
    set_CODEN("j-COED",					"CWLJDP")
    set_CODEN("j-COGN-SCI",				"COGSD5")
    set_CODEN("j-COGNITION",				"CGTNAU")
    set_CODEN("j-COLD-SPRING-HARBOR-SYMP-QUANT-BIOL",	"CSHSAZ")
    set_CODEN("j-COLL-ALGOR-ACM",			"????")
    set_CODEN("j-COLL-ENGL",				"????")
    set_CODEN("j-COLL-MICRO",				"CMICDL")
    set_CODEN("j-COLL-OCEAN-WORKS",			"????")
    set_CODEN("j-COLL-RESEARCH-LIB",			"CRLIAI")
    set_CODEN("j-COLL-RESEARCH-LIB-NEWS",		"????")
    set_CODEN("j-COLLECT-CZECH-CHEM-COMMUN",		"CCCCAK")
    set_CODEN("j-COLLEGE-MATH-J",			"????")
    set_CODEN("j-COLLNET-J-SCIENTOMETRICS-INF-MANAGE",	"????")
    set_CODEN("j-COLLOQ-GER",				"????")
    set_CODEN("j-COLLOQ-MATH",				"CQMAAQ")
    set_CODEN("j-COLLOQ-MATH-BOLYAI",			"????")
    set_CODEN("j-COLO-LAWYER",				"????")
    set_CODEN("j-COLO-LIBR",				"????")
    set_CODEN("j-COLUMBIA-LAW-REV",			"????")
    set_CODEN("j-COMBINATORICA",			"COMBDI")
    set_CODEN("j-COMM-APPL-ANAL",			"")
    set_CODEN("j-COMM-APPL-NUM-METH",			"CANMER")
    set_CODEN("j-COMM-NONLIN-SCI-NUM-SIM",		"????")
    set_CODEN("j-COMM-NUMER-METHODS-ENGRG",		"")
    set_CODEN("j-COMM-PARTIAL-DIFF-EQNS",		"CPDIDZ")
    set_CODEN("j-COMM-PURE-APPL-MATH",			"CPAMAT, CPMAMV")
    set_CODEN("j-COMM-THEOR-PHYS",			"CTPHDI")
    set_CODEN("j-COMMENT-MATH-HELV",			"COMHAX")
    set_CODEN("j-COMMENT-MATH-UNIV-CAROLINEA",		"CMUCAA")
    set_CODEN("j-COMMENT-PONTIF-ACAD-SCI",		"CPOSAF")
    set_CODEN("j-COMMENTS-AT-MOL-PHYS",			"CAMPBS")
    set_CODEN("j-COMMENTS-NUCL-PART-PHYS",		"CNPPAV")
    set_CODEN("j-COMMENTS-THEOR-BIOL",			"CTBIEK")
    set_CODEN("j-COMMON-CAUSE",				"????")
    set_CODEN("j-COMMON-CAUSE-MAGAZINE",		"????")
    set_CODEN("j-COMMUN-ALGEBRA",			"COALDM")
    set_CODEN("j-COMMUN-APPL-MATH-COMPUT-SCI",		"????")
    set_CODEN("j-COMMUN-BOOKNOTES-Q",			"????")
    set_CODEN("j-COMMUN-COMPUT-PHYS",			"")
    set_CODEN("j-COMMUN-CONTEMP-MATH",			"????")
    set_CODEN("j-COMMUN-DESIGN-Q-REVIEW",		"????")
    set_CODEN("j-COMMUN-INF-SYST",			"????")
    set_CODEN("j-COMMUN-KOREAN-MATH-SOC",		"????")
    set_CODEN("j-COMMUN-MATH-PHYS",			"CMPHAY")
    set_CODEN("j-COMMUN-MATH-SCI",			"????")
    set_CODEN("j-COMMUN-MATH-STAT",			"????")
    set_CODEN("j-COMMUN-NEWS",				"CMUNA9")
    set_CODEN("j-COMMUN-Q",				"????")
    set_CODEN("j-COMMUN-STAT",				"COSTCX")
    set_CODEN("j-COMMUN-STAT-SIMUL-COMPUT",		"CSSCDB")
    set_CODEN("j-COMMUN-STAT-THEORY-METH",		"CSTMDC")
    set_CODEN("j-COMMUNICATION-ARTS",			"COATBA")
    set_CODEN("j-COMP-APPLIC-BIOSCI",			"COABER")
    set_CODEN("j-COMP-ARCH-NEWS",			"CANED2")
    set_CODEN("j-COMP-ART-INTELL",			"CARIDY")
    set_CODEN("j-COMP-AUTO",				"CPAUAJ")
    set_CODEN("j-COMP-AUTO-PEOPLE",			"CPAUAJ", 1)
    set_CODEN("j-COMP-BIOCHEM-PHYSIOL",			"CPCPAI")
    set_CODEN("j-COMP-BIOCHEM-PHYSIOL-B",		"CBPBB8")
    set_CODEN("j-COMP-CHEM-ENG",			"CCENDW")
    set_CODEN("j-COMP-CIVIL-ENG",			"JCCEE5")
    set_CODEN("j-COMP-COMM",				"COCOD7")
    set_CODEN("j-COMP-COMM-REV",			"CCRED2")
    set_CODEN("j-COMP-CONTROL-ENG-J",			"CCEJEL")
    set_CODEN("j-COMP-DESIGN",				"CMPDAM")
    set_CODEN("j-COMP-ECONOMICS",			"CNOMEL")
    set_CODEN("j-COMP-ECONOMICS-REP",                   "")
    set_CODEN("j-COMP-EDU",				"COMEDR")
    set_CODEN("j-COMP-EDU-J",				"CEJOE7")
    set_CODEN("j-COMP-FLUIDS",				"CPFLBI")
    set_CODEN("j-COMP-FRAUD-SECURITY-BULL",		"CFSBEK")
    set_CODEN("j-COMP-GEOLOGY",				"COMGDX")
    set_CODEN("j-COMP-GEOM",				"")
    set_CODEN("j-COMP-GEOSCI",				"CGEODT, CGOSDN")
    set_CODEN("j-COMP-GRAPHICS",			"CGRADI, CPGPBZ")
    set_CODEN("j-COMP-GRAPHICS-PROC",			"CGPSFU")
    set_CODEN("j-COMP-HUM",				"COHUAD")
    set_CODEN("j-COMP-INDUSTRY",			"CINUD4")
    set_CODEN("j-COMP-J",				"CMPJA6")
    set_CODEN("j-COMP-LANG-MAG",			"COMLEF")
    set_CODEN("j-COMP-LANGS",				"COLADA")
    set_CODEN("j-COMP-LANGS-SYS-STRUCT",		"")
    set_CODEN("j-COMP-LAW-J",				"COLJD3")
    set_CODEN("j-COMP-LAW-SECURITY-REP",		"CLSRE8")
    set_CODEN("j-COMP-LAWYER",				"COLAEB")
    set_CODEN("j-COMP-LIB",				"CPLIE8")
    set_CODEN("j-COMP-LING",				"AJCLD9")
    set_CODEN("j-COMP-MATH",				"????")
    set_CODEN("j-COMP-MATH-APP",			"????")
#    set_CODEN("j-COMP-MATH-APPL",			"CMAPDK")
#    set_CODEN("j-COMP-MATH-APPL-A",			"CMAPDK", 1)
#    set_CODEN("j-COMP-MATH-APPL-B",			"CMAPDK", 1)
    set_CODEN("j-COMP-MATH-SCI-TEACHING",		"JCMTDV")
    set_CODEN("j-COMP-MUSIC-J",				"CMUJDY")
    set_CODEN("j-COMP-NET",				"CNETDP")
    set_CODEN("j-COMP-NET-ISDN",			"CNISE9")
    set_CODEN("j-COMP-NET-AMSTERDAM",			"????")
    set_CODEN("j-COMP-OP-RES",				"CMORAP")
    set_CODEN("j-COMP-OPTIM-APPL",			"CPPPEF")
    set_CODEN("j-COMP-PERSONNEL",			"CPPNB6")
    set_CODEN("j-COMP-PHYS-COMM",			"CPHCBZ")
    # set_CODEN("j-COMP-PHYSICS",				"CPHYE2")
    set_CODEN("j-COMP-PHYSIOL-C",			"CBPCEE")
    set_CODEN("j-COMP-PICTURES",			"????")
    set_CODEN("j-COMP-RESELLER-NEWS",			"????")
    set_CODEN("j-COMP-RETAIL-WEEK",			"????")
    set_CODEN("j-COMP-REV",				"CPGRA6")
    set_CODEN("j-COMP-SCI-INFO",			"CSINET")
    set_CODEN("j-COMP-SCI-REV",				"????")
    set_CODEN("j-COMP-SCI-SCI-COMP",			"????")
    set_CODEN("j-COMP-SPEECH-LANG",			"CSPLEO")
    set_CODEN("j-COMP-SPEECH-PROC",			"????")
    set_CODEN("j-COMP-STANDARDS-INTERFACES",		"CSTIEZ")
    set_CODEN("j-COMP-STAT",				"CSTAEB")
    ## DUPLICATE: set_CODEN("j-COMP-STAT-DATA-ANA",			"CSDADW")
    set_CODEN("j-COMP-STRUCTURES",			"CMSTCJ")
    set_CODEN("j-COMP-SURV",				"CMSVAN")
    set_CODEN("j-COMP-SYS",				"CMSYE2")
    set_CODEN("j-COMP-SYS-NEWS",			"CSYND6")
    # [03-Feb-1999]: j-COMP-SYS-SCI-ENG replaced by j-COMPUT-SYST-SCI-ENG
    # set_CODEN("j-COMP-SYS-SCI-ENG",			"CSSEEI")
    set_CODEN("j-COMP-TECH-REV",			"CTERES")
    set_CODEN("j-COMP-VIS-IMAGE-UNDERSTANDING",		"CVIUF4")
    set_CODEN("j-COMPCON-SPRING89",			"????")
    set_CODEN("j-COMPLEX-SYSTEMS",			"????")
    set_CODEN("j-COMPLEX-VAR-ELLIPTIC-EQU",		"????")
    set_CODEN("j-COMPLEX-VARIABLES-THEORY-APPL",	"CVTADV")
    set_CODEN("j-COMPLEXITY",				"COMPFS")
    set_CODEN("j-COMPOS-ENG",				"CMENEZ")
    set_CODEN("j-COMPOS-MATH",				"CMPMAF")
    set_CODEN("j-COMPOS-SCI-TECH",			"CSTCEH")
    set_CODEN("j-COMPOS-STRUCT",			"COMSE2")
    set_CODEN("j-COMPUT-ACOUSTICS",			"")
    set_CODEN("j-COMPUT-AIDED-CIVIL-INFRASTRUCT-ENG",	"CCIEFR")
    set_CODEN("j-COMPUT-AIDED-DES",			"CAIDA5")
    set_CODEN("j-COMPUT-AIDED-ENG",			"CCAEDJ")

    ## NB: j-COMPUT-AND-BIOMED-RES and j-COMPUT-BIOMED-RES are
    ## DIFFERENT, but both published by Academic Press:
    ##     Computers and biomedical research 1967--2000
    ##     Computers in biomedical research  Vol. 1(1965)-Vol. 4 (1974)
    ## The former is succeeded by Journal of Biomedical Informatics.
    set_CODEN("j-COMPUT-AND-BIOMED-RES",		"CBMRB7")

    set_CODEN("j-COMPUT-ANIM-VIRTUAL-WORLDS",		"")
    set_CODEN("j-COMPUT-APPL-ENG-EDUC",			"CAPEED")
    set_CODEN("j-COMPUT-BIOL-MED",			"CBMDAW")

    ## NB: j-COMPUT-AND-BIOMED-RES and j-COMPUT-BIOMED-RES are
    ## DIFFERENT, but both published by Academic Press:
    ##     Computers and biomedical research 1967--2000
    ##     Computers in biomedical research  Vol. 1(1965)-Vol. 4 (1974)
    ## The former is succeeded by Journal of Biomedical Informatics.
    set_CODEN("j-COMPUT-BIOMED-RES",			"CPBRAF")

    set_CODEN("j-COMPUT-BULL",				"COBUAH")
    set_CODEN("j-COMPUT-CARDIOL",			"COCADX")
    set_CODEN("j-COMPUT-CHEM",				"COCHDK")
    set_CODEN("j-COMPUT-CHEM-INSTRUM",			"CPCIBS")
    set_CODEN("j-COMPUT-COMPLEX",			"CPTCEU")
    set_CODEN("j-COMPUT-DECIS",				"CODCB8, COMDEP")
    set_CODEN("j-COMPUT-EDGE",				"????")
    set_CODEN("j-COMPUT-ELECTRON-AGRIC",		"CEAGE6")
    set_CODEN("j-COMPUT-ELECTR-ENG",			"CPEEBQ")
    set_CODEN("j-COMPUT-GEOSCI",			"CGOEBD")
    set_CODEN("j-COMPUT-HUM-BEHAV",			"CHBEEQ")
    set_CODEN("j-COMPUT-IND-ENG",			"CINDDL")
    set_CODEN("j-COMPUT-INTELL",			"COMIE6")
    set_CODEN("j-COMPUT-MATER-SCI",			"CMMSEM")
    set_CODEN("j-COMPUT-MATH-APPL",			"CMAPDK")
    set_CODEN("j-COMPUT-MATH-APPL-A",			"CMAPDK", 1)
    set_CODEN("j-COMPUT-MATH-APPL-B",			"CMAPDK", 1)
    set_CODEN("j-COMPUT-MATH-MATH-PHYS",		"????")
    set_CODEN("j-COMPUT-MECH",				"CMMEEE")
    set_CODEN("j-COMPUT-METH-APPL-MATH",		"")
    set_CODEN("j-COMPUT-METH-APPL-MECH-ENG",		"CMMECC")
    set_CODEN("j-COMPUT-METH-FUNCT-THEORY",		"")
    set_CODEN("j-COMPUT-METH-PROG-BIOMED",		"CMPBEK")
    set_CODEN("j-COMPUT-PHYS",				"CPHYE2")
    set_CODEN("j-COMPUT-PHYS-REP",			"CPHREF")
    set_CODEN("j-COMPUT-PROGRAMS-BIOMED",		"COPMBU")
    set_CODEN("j-COMPUT-RES-NEWS",			"????")
    set_CODEN("j-COMPUT-SCH",				"")
    set_CODEN("j-COMPUT-SCI-ECON-MANAG",		"CSMNEF")
    set_CODEN("j-COMPUT-SCI-ENG",			"CSENFA")
    set_CODEN("j-COMPUT-SECUR",				"CPSEDU")
    set_CODEN("j-COMPUT-SECUR-J",			"CSJLDR")
    set_CODEN("j-COMPUT-SOFTW-BIG-SCI",			"????")
    set_CODEN("j-COMPUT-STAND",				"COSTEZ")
    set_CODEN("j-COMPUT-STAT-Q",			"CSQUEM")
    set_CODEN("j-COMPUT-STAT-DATA-ANAL",		"CSDADW")
    set_CODEN("j-COMPUT-SUPPORTED-COOP-WORK",		"CSCWEQ")
    set_CODEN("j-COMPUT-SYST-ENG",			"COSEEO")
    set_CODEN("j-COMPUT-SYST-SCI-ENG",			"CSSEEI")
    set_CODEN("j-COMPUT-TEACH",				"????")
    set_CODEN("j-COMPUT-THEOR-CHEM",			"CTCOA5")
    set_CODEN("j-COMPUT-VIS-SCI",			"")
    set_CODEN("j-COMPUTABILITY",			"")
    set_CODEN("j-COMPUTE",				"COMPER")
    set_CODEN("j-COMPUTER",				"CPTRB4")
    set_CODEN("j-COMPUTER-PROC-CHINESE-ORIENTAL-LANG",	"CPCLE6")
    set_CODEN("j-COMPUTER-SHOPPER",			"????")
    set_CODEN("j-COMPUTERS-AND-GRAPHICS",		"COGRD2")
    set_CODEN("j-COMPUTERWOCHE",			"????")
    set_CODEN("j-COMPUTERWORLD",			"CMPWAB")
    set_CODEN("j-COMPUTING",				"CMPTA2")
    set_CODEN("j-COMPUTING-SUPPLEMENTUM",		"COSPDM")
    set_CODEN("j-COMUN-ESTAD",				"????")
    set_CODEN("j-CONCEPTS-NEUROSCI",			"CNEVEW")
    set_CODEN("j-CONF-LOCAL-COMPUT-NETW",		"CLCPDN")
    set_CODEN("j-CONFIGURATIONS",			"????")
    set_CODEN("j-CONG-NUM",				"????")
    set_CODEN("j-CONGR-Q-WKLY-REP",			"")
    set_CODEN("j-CONN-LAW-REVIEW",			"")
    set_CODEN("j-CONSERV-BIOL",				"CBIOEF")
    set_CODEN("j-CONSPECTUS",                           "CONSF8")
    set_CODEN("j-CONST-APPROX",				"????")
    set_CODEN("j-CONTACT-CONTEXT",			"")
    set_CODEN("j-CONTEMP-BR-HIST",			"????")
    set_CODEN("j-CONTEMP-MATH",				"????")
    set_CODEN("j-CONTEMP-PHYS",				"CTPHAF")
    set_CODEN("j-CONTEMP-SOCIOL",			"????")
    set_CODEN("j-CONTIN-MECH-THERMODYN",		"CMETEJ")
    set_CODEN("j-CONTRACT-DES",				"????")
    set_CODEN("j-CONTROL-CYBERN",			"CCYBAP")
    set_CODEN("j-CONTROL-ENG",				"CENGAX")
    set_CODEN("j-CONTROL-ENG-PRACT",			"COEPEL")
    set_CODEN("j-CONTROLLED-CLIN-TRIALS",		"CCLTDH")
    set_CODEN("j-CORMOSEA-BULL",			"????")
    set_CODEN("j-CORNELL-ENG",				"CNLEAC")
    set_CODEN("j-CORNELL-REV",				"????")
    set_CODEN("j-CPE",					"CPEXEI")
    set_CODEN("j-CPSR",					"????")
    set_CODEN("j-CQ-RES",				"????")
    set_CODEN("j-CRAS",					"????")
    set_CODEN("j-CRAY-CHANNELS",			"CRCHE8")
    set_CODEN("j-CREAT-COMPUT",				"CCOMDB")
    set_CODEN("j-CRC-CRIT-REV-BIOCHEM",			"CRBCAI")
    set_CODEN("j-CRC-CRIT-REV-BIOMED-ENG",		"CRBEDR")
    set_CODEN("j-CRIT-CARE-MED",			"????")
    set_CODEN("j-CRIT-REV-MICROBIOL",			"CRVMAC")
    set_CODEN("j-CRITICA-MEXICO",			"????")
    set_CODEN("j-CROAT-CHEM-ACTA",			"CCACAA")
    set_CODEN("j-CROSSROADS",				"????")
    set_CODEN("j-CRYPTOBYTES",				"????")
    set_CODEN("j-CRYPTOGR-COMMUN",			"????")
    set_CODEN("j-CRYPTOLOGIA",				"CRYPE6")
    set_CODEN("j-CRYST-LATTICE-DEFECTS",		"CLADA8")
    set_CODEN("j-CRYST-RES-TECHNOL",			"CRTEDF")
    set_CODEN("j-CRYSTAL-GROWTH",			"CRGRDN")
    set_CODEN("j-CSGD",					"????")
    set_CODEN("j-CSSP",					"CSSPEH")
    set_CODEN("j-CT",					"????")
    set_CODEN("j-CUJ",					"????")
    set_CODEN("j-CURR-BIOL",				"CUBLE2")
    set_CODEN("j-CURR-CONTENTS-PHYS-CHEM-EARTH-SCI",	"????")
    set_CODEN("j-CURR-CONTENTS-ENG-TECH-APPL-SCI",	"CCETA")
    set_CODEN("j-CURR-GEN",				"CUGED5")
    set_CODEN("j-CURR-MICROBIOL",			"CUMIDD")
    set_CODEN("j-CURR-OPIN-BIOTECH",			"CUOBE3")
    set_CODEN("j-CURR-OPIN-CELL-BIOL",			"COCBE3")
    set_CODEN("j-CURR-OPIN-GENET-DEV",			"COGDET")
    set_CODEN("j-CURR-OPIN-IMMUNOL",			"COPIEL")
    set_CODEN("j-CURR-OPIN-HEMATOL",			"COHEF4")
    set_CODEN("j-CURR-SCI",				"CUSCAM")
    set_CODEN("j-CURR-TOP-CELL-REGUL",			"CTCRAE")
    set_CODEN("j-CURR-TOP-DEV-BIOL",			"CTDBA5")
    set_CODEN("j-CURR-TOPICS-MEMBRANES-TRANSPORT",	"CTMEET")
    set_CODEN("j-CVGIP",				"CVGPDB")
    set_CODEN("j-CVGIP-GMIP",				"CGMPE5")
    set_CODEN("j-CVGIP-IU",				"CIUNEJ")
    set_CODEN("j-CWI-QUARTERLY",			"????")
    set_CODEN("j-CYBER",				"CYBNAW")
    set_CODEN("j-CYBERNETICS-SYSTEMS",			"CYSYDH")
    set_CODEN("j-CYTOBIOLOGIE",				"CYTZAM")
    set_CODEN("j-CYTOLOGIA",				"CYTOAN")
    set_CODEN("j-CYTOMETRY",				"CYTODQ")
    set_CODEN("j-CZECH-J-PHYS",				"CZYPAO")
    set_CODEN("j-CZECH-MATH-J",				"CZMJAE")
    set_CODEN("j-D-LIB-MAGAZINE",			"????")
    set_CODEN("j-DAEDALUS",				"DAEDAU")
    set_CODEN("j-DANCE-TEACHER-NOW",                    "")
    set_CODEN("j-DATA-COMMUNICATIONS",			"DACODM")
    set_CODEN("j-DATA-HANDLING-SCI-TECH",		"DHSTEV")
    set_CODEN("j-DATA-KNOWLEDGE-ENG",			"DKENEW")
    set_CODEN("j-DATA-PROCESS",				"????")
    set_CODEN("j-DATABASE",				"DTBSDQ")
    set_CODEN("j-DATABASE-DIRECTORY",			"DBADEL")
    set_CODEN("j-DATABASES-J",                          "DAJOFP")
    set_CODEN("j-DATAMATION",				"DTMNAT")
    set_CODEN("j-DBMS",					"DBMSEO")
    set_CODEN("j-DDDU",					"????")
    set_CODEN("j-DDJ",					"DDJOEB")
    set_CODEN("j-DDJ-SOURCEBOOK",			"????")
    set_CODEN("j-DEC-PROFESSIONAL",			"DECPDJ")
    set_CODEN("j-DEC-SUPP-SYS",				"DSSYDK")
    set_CODEN("j-DEC-TECH-J",				"DTJOEL")
    set_CODEN("j-DEEP-SEA-RES-PART-2-TOP-STUD-OCEANOGR", "DSROEK")	
    set_CODEN("j-DELFT-PROG-REP",			"DPRED2")
    set_CODEN("j-DELTA-KAPPA-GAMMA-BULL",               "DKGBF7")
    set_CODEN("j-DEMOGRAPHY",				"????")
    set_CODEN("j-DEMONSTRATIO-MATHEMATICA",		"DEMADO")
    set_CODEN("j-DESIGN-NEWS",				"DIGNAO")
    set_CODEN("j-DESIGNS-CODES-CRYPTOGR",		"DCCREC")
    set_CODEN("j-DESKTOP-PUB-COMM",			"DPCOEQ")
    set_CODEN("j-DEUTSCH-MATH-V",			"????")
    set_CODEN("j-DEV-CELL",				"DCEEBE")
    set_CODEN("j-DEV-DYNAMICS",                         "DEDYEI")
    set_CODEN("j-DEVEL",				"DEVPED")
    set_CODEN("j-DEVEL-BIOL",				"DEBIAO")
    set_CODEN("j-DEVEL-BIOL-N-Y",			"????")
    set_CODEN("j-DEVEL-GENETICS",			"DGNTDW")
    set_CODEN("j-DEVEL-GROWTH-DIFF",			"DGDFA5")
    set_CODEN("j-DEVEL-SUPPL",				"DESUED")
    set_CODEN("j-DGOV",					"????")
    set_CODEN("j-DIABETOLOGIA",				"DBTGAJ")
    set_CODEN("j-DIALECTICA",				"????")
    set_CODEN("j-DIALOGUE",				"????")
    set_CODEN("j-DIFF-EQ",				"DIEQAN")
    set_CODEN("j-DIFFER-URAVN-MINSK-1965",		"????")
    set_CODEN("j-DIFFERENTIATION",			"DFFNAW")
    set_CODEN("j-DIGEST-PAPERS-IEEE-SYMP-MASS-STOR-SYS","DPISDX")
    set_CODEN("j-DIGITAL-AGE",				"????")
    set_CODEN("j-DIGITAL-MEDIA",			"DMEDEG")
    set_CODEN("j-DIGITAL-NEWS-REVIEW",			"????")
    set_CODEN("j-DIGITAL-REVIEW",			"DIRVE5")
    set_CODEN("j-DIGITAL-SYS-J",			"DSJOEE")
    set_CODEN("j-DIGITAL-SYS-REP",                      "DSREFP")
    set_CODEN("j-DIN-SPLOS-SREDY",			"DSSYAH")
    set_CODEN("j-DIPL-HIST",				"????")
    set_CODEN("j-DISCRETE-APPL-MATH",			"DAMADU")
    set_CODEN("j-DISCRETE-COMPUT-GEOM",			"DCGEER")
    set_CODEN("j-DISCRETE-CONTIN-DYN-SYST",		"")
    set_CODEN("j-DISCRETE-DYN-NAT-SOC",			"DDNSFA")
    set_CODEN("j-DISCRETE-MATH",			"DSMHA4")
    set_CODEN("j-DISCRETE-MATH-APPL",			"DMAPEW")
    set_CODEN("j-DISCRETE-MATH-THEOR-COMPUT-SCI",	"????")
    set_CODEN("j-DISTRIB-COMPUT",			"DICOEB")
    set_CODEN("j-DISTRIBUTION",				"????")
    set_CODEN("j-DLT",					"????")
    set_CODEN("j-DNA",					"DNAADR")
    set_CODEN("j-DNA-CELL-BIOL",			"DCEBE8")
    set_CODEN("j-DNA-SEQ",				"DNSEES")
    set_CODEN("j-DOC-MATH",				"????")
    set_CODEN("j-DOCUMENTALISTE-SCI-INFO",		"DSINE6")
    set_CODEN("j-DOKL-AKAD-NAUK",			"DANKAS", 1)
    set_CODEN("j-DOKL-MATH",				"????")
    set_CODEN("j-DOOPS",				"????")
    set_CODEN("j-DRUG-DISCOVERY-TODAY",			"DDTOFS")
    set_CODEN("j-DTRAP",				"????")
    set_CODEN("j-DUKE-MATH-J",				"DUMJAO")
    set_CODEN("j-DYN-CONTIN-DISCR-IMPULS-B",		"DCDIS4")
    set_CODEN("j-DYNAMICS-CONTROL",			"")
    set_CODEN("j-EARTH-SURF-PROCESSES",			"ESPRDT")
    set_CODEN("j-EARTH-SURF-PROCESSES-LANDFORMS",	"ESPLDB")
    set_CODEN("j-EARTHQUAKE-ENG-STRUCT-DYN",		"IJEEBG")
    set_CODEN("j-ECOL-MODELL",				"ECMODT")
    set_CODEN("j-ECOL-MONOGR",				"ECMOAQ")
    set_CODEN("j-ECOLOGY",				"ECOLAR")
    set_CODEN("j-ECON-GEOL",				"ECGLAL")
    set_CODEN("j-ECON-QUAL-CONTROL",			"????")
    set_CODEN("j-ECONOM-J",				"????")
    set_CODEN("j-ECONOM-LETT",				"ECLEDS")
    set_CODEN("j-ECONOM-STAT",				"????")
    set_CODEN("j-ECONOMIST",				"EONOEH")
    set_CODEN("j-ECONOMETRICA",				"ECMTA7")
    set_CODEN("j-ED-PUBL",				"????")
    set_CODEN("j-EDN",					"EDNSBH")
    set_CODEN("j-EDPACS",                               "EDPCDF")
    set_CODEN("j-EDU-CHEM",				"EDCHAU")
    set_CODEN("j-EDU-PSYCH-MEASUREMENT",		"EPMEAJ")
    set_CODEN("j-EDU-TRAINING-TECH",			"ETTIEU")
    set_CODEN("j-EDUC-STUD-MATH",			"EDSMAN")
    set_CODEN("j-EDUCOM-REV",				"EDREEW")
    set_CODEN("j-ELECT-COMM-ENG-J",			"ECEJE9")
    set_CODEN("j-ELECT-COMM-JAPAN-3-FUND-ELECT-SCI",	"ECJSER")
    set_CODEN("j-ELECT-COMPOSITION-IMAGING",		"????")
    set_CODEN("j-ELECT-J-COMB",				"????")
    set_CODEN("j-ELECT-LETTERS",			"ELLEAK")
    set_CODEN("j-ELECT-NOTES-THEOR-COMP-SCI",		"????")
    set_CODEN("j-ELECT-STUDIES",			"????")
    set_CODEN("j-ELECTR-COMMUN",			"ELCMAX")
    set_CODEN("j-ELECTR-ENG",				"ELENAC")
    set_CODEN("j-ELECTR-REV",				"ELREAG")
    set_CODEN("j-ELECTRICIAN",				"ELETAU")
    set_CODEN("j-ELECTRO",				"ELCRDH")
    set_CODEN("j-ELECTROMAGNETICS",			"")
    set_CODEN("j-ELECTRON-COMMUN-JPN",			"ECOJAL")
    set_CODEN("j-ELECTRON-COMMUN-JPN-PART-1-COMMUN",	"????")
    set_CODEN("j-ELECTRON-COMMUN-PROBAB",		"????")
    set_CODEN("j-ELECTRON-ENG",				"ELEGAP")
    set_CODEN("j-ELECTRON-J-BOUND-ELEM",		"")
    set_CODEN("j-ELECTRON-J-LINEAR-ALGEBRA",		"????")
    set_CODEN("j-ELECTRON-J-PROBAB",			"????")
    set_CODEN("j-ELECTRON-J-THEOR-PHYS",		"EJTPBC")
    set_CODEN("j-ELECTRON-MICROSC-REV",			"EMIREL")
    set_CODEN("j-ELECTRON-POWER",			"ELPWAQ")
    set_CODEN("j-ELECTRON-TRANS-NUMER-ANAL",		"")
    set_CODEN("j-ELECTRONIC-DESIGN",			"ELODAW")
    set_CODEN("j-ELECTRONIC-ENG-TIMES",			"????")
    set_CODEN("j-ELECTRONIC-LEARNING",			"ELEADA")
    set_CODEN("j-ELECTRONIC-LIBRARY",			"ELLIDZ")
    set_CODEN("j-ELECTRONIC-MUSICIAN",			"????")
    set_CODEN("j-ELECTRONIC-PRODUCTS",			"ELPOA2")
    set_CODEN("j-ELECTRONICS",				"????")
    set_CODEN("j-ELECTRONICS-WORLD-WIRELESS-WORLD",	"EWWWE6")
    set_CODEN("j-ELECTRONIK",				"EKRKAR")
    set_CODEN("j-ELECTROPHORESIS",			"ELCTDN")
    set_CODEN("j-ELEK-INFO-KYBER",			"EIVKAX")
    set_CODEN("j-ELEK-RECHENANLAGEN",			"ELRAA4")
    set_CODEN("j-ELEKTRONIKER",				"ELKRBL")
    set_CODEN("j-ELEM-MATH",				"????")
    set_CODEN("j-ELEMENTA-TMFK",			"EMNTAE")
    set_CODEN("j-ELET-IRODALOM",			"????")
    set_CODEN("j-ELET-TUDOMANY",			"????")
    set_CODEN("j-ELETTRONICA-OGGI",                     "ELOGDA")
    set_CODEN("j-ELETTROTECNICA",			"ETRTAF")
    set_CODEN("j-EMBED-SYS-PROG",			"EYPRE4")
    set_CODEN("j-EMBEDDED-LINUX-J",			"????")
    set_CODEN("j-EMBO-J",				"EMJODG")
    set_CODEN("j-EMORY-LAW",				"????")
    set_CODEN("j-EMPIR-SOFTWARE-ENG",			"ESENFW")
    set_CODEN("j-EMPIRICA",				"????")
    set_CODEN("j-ENCYCL-LIB-INFO-SCI",			"????")
    set_CODEN("j-ENDEAVOUR",				"ENDEAS")
    set_CODEN("j-ENDOCRINE",				"EOCRE5")
    set_CODEN("j-ENDOCRINOL",				"ENDOAO")
    set_CODEN("j-ENERGY-RES",				"ENRSD7")
    set_CODEN("j-ENERGY-TECHNOL-REV",			"????")
    set_CODEN("j-ENEWS",				"ELNEAU")
    set_CODEN("j-ENG-ANAL-BOUND-ELEM",			"")
    set_CODEN("j-ENG-AUTOMATION",			"EAPPEY")
    set_CODEN("j-ENG-COMP",				"ENCOEN")
    set_CODEN("j-ENG-COMPUT",				"ENGCE7")
    set_CODEN("j-ENG-CORNELL-Q",			"")
    set_CODEN("j-ENG-DESIGN-GRAPHICS-J",		"????")
    set_CODEN("j-ENG-FRACTURE-MECH",			"EFMEAH")
    set_CODEN("j-ENG-MAT",				"????")
    set_CODEN("j-ENG-SCI",				"ENSCAT")
    set_CODEN("j-ENG-SCI-REP-KYUSHU",			"SRKHE")
    set_CODEN("j-ENG-TRANS",				"RZINAZ")
    set_CODEN("j-ENGINEER",				"ENGIAL")
    set_CODEN("j-ENGLISH-LANGUAGE-TEACHING",		"ELNTA7")
    set_CODEN("j-ENSEIGN-MATH",				"ENMAAR")
    set_CODEN("j-ENSEIGN-MATH-2",			"ENMAAR")
    set_CODEN("j-ENTROPY",				"ENTRFG")
    set_CODEN("j-ENV-POLLUTION",			"ENPOEK")
    set_CODEN("j-ENV-POLLUTION-A",			"EPEBD7")
    set_CODEN("j-ENV-SCI-TECH",				"ESTHAG")
    set_CODEN("j-ENVIRON-HIST",				"????")
    set_CODEN("j-ENVIRON-MONIT-ASSESS",			"EMASDH")
    set_CODEN("j-EPILEPSIA",				"EPILAK")
    set_CODEN("j-EPJ-APPL-PHYS",			"EPAPFV")
    set_CODEN("j-EPODD",				"EPODEU")
    set_CODEN("j-ERGEB-EXAKTEN-NATURWISS",		"EENAA3")
    set_CODEN("j-ERGEB-MATH-GRENZGEBIETE",		"ERMGB6")
    set_CODEN("j-ERGOD-THEORY-DYN-SYST",		"")
    set_CODEN("j-ERGONOMICS",				"ERGOAX")
    set_CODEN("j-ERKENNTNIS",				"????")
    set_CODEN("j-ERKENNTNIS-1975",			"ERKEDQ")
    set_CODEN("j-ESAIM-PROBAB-STATIST",			"????")
    set_CODEN("j-ESSAYS-BIOCHEM",			"ESBIAV")
    set_CODEN("j-ETT",					"ETTTET")
    set_CODEN("j-EUGEN-REV",				"EUREAB")
    set_CODEN("j-EULERIANA",				"????")
    set_CODEN("j-EUR-J-APPL-MATH",			"????")
    set_CODEN("j-EUR-J-BIOCHEM",			"EJBCAI")
    set_CODEN("j-EUR-J-CELL-BIOL",			"EJCBDN")
    set_CODEN("j-EUR-J-CLIN-CHEM-CLIN-BIOCHEM",		"EJCBEO")
    set_CODEN("j-EUR-J-COMB",				"EJOCDI")
    set_CODEN("j-EUR-J-INORG-CHEM",			"EJICFO")
    set_CODEN("j-EUR-J-MECH-A-SOLIDS",			"EJASEV")
    set_CODEN("j-EUR-J-OPER-RES",			"EJORDT")
    set_CODEN("j-EUR-J-PHYS",				"EJPHD4")
    set_CODEN("j-EUR-J-PROTIST",			"EJPREZ")
    set_CODEN("j-EUR-MATH-SOC-NEWSL",			"")
    set_CODEN("j-EUR-PHYS-J-A",				"EPJAFV")
    set_CODEN("j-EUR-PHYS-J-B",				"EPJBFY")
    set_CODEN("j-EUR-PHYS-J-C",				"EPCFFB")
    set_CODEN("j-EUR-PHYS-J-D",				"EPJDF6")
    set_CODEN("j-EUR-PHYS-J-E",				"EPJSFH")
    set_CODEN("j-EUR-PHYS-J-H",				"EPJHAD")
    set_CODEN("j-EUR-PHYS-J-PLUS",			"EPJPA3")
    set_CODEN("j-EUR-PHYS-J-SPEC-TOP",			"EPJSAC")
    set_CODEN("j-EUR-PSYCH",				"????")
    set_CODEN("j-EUR-REV-HIST",				"????")
    set_CODEN("j-EUR-SCI-EDIT",				"????")
    set_CODEN("j-EUR-TRANS-TELECOMMUN-RELAT-TECHNOL",	"????")
    set_CODEN("j-EURASIP-J-ADV-SIGNAL-PROCESS",		"????")
    set_CODEN("j-EURASIP-J-EMBED-SYS",			"????")
    set_CODEN("j-EUROMATH-BULL",			"????")
    set_CODEN("j-EUROPEN-NEWSLETTER",			"EONLE8")
    set_CODEN("j-EUROPHYS-LETT",			"EULEEJ")
    set_CODEN("j-EUROPHYS-NEWS",			"EUPNAS")
    set_CODEN("j-EUUG-NEWSLETTER",			"EONLE8", 1)
    set_CODEN("j-EVOLUTION",				"EVOLAO")
    set_CODEN("j-EVOL-COMPUT",				"EOCMEO")
    set_CODEN("j-EVOL-ECOL",				"EVECEJ")
    set_CODEN("j-EVOL-INTEL",				"????")
    set_CODEN("j-EW-J-NUM-MATH",			"EJNMEA")
    set_CODEN("j-EXE",					"EXEEE5")
    set_CODEN("j-EXEC-EDUC",				"EXEREA")
    set_CODEN("j-EXP-CELL-RES",				"ECREAL")
    set_CODEN("j-EXP-HEMATOL",				"EXHMA6")
    set_CODEN("j-EXP-HEMATOL-TODAY",			"EHTODV")
    set_CODEN("j-EXP-MATH",				"????")
    set_CODEN("j-EXP-MYCO",				"EXMYD2")
    set_CODEN("j-EXP-NEUROL",				"EXNEAC")
    set_CODEN("j-EXP-PARASITOL",			"EXPAAA")
    set_CODEN("j-EXPEDITION",				"????")
    set_CODEN("j-EXPERIENTIA",				"EXPEAM")
    set_CODEN("j-EXPERIENTIA-SUPPL",			"EXPSAU")
    set_CODEN("j-EXPERT-SYST-APPL",			"ESAPEH")
    set_CODEN("j-EXPO-MATH",				"")
    set_CODEN("j-EXS",					"EXSEE7")
    set_CODEN("j-EYE",					"EYEEEC")
    set_CODEN("j-FACTA-PHILOS",				"????")
    set_CODEN("j-FAR-EAST-J-APPL-MATH",			"")
    set_CODEN("j-FAR-EAST-J-THEOR-STAT",		"????")
    set_CODEN("j-FASEB-J",				"FAJOEC")
    set_CODEN("j-FEBS",					"FEBPBY")
    set_CODEN("j-FEBS-LETT",				"FEBLAL")
    set_CODEN("j-FED",					"FEDSDL")
    set_CODEN("j-FED-COMPUTER-WEEK",			"????")
    set_CODEN("j-FED-PROC",				"FEPRA7")
    set_CODEN("j-FED-REGIST",				"FEREAC")
    set_CODEN("j-FEMS-MICROBIOL-LETT",			"FMLED7")
    set_CODEN("j-FEMS-MICROBIOL-REV",			"FMREE4")
    set_CODEN("j-FERROELECTRICS",			"FEROA8")
    set_CODEN("j-FIB-QUART",				"FIBQAU")
    set_CODEN("j-FINANC-ANAL-J",			"FIAJA4")
    set_CODEN("j-FINANC-TECH-INT-BULL",			"FTIBFY")
    set_CODEN("j-FINITE-ELEMENTS-ANAL-DESIGN",		"FEADEU")
    set_CODEN("j-FINITE-FIELDS-APPL",			"FFTAFM")
    set_CODEN("j-FIRST-MONDAY",                         "")
    set_CODEN("j-FISH-AQUACULT-J",			"FAJIAO")
    set_CODEN("j-FISH-BULL",				"FSYBAY")
    set_CODEN("j-FISH-FISH",				"FFIIAK")
    set_CODEN("j-FISH-OCEANOGR",			"FIOCEN")
    set_CODEN("j-FISH-PHYSIOL-BIOCHEM",			"FPBIEP")
    set_CODEN("j-FISH-RES",				"FISRDJ")
    set_CODEN("j-FISHERIES",				"????")
    set_CODEN("j-FISHES",				"????")
    set_CODEN("j-FIZ-SZ",				"FISZA6")
    set_CODEN("j-FIZMAT-SPIS-BULGAR-AKAD-NAUK",		"FMBMAC")
    set_CODEN("j-FJCC",					"????")
    set_CODEN("j-FLEX-TECH-J",				"????")
    set_CODEN("j-FLUCT-NOISE-LETT",			"????")
    set_CODEN("j-FOLIA-HAEMATOL",			"FOHEAW")
    set_CODEN("j-FOLIO",				"????")
    set_CODEN("j-FORBES",				"FORBA5")
    set_CODEN("j-FOREFRONTS",				"????")
    set_CODEN("j-FOREIGN-AFFAIRS",			"FRNAA3")
    set_CODEN("j-FORMA",				"????")
    set_CODEN("j-FORM-ASP-COMPUT",			"FACME5")
    set_CODEN("j-FORM-METHODS-SYST-DES",		"FMSDE6")
    set_CODEN("j-FORSCH-FORTSCHR",			"FOFOAI")
    set_CODEN("j-FORSKNINGSNYTT",			"????")
    set_CODEN("j-FORTEC-FORUM",				"????")
    set_CODEN("j-FORTH-APPL-RES",			"????")
    set_CODEN("j-FORTH-DIMENSIONS",			"FODMD5")
    set_CODEN("j-FORTRAN-FORUM",			"????")
    set_CODEN("j-FORTRAN-J",				"????")
    set_CODEN("j-FORTSCHR-PHYS",			"FPYKA6")
    set_CODEN("j-FORTUNE",				"FORTAP")
    set_CODEN("j-FORUM-MATH",				"FOMAEF")
    set_CODEN("j-FOUND-CHEM",				"FOCHFL")
    set_CODEN("j-FOUND-COMPUT-MATH",			"")
    set_CODEN("j-FOUND-PHYS",				"FNDPA4")
    set_CODEN("j-FOUND-PHYS-LETT",			"FPLEET")
    set_CODEN("j-FOUND-SCI",				"FOSCFI")
    set_CODEN("j-FOURIER-ANAL-APPL",			"????")
    set_CODEN("j-FRACTALS",				"FRACEG")
    set_CODEN("j-FREE-INQUIRY",				"FRINFM")
    set_CODEN("j-FRONTIERS-EDU-CONF",			"PFECDR")
    set_CODEN("j-FRONTIERS-MAR-SCI",			"????")
    set_CODEN("j-FRONTIERS-MASS-PAR-COMP-CONF-PROC",	"????")
    set_CODEN("j-FSTTCS",				"????")
    set_CODEN("j-FUJITSU",				"FUJTAR")
    set_CODEN("j-FUJITSU-SCI-TECH-J",			"FUSTA4")
    set_CODEN("j-FUNCT-ANAL-APPL",			"FAAPBZ")
    set_CODEN("j-FUNCT-ECOL",				"FECOE5")
    set_CODEN("j-FUNCT-SPACES",				"????")
    set_CODEN("j-FUND-INFO",				"FUMAAJ")
    set_CODEN("j-FUND-SCI",				"FUSCDO")
    set_CODEN("j-FUNDAM-MATH",				"????")
    set_CODEN("j-FUNKCIAL-EKVAC",			"FESIAT")
    set_CODEN("j-FUNKT-BIOL-MED",			"FBMED3")
    set_CODEN("j-FUSION-SCI-TECHNOL",			"FSTUCY")
    set_CODEN("j-FUSION-TECHNOL",			"FUSTE8")
    set_CODEN("j-FUT-GEN-COMP-SYS",			"FGSEVI")
    set_CODEN("j-FUTURE-INTERNET",			"????")
    set_CODEN("j-FUTURES",				"FUTUBD")
    set_CODEN("j-FUZZY-SETS-SYSTEMS",			"FSSYD8")
    set_CODEN("j-G-FIS",				"GFSIAD")
    set_CODEN("j-GAKUJUTSU-GEPPO",			"")
    set_CODEN("j-GAMES",				"????")
    set_CODEN("j-GAMM-MIT",				"????")
    set_CODEN("j-GAZ-MATH",				"")
    set_CODEN("j-GEN",					"GENTAE")
    set_CODEN("j-GEN-RELATIVITY-GRAV",			"GRGVA8")
    set_CODEN("j-GENE",					"GENED6")
    set_CODEN("j-GENERAL-SUBJ",				"????")
    set_CODEN("j-GENES-DEVEL",				"GEDEEP")
    set_CODEN("j-GENIE-LOGICIEL-SYS-EXPERTS",		"GLSEED")
    set_CODEN("j-GENOME-BIOL",				"????")
    set_CODEN("j-GENOME-RES",				"GEREFS")
    set_CODEN("j-GENOMICS",				"GNMCEP")
    set_CODEN("j-GENUS",				"GNUSA7")
    set_CODEN("j-GEOBYTE",				"????")
    set_CODEN("j-GEODERMA",				"GEDMAB")
    set_CODEN("j-GEOGR-J",				"GGJOAR")
    set_CODEN("j-GEOPHYS-J-INT",			"GJINEA")
    set_CODEN("j-GEOPHYS-J-R-ASTRON-SOC",		"GEOJAN")
    set_CODEN("j-GEOPHYS-MONOGR",			"GPMGAD")
    set_CODEN("j-GEOPHYS-RES-LETT",			"GPRLAJ")
    set_CODEN("j-GEOPHYSICS",				"GPYSA7")
    set_CODEN("j-GEOSCI-MODEL-DEV",			"????")
    set_CODEN("j-GER-ECON-REV",				"????")
    set_CODEN("j-GER-STUD-REV",				"GSREFO")
    set_CODEN("j-GERMAN-RES-REP-DFG",			"")
    set_CODEN("j-GLASG-MATH-J",				"????")
    set_CODEN("j-GLIA",                                 "GLIAEJ")
    set_CODEN("j-GLOB-ECOL-BIOGEOGRAPHY",		"GEBIFS")
    set_CODEN("j-GLOB-FINANCE-J",			"????")
    set_CODEN("j-GLYCOBIOLOGY",				"GLYCE3")
    set_CODEN("j-GOV-COMP-NEWS",			"????")
    set_CODEN("j-GRAPH-MODELS-IMAGE-PROC",              "GMIPF4")
    set_CODEN("j-GRAPH-MODELS",				"GRMOFM")
    set_CODEN("j-GRAPHIC-ARTS-MONTHLY",			"GAMOE4")
    set_CODEN("j-GROUND-WATER",				"GRWAAP")
    set_CODEN("j-GROUPS-COMPLEX-CRYPTOL",		"????")
    set_CODEN("j-GSA-TODAY",				"????")
    set_CODEN("j-GUARDIAN",				"????")
    set_CODEN("j-GUTENBERG",				"????")
    set_CODEN("j-HADRONIC-J",				"HAJODX")
    set_CODEN("j-HAEMATOLOGICA",			"HAEMAX")
    set_CODEN("j-HARPERS-MAG",				"HAMAA3")
    set_CODEN("j-HARVARD-BUS-REV",			"HABRAX")
    set_CODEN("j-HARVARD-EDUC-REV",			"HVERAP")
    set_CODEN("j-HARVARD-INT-REV",			"????")
    set_CODEN("j-HARVARD-LAW-REV",			"HALRAF")
    set_CODEN("j-HARVARD-REV",				"????")
    set_CODEN("j-HARVEY-LECTURES",			"HALEAA")
    set_CODEN("j-HEALTH-PHYSICS",			"HLTPAO")
    set_CODEN("j-HEBREW-LINGUISTICS",			"HELIEK")
    set_CODEN("j-HELV-CHIM-ACTA",			"HCACAV")
    set_CODEN("j-HELV-PHYS-ACTA",			"HPACAK")
    set_CODEN("j-HEREDITY",				"HDTYAT")
    set_CODEN("j-HERMIS",				"")
    set_CODEN("j-HEWLETT-PACKARD-J",			"HPJOAX")
    set_CODEN("j-HEXAGON",				"????")
    set_CODEN("j-HEYTHROP-J",				"????")
    set_CODEN("j-HIGH-PERFORM-SYST",			"HPSYEA")
    set_CODEN("j-HIGH-PRESSURE-RES",			"HPRSEL")
    set_CODEN("j-HIGH-TECH-LETT",			"GTONE8")

    # [11-Feb-1999] j-HIGHER-ORDER-SYMBOLIC-COMP continues
    # j-LISP-SYMB-COMPUT but (for now) has same CODEN, but different
    # ISSN
    set_CODEN("j-HIGHER-ORDER-SYMB-COMPUT",		"LSCOEX", 1)

    set_CODEN("j-HIST-GEO-SPACE-SCI",			"????")
    set_CODEN("j-HIST-MATH",				"HIMADS")
    set_CODEN("j-HIST-PHILOS-LOGIC",			"????")
    set_CODEN("j-HIST-REC-AUSTRAL-SCI",			"HRASEI")
    set_CODEN("j-HIST-SCI",				"HISCDU")
    set_CODEN("j-HIST-SCI-2",				"HISCDU")
    set_CODEN("j-HIST-SCI-UK",				"HISCAR")
    set_CODEN("j-HIST-STUD-NAT-SCI",			"????")
    set_CODEN("j-HIST-STUD-PHYS-BIOL-SCI",		"HSPSEW")
    set_CODEN("j-HIST-STUD-PHYS-SCI",			"HSPSAS")
    set_CODEN("j-HIST-TEACH",				"????")
    set_CODEN("j-HIST-TECHNOL",				"HITEE8")
    set_CODEN("j-HISTOCHEMISTRY",			"HCMYAL")
    set_CODEN("j-HISTORIAN",				"????")
    set_CODEN("j-HOCHFREQUENZTECH-ELEKTROAKUST",	"HOELAQ")
    set_CODEN("j-HOKKAIDO-MATH-J",			"HMAJDN")
    set_CODEN("j-HOME-OFF-COMPUT",                      "HOCOBQ")
    set_CODEN("j-HONEYWELL-COMP-J",			"HNCJA3")
    set_CODEN("j-HOOVER-DIG",				"????")
    set_CODEN("j-HORM-METAB-RES-SUPPL",			"HMRSAU")
    set_CODEN("j-HOUSTON-J-MATH",			""HJMADZ)
    set_CODEN("j-HP-CHRONICLE",				"????")
    set_CODEN("j-HP-PROF",				"????")
    set_CODEN("j-HUM-BIOL",				"HUBIAA")
    set_CODEN("j-HUM-FACTORS",				"HUFAA6")
    set_CODEN("j-HUM-NEUROBIOL",			"HUNEDR")
    set_CODEN("j-HUMAN-HEREDITY",			"HUHEAS")
    set_CODEN("j-HUNG-J-INDUSTRIAL-CHEM",		"HJICAI")
    set_CODEN("j-HYDROBIOLOGIA",			"HYDRB8")
    set_CODEN("j-HYDROCARBON-PROC-INT",			"IHPRBS")
    set_CODEN("j-HYDROCARBON-PROC-US",			"HYPRAX")
    set_CODEN("j-HYDROMETALLURGY",			"HYDRDA")
    set_CODEN("j-HYPERMEDIA",				"HYPEEW")
    set_CODEN("j-I-CHUAN-HSUEH-PAO",			"ICHPCG")
    set_CODEN("j-I-S-ANALYZER",				"ISANEL")
    set_CODEN("j-IAEA-BULL",				"IAEBAB")
    set_CODEN("j-IBM-JRD",				"IBMJAE")
    set_CODEN("j-IBM-SYS-J",				"IBMSA7")
    set_CODEN("j-IBM-TDB",				"IBMTAA")
    set_CODEN("j-ICARUS-IJSSS",				"ICRSA5")
    set_CODEN("j-ICC-BULL",				"ICCBAF")
    set_CODEN("j-ICES-J-MAR-SCI",			"ICESEC")
    set_CODEN("j-IECON-PROC-IND-ELEC-CONF",		"IEPREA")
    set_CODEN("j-IEE-CONF-PUBL",			"IECPB4")
    set_CODEN("j-IEE-PROC",				"????")
    set_CODEN("j-IEE-PROC-A",				"IPPRDI")
    set_CODEN("j-IEE-PROC-B",				"IPPADZ")
    set_CODEN("j-IEE-PROC-C",				"IPPDDA")
    set_CODEN("j-IEE-PROC-D",				"IPDAD9")
    set_CODEN("j-IEE-PROC-E",				"IPETD3")
    set_CODEN("j-IEE-PROC-COMPUT-DIGIT-TECH",		"ICDTEA")
    set_CODEN("j-IEE-PROC-VIS-IMAGE-SIGNAL-PROCESS",	"IVIPEK")
    set_CODEN("j-IEE-REV",				"IEREEF")
    set_CODEN("j-IEEE-ACCESS",				"????")
    set_CODEN("j-IEEE-ACM-TASLP",			"????")
    set_CODEN("j-IEEE-ANN-HIST-COMPUT",			"IAHCEX")
    set_CODEN("j-IEEE-ANTENNAS-WIREL-PROPAG-LETT",	"IAWPA7")
    set_CODEN("j-IEEE-APM",				"IAPMEZ")
    set_CODEN("j-IEEE-ASIA-PACIFIC-CONF-CIRCUITS-SYS-PROC","????")
    set_CODEN("j-IEEE-ASSP-MAG",			"????")
    set_CODEN("j-IEEE-CAP",				"ICAPEH")
    set_CODEN("j-IEEE-CGA",				"ICGADZ")
    set_CODEN("j-IEEE-COMM-MAG",			"ICOMD9")
    set_CODEN("j-IEEE-COMMUN-LET",			"ICLEF6")
    set_CODEN("j-IEEE-COMPUT-ARCHIT-LETT",		"????")
    set_CODEN("j-IEEE-COMPUT-SCI-ENG",			"ISCEE4")
    set_CODEN("j-IEEE-CONCURR",				"IECMFX")
    set_CODEN("j-IEEE-CONTROL-SYST-MAG",		"ISMAD7")
    set_CODEN("j-IEEE-CONF-CONTROL-APPL",		"ICOAE8")
    set_CODEN("j-IEEE-DES-TEST-COMPUT",			"????")
    set_CODEN("j-IEEE-DISTRIB-SYST-ONLINE",		"????")
    set_CODEN("j-IEEE-ENG-MED-BIOL-MAG",		"IEMBDE")
    set_CODEN("j-IEEE-EXPERT",				"IEEXE7")
    set_CODEN("j-IEEE-INT-CONF-ALG-ARCH-PAR-PROC",	"????")
    set_CODEN("j-IEEE-INT-PROFL-COMM-CONF",		"????")
    set_CODEN("j-IEEE-INT-SYMP-HIGH-PERF-DIST-COMP-PROC","PIDCFB")
    set_CODEN("j-IEEE-INT-SYMP-INF-THEORY",		"PISTFZ")
    set_CODEN("j-IEEE-INTELL-SYST",			"????")
    set_CODEN("j-IEEE-INTERNET-COMPUT",			"IICOFX")
    set_CODEN("j-IEEE-J-QUANT-ELECT",			"IEJQA7")
    set_CODEN("j-IEEE-J-ROBOTICS-AUTOMATION",		"IJRAE4")

    # [27-Dec-1998] NB: Formerly j-IEEE-J-SAC
    set_CODEN("j-IEEE-J-SEL-AREAS-COMMUN",		"ISACEM")

    # [27-Dec-1998] NB: Formerly j-IEEE-J-SSC
    set_CODEN("j-IEEE-J-SOLID-STATE-CIRCUITS",		"IJSCBC")

    set_CODEN("j-IEEE-LTS",				"IELTEU")
    set_CODEN("j-IEEE-MICRO",				"IEMIDZ")
    set_CODEN("j-IEEE-MICROW-GUIDED-WAVE-LETT",		"IMGLE3")
    set_CODEN("j-IEEE-MICROW-WIREL-COMPON-LETT",	"")
    set_CODEN("j-IEEE-MULTIMEDIA",			"IEMUE4")
    set_CODEN("j-IEEE-NETWORK",				"IENEET")
    set_CODEN("j-IEEE-PACIFIC-RIM-CONF-COMM-COMPUT-SIGNAL-PROC-PROC","????")
    set_CODEN("j-IEEE-PAR-DIST-TECH",			"IPDTEX")
    set_CODEN("j-IEEE-POT",				"IEPTDF")
    set_CODEN("j-IEEE-PHOTONICS-TECHNOL-LETT",		"????")
    set_CODEN("j-IEEE-ROBOTICS-AUTOMATION-MAG",		"IRAMEB")
    set_CODEN("j-IEEE-SEC-PRIV",			"????")
    set_CODEN("j-IEEE-SIGNAL-PROCESS-LETT",		"ISPLEM")
    set_CODEN("j-IEEE-SIGNAL-PROCESS-MAG",		"ISPRE6")
    set_CODEN("j-IEEE-SOFTWARE",			"IESOEG")
    set_CODEN("j-IEEE-SPECTRUM",			"IEESAM")
    set_CODEN("j-IEEE-SPEECH-SIGNAL-PROC",		"????")
    set_CODEN("j-IEEE-SYMP-PAR-DIST-PROC-PROC",		"PSPDF8")
    set_CODEN("j-IEEE-TECHNOL-SOC-MAG",			"ITSMDC")
    set_CODEN("j-IEEE-TRANS-ACOUST-SPEECH",		"IETABA")
    set_CODEN("j-IEEE-TRANS-AEROSP-ELECTRON-SYST",	"IEARAX")
    set_CODEN("j-IEEE-TRANS-ANTENNAS-PROPAG",		"IETPAK")
    set_CODEN("j-IEEE-TRANS-APPL-SUPERCOND",		"ITASE9")
    set_CODEN("j-IEEE-TRANS-AUDIO-ELECTROACOUST",	"ITADAS")
    set_CODEN("j-IEEE-TRANS-AUTOMAT-CONTR",		"IETAA9")
    set_CODEN("j-IEEE-TRANS-BIG-DATA",			"????")
    set_CODEN("j-IEEE-TRANS-BIOMED-ENG",		"IEBEAX")
    set_CODEN("j-IEEE-TRANS-BROADCAST",			"IETBAC")
    set_CODEN("j-IEEE-TRANS-CAD-ICS",			"ITCSDI")
    set_CODEN("j-IEEE-TRANS-CIRCUIT-THEORY",		"IECTAF")
    set_CODEN("j-IEEE-TRANS-CIRCUITS-SYST",		"ICSYBT")
    set_CODEN("j-IEEE-TRANS-CIRCUITS-SYST-1",		"????")
    set_CODEN("j-IEEE-TRANS-CIRCUITS-SYST-2",		"ICSPE5")
    set_CODEN("j-IEEE-TRANS-CIRCUITS-SYST-I-FUNDAM-THEORY-APPL", "ITCAEX")
    set_CODEN("j-IEEE-TRANS-CIRCUITS-SYST-II-EXPRESS-BRIEFS", "????")
    set_CODEN("j-IEEE-TRANS-CIRCUITS-SYST-VIDEO-TECH",	"ITCTEM")
    set_CODEN("j-IEEE-TRANS-COMM",			"IECMBT")
    set_CODEN("j-IEEE-TRANS-COMMUN-TECHNOL",		"????")
    set_CODEN("j-IEEE-TRANS-COMPUT",			"ITCOB4")
    set_CODEN("j-IEEE-TRANS-COMPONENTS-HYBRIDS-MANUF-TECHNOL",	"ITTEDR")
    set_CODEN("j-IEEE-TRANS-COMPONENTS-PACK-MANUF-TECHNOL-A",	"IMTAEZ")
    set_CODEN("j-IEEE-TRANS-CONSUMER-ELECTRONICS",	"ITCEDA")
    set_CODEN("j-IEEE-TRANS-CONTROL-SYST-TECHNOL",	"IETTE2")
    set_CODEN("j-IEEE-TRANS-EDUC",			"IEEDAB")
    set_CODEN("j-IEEE-TRANS-ELEC-COMP",			"IEECA8")
    set_CODEN("j-IEEE-TRANS-ELEC-INSUL",		"IETIAX")
    set_CODEN("j-IEEE-TRANS-ELECTROMAGN-COMPAT",	"IEMCAE")
    set_CODEN("j-IEEE-TRANS-ELECTRON-DEVICES",		"IETDAI")
    set_CODEN("j-IEEE-TRANS-EMERG-TOP-COMPUT",		"????")
    set_CODEN("j-IEEE-TRANS-ENG-WRIT-SPEECH",		"IEEWAY")
    set_CODEN("j-IEEE-TRANS-FUZZY-SYSTEMS",		"IEFSEV")
    set_CODEN("j-IEEE-TRANS-GEOSCI-REMOTE-SENSING",	"IGRSD2")
    set_CODEN("j-IEEE-TRANS-IMAGE-PROCESS",		"IIPRE4")
    set_CODEN("j-IEEE-TRANS-IND-ELECTRON",		"ITIED6")
    set_CODEN("j-IEEE-TRANS-INF-FOREN-SEC",		"????")
    set_CODEN("j-IEEE-TRANS-INF-THEORY",		"IETTAW")
    set_CODEN("j-IEEE-TRANS-INSTRUM-MEAS",		"IEIMAO")
    set_CODEN("j-IEEE-TRANS-KNOWL-DATA-ENG",		"ITKEEH")
    set_CODEN("j-IEEE-TRANS-MAGNETICS",			"IEMGAQ")
    set_CODEN("j-IEEE-TRANS-MED-IMAG",			"ITMID4")
    set_CODEN("j-IEEE-TRANS-MICROWAVE-THEORY-TECH",	"IETMAB")
    set_CODEN("j-IEEE-TRANS-NETWORKING",		"IEANEP")
    set_CODEN("j-IEEE-TRANS-NEURAL-NETW",		"ITNNEP")
    set_CODEN("j-IEEE-TRANS-NUCL-SCI",			"IRNSAM")
    set_CODEN("j-IEEE-TRANS-PAR-DIST-SYS",		"ITDSEO")
    set_CODEN("j-IEEE-TRANS-PATT-ANAL-MACH-INTEL",	"ITPIDJ")
    set_CODEN("j-IEEE-TRANS-POWER-DELIV",		"ITPDE5")
    set_CODEN("j-IEEE-TRANS-POWER-SYSTEMS",		"ITPSEG")
    set_CODEN("j-IEEE-TRANS-PROF-COMMUN",		"IEPCBU")
    set_CODEN("j-IEEE-TRANS-PLASMA-SCI",		"ITPSBD")
    set_CODEN("j-IEEE-TRANS-REHABIL-ENG",		"IEEREN")
    set_CODEN("j-IEEE-TRANS-RELIAB",			"IEERAJ")
    set_CODEN("j-IEEE-TRANS-ROBOT",			"ITREAE")
    set_CODEN("j-IEEE-TRANS-ROBOT-AUTOM",		"IRAUEZ")
    set_CODEN("j-IEEE-TRANS-SIG-PROC",			"ITPRED")
    set_CODEN("j-IEEE-TRANS-SOFTW-ENG",			"IESEDJ")
    set_CODEN("j-IEEE-TRANS-SYST-MAN-CYBERN",		"ISYMAW")
    set_CODEN("j-IEEE-TRANS-VEH-TECHNOL",		"ITUTAB")
    set_CODEN("j-IEEE-TRANS-VIS-COMPUT-GRAPH",		"ITVGEA")
    set_CODEN("j-IEEE-TRANS-VLSI-SYST",			"IEVSE9")
    set_CODEN("j-IEEE-TRANS-WIREL-COMMUN",		"ITWCAX")
    set_CODEN("j-IEICE-TCEIS",				"IEITEF")
    set_CODEN("j-IEICE-TRANS-COMMUN",			"ITCMEZ")
    set_CODEN("j-IEICE-TRANS-ELECT",			"IELEEJ")
    set_CODEN("j-IEICE-TRANS-FUND-ELECT",		"IFESEX")
    set_CODEN("j-IETE-TECH-REV",			"ITREEI")
    set_CODEN("j-IFIP-TRANS-A",				"ITATEC")
    set_CODEN("j-IFIP-TRANS-B",				"ITBTEH")
    set_CODEN("j-IFLA-J",				"????")
    set_CODEN("j-IIE-TRANS",				"IIETDM")
    set_CODEN("j-IJCSS",				"????")
    set_CODEN("j-IJQC",					"IJQCB2")
    set_CODEN("j-IJQC-BIO-SYMP",			"IJQBDZ")
    set_CODEN("j-IJQC-QC-SYMP",				"IJQSDI")
    set_CODEN("j-IJQC-SYMP",				"IJQSAF")
    set_CODEN("j-IJSA",					"IJSAE9")
    set_CODEN("j-IJSAHPC",				"IJSCFG")
    set_CODEN("j-ILL-J-MATH",				"IJMTAW")
    set_CODEN("j-IM-INFORMATION-MANAGEMENT",		"")
    set_CODEN("j-IMA-BULL",				"????")
    set_CODEN("j-IMA-J-APPL-MATH",			"IJAMDM")
    set_CODEN("j-IMA-J-MATH-CONTROL-INF",		"IJMIE3")
    set_CODEN("j-IMA-J-MATH-APPL-MED-BIOL",             "IJMBEG")
    set_CODEN("j-IMA-J-NUMER-ANAL",			"IJNADH")
    set_CODEN("j-IMA-NUM-ANA-NEWSLETTER",		"????")
    set_CODEN("j-IMAGE-VIDEO-PROCESS",			"????")
    set_CODEN("j-IMAGE-VIS-COMPUT",			"IVCODK")
    set_CODEN("j-IMAGING-MAGAZINE",                     "IMNYE9")
    set_CODEN("j-IMMUNOL-HEMATOL-RES-MONOGR",		"IHRMEQ")
    set_CODEN("j-IMP-COMP-SCI-ENG",			"ICOEEK")
    set_CODEN("j-IMS-BULL",				"????")
    set_CODEN("j-IMWUT",				"????")
    set_CODEN("j-IN-PLANT-REPROD",			"????")
    set_CODEN("j-IN-VITRO-CEL-DEV-BIO-ANIM",		"IVCAED")
    set_CODEN("j-INC",                                  "INCCDU")
    set_CODEN("j-INCIDER",				"INCIDE")
    set_CODEN("j-INCIDER-A",				"????")
    set_CODEN("j-IND-ENG-CHEM-RES",			"IECRED")
    set_CODEN("j-IND-MATH",				"IMTHAI")
    set_CODEN("j-IND-WEEK",				"IWEEA4")
    set_CODEN("j-INDAG-MATH",				"IMTHBJ")
    set_CODEN("j-INDAG-MATH-PROC",			"????")
    set_CODEN("j-INDEXER",				"IDXRA5")
    set_CODEN("j-INDIAN-J-BIOCHEM-BIOPHYS",		"IJBBBQ")
    set_CODEN("j-INDIAN-J-EXP-BIO",			"IJEBA6")
    set_CODEN("j-INDIAN-J-HIST-SCI",			"IJHSA4")
    set_CODEN("j-INDIAN-J-MATH",			"IJOMAL")
    set_CODEN("j-INDIANA-U-MATH",			"IUMJAB")
    set_CODEN("j-INF-COMM-TECH-LAW",			"")
    set_CODEN("j-INF-COMPUT",				"INFCEC")
    set_CODEN("j-INF-CONTROL",				"IFCNA4")
    set_CODEN("j-INF-INTELL-ONLINE-LIB-MICROCOMPUT",	"IIOMEI")
    set_CODEN("j-INF-INTELL-ONLINE-NEWSL",		"IIONDK")
    set_CODEN("j-INF-PROC",				"????")
    set_CODEN("j-INF-PROCESS-MACH",			"IPRMDD")
    set_CODEN("j-INF-RETR",				"IFRTFY")
    set_CODEN("j-INF-SOC",				"INSCD8")
    set_CODEN("j-INF-STAND-Q",				"ISQUEK")
    set_CODEN("j-INF-STORAGE-RETR",			"IFSRAS")
    set_CODEN("j-INF-TECH-RES-DEV-APPL",		"ITRDDE")
    set_CODEN("j-INFECT-IMMUN",				"INFIBR")
    set_CODEN("j-INFO-CANADA",				"IFCAE3")

    # Replaced by j-INF-COMPUT
    # set_CODEN("j-INFO-COMP",				"INFCEC")

    set_CODEN("j-INFO-DB",				"IFDBEB")
    set_CODEN("j-INFO-DECISION-TECHNOLOGIES",		"IDTEEI")
    set_CODEN("j-INFO-FERNSPRECH-VERMITT",		"????")
    set_CODEN("j-INFO-MANAGEMENT-COMP-SECURITY",	"IMCSE4")
    set_CODEN("j-INFO-MANAGEMENT-TECH",			"IMTHEM")
    set_CODEN("j-INFO-PROC-LETT",			"IFPLAT")
    set_CODEN("j-INFO-PROC-MAN",			"IPMADK")
    set_CODEN("j-INFO-RETRIEVAL-LIB-AUTO",		"IRLAAQ")
    set_CODEN("j-INFO-SCI",				"ISIJBC")
    set_CODEN("j-INFO-SEC-TECH-REP",			"ISTRFR")
    set_CODEN("j-INFO-SERVICES-USE",			"ISUDX8")
    set_CODEN("j-INFO-SOFTWARE-TECH",			"ISOTE7")
    set_CODEN("j-INFO-SYS",				"INSYD6")
    set_CODEN("j-INFO-SYST-J",				"????")
    set_CODEN("j-INFO-TECH-HUMAN",			"????")
    set_CODEN("j-INFO-TECH-LIB",			"ITLBDC")
    set_CODEN("j-INFO-TECH-NURSING",			"????")
    set_CODEN("j-INFOR",				"INFRCL")
    set_CODEN("j-INFORM-DIR",				"????")
    set_CODEN("j-INFORM-THEOR-APPL",			"RSITD7, RITAE4")
    set_CODEN("j-INFORMACNE-SYSTEMY",			"ISYSDJ")
    set_CODEN("j-INFORMATICA",				"INFOFF")
    set_CODEN("j-INFORMATIE",				"INFTCR")
    set_CODEN("j-INFORMATIK-FACHBERICHTE",		"????")
    set_CODEN("j-INFORMATIK-INFORMATIONEN-REPORTE",	"")
    set_CODEN("j-INFORMATIK-SPEKTRUM",			"INSKDW")
    set_CODEN("j-INFORMATION-WEEK",			"INFWE4")
    set_CODEN("j-INFORMATIONS-TECHNIK",			"ICSAES")
    set_CODEN("j-INFORMS-J-COMPUT",			"????")
    set_CODEN("j-INFOWORLD",				"INWODU")
    set_CODEN("j-INSECT-BIOCHEM-MOL-BIOL",		"IBMBES")
    set_CODEN("j-INST-PHYS-CONF-SER",			"IPHSAC")
    set_CODEN("j-INSTANT-SMALL-COMMERCIAL-PRINTER",	"????")
    set_CODEN("j-INSTRUCTOR",				"????")

    ## NB: j-INSTRUM-CONTROL-SYST is different from
    ## Instruments and Control Systems (INCSA7, 0020-4404)
    set_CODEN("j-INSTRUM-CONTROL-SYST",			"ICSYFX")

    set_CODEN("j-INSUR-MATH-ECON",			"IMECDX")
    set_CODEN("j-INT-AFF",				"????")
    set_CODEN("j-INT-AQUAT-RES",			"????")
    set_CODEN("j-INT-COMMUN-HEAT-MASS-TRANSF",		"IHMTDL")
    set_CODEN("j-INT-ECON-REV",				"INERAE")
    set_CODEN("j-INT-EQN-OP-TH",			"????")
    set_CODEN("j-INT-GEOSCIENCE-REMOTE-SENSING-SYMPOSIUM","IGRSE3")
    set_CODEN("j-INT-INFO-COMM-EDU",			"IICEE2")
    set_CODEN("j-INT-J-ACCOUNT-INFO-SYS",		"IJAIA7")
    set_CODEN("j-INT-J-AMBIENT-ENERGY",			"IJAEDW")
    set_CODEN("j-INT-J-ANDROL",				"IJANDP")
    set_CODEN("j-INT-J-APPL-CRYPTOGR",			"????")
    set_CODEN("j-INT-J-APPL-ELECTROMAGN-MATER",		"IJAMFO")
    set_CODEN("j-INT-J-APPL-MATH",			"????")
    set_CODEN("j-INT-J-APPL-MATH-STAT",			"????")
    set_CODEN("j-INT-J-APPROX-REASONING",		"IJARE4")
    set_CODEN("j-INT-J-ASTROBIOL",			"IJANFR")
    set_CODEN("j-INT-J-BIFURC-CHAOS-APPL-SCI-ENG",	"IJBEE4")
    set_CODEN("j-INT-J-BIOCHEM",			"IJBOBV")
    set_CODEN("j-INT-J-BIOCHEM-CELL-BIOL",		"IJBBFU")
    set_CODEN("j-INT-J-BIOMED-COMPUT",			"IJBCBT")
    set_CODEN("j-INT-J-CIRCUIT-THEORY-APPL",		"ICTACV")
    set_CODEN("j-INT-J-COMP-APPL-TECH",			"IJCTEK")
    set_CODEN("j-INT-J-COMP-INTEG-MANUFACTURING",	"ICIMEE")
    set_CODEN("j-INT-J-COMP-PROC-LANG",			"")
    set_CODEN("j-INT-J-COMP-PROC-ORIENTAL-LANG",	"")
    set_CODEN("j-INT-J-COMP-RESEARCH",			"")
    # [03-Feb-1999] Renamed from old j-INT-J-COMP-SYS-SCI-ENG to
    # j-INT-J-COMPUT-SYST-SCI-ENG to match journal name abbreviation.
    set_CODEN("j-INT-J-COMP-SYS-SCI-ENG",		"CSSEEI", 1)
    set_CODEN("j-INT-J-COMP-VISION",			"IJCVEQ")
    set_CODEN("j-INT-J-COMPUT-APPL",			"IJCAFW")
    set_CODEN("j-INT-J-COMPUT-ENG-SCI",			"????")
    set_CODEN("j-INT-J-COMPUT-FLUID-DYN",		"IJCFEC")
    set_CODEN("j-INT-J-COMPUT-INF-SCI",			"IJCIAH")
    set_CODEN("j-INT-J-COMPUT-GEOM-APPL",		"IJCAEV")
    set_CODEN("j-INT-J-COMPUT-MATH",			"IJCMAT")
    set_CODEN("j-INT-J-COMPUT-METHODS-ENG-SCI-MECH",	"IJCMCV")
    set_CODEN("j-INT-J-CONTROL",			"IJCOAZ")
    set_CODEN("j-INT-J-DAMAGE-MECH",			"IDMEEH")
    set_CODEN("j-INT-J-DEV-BIOL",			"IJDBE5")
    set_CODEN("j-INT-J-EEE",				"IJEEAF")
    set_CODEN("j-INT-J-ELECTRON",			"IJELA2")
    set_CODEN("j-INT-J-ENERGY-RES",			"IJERDN")
    set_CODEN("j-INT-J-ENG-EDUC",			"IEEDEF")
    set_CODEN("j-INT-J-ENG-SCI",			"IJESAN")
    set_CODEN("j-INT-J-EPIDEMIOL",			"IJEPBF")
    set_CODEN("j-INT-J-FOUND-COMP-SCI",			"IFCSEN")
    set_CODEN("j-INT-J-FRACTURE",			"IJFRAP")
    set_CODEN("j-INT-J-GEN-SYST",			"IJGSAX")
    set_CODEN("j-INT-J-HEALTH-SERV",			"IJUSC3")
    set_CODEN("j-INT-J-HEAT-MASS-TRANSFER",		"IJHMAK")
    set_CODEN("j-INT-J-HIGH-SPEED-COMPUTING",		"IHSCEZ")
    set_CODEN("j-INT-J-HOSP-MANAGEMENT",		"IJHMDN")
    set_CODEN("j-INT-J-HYPERTHERMIA",			"IJHYEQ")
    set_CODEN("j-INT-J-IMAGE-GRAPHICS",			"")
    set_CODEN("j-INT-J-INFO-SEC",			"????")
    set_CODEN("j-INT-J-INFO-TECH",                      "")
    set_CODEN("j-INT-J-INTELL-SYSTEMS",			"IJISED")
    set_CODEN("j-INT-J-MAN-MACHINE-STUDIES",		"IJMMBC")
    set_CODEN("j-INT-J-MANAGEMENT-SYS",			"????")
    set_CODEN("j-INT-J-MASS-SPECT-ION-PROC",		"IJMPDN")
    set_CODEN("j-INT-J-MATH",				"")
    set_CODEN("j-INT-J-MATH-COMP-MODELLING",		"????")
    set_CODEN("j-INT-J-MATH-EDU-SCI-TECH",		"IJMEBM")
    set_CODEN("j-INT-J-MATH-MATH-SCI",			"????")
    set_CODEN("j-INT-J-MECH-ENG-EDU",			"IMEEB3")
    set_CODEN("j-INT-J-MECH-SCI",			"IMSCAW")
    set_CODEN("j-INT-J-MINI-MICROCOMPUTERS",		"IJMMDE")
    set_CODEN("j-INT-J-MOD-PHYS-A",			"IMPAEF")
    set_CODEN("j-INT-J-MOD-PHYS-B",			"IJPBEV")
    set_CODEN("j-INT-J-MOD-PHYS-C",			"IJMPEO")
    set_CODEN("j-INT-J-MOD-PHYS-D",			"IMPDEO")
    set_CODEN("j-INT-J-MOD-PHYS-E",			"IMPEER")
    set_CODEN("j-INT-J-MODELLING-SIMUL",		"IMSIEK")
    set_CODEN("j-INT-J-NEURAL-SYST",			"IJSZEG")
    set_CODEN("j-INT-J-NUMBER-THEORY",			"????")
    set_CODEN("j-INT-J-NUMER-ANAL-METHODS-GEOMECH",	"IJNGDZ")
    set_CODEN("j-INT-J-NUMER-MODEL",			"IJNFEX")
    set_CODEN("j-INT-J-NUMER-METHODS-BIOMED-ENG",	"")
    set_CODEN("j-INT-J-NUMER-METHODS-ENG",		"IJNMBH")
    set_CODEN("j-INT-J-NUMER-METHODS-FLUIDS",		"IJNFDW")
    set_CODEN("j-INT-J-OPTOELECTRON",			"IJOOEV")
    set_CODEN("j-INT-J-PARALLEL-PROG",			"IJPPE5")
    set_CODEN("j-INT-J-PATTERN-RECOGNITION-ARTIFICIAL-INTELLIGENCE","IPJIEI")
    set_CODEN("j-INT-J-PLAST",				"IJPLER")
    set_CODEN("j-INT-J-PROD-ECON",			"JPCEYE")
    set_CODEN("j-INT-J-PSYCHOPHYSIOL",			"IJPSEE")
    set_CODEN("j-INT-J-PURE-APPL-MATH",			"")
    set_CODEN("j-INT-J-RADIAT-BIOL",			"IJRBE7")
    set_CODEN("j-INT-J-RADIAT-ONCOL-BIOL-PHYS",		"IOBPD3")
    set_CODEN("j-INT-J-RES-MARK",			"IJRME6")
    set_CODEN("j-INT-J-ROBOTICS-AUTOMATION",		"IJAUED")
    set_CODEN("j-INT-J-ROBOTICS-RES",			"IJRREL")
    set_CODEN("j-INT-J-ROCK-MECH-MINING-SCI-GEOMECH-ABS","IRMGBG")
    set_CODEN("j-INT-J-SATELL-COMMUN",			"IJSCEF")
    set_CODEN("j-INT-J-SCI-COMP-MOD",			"????")
    set_CODEN("j-INT-J-SCI-ENG-RESEARCH",		"????")
    set_CODEN("j-INT-J-SCI-MATH-EDUC",			"????")
    set_CODEN("j-INT-J-SOFTW-TOOLS-TECHNOL-TRANSFER",	"")
    set_CODEN("j-INT-J-SOLIDS-STRUCT",			"IJSOAD")
    set_CODEN("j-INT-J-STAT-PROBAB",			"????")
    set_CODEN("j-INT-J-SYST-SCI",			"IJSYA9")
    set_CODEN("j-INT-J-THEOR-PHYS",			"IJTPBM")
    set_CODEN("j-INT-J-THERMOPHYS",			"IJTHDY")
    set_CODEN("j-INT-J-TOMOGR-STAT",			"")
    set_CODEN("j-INT-J-UNITY-SCI",			"IJUSE5")
    set_CODEN("j-INT-J-WAVELETS-MULTIRESOLUT-INF-PROCESS", "????")
    set_CODEN("j-INT-PHILOS-Q",				"")
    set_CODEN("j-INT-PHOENIX-CONF-COMPUT-COMM",		"CIPCET")
    set_CODEN("j-INT-REV-CYTOLOGY",			"IRCYAJ")
    set_CODEN("j-INT-REV-PHYS",				"????")
    set_CODEN("j-INT-REV-VICTIM",			"IRVIE2")
    set_CODEN("j-INT-SCI-TECHNOL",			"ISCTAB")
    set_CODEN("j-INT-SECUR",				"????")
    set_CODEN("j-INT-SER-NUMER-MATH",			"????")
    set_CODEN("j-INT-STAT-REV",				"ISTRDP")
    set_CODEN("j-INT-STUD-PHILOS-SCI",			"????")
    set_CODEN("j-INT-SYMP-SYMB-COMPUT-ISSAS-PROC",	"????")
    set_CODEN("j-INT-TELEMETERING-CONFERENCE",		"ITCOD6")
    set_CODEN("j-INT-TRANS-OPL-RES",			"ITORF9")
    set_CODEN("j-INT-YEARBOOK-LAW-COMP-TECH",		"????")
    set_CODEN("j-INTEGERS",				"INTEHN")
    set_CODEN("j-INTEGRAL-TRANSFORMS-SPEC-FUNCT",	"????")
    set_CODEN("j-INTEGRATION-VLSI-J",			"IVJODL")
    set_CODEN("j-INTEGR-ENVIRON-ASSES-MANAG",		"????")
    set_CODEN("j-INTELL-INSTR-COMP",			"IICOEW")
    set_CODEN("j-INTELL-NATL-SECUR",			"")
    set_CODEN("j-INTELL-TUTORING-MEDIA",		"ITMEER")
    set_CODEN("j-INTERACTIONS",				"IERAE3")
    set_CODEN("j-INTERACTIVE-AGE",			"????")
    set_CODEN("j-INTERACTIVE-SYS-EXP-APPL-MATH",	"????")
    set_CODEN("j-INTERDISCIP-INFORM-SCI",		"????")
    set_CODEN("j-INTERFACE",				"IFCEBC")
    set_CODEN("j-INTERFACE-CHICAGO",			"????")
    set_CODEN("j-INTERFACE-GHENT",			"IFCEBC")
    set_CODEN("j-INTERFACE-SANTA-CRUZ",			"INFCDB")
    set_CODEN("j-INTERFACE-SCI",			"INSCE9")
    set_CODEN("j-INTERFACES",				"INFAC4")
    set_CODEN("j-INTERLEND-DOC-SUPPLY",			"IDSUDQ")
    set_CODEN("j-INTERNET-HIST",			"????")
    set_CODEN("j-INTERNET-J-CHEM",			"IJCHFJ")
    set_CODEN("j-INTERNET-MATH",			"????")
    set_CODEN("j-INTERNET-RES",				"IRESEF")
    set_CODEN("j-INTERNET-WORLD",			"IERNE8")
    set_CODEN("j-INTERNETWORK",				"????")
    set_CODEN("j-INTERNETWORKING",			"IREEE7")
    set_CODEN("j-INTERVAL-COMP",			"????")
    set_CODEN("j-INTRANET-NETWORKING-STRATEGIES-REP",   "")
    set_CODEN("j-INV-OP",				"????")
    set_CODEN("j-INVENT-MATH",				"INVMBH")
    set_CODEN("j-INVERSE-PROBLEMS",			"INPEEY")
    set_CODEN("j-INVERSE-PROBL-IMAGING",		"????")
    set_CODEN("j-INVERSE-PROBL-SCI-ENG",		"IPSECR")
    set_CODEN("j-IR-J-PSYCHOL-MED",			"????")
    set_CODEN("j-IRE-PROC",				"????")
    set_CODEN("j-IRE-TRANS-ELEC-COMPUT",		"IRELAO")
    set_CODEN("j-IRE-TRANS-ENG-WRIT-SPEECH",		"????")
    set_CODEN("j-IRE-TRANS-INF-THEORY",			"IRITAY")
    set_CODEN("j-IRISH-ASTRON-J",			"IRAJAW")
    set_CODEN("j-IRISH-COMP",                           "IRCODQ")
    set_CODEN("j-IRISH-MATH-SOC-BULL",			"????")
    set_CODEN("j-IRIS-UNIVERSE",			"????")
    set_CODEN("j-ISIS",					"ISISA4")
    set_CODEN("j-ISRAEL-J-CHEM",			"ISJCAT")
    set_CODEN("j-ISRAEL-J-MATH",			"ISJMAP")
    set_CODEN("j-ISRAEL-STUD",				"????")
    set_CODEN("j-ISSUES-SCI-TECHNOL",			"????")
    set_CODEN("j-IT-IT",				"ITINEY")
    set_CODEN("j-IT-MAGAZINE",				"ITMGEX")
    set_CODEN("j-IT-PRO",				"IPMAFM")
    set_CODEN("j-ITAL-J-PURE-APPL-MATH",		"????")
    set_CODEN("j-ITE-J",				"ITEJDZ")
    set_CODEN("j-ITNOW",				"????")
    set_CODEN("j-IZV-AKAD-ARM-SSR-MEH",			"IAMHAZ")
    set_CODEN("j-IZV-AKAD-NAUK-SSSR-MAT",		"IZAMAT")
    set_CODEN("j-IZV-AKAD-NAUK-SSSR-MEH-TVERD-TELA",	"IZMTB9")
    set_CODEN("j-IZV-SEKTS-ASTRON-BULG-AKAD-NAUK",	"IBASBG")
    set_CODEN("j-IZV-VYSS-UCEBN-ZAVED-MAT",		"IVUMBY")
    set_CODEN("j-J-ACCOUNT-EDUC",			"????")
    set_CODEN("j-J-ACCOUNTANCY",			"JACYAD")
    set_CODEN("j-J-ACM",				"JACOAH")
    set_CODEN("j-J-ACOUST-SOC-AM",			"JASMAN")
    set_CODEN("j-J-AERO-SPACE-SCI",			"????")
    set_CODEN("j-J-AEROSOL-SCI",			"JALSB7")
    set_CODEN("j-J-AGRIC-SCI",				"JASIAB")
    set_CODEN("j-J-ALG",				"JOALDV")
    set_CODEN("j-J-ALGEBRA",				"JALGA4")
    set_CODEN("j-J-ALGEBR-COMB",			"JAOME7")
    set_CODEN("j-J-ALGORITHMS-COMPUT-TECHNOL",		"")
    set_CODEN("j-J-AM-CERAM-SOC",			"JACTAW")
    set_CODEN("j-J-AM-COLL-CARDIOL",                    "JACCDI")
    set_CODEN("j-J-AM-HIST",				"????")
    set_CODEN("j-J-AM-MATH-SOC",			"????")
    set_CODEN("j-J-AM-MED-ASSOC",			"JAMAAP")
    set_CODEN("j-J-AM-SOC-INF-SCI",			"AISJB6")
    set_CODEN("j-J-AM-SOC-INF-SCI-TECHNOL",		"JASIEF")
    set_CODEN("j-J-AM-STAT-ASSOC",			"JSTNAL")
    set_CODEN("j-J-ANAL-MATH",				"JOAMAV")
    set_CODEN("j-J-ANIM-ECOL",				"JAECAP")
    set_CODEN("j-J-APPL-CRYSTAL",			"JACGAR")
    set_CODEN("j-J-APPL-ECOL",				"JAPEAI")
    set_CODEN("j-J-APPL-ECONOMETRICS",			"JAECET")
    set_CODEN("j-J-APPL-MATH",				"")
    set_CODEN("j-J-APPL-MATH-MECH",			"JAMMAR")
    set_CODEN("j-J-APPL-MATH-PHYS",			"ZAMPDB")
    set_CODEN("j-J-APPL-MECH",				"JAMCAV")
    set_CODEN("j-J-APPL-MECH-TECH-PHYS",		"JMPYAQ")
    set_CODEN("j-J-APPL-PHYS",				"JAPIAU")
    set_CODEN("j-J-APPL-PROBAB",			"JPRBAM")
    set_CODEN("j-J-APPL-PSYCHOL",			"JAPGBP")
    set_CODEN("j-J-APPL-STAT",				"????")
    set_CODEN("j-J-APPL-TOXIC",				"JJATDK")
    set_CODEN("j-J-APPROX-THEORY",			"JAXTAZ")
    set_CODEN("j-J-AQUACULT-RES-DEV",			"JARDCR")
    set_CODEN("j-J-ASSET-MANAGE",			"????")
    set_CODEN("j-J-ASSOC-INF-SCI-TECHNOL",		"????")
    set_CODEN("j-J-ASTRONAUTICAL-SCIENCES",		"JALSA6")
    set_CODEN("j-J-ASTROPHYS-ASTRON",			"JASRD7")
    set_CODEN("j-J-ATMOS-SCI",				"JATSDF, JAHSAK")
    set_CODEN("j-J-ATMOS-SOL-TERR-PHYS",		"JASPF3")
    set_CODEN("j-J-AUDIO-ENG-SOC",			"ADIOA3")
    set_CODEN("j-J-AUSTRAL-MATH-SOC-SER-A",		"JAMADS")
    set_CODEN("j-J-AUSTRAL-MATH-SOC-SER-B",		"JAMMDU")
    set_CODEN("j-J-AUSTRALIAN-MATH-SOC",		"JAUMAX")
    set_CODEN("j-J-AUTOM-REASON",			"JAREEW")
    set_CODEN("j-J-BACTERIOL",				"JOBAAY")
    set_CODEN("j-J-BIOCHEM",				"JOBIAO")
    set_CODEN("j-J-BIOCHEM-BIOPHYS-METH",		"JBBMDG")
    set_CODEN("j-J-BIOINF-COMPUT-BIOL",			"JBCBBK")
    set_CODEN("j-J-BIOL-CHEM",				"JBCHA3")
    set_CODEN("j-J-BIOL-RHYTHMS",			"JBRHEE")
    set_CODEN("j-J-BIOL-SYSTEMS",			"JBSYE2")
    set_CODEN("j-J-BIOMECH",				"JBMCBS")
    set_CODEN("j-J-BIOMED-ENG",				"JBIEDR")
    set_CODEN("j-J-BIOMED-INF",				"JBIOBL")
    set_CODEN("j-J-BIOMED-MATER-RES",			"JBMRBG")
    set_CODEN("j-J-BIOMOL-STRUCT-DYNAMICS",		"JBSDD6")
    set_CODEN("j-J-BIOSCI",				"JOBSDN")
    ## BAD: set_CODEN("j-J-BIOTECH",				"JBDITD")
    set_CODEN("j-J-BIOTECH",				"JBITD4")	# [04-Jan-2006] corrected
    set_CODEN("j-J-BONE-MINERAL-RES",			"JBMREJ")
    set_CODEN("j-J-BR-ASTRON-ASSOC",			"JBAAA6")
    set_CODEN("j-J-BR-INTERPLANET-SOC",			"JBISAW")
    set_CODEN("j-J-BRAZIL-COMPUT-SOC",			"????")
    set_CODEN("j-J-BUS-ECON-STAT",			"????")
    set_CODEN("j-J-BUS-UNIV-CHIC",			"????")
    set_CODEN("j-J-CARDIOVASC-PHARMACOL",               "JCPCDT")
    set_CODEN("j-J-CARDIOVASC-ELECTROPHYSIOL",		"JCELE2")
    set_CODEN("j-J-CELL-BIOCHEM",			"JCEBD5")
    set_CODEN("j-J-CELL-BIOL",				"JCLBA3")
    set_CODEN("j-J-CELL-COMP-PHYSIOL",			"JCLLAX")
    set_CODEN("j-J-CELL-PHYSIOL",			"JCLLAX", 1)
    set_CODEN("j-J-CELL-SCI",				"JNCSAI")
    set_CODEN("j-J-CELL-SCI-SUPPL",			"JCSSEP")
    set_CODEN("j-J-CEREB-BLOOD-FLOW-METAB",		"JCBMDN")
    set_CODEN("j-J-CHEM-EDUC",				"JCEDA8")
    set_CODEN("j-J-CHEM-INFO-COMP-SCI",			"JCISD8")
    set_CODEN("j-J-CHEM-INFO-MODEL",			"JCISD8")
    set_CODEN("j-J-CHEM-PHYS",				"JCPSA6")
    set_CODEN("j-J-CHEM-SOC",				"JCSOA9")
    set_CODEN("j-J-CHEM-SOC-FARADAY-TRANS",		"")
    set_CODEN("j-J-CHEM-SOC-FARADAY-TRANS-2",		"JCFTBS")
    set_CODEN("j-J-CHEM-SOC-TRANS",			"JCHTA3")
    set_CODEN("j-J-CHEM-THEORY-COMPUT",			"JCTCCE")
    set_CODEN("j-J-CHEMOM",				"JOCHEU")
    set_CODEN("j-J-CHILD-MATH-BEHAV",			"JCMBDB")
    set_CODEN("j-J-CHINESE-INST-ENG",			"CKCKDZ")
    set_CODEN("j-J-CHROMATOGR-A",			"JCRAEY")
    set_CODEN("j-J-CIV-DEF",				"????")
    set_CODEN("j-J-CLIN-INVEST",			"JCINAO")
    set_CODEN("j-J-CLIN-PATHOL",			"JCPAAK")
    set_CODEN("j-J-CLIN-PSYCHOL",			"JCPYAO")
    set_CODEN("j-J-COLD-REG-ENG",			"JCRGEI")
    set_CODEN("j-J-COLD-WAR-STUD",			"????")
    set_CODEN("j-J-COLL-SCI-TEACH",			"JSCTBN")
    set_CODEN("j-J-COLLOID-INTERFACE-SCI",		"JCISA5")
    set_CODEN("j-J-COMB",				"")
    set_CODEN("j-J-COMB-DES",				"JDESEU")
    set_CODEN("j-J-COMB-OPTIM",				"JCOPFV")
    set_CODEN("j-J-COMB-THEORY",			"JCTHAR")
    set_CODEN("j-J-COMB-THEORY-A",			"JCBTA7")
    set_CODEN("j-J-COMB-THEORY-B",			"JCBTB8")
    set_CODEN("j-J-COMP-BASED-INST",			"JCOID8")
    set_CODEN("j-J-COMP-INFO",				"????")
    set_CODEN("j-J-COMP-INFO-SYS",			"JCISE9")
    set_CODEN("j-J-COMP-MATH",				"JCMMEB")
    set_CODEN("j-J-COMP-NEUROL",			"JCNEAM")
    set_CODEN("j-J-COMP-NEUROSCI",			"JCNEFR")
    set_CODEN("j-J-COMP-PHYSIOL",			"JRCPA3")
    set_CODEN("j-J-COMP-PHYSIOL-A",			"JCPADN")
    set_CODEN("j-J-COMP-PHYSIOL-B",			"JPBPDL")
    set_CODEN("j-J-COMP-SCI-TECH",			"JCTEEM")
    set_CODEN("j-J-COMP-SECUR",				"JCSIET")
    set_CODEN("j-J-COMP-SYS-SCI",			"JCSSBM")
    set_CODEN("j-J-COMPLEX-NETWORKS",			"????")
    set_CODEN("j-J-COMPLEXITY",				"JOCOEH")
    set_CODEN("j-J-COMPOS-MATER",			"JCOMBI")
    set_CODEN("j-J-COMPUT-AIDED-MATER-DES",		"JCODES")
    set_CODEN("j-J-COMPUT-APPL-MATH",			"JCAMDI")
    set_CODEN("j-J-COMPUT-ASSIST-LEARNING",		"JCALEG")
    set_CODEN("j-J-COMPUT-ASSIST-MICROSC",		"JCMIEX")
    set_CODEN("j-J-COMPUT-ASSIST-TOMOGRAPHY",		"JCATD5")
    set_CODEN("j-J-COMPUT-BIOL",			"JCOBEM")
    set_CODEN("j-J-COMPUT-CHEM",			"JCCHDD")
    set_CODEN("j-J-COMPUT-FINANCE",			"????")
    set_CODEN("j-J-COMPUT-GEOM",			"????")
    set_CODEN("j-J-COMPUT-GRAPH-STAT",			"????")
    set_CODEN("j-J-COMPUT-METHODS-SCI-ENG",		"JCMSCR")
    set_CODEN("j-J-COMPUT-PHYS",			"JCTPAH")
    set_CODEN("j-J-COMPUT-SCI",				"")
    set_CODEN("j-J-COMPUT-SYST-SCI-INT",		"JSSIE5")
    ## [29-Nov-2012] Preferred abbreviation changed to j-J-COMPUT-CHEM
    ## set_CODEN("j-J-COMPUTATIONAL-CHEM",			"JCCHDD")
    set_CODEN("j-J-CONFL-RESOLUT",			"JCFRAL")
    set_CODEN("j-J-CONTEMP-HIST",			"????")
    set_CODEN("j-J-CONTROL-THEORY-APPL",		"")
    set_CODEN("j-J-CONVEX-ANAL",			"????")
    set_CODEN("j-J-CRYPTO-ENG",				"????")
    set_CODEN("j-J-CRYPTOLOGY",				"JOCREQ")
    set_CODEN("j-J-CRYSTAL-GROWTH",			"JCRGAE")
    set_CODEN("j-J-CYCLIC-NUCLEOTIDE-PROTEIN-PHOSPHOR-RES","JCNREV")
    set_CODEN("j-J-DAIRY-SCI",				"JDSCAE")
    set_CODEN("j-J-DATA-COMP-COMM",			"????")
    set_CODEN("j-J-DATABASE-ADM",			"JDADEX")
    set_CODEN("j-J-DES-HIST",				"????")
    set_CODEN("j-J-DIFFER-EQU",				"JDEQAK")
    set_CODEN("j-J-DIFFER-GEOM",			"JDGEAS")
    set_CODEN("j-J-DIFFERENCE-EQU-APPL",		"JDEAEA")
    set_CODEN("j-J-DIGITAL-IMAGING",			"JDIMEW")
    set_CODEN("j-J-DIGITAL-INFO",			"")
    set_CODEN("j-J-DISCRETE-ALGORITHMS",		"????")
    set_CODEN("j-J-DISCR-MATH-SCI-CRYPTO",		"????")
    set_CODEN("j-J-DOC",				"JDOCAS")
    set_CODEN("j-J-DYN-CONTROL-SYST",			"JDCSEK")
    set_CODEN("j-J-DYN-DIFFER-EQU",			"JDDEEH")
    set_CODEN("j-J-DYN-SYST-MEAS-CONTROL",		"JDSMAA")
    set_CODEN("j-J-ECON-DYN-CONTROL",			"JEDCDH")
    set_CODEN("j-J-ECON-LIT",				"JECLB3")
    set_CODEN("j-J-ECON-THEORY",			"JECTAQ")
    set_CODEN("j-J-ECONOMETRICS",			"JECMB6")
    set_CODEN("j-J-EDU-RESEARCH",			"JEDRAP")
    set_CODEN("j-J-EDUC-BEHAV-STAT",			"????")
    set_CODEN("j-J-EDUC-SOCIOL-NEW-YORK",		"")
    set_CODEN("j-J-ELAST",				"JELSAY")
    set_CODEN("j-J-ELECTROCARDIOL",			"JECAB4")
    set_CODEN("j-J-ELECTROCHEM-SOC",			"JESOAN")
    set_CODEN("j-J-ELECTROMAGN-WAVES-APPL",		"JEWAE5")
    set_CODEN("j-J-ELECTRON-IMAGING",			"JEIME5")
    set_CODEN("j-J-ELECTRON-MICROSC-TECH",		"JEMTEC")
    set_CODEN("j-J-ELECTRON-SPECTROSC-RELAT-PHENOM",	"JESRAW")
    set_CODEN("j-J-ELECTROST",				"JOELDH")
    set_CODEN("j-J-ELISHA-MITCHELL-SCI-SOC",		"JEMSA5")
    set_CODEN("j-J-EMBRYOL-EXP-MORPHOL",		"JEEMAF")
    set_CODEN("j-J-EMPIR-FINANCE",			"JEFIEC")
    set_CODEN("j-J-ENG-MATER-TECHNOL",			"JEMTA8")
    set_CODEN("j-J-ENG-MATH",				"JLEMAU")
    set_CODEN("j-J-ENG-MECH",				"JENMDT")
    set_CODEN("j-J-EUKARYOT-MICROBIOL",			"JEMIED")
    set_CODEN("j-J-EXP-BIOL",				"JEBIAM")
    set_CODEN("j-J-EXP-MED",				"JEMEAV")
    set_CODEN("j-J-EXP-PSYCH-GEN",			"JPGEDD")
    set_CODEN("j-J-EXP-PSYCH-LMC",			"JEPCEA")
    set_CODEN("j-J-EXP-THEOR-ARTIF-INTELL",		"JEAIEL")
    set_CODEN("j-J-EXP-THEOR-PHYS",			"JTPHES")
    set_CODEN("j-J-EXP-ZOOL",				"JEZOAO")
    set_CODEN("j-J-FINANC-ECON",			"JFECDT")
    set_CODEN("j-J-FISH-BIOL",				"JFIBA9")
    set_CODEN("j-J-FISH-DIS",				"JFIDDI")
    set_CODEN("j-J-FISH-RES-BOARD-CAN",			"JFRBAK")
    set_CODEN("j-J-FISHERIESCIENCES-COM",		"JFOIAQ")
    set_CODEN("j-J-FLUID-MECH",				"JFLSA7")
    set_CODEN("j-J-FLUIDS-ENG",				"JFEGA4")
    set_CODEN("j-J-FORENSIC-ACCOUNT",			"????")
    set_CODEN("j-J-FORTH-APPL-RES",			"JFAREL")
    set_CODEN("j-J-FUNCT-ANAL",				"JFUAAW")
    set_CODEN("j-J-FUNCT-LOGIC-PROG",			"")
    set_CODEN("j-J-FUNCT-PROGRAM",			"JFPRES")
    set_CODEN("j-J-FRANKLIN-INST",			"JFINAB")
    set_CODEN("j-J-GAMBL-STUD",				"JGSTEM")
    set_CODEN("j-J-GEN-MICROBIOL",			"JGMIAN")
    set_CODEN("j-J-GEN-PHILOS-SCI",			"JGPSE4")
    set_CODEN("j-J-GEN-PHYSIOL",			"JGPLAD")
    set_CODEN("j-J-GEN-PSYCH",				"JGPSAY")
    set_CODEN("j-J-GENET",				"JOGNAU")
    set_CODEN("j-J-GEOCHEM-EXPLOR",			"JGCEAT")
    set_CODEN("j-J-GEOL",				"JGEOAZ")
    set_CODEN("j-J-GEOM-ANAL",				"JGANEG")
    set_CODEN("j-J-GEOM-PHYS",				"JGPHE5")
    set_CODEN("j-J-GEOMAGN-GEOELEC",			"JGEGAB")
    set_CODEN("j-J-GEOPHYS-RES",			"JGREA2")
    set_CODEN("j-J-GEOPHYS-RES-A",			"JJGPD4")
    set_CODEN("j-J-GEOPHYS-RES-D",			"????")
    set_CODEN("j-J-GEOPHYS-RES-OCEAN",			"????")
    set_CODEN("j-J-GEOPHYS-RES-SOLID-EARTH",		"????")
    set_CODEN("j-J-GLOBAL-OPT",				"JGOPEO")
    set_CODEN("j-J-GRAPH-TH",				"JGTHDO")
    set_CODEN("j-J-GRAPHICS-TOOLS",			"JGTOFD")
    set_CODEN("j-J-GRID-COMP",				"")
    set_CODEN("j-J-HEREDITY",				"JOHEA8")
    set_CODEN("j-J-HEURISTICS",				"JOHEFD")
    set_CODEN("j-J-HIGH-ENERGY-PHYS",			"JHEPAB")
    set_CODEN("j-J-HIGH-ENERGY-PHYS-ONLINE",		"JHEPFG")
    set_CODEN("j-J-HIST-ASTRON",			"JHSAA2")
    set_CODEN("j-J-HIST-BEHAV-SCI",			"JHBSA5")
    set_CODEN("j-J-HIST-BIOL",				"JHBIA9")
    set_CODEN("j-J-HIST-IDEAS",				"????")
    set_CODEN("j-J-HUM-HYPERTENS",			"")
    set_CODEN("j-J-HUM-RESOUR",				"JHREA9")
    set_CODEN("j-J-HUMANIST-MATH",			"????")
    set_CODEN("j-J-HYDRAULICS-DIV",			"JYCEAJ")
    set_CODEN("j-J-HYDROL",				"JHYDA7")
    set_CODEN("j-J-IEEE",				"????")
    set_CODEN("j-J-IIEE-JAPAN",				"????")
    set_CODEN("j-J-IND-MICROBIOL",			"JIMIE7")
    set_CODEN("j-J-INEQUAL-APPL",			"????")
    set_CODEN("j-J-INF-OPTIM-SCI",			"JIOSDC")
    set_CODEN("j-J-INF-PROCESS",			"JIPRDE")
    set_CODEN("j-J-INFO-ENG",				"????")
    set_CODEN("j-J-INFO-ORG-SCI",			"")
    set_CODEN("j-J-INFO-PROC-CYBERNETICS-EIK",		"JICYE5")
    set_CODEN("j-J-INFO-PROC-SOC-JAPAN",		"JOSHA4")
    set_CODEN("j-J-INFO-SCI-PRINCIPLES-PRACTICE",	"JISCDI")
    set_CODEN("j-J-INFO-SCI-ENG",			"JINEEY")
    set_CODEN("j-J-INFO-SEC-APPL",			"????")
    set_CODEN("j-J-INFORMETRICS",			"????")
    set_CODEN("j-J-INST-ACTUARIES",			"")
    set_CODEN("j-J-INST-ELEC-INFO-COMM-ENG",		"DJTGEB")
    set_CODEN("j-J-INST-ELEC-TELECOMM-ENG",		"JIETAU")
    set_CODEN("j-J-INST-ELECTR-ENG",			"JISEAL")
    set_CODEN("j-J-INST-MATH-APPL",			"JMTAA8")
    set_CODEN("j-J-INST-PET",				"JIPEA6")
    set_CODEN("j-J-INT-ASSOC-MATH-GEOL",		"IMGJBS")
    set_CODEN("j-J-INT-ECON",				"JIECBE")
    set_CODEN("j-J-INT-FINANC-MANAG-ACCOUNT",		"????")
    set_CODEN("j-J-INTEGER-SEQ",			"????")
    set_CODEN("j-J-INTEGRAL-EQU-APPL",			"????")
    set_CODEN("j-J-INTELL-MATER-SYST-STRUCT",		"JMSSER")
    set_CODEN("j-J-INTERDISCIP-CYCLE-RES",		"JICRBF")
    set_CODEN("j-J-INTERDISCIP-HIST",			"????")
    set_CODEN("j-J-INVERSE-ILL-POSED-PROBL",		"JIVPE5")
    set_CODEN("j-J-INVESTMENT-MANAGE",			"????")
    set_CODEN("j-J-IRREPROD-RESULTS",			"JIRRAL")
    set_CODEN("j-J-JAPAN-SOC-COMPUT-STAT",		"????")
    set_CODEN("j-J-JPN-INT-ECON",			"JJIEBD")
    set_CODEN("j-J-KOREA-INFO-SCI-SOCIETY",		"HJKHDC")
    set_CODEN("j-J-KOREAN-PHYS-SOC",			"JKPSDV")
    set_CODEN("j-J-LAB-CLIN-MED",			"JLCMAK")
    set_CODEN("j-J-LINUX-TECH",				"") # unknown
    set_CODEN("j-J-LOGIC-ALG-PROG",			"????")
    set_CODEN("j-J-LOGIC-LANGUAGE-INFO",		"JLLIEN")
    set_CODEN("j-J-LOGIC-PROG",				"JLPRE2")
    set_CODEN("j-J-LOND-MATH-SOC",			"JLMSAK")
    set_CODEN("j-J-LOND-MATH-SOC-2",			"JLMSAK")
    set_CODEN("j-J-MACH-LEARN-RES",			"JMLRAJ")
    set_CODEN("j-J-MAG-RES-A",				"JMRAE2")
    set_CODEN("j-J-MANUFACTURING-SYS",                  "JMSYEB")
    set_CODEN("j-J-MAR-SYST",				"JMASE5")
    set_CODEN("j-J-MATER",				"JMLSAM")
    set_CODEN("j-J-MATER-RES",				"JMREEE")
    set_CODEN("j-J-MATER-SCI",				"JMTSAS")
    set_CODEN("j-J-MATER-SCI-LETT",			"JMSLD5, JMTSAS")
    set_CODEN("j-J-MATH-ANAL-APPL",			"JMANAK")
    set_CODEN("j-J-MATH-APPL-ANAL",			"????")
    set_CODEN("j-J-MATH-ARTS",				"????")
    set_CODEN("j-J-MATH-BEHAV",				"????")
    set_CODEN("j-J-MATH-BIOL",				"JMBLAJ")
    set_CODEN("j-J-MATH-CHEM",				"JMCHEG")
    set_CODEN("j-J-MATH-CRYPTOL",			"????")
    set_CODEN("j-J-MATH-IMAG-VIS",			"JMIVEK")
    set_CODEN("j-J-MATH-INEQUAL",			"????")
    set_CODEN("j-J-MATH-KYOTO-UNIV",			"JMKYAZ")
    set_CODEN("j-J-MATH-MECH",				"JOMMAN")
    set_CODEN("j-J-MATH-PHYS",				"JMAPAQ")
    set_CODEN("j-J-MATH-PHYS-MIT",			"JMPHA9")
    set_CODEN("j-J-MATH-PSYCHOL",			"JMTPAJ")
    set_CODEN("j-J-MATH-PURES-APPL",			"JMPAAM")
    set_CODEN("j-J-MATH-RES-APPL",			"????")
    set_CODEN("j-J-MATH-SCI-ADV-APPL",			"????")
    set_CODEN("j-J-MATH-SCI-NY-NY",			"JMTSEW")
    set_CODEN("j-J-MATH-SOC-JPN",			"NISUBC")
    set_CODEN("j-J-MEC",				"JOMCAR")
    set_CODEN("j-J-MECH-DESIGN",			"JMDEEC")
    set_CODEN("j-J-MECH-MATER-STRUCT",			"????")
    set_CODEN("j-J-MECH-PHYS-SOLIDS",			"JMPSA8")
    set_CODEN("j-J-MED-CHEM",				"JMCMAR")
    set_CODEN("j-J-MED-SYST",				"JMSYDA")
    set_CODEN("j-J-MEMBR-BIOL",				"JMBBBO")
    set_CODEN("j-J-MICROELECTROMECHANICAL-SYSTEMS",	"JMIYET")
    set_CODEN("j-J-MICROCOMPUT-APPL",			"JMIADO, MIAPEZ")
    set_CODEN("j-J-MIL-HIST",				"????")
    set_CODEN("j-J-MOD-APPL-STAT-METH",			"????")
    set_CODEN("j-J-MOD-ITAL-STUD",			"????")
    set_CODEN("j-J-MOD-OPT",				"JMOPEW")
    set_CODEN("j-J-MOD-HIST",				"")
    set_CODEN("j-J-MOL-BIOL",				"JMOBAK")
    set_CODEN("j-J-MOL-EVOL",				"JMEVAU")
    set_CODEN("j-J-MOL-MODEL",				"JMMOFK")
    set_CODEN("j-J-MOL-SPECTROSC",			"JMOSA3")
    set_CODEN("j-J-MOL-STRUCT",				"JMOSB4")
    set_CODEN("j-J-MOL-STRUCT-THEOCHEM",		"THEODJ")
    set_CODEN("j-J-MULTIVAR-ANAL",			"JMVAAI")
    set_CODEN("j-J-MUSCLE-RES-CELL-MOTIL",		"JMRMD3")
    set_CODEN("j-J-NANOMATER",				"JNOABP")
    set_CODEN("j-J-NANOSCI-NANOTECHNOL",		"JNNOAR")
    set_CODEN("j-J-NAT-CANCER-INST",			"JNCIAM")
    set_CODEN("j-J-NAT-CANCER-INST-1978-1987",		"JJIND8")
    set_CODEN("j-J-NAT-CANCER-INST-BETHESDA",		"JNCIEQ")
    set_CODEN("j-J-NAT-CANCER-INST-MONOGR",		"JNCME4")
    set_CODEN("j-J-NETW-COMPUT-APPL",			"JNCAF3")
    set_CODEN("j-J-NUCL-ENERGY-1954",			"????")
    set_CODEN("j-J-NUCL-MATER",				"JNUMAM")
    set_CODEN("j-J-NEURAL-TRANSM-SUPPL",                "JNTSD4")
    set_CODEN("j-J-NEUROCHEM",				"JONRA9")
    set_CODEN("j-J-NEUROBIOL",				"JNEUBZ")
    set_CODEN("j-J-NEUROCYTOL",				"JNCYA2")
    set_CODEN("j-J-NEUROPHYSIOL",			"JONEA4")
    set_CODEN("j-J-NEUROSCI",				"JNRSDS")
    set_CODEN("j-J-NEUROSCI-METHODS",			"JNMEDT")
    set_CODEN("j-J-NON-CRYST-SOLIDS",			"JNCSBJ")
    set_CODEN("j-J-NON-NEWTONIAN-FLUID-MECH",		"JNFMDI")
    set_CODEN("j-J-NONMETALS",				"JNMTA3")
    set_CODEN("j-J-NONLINEAR-CONVEX-ANAL",		"????")
    set_CODEN("j-J-NONLINEAR-SCI",			"JNSCEK")
    set_CODEN("j-J-NUMBER-THEORY",			"JNUTA9")
    set_CODEN("j-J-NUMER-METHODS-COMPUT-APPL",		"")
    set_CODEN("j-J-NUTR",				"JONUAI")
    set_CODEN("j-J-OCCUP-MED",				"JOCMA7")
    set_CODEN("j-J-OOP",				"JOOPEC")
    set_CODEN("j-J-OPEN-RES-SOFT",			"????")
    set_CODEN("j-J-OPER-MANAGE",			"????")
    set_CODEN("j-J-OPER-RES-SOC",			"OPRQAK")
    set_CODEN("j-J-OPER-RES-SOC-JPN",			"JORJA5")
    set_CODEN("j-J-OPER-RESEARCH",			"????")
    set_CODEN("j-J-OPT-A",				"JOAOF8")
    set_CODEN("j-J-OPT-B",				"JOBOFD")
    set_CODEN("j-J-OPT-SOC-AM-1917",			"")
    set_CODEN("j-J-OPT-SOC-AM",				"JOSAAH")
    set_CODEN("j-J-OPT-SOC-AM-A",			"JOAOD6")
    set_CODEN("j-J-OPT-SOC-AM-B",			"JOBPDE")
    set_CODEN("j-J-OPT-SOC-AM-REV-SCI-INSTRUM",		"JOTSA8")
    set_CODEN("j-J-OPT-THEORY-APPL",			"JOTABN")
    set_CODEN("j-J-ORG-CHEM",				"JOCEAH")
    set_CODEN("j-J-PAR-DIST-COMP",			"JPDCER")
    set_CODEN("j-J-PARAPSYCHOL",			"JPRPAU")
    set_CODEN("j-J-PAS-ADA",				"????")
    set_CODEN("j-J-PAS-ADA-MOD",			"JOPAD5")
    set_CODEN("j-J-PATHOL",				"JPTLAS")
    set_CODEN("j-J-PEACE-RES",				"????")
    set_CODEN("j-J-PERIODONTAL-RES",			"JPDRAY")
    set_CODEN("j-J-PET-TECHNOL",			"JPTCAZ")
    set_CODEN("j-J-PHARMACOL-EXP-THER",			"JPETAB")
    set_CODEN("j-J-PHILOS",				"????")
    set_CODEN("j-J-PHILOS-LOGIC",			"JPLGA7")
    set_CODEN("j-J-PHON",				"JPHNB9")
    set_CODEN("j-J-PHYS-A",				"JPHAC5")
    set_CODEN("j-J-PHYS-A-MATH-THEOR",			"JPAMB5")
    set_CODEN("j-J-PHYS-B",				"JPAMA4")
    set_CODEN("j-J-PHYS-B-AT-MOL-OPT-PHYS",		"JPAPEH")
    set_CODEN("j-J-PHYS-C",				"JPSOAW")
    set_CODEN("j-J-PHYS-CHEM",				"JPCHAX")
    set_CODEN("j-J-PHYS-CHEM-A",			"JPCAFH")
    set_CODEN("j-J-PHYS-CHEM-B",			"JPCBFK")
    set_CODEN("j-J-PHYS-CHEM-SOLIDS",			"JPCSAW")
    set_CODEN("j-J-PHYS-COLLOQ",			"JPQCAK")
    set_CODEN("j-J-PHYS-CONDENS-MATTER",		"JCOMEL")
    set_CODEN("j-J-PHYS-CONF-SER",			"JPCSDZ")
    set_CODEN("j-J-PHYS-D",				"JPAPBE")
    set_CODEN("j-J-PHYS-E-J-SCIENT-INSTRUM",		"????")
    set_CODEN("j-J-PHYS-E",				"JPSIAE")
    set_CODEN("j-J-PHYS-F",				"JPFMAT")
    set_CODEN("j-J-PHYS-IV-COLLOQUE",			"JPICEI")
    set_CODEN("j-J-PHYS-LETT",				"JPSLBO")
    set_CODEN("j-J-PHYS-RADIUM",			"JPRAAJ")
    set_CODEN("j-J-PHYS-SOC-JAP",			"JUPSAU")
    set_CODEN("j-J-PHYS-THEOR-APPL",			"JPTAAT")
    set_CODEN("j-J-PHYSIOL",				"JPHYA7")
    set_CODEN("j-J-PHYSIOLOGIE",			"JOPHAN")
    set_CODEN("j-J-PHYSIQUE",				"JOPQAG")
    set_CODEN("j-J-PLANKTON-RES",			"JPLRD9")
    set_CODEN("j-J-PLASMA-PHYS",			"JPLPBZ")
    set_CODEN("j-J-POLITICS",				"????")
    set_CODEN("j-J-POLYM-SCI",				"JPSCAU")
    set_CODEN("j-J-POLYM-SCI-POLYM-LETT-ED",		"JPYBAN")
    set_CODEN("j-J-POLYM-SCI-C-POLYM-LETT",		"JSCLE2")
    set_CODEN("j-J-POP-CULT",				"????")
    set_CODEN("j-J-PROD-BRAND-MANAG",			"????")
    set_CODEN("j-J-PROF-ISSUES-ENG",			"JPIEDN")
    set_CODEN("j-J-PROF-ISSUES-ENG-EDUC-PRACT",		"JPEPE3")
    set_CODEN("j-J-PROGRAM-LANG",			"JPLAER")
    set_CODEN("j-J-PROTEIN-CHEM",			"JPCHD2")
    set_CODEN("j-J-PSYCHOL",				"JOPSAM")
    set_CODEN("j-J-QUALITY-TECH",			"JQUTAU")
    set_CODEN("j-J-QUANT-CRIMINOL",			"JQCRE6")
    set_CODEN("j-J-QUANT-LINGUISTICS",			"????")
    set_CODEN("j-J-QUANT-SPECTROSC-RADIAT-TRANSFER",	"JQSRAE")
    set_CODEN("j-J-R-AERONAUT-SOC",			"????")
    set_CODEN("j-J-R-ASTRON-SOC-CAN",			"JRASA2")
    set_CODEN("j-J-R-COLL-PHYSICANS-LOND",		"RCPJAX")
    set_CODEN("j-J-R-SOC-ARTS",				"JRSAA4")
    set_CODEN("j-J-R-STAT-SOC",				"")
    set_CODEN("j-J-R-STAT-SOC-SER-A-GENERAL",		"JSSAEF")
    set_CODEN("j-J-R-STAT-SOC-SER-A-STAT-SOC",		"JSSAEF", 1)
    set_CODEN("j-J-R-STAT-SOC-SER-B-METHODOL",		"JSTBAJ")
    ## set_CODEN("j-J-R-STAT-SOC-SER-C-APPL-STAT",		"APSTAG", 1)
    set_CODEN("j-J-R-STAT-SOC-SER-D-STATISTICIAN",	"????")
    set_CODEN("j-J-RADIAT-RES",				"JRARAX")
    set_CODEN("j-J-RADIOANAL-NUCL-CHEM",		"JRNCDM")
    set_CODEN("j-J-REC-MATH",				"JRMAB9")
    set_CODEN("j-J-REG-SCI",				"????")
    set_CODEN("j-J-REINE-ANGEW-MATH",			"JRMAA8")
    set_CODEN("j-J-REINF-PLAST-COMPOS",			"JRPCDW")
    set_CODEN("j-J-RELIG-HEALTH",			"JRHEAT")
    set_CODEN("j-J-RES-COMMUN-STUD",			"JRCSDF")
    set_CODEN("j-J-RES-COMP-EDU",			"JRCEE8")
    set_CODEN("j-J-RES-NATL-BUR-STAND-1934",		"????")
    set_CODEN("j-J-RES-NATL-BUR-STAND-1977",		"JRNBAG")
    set_CODEN("j-J-RES-NATL-BUR-STAND-A",		"JNBAAR")
    set_CODEN("j-J-RES-NATL-BUR-STAND-B",		"JNBBAU")
    set_CODEN("j-J-RES-NATL-BUR-STAND-C",		"JNBCAX")
    set_CODEN("j-J-RES-NATL-BUR-STAND-D",		"JNBRAA")
    set_CODEN("j-J-RES-NATL-INST-STAND-TECHNOL",	"JRITEF")
    set_CODEN("j-J-RES-SCI-TEACH",			"JRSTAR")
    set_CODEN("j-J-RISK-UNCERT",			"JRUNEN")
    set_CODEN("j-J-ROBOTIC-SYS",			"JRSYDB")
    set_CODEN("j-J-SCH-PUBL",				"JSPUEQ")
    set_CODEN("j-J-SCI-COMPUT",				"JSCOEB")
    set_CODEN("j-J-SCI-EDUC-TECHNOL",			"JSEEEP")
    set_CODEN("j-J-SCI-IND-RES",			"JSIRAC")
    set_CODEN("j-J-SCIENT-INSTR",			"JSINAY")
    set_CODEN("j-J-SEISMIC-EXPLORATION",		"????")
    set_CODEN("j-J-SIAM",				"JSIMAV")
    set_CODEN("j-J-SIMUL",				"????")
    set_CODEN("j-J-SOC-BIOL-STRUCT",			"????")
    set_CODEN("j-J-SOC-CHEM-IND-LONDON",		"JSCIAN")
    set_CODEN("j-J-SOC-HIST",				"????")
    set_CODEN("j-J-SOC-IND-APPL-MATH-A-ON-CONTROL",	"")
    set_CODEN("j-J-SOC-INSTR-CONTROL-ENG",		"KESEA4")
    set_CODEN("j-J-SOFTW-EVOL-PROC",			"????")
    set_CODEN("j-J-SOFTW-MAINT",			"JSMPEU")
    set_CODEN("j-J-SOFTW-MAINT-EVOL",			"JSMECT")
    set_CODEN("j-J-SOFTWARE-ALGEBRA-GEOM",		"")
    set_CODEN("j-J-SOFTWARE-MAINT",			"JSMPEU")
    set_CODEN("j-J-SOUND-VIB",				"JSVIAG")
    ## BAD: set_CODEN("j-J-SOV-MATH",				"JSOMAR, JOSMAR")
    set_CODEN("j-J-SOV-MATH",				"JSOMAR")	# [04-Jan-2006] corrected
    set_CODEN("j-J-STAT-COMPUT-SIMUL",			"JSCSAJ")
    set_CODEN("j-J-STAT-MECH-THEORY-EXP",		"JSMTC6")
    set_CODEN("j-J-STAT-PHYS",				"JSTPSB")
    set_CODEN("j-J-STAT-PLANN-INFERENCE",		"JSPIDN")
    set_CODEN("j-J-STAT-SOC-LONDON",			"????")
    set_CODEN("j-J-STAT-SOFT",				"JSSOBK")
    set_CODEN("j-J-STAT-THEORY-PRACT",			"????")
    set_CODEN("j-J-STRATEG-STUD",			"????")
    set_CODEN("j-J-STRUCT-BIO",				"JSBIEM")
    set_CODEN("j-J-STRUCT-ENG",				"JSENEI")
    set_CODEN("j-J-STRUCT-ENG-NY",			"JSENDH")
    set_CODEN("j-J-STRUCT-MECH",			"JSMHA2")
    set_CODEN("j-J-SUPERCOMPUTING",			"JOSUED")
    set_CODEN("j-J-SUPERCOND",				"JOUSEH")
    set_CODEN("j-J-SUPERCOND-NOVEL-MAGN",		"JSNMBN")
    set_CODEN("j-J-SYMBOLIC-COMP",			"JSYCEH")
    set_CODEN("j-J-SYMBOLIC-LOGIC",			"JSYLA6")
    set_CODEN("j-J-SYS-MANAGEMENT",			"JSYMA9")
    set_CODEN("j-J-SYST-ARCH",				"JSARFB")
    set_CODEN("j-J-SYST-SOFTW",				"JSSODM")
    set_CODEN("j-J-THEOR-BIOL",				"JTBIAP")
    set_CODEN("j-J-THEOR-PROBAB",			"JTPREO")
    set_CODEN("j-J-THERM-STRESS",			"JTSTDA")
    set_CODEN("j-J-THORAC-CARDIOVASC-SURG",		"JTCSAQ")
    set_CODEN("j-J-TIME-SER-ANAL",			"JTSADL")
    set_CODEN("j-J-TIME-SER-ECONOM",			"????")
    set_CODEN("j-J-TRANSPORT-ENG",			"JTPEDI")
    set_CODEN("j-J-UCS",				"")
    set_CODEN("j-J-UNIV-SCI-TECHNOL-CHINA",		"CKHPD7")
    set_CODEN("j-J-URBAN-ECON",				"JUECDW")
    set_CODEN("j-J-VAC-SCI-TECHNOL",			"JVSTAL")
    set_CODEN("j-J-VAC-SCI-TECHNOL-A",			"JVTAD6")
    set_CODEN("j-J-VAC-SCI-TECHNOL-B",			"JVSTBM")
    set_CODEN("j-J-VIRO",				"JOVIAM")
    set_CODEN("j-J-VIS-COMMUN-IMAGE-REPRESENT",		"JVCRE7")
    set_CODEN("j-J-VIS-COMP-ANIMATION",			"JVCAEO")
    set_CODEN("j-J-VIS-LANG-COMPUTING",			"JVLCE7")
    set_CODEN("j-J-VLSI-COMPUT-SYST",			"????")
    set_CODEN("j-J-VLSI-SIGNAL-PROC",			"JVSPED")
    set_CODEN("j-J-WASH-ACAD-SCI",			"JWASA3")
    set_CODEN("j-JAARBOEKJE-LEIDEN",			"????")
    set_CODEN("j-JABES",				"????")
    set_CODEN("j-JACS",					"JACSAT")
    set_CODEN("j-JAHRB-BAYER-AKAD-WISS",		"BAWJAE")
    set_CODEN("j-JAHRB-KGL-BAYER-AKAD-WISS",		"????")
    set_CODEN("j-JAHRB-RADIOAKT-ELECTRON",		"JAREAS")
    set_CODEN("j-JAHRESBER-DEUTSCH-MATH-VEREIN",	"JDMVA7")
    set_CODEN("j-JAMA",					"JAMAAP")
    set_CODEN("j-JAPAN-J-APPL-PHYS",			"JJAPA5")
    set_CODEN("j-JAPAN-J-INDUST-APPL-MATH",		"JAPJI7")
    set_CODEN("j-JAPAN-J-MATH-N-S",			"????")
    set_CODEN("j-JARATAZA",				"JRNAAD")
    set_CODEN("j-JAVA-REPORT",				"JREPFI")
    set_CODEN("j-JCD",					"AJCDBH")
    set_CODEN("j-JCLT",					"????")
    set_CODEN("j-JDIQ",					"")
    set_CODEN("j-JERIC",				"")
    set_CODEN("j-JETC",					"")
    set_CODEN("j-JETP-LETT",				"JTPLA2")
    set_CODEN("j-JEWISH-SOCIAL-STUDIES",		"JWSSAP")
    set_CODEN("j-JHAPLTD",				"JHADDQ")
    set_CODEN("j-JIPAM-J-INEQUAL-PURE-APPL-MATH",	"????")
    set_CODEN("j-JNLAA",				"????")
    set_CODEN("j-JOCCH",				"")
    set_CODEN("j-JOHN-HOPKINS-MAG",			"????")
    set_CODEN("j-JOHO-KANRI",				"JOKAAB")
    set_CODEN("j-JOHO-SHORI",				"JOSHA4", 1)
    set_CODEN("j-JOSA-COMM",				"????")
    set_CODEN("j-JOURNAL-Q",				"JOQUAX")
    set_CODEN("j-JPN-HEART-J",				"JHEJAR")
    set_CODEN("j-JPN-STUD-HIST-SCI",			"JSHIAE")
    set_CODEN("j-KERNTECHNIK",				"KERNEU")
    set_CODEN("j-KIBERNETIKA",				"KBRNA5")
    set_CODEN("j-KNOWL-ENG-REV",			"KEREE3")
    set_CODEN("j-KNOWL-ORGAN",				"KNOREM")
    set_CODEN("j-KOMOEDIE",				"????")
    set_CODEN("j-KOREA-INFO-SCI-SOC-REV",		"CHKWEN")
    set_CODEN("j-KUNSTLICHE-INTELLIGENZ",		"????")
    set_CODEN("j-KVANT",				"KVANEU")
    set_CODEN("j-KYBER",				"KYBEAP")
    set_CODEN("j-KYBERNETIKA",				"KYBNAI")
    set_CODEN("j-LAB-MICROCOMP",			"LMICDI")
    set_CODEN("j-LAN",					"LANNER")
    set_CODEN("j-LAN-TIMES",				"????")
    set_CODEN("j-LANCET",				"LANCAO")
    set_CODEN("j-LANG-SCI",				"????")
    set_CODEN("j-LANGMUIR",				"LANGD5")
    set_CODEN("j-LANGUAGE",				"????")
    set_CODEN("j-LANGUAGE-INT",				"LAINE2")
    set_CODEN("j-LARGE-SCALE-SYSTEMS",			"LSSAD2")
    set_CODEN("j-LASER-FOCUS-WORLD",			"LFWOE8")
    set_CODEN("j-LASER-PART-BEAMS",			"LPBEDA")
    set_CODEN("j-LASER-PHYS-LETT",			"LPLABC")
    set_CODEN("j-LATV-MAT-EZEG",			"????")
    set_CODEN("j-LAW-COMP-AI",				"LCAIET")
    set_CODEN("j-LAW-LIBR-LONDON",			"LALIE2")
    set_CODEN("j-LAW-TECH",				"LATEDT")
    set_CODEN("j-LAWYERS-PC",				"????")
    set_CODEN("j-LEAD-EDGE",				"LEEDFF")
    set_CODEN("j-LEARN-PUBL",				"LEPUFJ")
    set_CODEN("j-LEARNING",				"????")
    set_CODEN("j-LECT-APPL-MATH",			"????")
    set_CODEN("j-LECT-NOTES-BIOMATH",			"LNBMAH")
    set_CODEN("j-LECT-NOTES-COMP-SCI",			"LNCSD9")
    set_CODEN("j-LECT-NOTES-CONTROL-INF-SCI",		"????")
    set_CODEN("j-LECT-NOTES-MATH",			"LNMAA2")
    set_CODEN("j-LECT-NOTES-PHYSICS",			"LNPHA4")
    set_CODEN("j-LECT-NOTES-STAT",			"????")
    set_CODEN("j-LECT-SER-COMPUT-COMPUT-SCI",		"LSCCAR")
    set_CODEN("j-LEGAL-MANAGE",				"LEMAEB")
    set_CODEN("j-LEONARDO",				"LEONDP")
    set_CODEN("j-LET-MATH-PHYS",			"LMPHDY")
    set_CODEN("j-LETT-APPL-ENG-SCI",			"LAESBS")
    set_CODEN("j-LETT-NUOVO-CIMENTO",			"NCLTAX")
    set_CODEN("j-LETT-NUOVO-CIMENTO-2",			"LNUCAE")
    set_CODEN("j-LIB-COMP-SYS-EQUIP-REVIEW",		"LCSREA")
    set_CODEN("j-LIB-HI-TECH",				"LIHTD2")
    set_CODEN("j-LIB-HI-TECH-NEWS",			"????")
    set_CODEN("j-LIB-RESOURCES-TECH-SERVICES",		"LRTSAH")
    set_CODEN("j-LIB-SYSTEMS",				"????")
    set_CODEN("j-LIBERTAS-MATH",			"")
    set_CODEN("j-LIBR-J",				"LIBJA7")
    set_CODEN("j-LIBR-SOFTW-REV",			"LSREEA")
    set_CODEN("j-LIBR-TRENDS",				"LIBTA3")
    set_CODEN("j-LIFE-SUPPORT-SYST",			"LSSYD6")
    set_CODEN("j-LIGHT-SCI-APPL",			"")
    set_CODEN("j-LIGHTWAVE-TECHNOL",			"JLTEDG")
    set_CODEN("j-LIMNOL-OCEANOGR",			"LIOCAH")
    set_CODEN("j-LIMNOL-OCEANOGR-LETT",			"????")
    set_CODEN("j-LIN-AND-MULT-ALGEBRA",			"LNMLAZ")
    set_CODEN("j-LIN-MULT-ALGEBRA",			"LNMLAZ")
    set_CODEN("j-LINEAR-ALGEBRA-APPL",			"LAAPAW")
    set_CODEN("j-LINUX-J",				"LIJOFX")
    set_CODEN("j-LISP-SYMB-COMPUT",			"LSCOEX", 1)
    set_CODEN("j-LIT-LING-COMP",			"LLCOEI")
    set_CODEN("j-LIVING-REV-RELATIVITY",		"????")
    set_CODEN("j-LMS-J-COMPUT-MATH",			"????")
    set_CODEN("j-LOG-INFO-MANAGEMENT",			"LINMEC")
    set_CODEN("j-LOGIC-PROG-ALP-NEWSLETTER",		"????")
    set_CODEN("j-LOGIN",				"LOGNEM")
    set_CODEN("j-LONDON-REV-BOOKS",			"????")
    set_CODEN("j-LOPLAS",				"ALPSE8")
    set_CODEN("j-LOS-ALAMOS-SCIENCE",			"LASCDI")
    set_CODEN("j-LOTUS",				"????")
    set_CODEN("j-M-COMPUTING",                          "MCPUEF")
    set_CODEN("j-MAA-STUD-MATH",			"MSTMBI")
    set_CODEN("j-MACH-GRAPH-VIS",			"????")
    set_CODEN("j-MACH-INTELL",				"MACIBX")
    set_CODEN("j-MACH-TRANSL",				"MACTEZ")
    set_CODEN("j-MACH-VIS-APPL",			"MVAPEO")
    set_CODEN("j-MACHINE-DESIGN",			"MADEAP")
    set_CODEN("j-MACQUARIE-MATH-REP",			"????")
    set_CODEN("j-MACROMOLECULES",			"MAMOBX")
    set_CODEN("j-MACUSER",				"MCUSEY")
    set_CODEN("j-MACWEEK",				"MWEEEI")
    set_CODEN("j-MACWORLD",				"MACWEA")
    set_CODEN("j-MAD",					"????")
    set_CODEN("j-MAGMA",				"MAGMEY")
    set_CODEN("j-MAGN-MAGN-MATER",			"JMMMDC")
    set_CODEN("j-MAGN-RESON",				"JOMRA4")
    set_CODEN("j-MAGY-FIZ-FOLY",			"MGFFAC")
    set_CODEN("j-MAGY-TUDOMANY",			"????")
    set_CODEN("j-MANAGEMENT-SCIENCE",			"MSCIAM")
    set_CODEN("j-MANAGING-INFO",			"MAIOEG")
    set_CODEN("j-MANCHESTER-GUARDIAN",			"????")
    set_CODEN("j-MANUFACTURING-SYSTEMS",		"MASYES")
    set_CODEN("j-MANUSCR-MATH",				"MSMHB2")
    set_CODEN("j-MAPLE-NEWS",				"????")
    set_CODEN("j-MAPLE-TECH-NEWS",			"????")
    set_CODEN("j-MAR-BIOL-RES",				"????")
    set_CODEN("j-MAR-BIOTECHNOL",			"MABIFW")
    set_CODEN("j-MAR-ECOL-PROG-SER",			"MESEDT")
    set_CODEN("j-MAR-POLICY",				"????")
    set_CODEN("j-MARIN-RESOURC-ECON",			"JMREDD")
    set_CODEN("j-MARKETING-COMP",			"????")
    set_CODEN("j-MARKUP-LANG",				"MLTPFG")
    set_CODEN("j-MAT-CONTEMP",				"")
    set_CODEN("j-MAT-SB",				"????")
    set_CODEN("j-MAT-SB-MOSK",				"MATSAB")
    set_CODEN("j-MAT-TERMESZETTUD-ERT",			"MNAUAD")
    set_CODEN("j-MAT-ZAMETKI",				"????")
    set_CODEN("j-MATER-RES-SOC-SYMP-PROC",		"MRSPDH")
    set_CODEN("j-MATER-SCI-ENG",			"MSCEAA")
    set_CODEN("j-MATER-SCI-ENG-A",			"MSAPE3")
    set_CODEN("j-MATER-SCI-FORUM",			"MSFOEP")
    set_CODEN("j-MATER-TODAY",				"MTOUAN")
    set_CODEN("j-MATH-ANN",				"MAANA3")
    set_CODEN("j-MATH-APP-COMP",			"????")
    set_CODEN("j-MATH-BIOSCI",				"MABIAR")
    set_CODEN("j-MATH-CLUJ",				"MTHCA2")
    set_CODEN("j-MATH-COMPUT",				"MCMPAF")
    set_CODEN("j-MATH-COMPUT-SCI",			"")
    set_CODEN("j-MATH-COMP-EDU",			"MCEDDA")
    set_CODEN("j-MATH-COMP-MODELLING",			"MCMOEG")
    set_CODEN("j-MATH-COMP-SIM",			"MCSIDR")
    set_CODEN("j-MATH-CONTROL-SIGNALS-SYST",		"MCSYE8")
    set_CODEN("j-MATH-GAZ",				"MAGAAS")
    set_CODEN("j-MATH-GEOL",				"MATGED")
    set_CODEN("j-MATH-GEOSCI",				"????")
    set_CODEN("j-MATH-INEQUAL-APPL",			"")
    set_CODEN("j-MATH-INTEL",				"MAINDC")
    set_CODEN("j-MATH-JAPON",				"MAJAA9")
    set_CODEN("j-MATH-LOGIC-QUART",			"MLQUEF")
    set_CODEN("j-MATH-MAG",				"MAMGA8")
    set_CODEN("j-MATH-MECH-COMPLEX-SYST",		"????")
    set_CODEN("j-MATH-MECH-SOLIDS",			"MMESFP")
    set_CODEN("j-MATH-MED-BIOL",			"MMBABK")
    set_CODEN("j-MATH-METHODS-APPL-SCI",		"MMSCDB")
    set_CODEN("j-MATH-METHODS-STAT",			"????")
    set_CODEN("j-MATH-MODEL",				"MMDEEB")
    set_CODEN("j-MATH-MODEL-NUM-ANA",			"RMMAEV")
    set_CODEN("j-MATH-MODELS-METHODS-APPL-SCI",		"MMMSEU")
    set_CODEN("j-MATH-NACHR",				"MTMNAQ")
    set_CODEN("j-MATH-NATURWISS-UNTERR",		"MNWUAL")
    set_CODEN("j-MATH-NOTES",				"????")
    set_CODEN("j-MATH-NOTES-ACAD-SCI-USSR",		"MTHNB2")
    set_CODEN("j-MATH-OP-RES",				"MOREDQ")
    set_CODEN("j-MATH-OPERATIONSFORSCH-STAT",		"MTOSBI")
    set_CODEN("j-MATH-PHYS-SEMESTERBERICHTE",		"MPYSA5")
    set_CODEN("j-MATH-PHYSICS",				"????")
    set_CODEN("j-MATH-PROC-CAMB-PHILOS-SOC",		"MPCPCO")
    set_CODEN("j-MATH-PROG",				"MHPGA4")
    set_CODEN("j-MATH-PROG-SOC-COAL-NEWSLETTER",	"????")	# is this same as j-COAL??
    set_CODEN("j-MATH-PROG-STUDY",			"MPSTDF")
    set_CODEN("j-MATH-PROGRAM-COMPUT",			"????")
    set_CODEN("j-MATH-RECR-ESSAYS",			"????")
    set_CODEN("j-MATH-RES-LETT",			"????")
    set_CODEN("j-MATH-REV",				"MAREAR")
    set_CODEN("j-MATH-SCAND",				"MTSCAN")
    set_CODEN("j-MATH-SCHULE",				"MKSCAS")
    set_CODEN("j-MATH-SCI",				"????")
    set_CODEN("j-MATH-SCI-ENG",				"MTSEAT")
    set_CODEN("j-MATH-SEMESTERBER",			"????")
    set_CODEN("j-MATH-SLOVACA",				"MASLDM")
    set_CODEN("j-MATH-SOC-SCI",				"????")
    set_CODEN("j-MATH-STOS",				"????")
    set_CODEN("j-MATH-STUDENT",				"MTHSBH")
    set_CODEN("j-MATH-SYS-THEORY",			"MASTBA")
    set_CODEN("j-MATH-TABLES-OTHER-AIDS-COMPUT",	"MTTCAS")
    set_CODEN("j-MATH-TEACH",				"????")
    set_CODEN("j-MATH-TODAY",				"")
    set_CODEN("j-MATH-USSR-IZV",			"MUSIAE")
    set_CODEN("j-MATH-USSR-SBORNIK",			"MUSBBS")
    set_CODEN("j-MATH-Z",				"MAZEAX")
    set_CODEN("j-MATHEMATECH",				"????")	# no CODEN
    set_CODEN("j-MATHEMATICA-EDUC",			"????")
    set_CODEN("j-MATHEMATICA-J",			"????")
    set_CODEN("j-MATHEMATIKA",				"MTKAAB")
    set_CODEN("j-MATHWORKS-NEWSLETTER",			"????")
    set_CODEN("j-MAYFLOWER-QUARTERLY",			"????")
    set_CODEN("j-MAYO-CLIN-PROC",			"MACPAJ")
    set_CODEN("j-MC",					"????") # Ambiguous
    set_CODEN("j-MD-COMPUTING-CMP",			"MDCOE7")
    set_CODEN("j-MDMV",					"????")
    set_CODEN("j-MEASUREMENT",				"????")
    set_CODEN("j-MEASUREMENT-CONTROL",			"MEACBX")
    set_CODEN("j-MEASUREMENTS-CONTROL",			"????")
    set_CODEN("j-MECCANICA-MILAN",			"MECCB9")
    set_CODEN("j-MECH-AGEING-DEV",			"MAGDA3")
    set_CODEN("j-MECH-DEVEL",				"MEDVE6")
    set_CODEN("j-MECH-ENG",				"MEENAH")
    set_CODEN("j-MECH-ENG-BULLL",			"MEGBBQ")
    set_CODEN("j-MECH-MATER",				"MSMSD3")
    set_CODEN("j-MECH-RESEARCH-COMM",			"MRCOD2")
    set_CODEN("j-MECH-SOLIDS",				"MESOBN")
    set_CODEN("j-MECHAN-STRUCT-MACH",			"MSMAEI")
    set_CODEN("j-MED-DECIS-MAKING",			"????")
    set_CODEN("j-MED-ELECT",				"????")
    set_CODEN("j-MED-BIOL-ENG-COMPUT",			"MBECDY")
    set_CODEN("j-MED-HYPOTH",				"MEHYDY")
    set_CODEN("j-MED-INSTRUM",				"MLISBY")
    set_CODEN("j-MED-J-AUST",				"MJAUAJ")
    set_CODEN("j-MED-OPIN-REV",				"????")
    set_CODEN("j-MED-PHYS",				"MPHYA6")
    set_CODEN("j-MED-REF-SERV-Q",			"MRSQDK")
    set_CODEN("j-MED-WAR",				"MEWAE4")
    set_CODEN("j-MEDIA-HIST",				"????")
    set_CODEN("j-MEDIA-INF-AUST",			"????")
    set_CODEN("j-MEDIA-METHODS",			"????")
    set_CODEN("j-MEDIAWEEK",				"????")
    set_CODEN("j-MEDICINE",				"MEDIAV")
    set_CODEN("j-MEM-AMS",				"MAMCAU")
    set_CODEN("j-MEM-COG",				"MYCGAO")
    set_CODEN("j-MEM-FAC-SCI-KYUSHU-UNIV",		"????")
    set_CODEN("j-MEM-FAC-SCI-KYUSHU-UNIV-A",		"MFKAAF")
    set_CODEN("j-MEM-PROC-MANCHESTER-LIT-PHILOS-SOC",	"MPMLAQ")
    set_CODEN("j-METAB-CLIN-EXP",			"METAAJ")
    set_CODEN("j-METALL-TRANS",				"MTGTBF")
    set_CODEN("j-METALL-MATER-TRANS-A",			"MMTAEB")
    set_CODEN("j-METALL-TRANS-A-PHYS-METALL-MATER-SCI",	"MTTABN")
    set_CODEN("j-METALLWIRTSCH-METALLWISS-METALLTECH",	"METWAH")
    set_CODEN("j-METAPHILOSOPHY",			"????")
    set_CODEN("j-METH-INFO-MED",			"MIMCAI")
    set_CODEN("j-METH-MOL-BIOL",			"MMBYBO")
    set_CODEN("j-METH-MOL-BIOL-CLIFTON",		"MMBIED")
    set_CODEN("j-METHODS-APPL-ANAL",			"????")
    set_CODEN("j-METHODS-CELL-BIOL",			"MCBLAG")
    set_CODEN("j-METHODS-ENZYMOL",			"MENZAU")
    set_CODEN("j-METRIKA",				"MTRKA8")
    set_CODEN("j-METRON",				"MRONAM")
    set_CODEN("j-MICH-MATH-J",				"MIMJA5")
    set_CODEN("j-MICRO-CORNUCOPIA",			"????")
    set_CODEN("j-MICROBIOL",				"MROBEO")
    set_CODEN("j-MICROBIOL-REV",			"MBRED3")
    set_CODEN("j-MICROBIOL-SCI",			"MISCEI")
    set_CODEN("j-MICROBIOLOGICA",			"MIBLDR")
    set_CODEN("j-MICROBIOS",				"MCBIA7")
    set_CODEN("j-MICROCHIM-ACTA",			"MIACAQ")
    set_CODEN("j-MICROCOMP-CIVIL-ENG",			"MCENE7")
    set_CODEN("j-MICROCOMPUT-APPL",			"MIAPEZ")
    set_CODEN("j-MICROCOMPUT-INF-MANAGE",		"MIIMEW")
    set_CODEN("j-MICROELECT-J",				"MICEB9")
    set_CODEN("j-MICROELECT-RELIABILITY",		"MCRLAS")
    set_CODEN("j-MICROPROC-MICROPROG",			"MMICDT")
    set_CODEN("j-MICROPROC-MICROSYS",			"MIMID5")
    set_CODEN("j-MICROPROC-REP",			"????")
    set_CODEN("j-MICROSC-RES-TECH",			"MRTEEO")
    set_CODEN("j-MICROSOFT-SYS-J",			"MSJOEB")
    set_CODEN("j-MICROSYS-TECH",			"MCTCEF")
    set_CODEN("j-MICROW-OPT-TECHNOL-LETT",		"MOTLEO")
    set_CODEN("j-MIDDLE-EAST-STUDIES-ASSOC-BULL",	"MESBEL")
    set_CODEN("j-MIDWEST-STUD-PHILOS",			"????")
    set_CODEN("j-MIENTRAS-TANTO",			"????")
    set_CODEN("j-MIKROBIOLOGIIA",			"MIKBA5")
    set_CODEN("j-MIKROLAN",				"????")
    set_CODEN("j-MIND",					"MNDDAB")
    set_CODEN("j-MINDS-MACH",				"MMACEO")
    set_CODEN("j-MINERALS-BASEL",			"MBSIBI")
    set_CODEN("j-MINERVA-WASHINGTON",			"MINEFY")
    set_CODEN("j-MINI-MICRO-SYSTEMS",			"XWJXEH")
    set_CODEN("j-MINI-REV-MED-CHEM",			"MMCIAE")
    set_CODEN("j-MITT-MATH-GES-HAMBURG",		"MNGBAK")
    set_CODEN("j-MMT",					"????")
    set_CODEN("j-MOD-HEALTHC",				"")
    set_CODEN("j-MOD-INTELL-HIST",			"????")
    set_CODEN("j-MOD-ITALY",				"????")
    set_CODEN("j-MOD-PHYS-LETT-A",			"MPLAEQ")
    set_CODEN("j-MOD-PHYS-LETT-B",			"????")
    set_CODEN("j-MOD-PLAST",				"MOPLAY")
    set_CODEN("j-MODEL-SIMUL",				"MSPCD4")
    set_CODEN("j-MODEL-SIMUL-SCI-ENG",			"MSMEEU")
    set_CODEN("j-MODELLING-MEASUREMENT-CONTROL-B",	"MMBTEC")
    set_CODEN("j-MOL-BIO-CELL",				"MBCEEV")
    set_CODEN("j-MOL-BIO-EVOL",				"MBEVEO")
    set_CODEN("j-MOL-BIOCHEM-PARASITOL",		"MBIPDP")
    ## BAD: set_CODEN("j-MOL-BIOL",				"MLBB")
    set_CODEN("j-MOL-BIOL",				"MOLBBJ")	# [04-Jan-2006] corrected
    set_CODEN("j-MOL-BIOSYST",				"MBOIBW")
    set_CODEN("j-MOL-CELL-BIOCHEM",			"MCBIB8")
    set_CODEN("j-MOL-CELL-BIOL",			"MCEBD4")
    set_CODEN("j-MOL-CELL-CARDIOL",			"JMCDAY")
    set_CODEN("j-MOL-CELL-ENDOCRINOL",			"MCEND6")
    set_CODEN("j-MOL-ECOL",				"MOECEO")
    set_CODEN("j-MOL-ENDOCRINOL",			"MOENEN")
    set_CODEN("j-MOL-GENERAL-GENET",			"MGGEAE")
    set_CODEN("j-MOL-INF",				"MIONBS")
    set_CODEN("j-MOL-MICROBIOL",			"MOMIEE")
    set_CODEN("j-MOL-PHARMACOL",			"MOPMA3")
    set_CODEN("j-MOL-PHYLOGENET-EVOL",			"MPEVEK")
    set_CODEN("j-MOL-PHYS",				"MOPHAM")
    set_CODEN("j-MOL-PSYCHIATRY",			"MOPSFQ")
    set_CODEN("j-MOL-SIM",				"MOSIEA")
    set_CODEN("j-MOLECULES",				"MOLEFW")
    set_CODEN("j-MON-BER-DTSCH-AKAD-WISS-BERL",		"MDAWAH")
    set_CODEN("j-MONAT-MATH",				"MNMTA2")
    set_CODEN("j-MONAT-MATH-PHYSIK",			"MMPHA8")
    set_CODEN("j-MONIST",				"????")
    set_CODEN("j-MONTE-CARLO-METHODS-APPL",		"MCMAC6")
    set_CODEN("j-MONTHLY-NOT-ASTRON-SOC-SOUTH-AFRICA",	"")
    set_CODEN("j-MONTHLY-NOT-ROY-ASTRON-SOC",		"MNRAA4")
    set_CODEN("j-MONTHLY-WEATHER-REVIEW",		"MWREAB")
    set_CODEN("j-MOSCOW-UNIV-MECH-BULL",		"MUVMB8")
    set_CODEN("j-MOTHER-JONES",				"????")
    set_CODEN("j-MTNRCW",				"????")
    set_CODEN("j-MULTIBODY-SYST-DYN",			"MSDYFC")
    set_CODEN("j-MULTIMEDIA-SYSTEMS",			"MUSYEW")
    set_CODEN("j-MULTIMEDIA-TOOLS-APPLIC",		"MTAPFB")
    set_CODEN("j-MULTISCALE-MODELING-SIMUL",		"MMSUBT")
    set_CODEN("j-MULTIVARIATE-BEHAV-RES",		"MVBRAV")
    set_CODEN("j-MUSIC",				"????")
    set_CODEN("j-MUTAT-RES",				"MUREAV")
    set_CODEN("j-MUTAT-RES-GENETIC-TOXIC-TEST-BIOMON-ENV-OCC-EXPOSURE", "MUREAV", 1)
    set_CODEN("j-N-AM-J-FISH-MANAG",			"NAJMDP")
    set_CODEN("j-N-I-A-CR",				"????")
    set_CODEN("j-NA-DIGEST",				"????")
    set_CODEN("j-NACH-DOK",				"NADOAW")
    set_CODEN("j-NACH-ELEK",				"NTELAP")
    set_CODEN("j-NACHR-AKAD-WISS-GOTTINGEN-MATH-PHYS-KL-II",	"NAAKA5")
    set_CODEN("j-NACHR-CHEM",				"NACHFB")
    set_CODEN("j-NACHR-CHEM-TECH",			"NCHTAD")
    set_CODEN("j-NACHR-CHEM-TECH-LAB",			"NCTLDI")
    set_CODEN("j-NACHR-GES-WISS-GOETTINGEN-MATH-PHYS-KL",	"NWGAAN")
    set_CODEN("j-NAG-NEWSLETTER",			"????")
    set_CODEN("j-NAMS",					"AMNOAN")
    set_CODEN("j-NANO-LETT",				"NALEFD")
    set_CODEN("j-NANOBIOL",				"NNOBE7")
    set_CODEN("j-NANOTECHNOL",				"NNOTER")
    set_CODEN("j-NASA-CONF-PUBL",			"NACPDX")
    set_CODEN("j-NASA-TECH-BRIEFS",			"NSTBAT")
    set_CODEN("j-NAT-COMPUT",				"????")
    set_CODEN("j-NAT-J",				"????")
    set_CODEN("j-NAT-INTEREST",				"????")
    set_CODEN("j-NAT-LAMPOON",				"????")
    set_CODEN("j-NAT-PHILOS",				"NPHLAC")
    set_CODEN("j-NAT-RESOUR-MODEL",			"NRMOEU")
    set_CODEN("j-NAT-REV",				"????")
    set_CODEN("j-NAT-TECH-REP",				"NTROAV")
    set_CODEN("j-NAT-VERDEN",				"NAVDAL")
    set_CODEN("j-NATION",				"????")
    set_CODEN("j-NATL-BUR-STAND-CIRC",			"NBSCAA")
    set_CODEN("j-NATL-CONF-PUBL-INST-ENG-AUST",		"NPIEDX")
    set_CODEN("j-NATL-DEF-WASHINGTON",			"NTDFA2")
    set_CODEN("j-NATL-SCI-REV",				"????")
    set_CODEN("j-NATO-ASI-B",				"NASBD3")
    set_CODEN("j-NATO-ASI-F",				"NASFEG")
    set_CODEN("j-NATUR-SCI-J-XIANGTAN-UNIV",		"XDZEWR")
    set_CODEN("j-NATURE",				"NATUAS")
    set_CODEN("j-NATURE-BIOTECH",			"NABIF9")
    set_CODEN("j-NATURE-CELL-BIOL",			"NCBIFN")
    set_CODEN("j-NATURE-CHEM",				"NCAHBB")
    set_CODEN("j-NATURE-COMMUN",			"NCAOBW")
    set_CODEN("j-NATURE-GENETICS",			"NGENEC")
    set_CODEN("j-NATURE-GEOSCI",			"NGAEBU")
    set_CODEN("j-NATURE-MATER",				"NMAACR")
    set_CODEN("j-NATURE-METHODS",			"NMAEA3")
    set_CODEN("j-NATURE-NANOTECHNOL",			"NNAABX")
    set_CODEN("j-NATURE-NEW-BIOL",			"NNBYA7")
    set_CODEN("j-NATURE-PHOTONICS",			"NPAHBY")
    set_CODEN("j-NATURE-PHYS-SCI",			"NPSCA6")
    set_CODEN("j-NATURE-PHYSICS",			"NPAHAX")
    set_CODEN("j-NATURE-REV-CARDIOL",			"NRCAE6")
    set_CODEN("j-NATURE-REV-GENET",			"NRGAAM")
    set_CODEN("j-NATURE-REV-MOL-CELL-BIOL",		"NRMCBP")
    set_CODEN("j-NATURE-REV-NEUROSCI",			"NRNAAN")
    set_CODEN("j-NATURE-REV-PHYS",			"????")
    set_CODEN("j-NATURWISS-RUNDSCH",			"NARSAC")
    set_CODEN("j-NATURWISSENSCHAFTEN",			"NATWAY")
    set_CODEN("j-NEC-RES-DEV",				"NECRAU")
    set_CODEN("j-NEC-TECH-J",				"NECGEZ")
    set_CODEN("j-NED-TIJDSCHR-NATUURKD",		"NTINEL")
    set_CODEN("j-NEDERLAND-ARCH",			"????")
    set_CODEN("j-NEDERLAND-KUNST-JAARBOEK",		"????")
    set_CODEN("j-NETW-HETEROG-MEDIA",			"")
    set_CODEN("j-NETWORK-COMPUTING",			"NCOMEV")
    set_CODEN("j-NETWORK-MANAGE",			"NETME2")
    set_CODEN("j-NETWORK-SECURITY",			"NTSCF5")
    set_CODEN("j-NETWORK-WEEK",                         "NEWEFS")
    set_CODEN("j-NETWORK-WORLD",			"????")
    set_CODEN("j-NETWORKS",				"NTWKAA")
    set_CODEN("j-NEURAL-COMP",				"NEUCEB")
    set_CODEN("j-NEURAL-NETWORKS",			"NNETEB")
    set_CODEN("j-NEURAL-PAR-SCI-COMPUT",		"NPACEM")
    set_CODEN("j-NEUROCHEM-RES",			"NEREDZ")
    set_CODEN("j-NEUROCOMPUTING",			"NRCGEO")
    set_CODEN("j-NEUROIMAGE",				"NEIMEF")
    set_CODEN("j-NEUROSCI-LETT",			"NELED5")
    set_CODEN("j-NEUROSCI-LETT-SUPPL",			"NLSUE2")
    set_CODEN("j-NEUROREPORT",				"NERPEZ")
    set_CODEN("j-NEUROSCIENCE",				"NRSCDN")
    set_CODEN("j-NEUROSURGERY",				"????")
    set_CODEN("j-NEW-ASTRON",				"NEASFS")
    set_CODEN("j-NEW-BIO",				"NEBIE2")
    set_CODEN("j-NEW-BLACKFRIARS",			"????")
    set_CODEN("j-NEW-ENGLAND-HIST",			"????")
    set_CODEN("j-NEW-ENGLAND-J-MED",			"NEJMAG")
    set_CODEN("j-NEW-GEN-COMP",				"NGCOE5")
    set_CODEN("j-NEW-IDEAS-PSYCHOL",			"????")
    set_CODEN("j-NEW-J-PHYS",				"NJOPFM")
    set_CODEN("j-NEW-HUNG-Q",				"????")
    set_CODEN("j-NEW-ORLEANS-REV",			"????")
    set_CODEN("j-NEW-PERSPECT-Q",			"????")
    set_CODEN("j-NEW-REPUBLIC",				"????")
    set_CODEN("j-NEW-SCIENTIST",			"NWSCAL")
    set_CODEN("j-NEW-STATESMAN-SOC",			"NESSEF")
    set_CODEN("j-NEW-TECH-WORK-EMPLOYMENT",		"NWEMEJ")
    set_CODEN("j-NEW-YORK",				"????")
    set_CODEN("j-NEW-YORK-REV-BOOKS",			"????")
    set_CODEN("j-NEW-YORK-TIMES-BOOK-REVIEW",		"????")
    set_CODEN("j-NEW-YORK-TIMES-MAGAZINE",		"????")
    set_CODEN("j-NEW-YORK-TIMES-SYNDICATE",		"????")
    set_CODEN("j-NEW-YORKER",				"????")
    set_CODEN("j-NEW-ZEALAND-J-MATH",			"????")
    set_CODEN("j-NEW-ZEALAND-MATH-MAG",			"NZMAB7")
    set_CODEN("j-NEW-ZEALAND-SCI-REV",			"NZSRAJ")
    set_CODEN("j-NEWS-3X-400",				"????")
    set_CODEN("j-NEWS-PHYSIOL-SCI",			"NEPSEY")
    set_CODEN("j-NEWSWEEK",				"????")
    set_CODEN("j-NEWSL-SCI-TECHNOL-HUMAN-VALUES",	"????")
    set_CODEN("j-NIEMAN-REP",				"????")
    set_CODEN("j-NIEUW-ARCHIEF-WISKUNDE",		"NAWIA7")
    set_CODEN("j-NIEUW-ARCHIEF-WISKUNDE-4",		"NAWIA7")
    set_CODEN("j-NIEUW-ARCHIEF-WISKUNDE-5",		"NAWIA7")
    set_CODEN("j-NIKKEI-ELECTRONICS",			"NIERE4")
    set_CODEN("j-NIST-SPEC-PUBL",			"NSPUE2")
    set_CODEN("j-NONLINEAR-ANAL",			"NOANDD")
    set_CODEN("j-NONLINEAR-DYN",			"NODYES")
    set_CODEN("j-NONLINEARITY",				"NONLE5")
    set_CODEN("j-NORDIC-J-COMPUT",			"NJCOFR")
    set_CODEN("j-NORDISK-MATH-TIDSKR",			"????")
    set_CODEN("j-NORMAT",				"????")
    set_CODEN("j-NORSK-MAT-TIDSSKR",			"????")
    set_CODEN("j-NOTES-CRAS",				"????")
    set_CODEN("j-NOTES-MLA",				"????")
    set_CODEN("j-NOTES-REC-R-SOC-LOND",			"NOREAY")
    set_CODEN("j-NOTRE-DAME-J-FORM-LOG",		"NDJFAM")
    set_CODEN("j-NOUS",					"????")
    set_CODEN("j-NOUV-REV-FR-HEMATOL",			"NRFHA4")
    set_CODEN("j-NRL",					"NRLOEP")
    set_CODEN("j-NRLQ",					"NRLQAR")
    set_CODEN("j-NTG",					"????")
    set_CODEN("j-NTM",					"NTMSBJ")
    set_CODEN("j-NTT-R-D",                              "NTTDEC")
    set_CODEN("j-NUCL-ENERGY",				"????")
    set_CODEN("j-NUCL-ENERGY-PART-A",			"JNEAA8")
    set_CODEN("j-NUCL-GEOPHYS",				"????")
    set_CODEN("j-NUCL-INSTR-METH",			"NUIMAL")
    set_CODEN("j-NUCL-INSTRUM-METHODS-PHYS-RES",	"NIMRD9")
    set_CODEN("j-NUCL-INSTRUM-METHODS-PHYS-RES-SECT-A",	"NIMAER")
    set_CODEN("j-NUCL-INSTRUM-METHODS-PHYS-RES-SECT-B",	"NIMBEU")
    set_CODEN("j-NUCL-MED",				"JNMEAQ")
    set_CODEN("j-NUCL-NEWS",				"NUNWA8")
    set_CODEN("j-NUCL-PHYS",				"NUPHA7")
    set_CODEN("j-NUCL-PHYS-A",				"NUPABL")
    set_CODEN("j-NUCL-PHYS-B",				"NUPBBO")
    set_CODEN("j-NUCL-PHYS-B-PROC-SUPPL",		"NPBSE7")
    set_CODEN("j-NUCL-SCI-ENG",				"NSENAO")
    set_CODEN("j-NUCL-TECHNOL",				"NUTYBB")
    set_CODEN("j-NUCLEAR-INSTR-METH-PHYS-RES-A",	"NIMAER")
    set_CODEN("j-NUCLEAR-SAFETY",			"NUSAAZ")
    set_CODEN("j-NUCLEIC-ACIDS-RES",			"NARHAD")
    set_CODEN("j-NUM-LIN-ALG-APPL",			"NLAAEM")
    set_CODEN("j-NUM-MATH",				"NUMMA7")
    set_CODEN("j-NUM-MATH-THEORY-METHODS-APPL",		"????")
    set_CODEN("j-NUMER-ALGEBRA-CONTROL-OPTIM",		"????")
    set_CODEN("j-NUMER-ALGORITHMS",			"NUALEG")
    set_CODEN("j-NUMER-FUNCT-ANAL-OPTIM",		"NFAODL")
    set_CODEN("j-NUMER-HEAT-TRANSFER-B",		"NUHTD6")
    set_CODEN("j-NUMER-METHODS-PARTIAL-DIFFER-EQU",	"NMPDEB")
    set_CODEN("j-NUNCIUS",				"????")
    set_CODEN("j-NUOVO-CIMENTO-1",			"NUCIAD")
    set_CODEN("j-NUOVO-CIMENTO-2",			"NUCIAD")
    set_CODEN("j-NUOVO-CIMENTO-3",			"NUCIAD")
    set_CODEN("j-NUOVO-CIMENTO-4",			"NUCIAD")
    set_CODEN("j-NUOVO-CIMENTO-5",			"NUCIAD")
    set_CODEN("j-NUOVO-CIMENTO-6",			"NUCIAD")
    set_CODEN("j-NUOVO-CIMENTO-7",			"NUCIAD")
    set_CODEN("j-NUOVO-CIMENTO-8",			"NUCIAD")
    set_CODEN("j-NUOVO-CIMENTO-9",			"NUCIAD")
    set_CODEN("j-NUOVO-CIMENTO-10",			"NUCIAD")
    set_CODEN("j-NUOVO-CIMENTO-1955-1965",		"????")
    set_CODEN("j-NUOVO-CIMENTO-A",			"NIFAAM")
    set_CODEN("j-NUOVO-CIMENTO-B",			"NCIBAW")
    set_CODEN("j-NUOVO-CIMENTO-B-11",			"NCIBAW")
    set_CODEN("j-NUOVO-CIMENTO-D",			""NCSDDN)
    set_CODEN("j-NUOVO-CIMENTO-SOC-ITAL-FIS-B",		"NIFBAP")
    set_CODEN("j-NUOVO-CIMENTO-SUPPL",			"NUCUAF")
    set_CODEN("j-NUOVO-SAGGIATORE",			"????")
    set_CODEN("j-NY-TIMES",				"NYTIAO")
    set_CODEN("j-OAK-RIDGER",				"????")
    set_CODEN("j-OBIT-NOTICES-FELLOWS-ROY-SOC",		"????")
    set_CODEN("j-OBJECT-EXPERT",			"OBEXFJ")
    set_CODEN("j-OBJECT-MAG",				"OBMAFO")
    set_CODEN("j-OBSERVATORY",				"OBSEAR")
    set_CODEN("j-OBZORNIK-MAT-FIZ",			"OBMFAY")
    set_CODEN("j-OCEAN",				"OCNSDK")
    set_CODEN("j-OCLC-MICRO",				"OCMIEK")
    set_CODEN("j-OCLC-NEWSLETTER",			"OCLNDT")
    set_CODEN("j-OCTOBER",				"????")
    set_CODEN("j-OCTOGON-MATH-MAG",			"????")
    set_CODEN("j-OECOLOGIA",				"OECOBX")
    set_CODEN("j-OFF-OUR-BACKS",			"????")
    set_CODEN("j-OFFICE-SYS",				"OFSYEH")
    set_CODEN("j-OIKOS",				"OIKSAA")
    set_CODEN("j-OIL-GAS-INVESTOR",			"????")
    set_CODEN("j-OIL-GAS-J",				"OIGJAV")
    set_CODEN("j-OHIO-J-SCI",				"OJSCA9")
    set_CODEN("j-OMEGA",				"OMEGA6")
    set_CODEN("j-ONCOGENE",				"ONCNES")
    set_CODEN("j-ONLINE",				"ONLIDN")
    set_CODEN("j-ONLINE-CDROM-REV",			"ONCDEW")
    set_CODEN("j-OOPS-MESSENGER",			"OOMEEO")
    set_CODEN("j-OPEN-COMPUTING",			"OPCOEB")
    set_CODEN("j-OPEN-J-DISCRETE-MATH",			"????")
    set_CODEN("j-OPEN-SYSTEMS-TODAY",			"????")
    set_CODEN("j-OPER-MATRICES",			"????")
    set_CODEN("j-OPER-RES",				"OPREAI")
    set_CODEN("j-OPER-RES-LETT",			"ORLED5")
    set_CODEN("j-OPER-RES-VERFAHREN",			"ORVEAI")
    set_CODEN("j-OPER-SYS-REV",				"OSRED8")
    set_CODEN("j-OPT-COMM",				"OPCOB8")
    set_CODEN("j-OPT-CTL-APPL-METH",			"OCAMD5")
    set_CODEN("j-OPT-EXPRESS",				"OPEXFF")
    set_CODEN("j-OPT-LET",				"OPLEDP")
    set_CODEN("j-OPT-METH-APPL",			"????")
    set_CODEN("j-OPT-METH-SOFT",			"OMSOE2")
    set_CODEN("j-OPTICA",				"OPTIC8")
    set_CODEN("j-OPTICA-ACTA",				"OPACAT")
    set_CODEN("j-OPTICAL-ENG",				"OPEGAR")
    set_CODEN("j-OPTICS-NEWS",				"ONEWDU")
    set_CODEN("j-OPTICS-PHOTONICS-NEWS",		"OPPHEL")
    set_CODEN("j-OPTICAL-QUANTUM-ELECT",		"OQELDI")
    set_CODEN("j-OPTIK",				"OTIKAJ")
    set_CODEN("j-OPTIM-ENG",				"")
    set_CODEN("j-OPTIM-LETT",				"")
    set_CODEN("j-OPTIM-METHODS-SOFTW",			"")
    set_CODEN("j-OPTIMIZATION",				"OPTZDQ")
    set_CODEN("j-OPTIMIZATSIIA",			"????")
    set_CODEN("j-OPUSCULA-ROMANA",			"????")
    set_CODEN("j-ORACLE-INTEGRATOR",			"ORINEI")
    set_CODEN("j-ORDER-DORDRECHT",			"ORDRE5")
    set_CODEN("j-ORG-BEHAV-HUM-DECIS-PROCESS",		"OBDPFO")
    set_CODEN("j-ORG-GEOCHEM",				"ORGEDE")
    set_CODEN("j-ORGAN-DYN",				"ORDYAM")
    set_CODEN("j-ORIG-LIFE-EVOL-BIOSPH",		"OGLFAU")
    set_CODEN("j-ORSA-J-COMPUT",			"OJCOE3")
    set_CODEN("j-OSIRIS",				"OSIRAX")
    set_CODEN("j-OSIRIS-2",				"OSIRE3")
    set_CODEN("j-OTOLARYNGOL-CLIN-NORTH-AM",		"OCNABW")
    set_CODEN("j-OUD-HOLLAND",				"????")
    set_CODEN("j-OVERS-DAN-VIDENSK-SELSK-VIRKS",	"KVSVA4")
    set_CODEN("j-OXF-SURV-EVOL-BIOL",			"OSEBE3")
    set_CODEN("j-PAC-HIST-REV",				"????")
    set_CODEN("j-PAC-J-APPL-MATH",			"????")
    set_CODEN("j-PAC-J-MATH",				"PJMAAI")
    set_CODEN("j-PAC-NORTHWEST-Q",			"????")
    set_CODEN("j-PACE",					"????")
    set_CODEN("j-PACMPL",				"")
    set_CODEN("j-PAMM",					"")
    set_CODEN("j-PAP-REG-SCI",				"????")
    set_CODEN("j-PARALLEL-ALGORITHMS-APPL",		"PAAPEC")
    set_CODEN("j-PARALLEL-COMPUTING",			"PACOEJ")
    set_CODEN("j-PARALLEL-DIST-COMP-PRACT",		"????")
    set_CODEN("j-PARALLEL-PROCESS-LETT",		"PPLTEE")
    set_CODEN("j-PARALLELOGRAM",			"PRALE")
    set_CODEN("j-PATTERN-RECOGN",			"PTNRA8")
    set_CODEN("j-PATTERN-RECOGN-LETT",			"PRLEDG")
    set_CODEN("j-PC-COMPUTING",				"PCMPEI")
    set_CODEN("j-PC-KURIER",				"????")
    set_CODEN("j-PC-MAGAZINE",				"PCMGEP")
    set_CODEN("j-PC-PUB",				"????")
    set_CODEN("j-PC-PUBL-PRESENT",			"????")
    set_CODEN("j-PC-TECH-J",				"????")
    set_CODEN("j-PC-TECH",				"")
    set_CODEN("j-PC-USER",                              "PCUSDW")
    set_CODEN("j-PC-WEEK",				"????")
    set_CODEN("j-PC-WORLD",				"PCWDDV")
    ## OBSOLETE: set_CODEN("j-PDCP",					"")
    set_CODEN("j-PEDIATRIC-RES",			"????")
    set_CODEN("j-PENTAGON",				"????")
    set_CODEN("j-PERCEPTION-PSYCHOPHYSICS",		"PEPSBJ")
    set_CODEN("j-PERCEPTUAL-MOTOR-SKILLS",		"PMOSAZ")
    set_CODEN("j-PERF-EVAL",				"PEEVD9")
    set_CODEN("j-PERF-EVAL-REV",			"PEREDN")
    set_CODEN("j-PERFORM-COMPUT",			"UNRED5")
    set_CODEN("j-PERFORM-INSTR",			"PEISEL")
    set_CODEN("j-PERFORM-INSTR-J",			"????")
    set_CODEN("j-PERIOD-MATH-HUNGAR",			"PMHGAW")
    set_CODEN("j-PERS-COMP",				"PLCMDL")
    set_CODEN("j-PERS-COMPUT-WORLD",			"PCWODU")
    set_CODEN("j-PERSPECT-SCI",				"PRSIEU")
    set_CODEN("j-PERSPECT-SCI-CHRIST-FAITH",		"????")
    set_CODEN("j-PERSPECTIVES-BIO-MED",			"PBMEA8")
    set_CODEN("j-PESC-RECORD",				"PRICDT")
    set_CODEN("j-PFLUGERS-ARCH",			"PFLABK")
    set_CODEN("j-PHARM-J",				"PHJOAV")
    set_CODEN("j-PHARM-RES",				"PHREEB")
    set_CODEN("j-PHARMAZIE",				"PHARAT")
    set_CODEN("j-PHARMACOL-THER-OXF",			"PHTHDT")
    set_CODEN("j-PHASE-TRANSIT",			"PHTRDP")
    ## BAD: set_CODEN("j-PHILOS-MAG",			"PHMAA4, PMHAA4")
    set_CODEN("j-PHILOS-MAG",			"PHMAA4")	# [04-Jan-2006] corrected
    set_CODEN("j-PHIL-MAGAZINE-5",			"")
    set_CODEN("j-PHIL-MAGAZINE-6",			"")
    set_CODEN("j-PHILIPS-J-RES",			"PHJRD9")
    set_CODEN("j-PHILOS-MAG-6",				"PHMAA4")
    set_CODEN("j-PHILOS-MAG-7",				"PHMAA4")
    set_CODEN("j-PHILOS-MAG-8",				"PHMAA4")
    set_CODEN("j-PHILOS-MAG-A",				"PMAADG")
    set_CODEN("j-PHILOS-MAG-B",				"PMABDJ")
    set_CODEN("j-PHILOS-MAG-LETT",			"PMLEEG")
    set_CODEN("j-PHILOS-MATH-3",			"")
    set_CODEN("j-PHILOS-NATUR",				"????")
    set_CODEN("j-PHILOS-PHENOMENOL-RES",		"PPHRAI")
    set_CODEN("j-PHILOS-PSYCHOL",			"????")
    set_CODEN("j-PHILOS-SCI",				"PHSCA6")
    set_CODEN("j-PHILOS-SOC-SCI",			"????")
    set_CODEN("j-PHILOS-STUD",				"PLSDA3")
    set_CODEN("j-PHILOS-TOP",				"????")
    set_CODEN("j-PHILOS-TRANS-R-SOC-LOND",		"PTRSAV")
    set_CODEN("j-PHILOS-TRANS-R-SOC-LOND-A-CONTAIN-PAP-MATH-PHYS-CHARACTER",	"????")
    set_CODEN("j-PHILOS-TRANS-R-SOC-LOND-PHYS-SCI-ENG",	"????")
    set_CODEN("j-PHILOS-TRANS-R-SOC-LOND-SER-A",	"PTRMAD, PTMSFB")
    set_CODEN("j-PHILOS-TRANS-R-SOC-LOND-SER-A-MATH-PHYS-SCI",	"PTRMAD")
    set_CODEN("j-PHILOS-TRANS-R-SOC-LOND-SER-B-BIO-SCI", "PTRBAE")
    set_CODEN("j-PHOTO-ELECTRON-IMAGING",		"PELIE6")
    set_CODEN("j-PHOTOCHEM-PHOTOBIO",			"PHCBAP")
    set_CODEN("j-PHOTOGR-SCI-ENG",			"PSENAC")
    set_CODEN("j-PHOTOMETHODS",				"PHOTD6")
    set_CODEN("j-PHOTONICS-NANOSTRUCT",			"????")
    set_CODEN("j-PHOTONIQUES",				"????")
    set_CODEN("j-PHYS-AT-NUCL",				"PANUEO")
    set_CODEN("j-PHYS-BL",				"PHBLAG")
    set_CODEN("j-PHYS-BULL",				"PHSBB4")
    set_CODEN("j-PHYS-CANADA",				"????")
    set_CODEN("j-PHYS-CHEM-CHEM-PHYS",			"PPCPFQ")
    set_CODEN("j-PHYS-CHEM-LIQ",			"PCLQAC")
    set_CODEN("j-PHYS-CHEM-MINERALS",			"PCMIDU")
    set_CODEN("j-PHYS-EARTH-PLANET-INTER",		"PEPIAM")
    set_CODEN("j-PHYS-EDUC",				"PHEDA7")
    set_CODEN("j-PHYS-ESSAYS",				"PHESEM")
    set_CODEN("j-PHYS-FLUIDS",				"PHFLE6")
    set_CODEN("j-PHYS-FLUIDS-1958",			"PFLDAS")
    set_CODEN("j-PHYS-FLUIDS-A",			"PFADEB")
    set_CODEN("j-PHYS-J",				"PJHOB2")
    set_CODEN("j-PHYS-LET",				"PYLBAJ")
    set_CODEN("j-PHYS-LET-A",				"PYLAAG")
    set_CODEN("j-PHYS-LET-B",				"PYLBAJ", 1)
    set_CODEN("j-PHYS-MED-BIOL",			"PHMBA7")
    set_CODEN("j-PHYS-NORVEG",				"PHNOAH")
    set_CODEN("j-PHYS-PART-NUCL",			"PPNUER")
    set_CODEN("j-PHYS-PERSPECT",			"PHPEF2")
    set_CODEN("j-PHYS-PLASMAS",				"PHPAEN")
    set_CODEN("j-PHYS-PROCEDIA",			"PPHRCK")
    set_CODEN("j-PHYS-REP",				"PRPLCM")
    set_CODEN("j-PHYS-REV",				"PHRVAO")
    set_CODEN("j-PHYS-REV-1",				"PHRVAO", 1)
    set_CODEN("j-PHYS-REV-2",				"PHRVAO", 1)
    set_CODEN("j-PHYS-REV-A",				"PLRAAN")
    set_CODEN("j-PHYS-REV-A-3",				"PLRAAN")
    set_CODEN("j-PHYS-REV-B",				"PRBHB7")
    set_CODEN("j-PHYS-REV-B-CMMP",			"PRBMDO")
    set_CODEN("j-PHYS-REV-B-SS",			"PLRBAQ")
    set_CODEN("j-PHYS-REV-C",				"PRVCAN")
    set_CODEN("j-PHYS-REV-D",				"PRVDAQ")
    set_CODEN("j-PHYS-REV-E",				"PLEEE8")
    set_CODEN("j-PHYS-REV-FOCUS",			"PRFHAQ")
    set_CODEN("j-PHYS-REV-LET",				"PRLTAO")
    set_CODEN("j-PHYS-REV-X",				"PRXHAE")
    set_CODEN("j-PHYS-STATUS-SOLIDI",			"PHSSAK")
    set_CODEN("j-PHYS-STATUS-SOLIDI-A-APPL-RES",	"PSSABA")
    set_CODEN("j-PHYS-STATUS-SOLIDI-B-BASIC-RES",	"PSSBBD")
    set_CODEN("j-PHYS-STATUS-SOLIDI-RAPID-RES-LETT",	"????")
    set_CODEN("j-PHYS-TEACHER",				"PHTEAH")
    set_CODEN("j-PHYS-TODAY",				"PHTOAD")
    set_CODEN("j-PHYS-UNSERER-ZEIT",			"PHUZAH")
    set_CODEN("j-PHYS-USPEKHI",				"PHUSEY")
    set_CODEN("j-PHYS-WORLD",				"PHWOEW")
    set_CODEN("j-PHYS-Z-SOWJETUNION",			"PHZSAL")
    set_CODEN("j-PHYSICA",				"PHYSAG")
    set_CODEN("j-PHYSICA-A",				"PHYADX")
    set_CODEN("j-PHYSICA-B",				"PHYBE3")
    set_CODEN("j-PHYSICA-B-PLUS-C",			"PHBCDQ")
    set_CODEN("j-PHYSICA-C",				"PHYCE6")
    set_CODEN("j-PHYSICA-D",				"PDNPDT")
    set_CODEN("j-PHYSICA-SCRIPTA",			"PHSTBO")
    set_CODEN("j-PHYSICA-THE-HAGUE",			"PYSIA7")
    set_CODEN("j-PHYSICS",				"????")
    set_CODEN("j-PHYSIKAL-Z",				"PHZTAO")
    set_CODEN("j-PHYSIOL-CHEM-PHYS",			"PLCHB4")
    set_CODEN("j-PHYSIOL-REV",				"PHREA7")
    set_CODEN("j-PHYSIS",				"PYSSA3")
    set_CODEN("j-PHYSIS-NS",				"PYSSA3")
    set_CODEN("j-PI-MU-EPSILON-J",			"PMEJBR")
    set_CODEN("j-PITMAN-RES-NOTES-MATH-SER",		"????")
    set_CODEN("j-PLANET-SPACE-SCI",			"PLSSAE")
    set_CODEN("j-PLANT-J",				"PLJUED")
    set_CODEN("j-PLANT-MOL-BIO",			"PMBIDB")
    set_CODEN("j-PLANTA",				"PLANAB")
    set_CODEN("j-PLASMA-IONS",				"PLIOFP")
    set_CODEN("j-PLASMA-PHYS",				"PLPHBZ")
    set_CODEN("j-PLASMA-PHYS-CONTROL-FUSION",		"PPCFET")
    set_CODEN("j-PLASMID",				"PLSMDX")
    set_CODEN("j-PLATIN-MET-REV",			"PTMRA3")
    set_CODEN("j-PLI-BULL",				"????")
    set_CODEN("j-PLISKA-STUD-MATH-BULGAR",		"????")
    set_CODEN("j-PLOS-COMPUT-BIOL",			"PCBLBG")
    set_CODEN("j-PLOS-MED",				"PMLEAC")
    set_CODEN("j-PLOS-ONE",				"POLNCL")
    set_CODEN("j-POKROKY-MAT-FYS-ASTRON",		"PMFAA4")
    set_CODEN("j-POLIT-ANAL",				"????")
    set_CODEN("j-POLITY",				"????")
    set_CODEN("j-POLYMER",				"POLMAG")
    set_CODEN("j-POLYMER-J-TOKYO",			"POLJB8")
    set_CODEN("j-POMACS",				"????")
    set_CODEN("j-POP-COMP",				"????")
    set_CODEN("j-POP-COMP-CALABASAS",			"????")
    set_CODEN("j-PORT-MATH",				"")
    set_CODEN("j-POSITIVITY",				"????")
    set_CODEN("j-POSTSCRIPT-LANG-J",			"????")
    set_CODEN("j-POTENTIAL-ANAL",			"POANE2")
    set_CODEN("j-POWDER-DIFF",				"PODIE2")
    set_CODEN("j-PRAGMATICS-COGNITION",			"PCOGEZ")
    set_CODEN("j-PRAMANA",				"PRAMCI")
    set_CODEN("j-PRIKL-MAT-MEH",			"PMAMAF")
    set_CODEN("j-PRIKL-PROBLEMY-PROCH-I-PLAST",		"")
    set_CODEN("j-PRIMUS",				"????")
    set_CODEN("j-PRINT",				"????")
    set_CODEN("j-PRINTING-PRODUCTION",			"PRPRA4")
    set_CODEN("j-PRINTING-WORLD",			"PROWAE")
    set_CODEN("j-PRIRODA-MOSCOW",			"PRIRA3")
    set_CODEN("j-PROB-ENG-MECH",			"PEMEEX")
    set_CODEN("j-PROB-ENG-INFO-SCI",			"????")
    set_CODEN("j-PROBAB-SURV",				"????")
    set_CODEN("j-PROBAB-ENGRG-INFORM-SCI",		"????")
    set_CODEN("j-PROBAB-THEORY-RELAT-FIELDS",		"PTRFEU")
    set_CODEN("j-PROBL-INF-TRANSM",			"PRITA9")
    set_CODEN("j-PROBL-PEREDA-INF",			"PPDIA5")
    set_CODEN("j-PROC-ACM-SYMP-APPL-COMPUTING",		"????")
    set_CODEN("j-PROC-AM-ACAD-ARTS-SCI",		"PAAAAV")
    set_CODEN("j-PROC-AM-CONTROL-CONF",			"PRACEO")
    set_CODEN("j-PROC-AM-MATH-SOC",			"PAMYAR")
    set_CODEN("j-PROC-AMER-PHIL-SOC",			"PAPCAA")
    set_CODEN("j-PROC-ANN-SYMP-COMPUT-APPL-MED-CARE",	"????")
    set_CODEN("j-PROC-ANNUAL-SOUTHEAST-CONFERENCE",	"????")
    set_CODEN("j-PROC-ASEE-ANNU-CONF",			"ACOPDW")
    set_CODEN("j-PROC-ASIS-AM",				"PAISDQ")
    set_CODEN("j-PROC-CAMBRIDGE-PHIL-SOC",		"PCPSA4")
    set_CODEN("j-PROC-CHEM-SOC-LONDON",			"PCSLAW")
    set_CODEN("j-PROC-CMAANU",				"????")
    set_CODEN("j-PROC-CONTROL-AUTOMATION",		"PCAUA3")
    set_CODEN("j-PROC-EDINBURGH-MATH-SOC",		"PEMSA3")
    set_CODEN("j-PROC-EDINBURGH-MATH-SOC-2",		"PEMSA3")
    set_CODEN("j-PROC-GRAPHICS-INTERFACE",		"PGINEK")
    set_CODEN("j-PROC-ICASSP",				"IPRODJ")
    set_CODEN("j-PROC-IEE",				"PIEEAH")
    set_CODEN("j-PROC-IEEE",				"IEEPAD")
    set_CODEN("j-PROC-IEEE-INT-COMP-SOFTWARE-APPL-CONF","PSICD2")
    set_CODEN("j-PROC-IEEE-CONF-DECISION-CONTROL",	"PCDCDZ")
    set_CODEN("j-PROC-IEEE-CONF-SYST-MAN-CYBERN",	"PICYE3")
    set_CODEN("j-PROC-IEEE-INT-SOFTWARE-ENG-STAND-SYMP","????")
    set_CODEN("j-PROC-IEEE-WORK-REAL-TIME-OPER-SYS-SOFTWARE","????")
    set_CODEN("j-PROC-IMP-ACAD-TOKYO",			"????")
    set_CODEN("j-PROC-INDIAN-ACAD-SCI-CHEM-SCI",	"PIAADM")
    set_CODEN("j-PROC-INDIAN-ACAD-SCI-SECT-A",		"PISAA7")
    set_CODEN("j-PROC-INST-STATIST-MATH",		"????")
    set_CODEN("j-PROC-INT-CONF-DIST-COMPUT-SYS",	"PICSEJ")
    set_CODEN("j-PROC-INT-CONF-PAR-PROC",		"PCPADL")
    set_CODEN("j-PROC-INT-CONF-REQUIREMENTS-ENG",	"????")
    set_CODEN("j-PROC-INT-CONF-SOFTWARE-ENG",		"PCSEDE")
    set_CODEN("j-PROC-INT-CONF-SUPERCOMPUTING",		"????")
    set_CODEN("j-PROC-INT-MEETING-PETROLEUM-ENG",	"????")
    set_CODEN("j-PROC-INT-TEST-CONF",			"????")
    set_CODEN("j-PROC-IRE",				"PIREAE")
    set_CODEN("j-PROC-J-MATH",				"????")
    set_CODEN("j-PROC-JAPAN-ACAD-SER-A-MATH-SCI",	"PJAADT")
    set_CODEN("j-PROC-LINN-SOC-LONDON",			"PLSLAR")
    set_CODEN("j-PROC-LONDON-MATH-SOC-1",		"PLMTAL")
    set_CODEN("j-PROC-LONDON-MATH-SOC-2",		"PLMTAL")
    set_CODEN("j-PROC-LONDON-MATH-SOC-3",		"PLMTAL")
    set_CODEN("j-PROC-MANCHESTER-LIT-PHILOS-SOC",	"MPMLAQ", 1)
    set_CODEN("j-PROC-NATL-ACAD-SCI-USA",		"PNASA6")
    set_CODEN("j-PROC-NATL-ONLINE-MEET",		"PNOMDR")
    set_CODEN("j-PROC-PETROLEUM-COMPUT-CONF",		"PPCMEG")
    set_CODEN("j-PROC-PHYS-SOC",			"PPSOAU")
    set_CODEN("j-PROC-PHYS-SOC-LONDON-SECT-A",		"PPSAAM")
    set_CODEN("j-PROC-PHYS-SOC-LONDON-SECT-B",		"PPSBAP")
    set_CODEN("j-PROC-R-INST-G-B",			"PIGBAI")
    set_CODEN("j-PROC-R-IR-ACAD-SECT-A",		"PRIAAK")
    set_CODEN("j-PROC-R-SOC-B",				"PRSBC7")
    set_CODEN("j-PROC-R-SOC-EDINB",			"PRSEAE")
    ## set_CODEN("j-PROC-R-SOC-EDINB-A",			"PREAAY")
    ## WRONG: set_CODEN("j-PROC-R-SOC-EDINB-SECT-A-MATH",		"PREAAY", 1)
    set_CODEN("j-PROC-R-SOC-EDINB-SECT-A-MATH",		"PEAMDU")
    set_CODEN("j-PROC-R-SOC-EDINB-SECT-A-MATH-PHYS-SCI", "PREAAY")
    set_CODEN("j-PROC-R-SOC-EDINB-SECT-B-BIOL-SCI",	"PRSSDP")
    set_CODEN("j-PROC-R-SOC-EDINB-SECT-B-NAT-ENVIRON",	"PREBA3")
    set_CODEN("j-PROC-R-PHILOS-SOC-GLASGOW",		"PHIJBC")
    set_CODEN("j-PROC-R-SOC-LOND",			"PRSLAZ")
    set_CODEN("j-PROC-R-SOC-LOND-SER-A-MATH-PHYS",	"????")
    set_CODEN("j-PROC-R-SOC-LOND-SER-A-MATH-PHYS-ENG-SCI",	"PRLAAZ") # same as next one according to Publication In Engineering (PIE)
    set_CODEN("j-PROC-R-SOC-LOND-SER-A-MATH-PHYS-SCI",	"PRLAAZ", 1)
    set_CODEN("j-PROC-R-SOC-LOND-SER-A",		"PRLAAZ", 1)
    set_CODEN("j-PROC-R-SOC-LOND-SER-B",		"PRLBA4")
    set_CODEN("j-PROC-R-SOC-LOND-SER-B-BIO-SCI",	"PRLBA4")
    set_CODEN("j-PROC-REAL-TIME-SYS-SYMP",		"PRSYEA")
    set_CODEN("j-PROC-SID",				"SIDPAA")
    set_CODEN("j-PROC-SOC-EXP-BIOL-MED",		"PSEBAA")
    set_CODEN("j-PROC-SOC-PSYCH-RES",			"PPSRA5")
    set_CODEN("j-PROC-SOIL-SCI-SOC-AM",			"SSSAA8")
    set_CODEN("j-PROC-SPIE",				"PSISDG")
    set_CODEN("j-PROC-STEKLOV-INST-MATH",		"TMISAF")
    set_CODEN("j-PROC-SUPERCOMPUT",			"????")
    set_CODEN("j-PROC-SYMP-APPL-MATH",			"PSYMA7")
    set_CODEN("j-PROC-SYMP-PURE-MATH",			"????")
    set_CODEN("j-PROC-VLDB-ENDOWMENT",			"????")
    set_CODEN("j-PROCEDIA-SOC-BEHAV-SCI",		"????")
    set_CODEN("j-PROG-ASTRONAUT-AERONAUT",		"PAAEA9")
    set_CODEN("j-PROG-BIOPHYS-BIOPHYS-CHEM",		"PBBCAF")
    set_CODEN("j-PROG-BIOPHYS-MOL-BIOL",                "PBIMAC")
    set_CODEN("j-PROG-CELL-CYCLE-RES",			"????")
    set_CODEN("j-PROG-CLIN-BIO-RES",			"PCBRD2")
    set_CODEN("j-PROG-COMP-SOFT",			"PCSODA")
    set_CODEN("j-PROG-ELECTROMAGN-RES",			"PELREX")
    set_CODEN("j-PROG-NUCL-PHYS",			"PNUPAT")
    set_CODEN("j-PROG-NUCLEIC-ACID-RES-MOL-BIO",	"PNMBAF")
    set_CODEN("j-PROG-PART-NUCL-PHYS",			"PPNPDB")
    set_CODEN("j-PROG-SURF-SCI",			"PSSFBP")
    set_CODEN("j-PROG-THEOR-PHYS",			"PTPKAV")
    set_CODEN("j-PROGR-OCEANOGR",			"POCNA8")
    set_CODEN("j-PROGRAM",				"PRGRDU, PRGMBD")
    set_CODEN("j-PROGRAM-J",				"????")
    set_CODEN("j-PROGRAMMIROVANIE",			"PROGD3")
    set_CODEN("j-PROGRESS-NUCLEAR-ENERGY",		"PNENDE")
    set_CODEN("j-PROLOGUE",				"????")
    set_CODEN("j-PROTEIN-SEQ-DATA-ANAL",		"PSDAE6")
    set_CODEN("j-PROTEIN-STRUCT-FUNCT-BIOINF",		"PSFBAF")
    set_CODEN("j-PROTEIN-STRUCT-MOL-ENZYM",		"BBACAQ", 1)
    set_CODEN("j-PROTEINS",				"PSFGEY")
    set_CODEN("j-PROTOPLASMA",				"PROTA5")
    set_CODEN("j-PSYCH-WOMEN",				"PWOQDY")
    set_CODEN("j-PSYCHIATRY",				"PSYCAB")
    set_CODEN("j-PSYCHOL-METHODS",			"????")
    set_CODEN("j-PSYCHOL-REP",				"PYRTAZ")
    set_CODEN("j-PSYCHOL-REV",				"PSRVAX")
    set_CODEN("j-PSYCHOMETRIKA",			"PSMIA3")
    set_CODEN("j-PTERIDINES",				"PTRDEO")
    set_CODEN("j-PUB-AFFAIRS-QUART",			"????")
    set_CODEN("j-PUB-CENTRE-EUR-ETUDES-BURGONDO-MEDIANES", "????")
    set_CODEN("j-PUB-MAT",				"????")
    set_CODEN("j-PUB-RELATIONS-REV",			"PREREL")
    set_CODEN("j-PUBL-ASTRON-SOC-JPN",			"PASJAC")
    set_CODEN("j-PUBL-ASTRON-SOC-PAC",			"PASPAU")
    set_CODEN("j-PUBL-MATH-DEBRECEN",			"PUMAAR")
    set_CODEN("j-PUBL-RELAT-J",				"PREJAR")
    set_CODEN("j-PUBLIC-ACCESS-COMPUT-SYST-REV",	"????")
    set_CODEN("j-PUBLIC-MANAGE",			"????")
    set_CODEN("j-PUBLISH",				"PBLIEJ")
    set_CODEN("j-PUBLISHERS-WEEKLY",			"????")
    set_CODEN("j-PUBLISHING",				"PUBLFA")
    set_CODEN("j-PUBLISHING-PROD-EXEC",			"PPEXEP")
    set_CODEN("j-PUGET-SOUND-BUS-J",			"")
    set_CODEN("j-PURE-APPL-CHEM",			"PACHAS")
    set_CODEN("j-PURE-APPL-GEOPHYS",			"PAGYAV")
    set_CODEN("j-PYRODYNAMICS",				"????")
    set_CODEN("j-Q-J-ECON",				"QJECAT")
    set_CODEN("j-Q-J-R-ASTRON-SOC",			"QJRAAK")
    set_CODEN("j-Q-REV-BIOL",				"QRBIAK")
    set_CODEN("j-QCPE",					"QCBUEN")
    set_CODEN("j-QJM",					"QTMJAO")
    set_CODEN("j-QRB",					"QRBUDP")
    set_CODEN("j-QSAR",					"QSARDI")
    set_CODEN("j-QUAD-STORIA-FISICA",			"????")
    set_CODEN("j-QUAD-UNIONE-MAT-ITAL",			"????")
    set_CODEN("j-QUAERENDO",				"????")
    set_CODEN("j-QUAL-QUANT",				"QQEJAV")
    set_CODEN("j-QUANT-FINANCE",			"????")
    set_CODEN("j-QUANTUM-INF-PROCESS",			"QIPUAT")
    set_CODEN("j-QUART-APPL-MATH",			"QAMAAY")
    set_CODEN("j-QUART-J-MATH",				"QJMAAT")
    set_CODEN("j-QUART-J-MATH-OXFORD",			"QJMAAT", 1)
    set_CODEN("j-QUART-J-MECH-APPLIED-MATH",		"QJMMAV")
    set_CODEN("j-QUART-J-MICROSCOP-SCI",		"QJMSAF")
    set_CODEN("j-QUART-J-ROY-METEOROL-SOC",		"QJRMAM")
    set_CODEN("j-QUEUE",				"AQCUAE")
    set_CODEN("j-QUILL",				"????")
    set_CODEN("j-R-SOC-OPEN-SCI",			"RSOSAV")
    set_CODEN("j-RADIAT-PHYS-CHEM",			"RPCHDM")
    set_CODEN("j-RADIAT-RES",				"RAREAE")
    set_CODEN("j-RADIO-ELECTRON-ENG",			"RDEEA4")
    set_CODEN("j-RADIO-SCI",				"RASCAD")
    set_CODEN("j-RADIOCHIM-ACTA",			"RAACAP")
    set_CODEN("j-RADIOLOGY",				"RADLAX")
    set_CODEN("j-RADIUM-PARIS",				"RADMA2")
    set_CODEN("j-RAIRO-AUTOMATIQUE-SYSTEMS-ANA-CONTROL","RFAADN")
    set_CODEN("j-RAIRO-NUM-ANA",			"RFANDS")
    set_CODEN("j-RAIRO-RECH-OPER",			"RSROD3")
    set_CODEN("j-RAMANUJAN-J",				"")
    set_CODEN("j-RAND-COMP-DYN",			"RCDYEM")
    set_CODEN("j-RAND-STRUCT",				"RSALFD")
    set_CODEN("j-RAPP-RECH",				"LCRCAO")
    set_CODEN("j-RCA-REV",				"RCARCI")
    set_CODEN("j-READERS-DIGEST",			"RDIGAU")
    set_CODEN("j-REAL-TIME-IMAGING",			"REIMFQ")
    set_CODEN("j-REAL-TIME-SYST",			"RESYE9")
    set_CODEN("j-REC-MATH-MAG",				"RMMGAB")
    set_CODEN("j-RECHENTECH-DATENVERARB",		"RTDVAQ")
    set_CODEN("j-RECHERCHE",				"RCCHBV")
    set_CODEN("j-REF-LIBR",				"RELBD6")
    set_CODEN("j-REG-SCI-URBAN-ECON",			"RSUEDM")
    set_CODEN("j-REGISTER",				"????")
    set_CODEN("j-RELIABLE-COMPUTING",			"RCOMF8")
    set_CODEN("j-RENAISSANCE-Q",			"????")
    set_CODEN("j-REND-CIRC-MAT",			"RCMMAR")
    set_CODEN("j-REND-CIRC-MAT-II",			"????")
    set_CODEN("j-REND-LINCEI",				"AANLAW")
    set_CODEN("j-REND-MAT-APPL-1981",			"RNMTAN")
    set_CODEN("j-REP-BRIT-ASSOC-ADV-SCI",		"????")
    set_CODEN("j-REP-MATH-PHYS",			"RMHPBE")
    set_CODEN("j-REP-OBJECT-ANA-DESIGN",                "")
    set_CODEN("j-REP-PROG-PHYS",			"RPPHAG")
    set_CODEN("j-RES-DEV",				"REDEEA")
    set_CODEN("j-RES-MATH-SCI",				"????")
    set_CODEN("j-RES-MICROBIOL",			"ANMBCM")
    set_CODEN("j-RES-NOTES-MATH",			"????")
    set_CODEN("j-RES-OP",				"????")
    set_CODEN("j-RES-POLICY",				"????")
    set_CODEN("j-RESONANCE",				"RESOFE")
    set_CODEN("j-RESOUR-SHAR-INF-NETW",			"????")
    set_CODEN("j-RESULTS-MATH",				"????")
    set_CODEN("j-RESUSCITATION",			"RSUSBS")
    set_CODEN("j-RETE",					"RETECK")
    set_CODEN("j-REV-AM-HIST",				"????")
    set_CODEN("j-REV-ANAL-NUMER-TEORIA-APROX",		"????")
    set_CODEN("j-REV-BRAS-FIS",				"RBFSA3")
    set_CODEN("j-REV-ECON-STAT",			"RECSA9")
    set_CODEN("j-REV-ECON-STUD",			"")
    set_CODEN("j-REV-ELECTR-COMMUN-LAB",		"RELTAN")
    set_CODEN("j-REV-ESP-ELECT",			"RVEEBT")
    set_CODEN("j-REV-ESP-FISIOL",			"REFIAS")
    set_CODEN("j-REV-FINANCE",				"????")
    set_CODEN("j-REV-FISH-BIOL-FISH",			"RFBFEA")
    set_CODEN("j-REV-FISH-SCI-AQUAC",			"????")
    set_CODEN("j-REV-GEN-ELECTR",			"RGELAC")
    set_CODEN("j-REV-GEN-SCI-PURES-APPL",		"")
    set_CODEN("j-REV-GEOPHYS-SPACE-PHYS",		"RGPSBL")
    set_CODEN("j-REV-HIST-MATH",			"")
    set_CODEN("j-REV-HIST-SCI-LEURS-APPL",		"RHSAAM")
    set_CODEN("j-REV-HIST-SCI",				"RHSAAM")
    set_CODEN("j-REV-INST-INT-STATIST",			"????")
    set_CODEN("j-REV-INT-ECON",				"????")
    set_CODEN("j-REV-MATH-IBER",			"????")
    set_CODEN("j-REV-MATH-PHYS",			"RMPHEX")
    set_CODEN("j-REV-METAPHYS",				"????")
    set_CODEN("j-REV-METAPHYS-MORALE",			"????")
    set_CODEN("j-REV-MEX-FIS",				"RMXFAT")
    set_CODEN("j-REV-MOD-PHYS",				"RMPHAT")
    set_CODEN("j-REV-NETW-ECON",			"????")
    set_CODEN("j-REV-PHILOS-FR-ETRANG",			"????")
    set_CODEN("j-REV-PORT-PHILOS",			"????")
    set_CODEN("j-REV-QUEST-SCI",			"RQSCAN")
    set_CODEN("j-REV-SCI-INSTRUM",			"RSINAK")
    set_CODEN("j-REV-SYMB-LOG",				"????")
    set_CODEN("j-REV-SYNTH",				"")
    set_CODEN("j-REV-TUN",				"????")
    set_CODEN("j-RF-DESIGN",				"RFDEDG")
    set_CODEN("j-RHEOL-ACTA",				"RHEAAK")
    set_CODEN("j-RHET-SOC-Q",				"????")
    set_CODEN("j-RIC-MAT",				"RCMTAE")
    set_CODEN("j-RIC-SCI",				"RISCAZ")
    set_CODEN("j-RIC-SCI-PROG-TEC",			"RSPTB6")
    set_CODEN("j-RISK-ANAL",				"RIANDF")
    set_CODEN("j-RISK-MANAGEMENT",			"????")
    set_CODEN("j-RISKNEWS",				"????")
    set_CODEN("j-RIV-INFO-FIRENZE",			"RIINDL")
    set_CODEN("j-RIV-INFO-MILANO",			"????")
    set_CODEN("j-RIV-MAT-UNIV-PARMA",			"????")
    set_CODEN("j-RIV-NUOVO-CIMENTO",			"RNUCAC")
    set_CODEN("j-ROBOTICS-AGE",				"ROAGD2")
    set_CODEN("j-ROCKY-MOUNTAIN-J-MATH",		"RMJMAE")
    set_CODEN("j-ROCZ-FILOZ",				"RFLZBF")
    set_CODEN("j-ROCZ-POL-TOW-MAT-SER-2",		"RPTWAD")
    set_CODEN("j-ROUX-ARCH-DEV-BIOL",			"RADBE7")
    set_CODEN("j-RS-MAGAZINE",				"????")
    set_CODEN("j-RS-POWER-PC-MAGAZINE",			"????")
    set_CODEN("j-RSR",					"????")
    set_CODEN("j-RUSS-J-MATH-PHYS",			"RJMPEL")
    set_CODEN("j-RUSS-J-NUM-ANAL-MATH-MODEL",		"RJNMEH")
    set_CODEN("j-RUSS-J-PHYS-CHEM-A",			"RJPCBS")
    set_CODEN("j-RUSS-J-PHYS-CHEM-B",			"RJPCCT")
    set_CODEN("j-RUSS-LIT",				"????")
    set_CODEN("j-RUSS-MATH",				"????")
    set_CODEN("j-RUSS-MATH-SURV",			"????")
    set_CODEN("j-RUTGERS-COMPUT-TECHNOL-LAW-J",		"RCTJDM")
    set_CODEN("j-RUTGERS-J-COMP-TECH-LAW",		"RJCLDQ")
    set_CODEN("j-S-B-AKAD-WISS-WIEN-MATH-NATURWISS-KL-ABT-2A",	"SWWPAX")
    set_CODEN("j-S-B-KAISERL-AKAD-WISS",		"SWWPAX, 1")
    set_CODEN("j-S-B-KONIG-PREUSS-AKAD-WISS",		"SPAWAV")
    set_CODEN("j-S-B-KONIG-PREUSS-AKAD-WISS-BERLIN",	"SPAWAV")
    set_CODEN("j-S-B-MATH-NATURWISS-KL-KAISERL-AKAD-WISS", "SWWPAX", 1)
    set_CODEN("j-S-B-PREUSS-AKAD-WISS",			"SPAWAV")
    set_CODEN("j-S-B-PREUSS-AKAD-WISS-BERLIN",		"")
    set_CODEN("j-S-B-PREUSS-AKAD-WISS-PHYS-MATH-KL",	"SPWPAI")
    set_CODEN("j-SAMPL-THEORY-SIGNAL-IMAGE-PROCESS",	"????")
    set_CODEN("j-SAN-JOSE-MERCURY-NEWS",		"????")
    set_CODEN("j-SANKHYA",				"SNKYA5")
    set_CODEN("j-SANKHYA-A",				"SANABS")
    set_CODEN("j-SANKHYA-B",				"SANBBV")
    set_CODEN("j-SANTA-CLARA-COMP-HI-TECH-LAW-J",	"????")
    set_CODEN("j-SCAND-ACTUAR-J",			"SAJODI")
    set_CODEN("j-SCAND-J-HAEMATOL",			"SJHAAQ")
    set_CODEN("j-SCAND-J-STAT",				"SJSADG")
    set_CODEN("j-SCAND-J-THORAC-CARDIOVASC-SURG",	"SJTCAO")
    set_CODEN("j-SCANNING-MICROSCOPY",			"SEMYBL")
    set_CODEN("j-SCH-PUBL",				"????")
    set_CODEN("j-SCH-REV",				"SCLRAE")
    set_CODEN("j-SCHOOL-LIBR-J",			"????")
    set_CODEN("j-SCHOOL-SCI-MATH",			"SSMAAC")
    set_CODEN("j-SCHWEIZ-TECH-Z",			"STZTA5")
    set_CODEN("j-SCI-ADV",				"SACDAF")
    set_CODEN("j-SCI-AMER",				"SCAMAC")
    set_CODEN("j-SCI-CHINA-MATH",			"????")
    set_CODEN("j-SCI-CHINA-SER-E-TECH-SCI",		"SCETFO")
    set_CODEN("j-SCI-CITIZEN",				"????")
    set_CODEN("j-SCI-COMPUT",				"SCHRCU")
    set_CODEN("j-SCI-COMPUT-PROGRAM",			"SCPGD4")
    set_CODEN("j-SCI-CONTEXT",				"SCCOEW")
    set_CODEN("j-SCI-CULT",				"????")
    set_CODEN("j-SCI-EDUC",				"SEDUAV")
    set_CODEN("j-SCI-EDUC-SPRINGER",			"SCEDE9")
    set_CODEN("j-SCI-FICT-STUD",			"????")
    set_CODEN("j-SCI-INF-BULL",				"SINBEM")
    set_CODEN("j-SCI-LIGHT-TOKYO",			"SCLIAL")
    set_CODEN("j-SCI-MATH-JPN",				"????")
    set_CODEN("j-SCI-MONTHLY",				"SCMOAA")
    set_CODEN("j-SCI-NEWS-LETT",			"SNLEAI")
    set_CODEN("j-SCI-PROC-ROY-DUBLIN-SOC",		"SPRDAP")
    set_CODEN("j-SCI-PROG",				"SCIPEV")
    set_CODEN("j-SCI-PROG-RUSHDEN-UK",			"SCPRAY")
    set_CODEN("j-SCI-PUBLIC-POL",			"????")
    set_CODEN("j-SCI-REP",				"SRCEC3")
    set_CODEN("j-SCI-REV-MENT-HEALTH-PRAC",		"????")
    set_CODEN("j-SCI-SOC",				"????")
    set_CODEN("j-SCI-STUD",				"????")
    set_CODEN("j-SCI-TEACHER",				"")
    set_CODEN("j-SCI-TECHNOL-HUMAN-VALUES",		"????")
    set_CODEN("j-SCI-TECHNOL-JPN",			"STJAE8")
    set_CODEN("j-SCI-TECHNOL-LIB",			"????")
    set_CODEN("j-SCIENCE",				"SCIEAS")
    set_CODEN("j-SCIENCE-NEWS",				"SCNEBK")
    set_CODEN("j-SCIENCE-SOFTWARE",			"SCISE6")
    set_CODEN("j-SCIENCES",				"SCNCAD")
    set_CODEN("j-SCIENTIA-MILAN",			"SCIMAI")
    set_CODEN("j-SCIENTIST",				"????")
    set_CODEN("j-SCIENTOMETRICS",			"SCNTDX")
    set_CODEN("j-SCITECH-J",				"SITJE8")
    set_CODEN("j-SCR-METALL",				"SCRMBU")
    set_CODEN("j-SCR-METALL-MATER",			"SCRMEX")
    set_CODEN("j-SCREEN",				"????")
    set_CODEN("j-SEARCHER",				"SMDPE8")
    set_CODEN("j-SECOND-MESSENGERS-PHOSPHOPROTEINS",	"SMEPED")
    set_CODEN("j-SECURITY",				"SECUEU")
    set_CODEN("j-SEJ",					"SEJOED")
    set_CODEN("j-SEM-CELL-BIOL",			"SCEBE3")
    set_CODEN("j-SEM-HOP-PARIS",			"SHPAAI")
    set_CODEN("j-SEMIN-HEMATOL",			"SEHEA3")
    set_CODEN("j-SEMIOTICA",				"????")
    set_CODEN("j-SENSORS-BASEL",			"SENSC9")
    set_CODEN("j-SER-REV",				"????")
    set_CODEN("j-SERB-ASTRON-J",			"SAJOFK")
    set_CODEN("j-SERDICA-MATH-J",			"????")
    set_CODEN("j-SERIALS-LIBRARIAN",			"SELID4")
    set_CODEN("j-SERIF",				"????")
    set_CODEN("j-SERVICE-NEWS-CESSP",			"????")
    set_CODEN("j-SET-VALUED-ANAL",			"SVANEG")
    set_CODEN("j-SET-VALUED-VAR-ANAL",			"")
    set_CODEN("j-SEX-ROLES",				"SROLDH")
    set_CODEN("j-SEYBOLD-REP-DESKTOP-PUB",		"SRDFED")
    set_CODEN("j-SEYBOLD-REP-INTERNET-PUBLISHING",      "")
    set_CODEN("j-SEYBOLD-REP-PUB-SYS",			"SRPSD9")
    set_CODEN("j-SIAM-ASA-J-UNCERTAIN-QUANTIF",		"SJUQA3")
    set_CODEN("j-SIAM-J-ALG-DISC-METH",			"SJAMDU")
    set_CODEN("j-SIAM-J-APPL-ALGEBR-GEOM",		"????")
    set_CODEN("j-SIAM-J-APPL-DYN-SYST",			"????")
    set_CODEN("j-SIAM-J-APPL-MATH",			"SMJMAP")
    set_CODEN("j-SIAM-J-COMPUT",			"SMJCAT")
    set_CODEN("j-SIAM-J-CONTROL",			"SJCOA9")
    set_CODEN("j-SIAM-J-CONTROL-OPTIM",			"SJCODC")
    set_CODEN("j-SIAM-J-DISCR-MATH",			"SJDMEC")
    set_CODEN("j-SIAM-J-FINANCIAL-MATH",		"SJFMBJ")
    set_CODEN("j-SIAM-J-IMAGING-SCI",			"SJISBI")
    set_CODEN("j-SIAM-J-MAT-ANA-APPL",			"SJMAEL")
    set_CODEN("j-SIAM-J-MATH-ANA",			"SJMAAH")
    set_CODEN("j-SIAM-J-MATH-DATA-SCI",			"SJMDAQ")
    set_CODEN("j-SIAM-J-NUMER-ANAL",			"SJNAAM")
    set_CODEN("j-SIAM-J-NUM-ANALYSIS-B",		"????")
    set_CODEN("j-SIAM-J-OPT",				"SJOPE8")
    set_CODEN("j-SIAM-J-SCI-COMP",			"SJOCE3")
    set_CODEN("j-SIAM-J-SCI-STAT-COMP",			"SIJCD4")
    set_CODEN("j-SIAM-NEWS",				"????")	# no CODEN
    set_CODEN("j-SIAM-REVIEW",				"SIREAD")
    set_CODEN("j-SIAM-THEOR-PROB-APPL",			"????")
    set_CODEN("j-SIB-MAT-Z",				"????")
    set_CODEN("j-SIB-MATH-J",				"SMTJAW")
    set_CODEN("j-SIBERIAN-ADV-MATH",			"????")
    set_CODEN("j-SID-DIG-TECH-PAP",			"DTPSDS")
    set_CODEN("j-SIG-PROC",				"SPRODR")
    set_CODEN("j-SIGACT",				"SIGNDM")
    set_CODEN("j-SIGADA-LETTERS",			"AALEE5")
    set_CODEN("j-SIGAPP",				"????")
    set_CODEN("j-SIGBIO-NEWSLETTER",			"SINWDG")
    set_CODEN("j-SIGCAPH",				"SGNWD2")
    set_CODEN("j-SIGCHI",				"SGBUD4")
    set_CODEN("j-SIGCSE",				"SIGSD3")
    set_CODEN("j-SIGDOC",				"????")
    set_CODEN("j-SIGIR-FORUM",				"FASRDV")
    set_CODEN("j-SIGKDD",				"????")
    set_CODEN("j-SIGMA-CHI-Q",				"SXQUAP")
    set_CODEN("j-SIGMAP-NEWSLETTER",			"????")
    set_CODEN("j-SIGMETRICS",				"????")
    set_CODEN("j-SIGMICRO",				"SIGMDJ")
    set_CODEN("j-SIGMOD",				"SRECD8")
    set_CODEN("j-SIGNAL-PROCESS-IMAGE-COMMUN",		"SPICEF")
    set_CODEN("j-SIGNIF",				"????")
    set_CODEN("j-SIGNUM",				"SNEWD6")
    set_CODEN("j-SIGOIS",				"SIGBEL")
    set_CODEN("j-SIGPLAN",				"SINODQ")
    set_CODEN("j-SIGSAC-REVIEW",			"SSARE7")
    set_CODEN("j-SIGSAM",				"SIGSBZ")
    set_CODEN("j-SIGSMALL-PC-NOTES",			"SGBLEC")
    set_CODEN("j-SIGSOFT",				"SFENDP")
    set_CODEN("j-SIGUCCS-NEWSL",			"SSNRD3")
    set_CODEN("j-SILICON-GRAPHICS-WORLD",		"????")
    set_CODEN("j-SIM-MODEL-PRACT-THEORY",		"SMPTCA")
    set_CODEN("j-SIM-NEWS-EUROPE",			"????")
    set_CODEN("j-SIM-PRACT-THEORY",			"SPTHEH")
    set_CODEN("j-SIM-SERIES",				"SMCPAX")
    set_CODEN("j-SIMON-STEVIN",				"SSWNAX")
    set_CODEN("j-SIMULATION",				"SIMUA2")
    set_CODEN("j-SIMULETTER",				"SIMUD5")
    set_CODEN("j-SJCC",					"????")
    set_CODEN("j-SKEPT-INQ",				"????")
    set_CODEN("j-SKY-TELESC",				"SKTEA3")
    set_CODEN("j-SMART-MAT-STRUCT",			"SMSTER")
    set_CODEN("j-SMITHSON-INST-ANNU-REP",		"SIAPAT")
    set_CODEN("j-SMITHSONIAN",				"SMSNA5")
    set_CODEN("j-SOC-INDIC-RES",			"SINRDZ")
    set_CODEN("j-SOC-METH-RES",				"????")
    set_CODEN("j-SOC-PET-ENG-J",			"SPTJAJ")
    set_CODEN("j-SOC-PROBL",				"SOPRAG")
    set_CODEN("j-SOC-SCI",				"????")
    set_CODEN("j-SOC-SCI-INFO",				"????")
    set_CODEN("j-SOC-STUD-SCI",				"????")
    set_CODEN("j-SOC-TEXT",				"")
    set_CODEN("j-SOCIAL-SCI-COMP-REV",			"SSCREH")
    set_CODEN("j-SOCIO-ECON",				"JSECFK")
    set_CODEN("j-SOCIO-ECON-PLANN-SCI",			"SEPSBI")
    set_CODEN("j-SOCIOL-METHODS-RES",			"????")
    set_CODEN("j-SOFT-COMP",				"????")
    set_CODEN("j-SOFT-PROT",				"SPROES")
    set_CODEN("j-SOFTWARE-CONCEPTS-TOOLS",		"SCOTE5")
    set_CODEN("j-SOFTWARE-ECONOMICS-LETTER",		"SECLE3")
    set_CODEN("j-SOFTWARE-ENG-WORKSTATIONS",		"SEWOEA")
    set_CODEN("j-SOFTWARE-LAW-J",			"????")
    set_CODEN("j-SOFTWARE-MAG",				"SMWMEQ")
    set_CODEN("j-SOFTWARE-NEWS",			"SFNED9")
    set_CODEN("j-SOFTWARE-SYST-MODEL",			"????")
    set_CODEN("j-SOGO-RINSHO",				"SORIAX")
    set_CODEN("j-SOLID-STATE-COMMUN",			"SSCOA4")
    set_CODEN("j-SOLID-STATE-PHYS-N-Y-1955",		"SSPHAE")
    set_CODEN("j-SOURCE-ART",				"????")
    set_CODEN("j-SOUTH-AFRICAN-COMP-J",			"SACJE3")
    set_CODEN("j-SOUTHCON",				"")
    set_CODEN("j-SOV-J-COMP-SYS-SCI",			"SJCSEP")
    set_CODEN("j-SOV-J-NUM-ANA-MATH-MOD",		"????")
    set_CODEN("j-SOV-J-QUANTUM-ELECTRON",		"SJQEAF")
    set_CODEN("j-SOV-MATH-NY",				"SOMADL")
    set_CODEN("j-SOV-MATH-PROVIDENCE",			"SVMDA8")
    set_CODEN("j-SOV-PHYS-JETP",			"SPHJAR")
    set_CODEN("j-SOV-PHYS-SOLID-STATE",			"SPSSA7")
    set_CODEN("j-SOV-PHYS-USP",				"SOPUAP")
    set_CODEN("j-SOVIET-J-DEVEL-BIO",			"SJDBA9")
    set_CODEN("j-SOVIET-MATH-DOKL",			"????")
    set_CODEN("j-SOVIET-PHYS-DOKL",			"SPHDA9")
    set_CODEN("j-SPACE-SCI-REV",			"SPSRA4")
    set_CODEN("j-SPATIAL-VIS",				"SPVIEU")
    set_CODEN("j-SPE",					"SPEXBL")
    set_CODEN("j-SPE-ASIA-PACIFIC-OIL-GAS-CONF",	"????")
    set_CODEN("j-SPEC-LIBR",				"SPLBAN")
    set_CODEN("j-SPECTROCHIM-ACTA",			"????")
    set_CODEN("j-SPECTROCHIMICA-ACTA-A",		"SAMCAS")
    set_CODEN("j-SPEECH",				"????")
    set_CODEN("j-SPEECH-COMM",				"SCOMDH")
    set_CODEN("j-SPEKTRUM-WISSENSCHAFT",		"SPEKDI")
    set_CODEN("j-SPELMAN-SCI-MATH-J",			"????")
    set_CODEN("j-SPIP",					"SPIPFL")
    set_CODEN("j-SPONT-GEN",				"????")
    set_CODEN("j-SPRAY-TECHNOL-MARK",			"STEMEJ")
    set_CODEN("j-SPRINGER-SER-CHEM-PHYS",		"SSCPDA")
    set_CODEN("j-SPRINGERPLUS",				"SPRIFB")
    set_CODEN("j-ST-PETERSBG-MATH-J",			"????")
    set_CODEN("j-STAG",					"????")
    set_CODEN("j-STANFORD-VIDEO-J",			"????")
    set_CODEN("j-STAT-COMPUT",				"STACE3")
    set_CODEN("j-STAT-INTERFACE",			"")
    set_CODEN("j-STAT-MED",				"SMEDDA")
    set_CODEN("j-STAT-METHODOL",			"????")
    set_CODEN("j-STAT-NEERLANDICA",			"????")
    set_CODEN("j-STAT-PAPERS",				"STPAE4")
    set_CODEN("j-STAT-PROB-LETT",			"SPLTDC")
    set_CODEN("j-STAT-SCI",				"STSCEP")
    set_CODEN("j-STAT-SINICA",				"STSNEO")
    set_CODEN("j-STATIST-PAPERS",			"STPAE4")
    set_CODEN("j-STATISTICA-BOLOGNA",			"????")
    set_CODEN("j-STATISTICS",				"MOSSD5")
    set_CODEN("j-STEREO-REV",				"????")
    set_CODEN("j-STERNE-WELTRAUM",			"STUWAN")
    set_CODEN("j-STOCH-ANAL-APPL",			"SAAPDA")
    set_CODEN("j-STOCH-DYNAM",				"????")
    set_CODEN("j-STOCH-MODELS",				"CSSME8")
    set_CODEN("j-STOCH-PROC-APPL",			"STOPB7")
    set_CODEN("j-STOCH-STOCH-REP",			"SSTREY")
    set_CODEN("j-STOCH-SYS-APPL",			"????")
    set_CODEN("j-STRUCT",				"STRUE6")
    set_CODEN("j-STRUCT-CHEM",				"STCHES")
    set_CODEN("j-STRUCT-MULTDISCIP-0PTIM",		"????")
    set_CODEN("j-STRUCT-OPTIM",				"SOPTEQ")
    set_CODEN("j-STRUCT-PROGRAM",			"STPGEM")
    set_CODEN("j-STUD-APPL-MATH",			"SAPMB6")
    set_CODEN("j-STUD-BIOPHYS",				"STBIBN")
    set_CODEN("j-STUD-CERCET-MAT",			"")
    set_CODEN("j-STUD-EAST-EUROPEAN-THOUGHT",		"SEETE3")
    set_CODEN("j-STUD-HIST-PHILOS-SCI",			"SHPSB5")
    set_CODEN("j-STUD-HIST-PHILOS-SCI-B",		"????")
    set_CODEN("j-STUD-HIST-PHILOS-SCI-C",		"????")
    set_CODEN("j-STUD-HIST-PHILOS-MOD-PHYS",		"????")
    set_CODEN("j-STUD-LINGUIST",			"????")
    set_CODEN("j-STUD-LOGICA",				"SLOGAP")
    set_CODEN("j-STUD-SOV-THOUGHT",			"SSVTBD")
    set_CODEN("j-STUD-STOR",				"")
    set_CODEN("j-STUDIA-MATH",				"SMATAZ")
    set_CODEN("j-STUDIA-ROSE",				"????")
    set_CODEN("j-STUDIES-COMP-SCI-ART-INTELL",		"????")
    set_CODEN("j-STUDIES-INTEGRO-DIFF-EQ",		"????")
    set_CODEN("j-STUDIUM-GEN",				"STGEAZ")
    set_CODEN("j-SUDHOFFS-ARCH",			"SUARAH")
    set_CODEN("j-SUN-OBSERVER",				"????")
    set_CODEN("j-SUNEXPERT",				"????")
    set_CODEN("j-SUNSERVER",				"????")
    set_CODEN("j-SUNWORLD",				"SUNWDW")
    set_CODEN("j-SUNWORLD-ONLINE",			"????")
    set_CODEN("j-SUPERCOMPUTER",			"SPCOEL")
    set_CODEN("j-SUPERCOMPUTING-REVIEW",		"SURVEG")
    set_CODEN("j-SUPERCOND-SCI-TECHNOL",		"SUSTEF")
    set_CODEN("j-SURF-INTERFACE-ANAL",			"SIANDQ")
    set_CODEN("j-SURF-SCI",				"SUSCAS")
    set_CODEN("j-SURF-SCI-LETT",			"????")
    set_CODEN("j-SURVIVAL",				"????")
    set_CODEN("j-SURVIVE",				"????")
    set_CODEN("j-SVENSK-KEMISK-TIDSKRIFT",		"KETIAL")
    set_CODEN("j-SVENSK-NATURVETENSKAP",		"SVNAB5")
    set_CODEN("j-SWIAT-NAUKI",				"????")
    set_CODEN("j-SYMP-SOC-EXP-BIO",			"SSEBA9")
    set_CODEN("j-SYMPOSIA-MATHEMATICA",			"????")
    set_CODEN("j-SYNTHESE",				"????")
    set_CODEN("j-SYS-ADMIN",				"SYADE7")
    set_CODEN("j-SYS-ANA-MODEL-SIM",			"SAMSEC")
    set_CODEN("j-SYS-COMP-JAPAN",			"SCJAEP")
    set_CODEN("j-SYS-INTEGRATION",			"SYINE9")
    set_CODEN("j-SYST-CONTROL-INFO",			"SYCNA9")
    set_CODEN("j-SYST-CONTROL-LETT",			"SCLEDC")
    set_CODEN("j-SYST-RES",				"SYREER")
    set_CODEN("j-SYST-RES-BEHAV-SCI",			"SRBSF9")
    set_CODEN("j-SYSTEM",				"????")
    set_CODEN("j-TAAS",					"????")
    set_CODEN("j-TACCESS",				"")
    set_CODEN("j-TACO",					"")
    set_CODEN("j-TAEHAN-HWAHAKHOE-CHI",			"DHWHAB")
    set_CODEN("j-TALG",					"")
    set_CODEN("j-TALIP",				"")
    set_CODEN("j-TALLIP",				"")
    set_CODEN("j-TAMKANG-J-MATH",			"????")
    set_CODEN("j-TAP",					"")
    set_CODEN("j-TAPPI-J",				"TAJODT")
    set_CODEN("j-TAXON",				"TAXNAP")
    set_CODEN("j-TCBB",					"ITCBCY")
    set_CODEN("j-TCPS",					"????")
    set_CODEN("j-TDS",					"????")
    set_CODEN("j-TEAC",					"????")
    set_CODEN("j-TEACHING-PSYCH",			"????")
    set_CODEN("j-TECH-COMMUN",				"TLCMBT")
    set_CODEN("j-TECH-CULTURE",				"TECUA3")
    set_CODEN("j-TECH-LEARNING",			"????")
    set_CODEN("j-TECH-MITT-KRUPP-ENGL-ED",		"")
    set_CODEN("j-TECH-REVIEW",				"TEREAU")
    set_CODEN("j-TECHNIQUE-SCI-INFORMATIQUES",		"TTSIDJ")
    set_CODEN("j-TECHNOL-FORECAST-SOC-CHANGE",		"TFSCB3")
    set_CODEN("j-TECHNOL-SOC",				"????")
    set_CODEN("j-TECHNOMETRICS",			"TCMTA2")
    set_CODEN("j-TECHNOVATION",				"????")
    set_CODEN("j-TECHTRENDS",				"TETREF")
    set_CODEN("j-TECS",					"????")
    set_CODEN("j-TELECOMM-RADIO-ENG",			"TCREAG")
    set_CODEN("j-TELECOMMUNICATIONS-AMERICAS-ED",	"TLCMDV")
    set_CODEN("j-TELECOMMUNICATIONS-INT-ED",		"TLCOAY")
    set_CODEN("j-TELEMAT-INFORM",			"TEINEG")
    set_CODEN("j-TELEPHONY",                            "TLPNAS")
    set_CODEN("j-TEORET-MATH-FIZ",			"TMFZAL")
    set_CODEN("j-TEST",					"????")
    set_CODEN("j-TETRAHEDRON-COMPUT-METH",		"TCMTE6")
    set_CODEN("j-TEX-J-SCI",				"TJSCAU")
    set_CODEN("j-TEX-TUG-NEWS",				"????")
    set_CODEN("j-TEXHAX",				"????")
    set_CODEN("j-TEXLINE",				"????")
    set_CODEN("j-TEXNIQUES",				"????")
    set_CODEN("j-TEXTURES-MICROSTRUCT",			"TEMIDK")
    set_CODEN("j-THE-J",				"THEJD4")
    set_CODEN("j-THEOR-BIOL-MED-MODEL",			"????")
    set_CODEN("j-THEOR-CHEM-ACCOUNTS",			"TCACFW")
    set_CODEN("j-THEOR-CHEM-LONDON",			"THCHDM")
    set_CODEN("j-THEOR-CHIM-ACTA",			"TCHAAM")
    set_CODEN("j-THEOR-COMP-SCI",			"TCSCDI")
    set_CODEN("j-THEOR-MATH-PHYS",			"TMPHAH")
    set_CODEN("j-THEOR-POPUL-BIOL",			"TLPBAQ")
    set_CODEN("j-THEOREMA",				"????")
    set_CODEN("j-THEORIA",				"THRAA5")
    set_CODEN("j-THEORIA-MADRID",			"????")
    set_CODEN("j-THEORY-COMPUT-SYST",			"TCSYFI")
    set_CODEN("j-THEORY-DECISION",			"THDCBA")
    set_CODEN("j-THEORY-PROBAB-APPL",			"TPRBAU")
    set_CODEN("j-THEORY-PROBAB-MATH-STAT",		"TPMSCO")
    set_CODEN("j-THIN-WALLED-STRUCTURES",		"TWASDE")
    set_CODEN("j-THRI",					"????")
    set_CODEN("j-THROMB-DIATH-HAEMORRH",		"TDHAAT")
    set_CODEN("j-TIME",					"TYMEA9")
    set_CODEN("j-TIMES",				"????")
    set_CODEN("j-TIIS",					"????")
    set_CODEN("j-TIOT",					"????")
    set_CODEN("j-TISSEC",				"ATISBQ")
    set_CODEN("j-TIST",					"")
    set_CODEN("j-TKDD",					"????")
    set_CODEN("j-TMIS",					"????")
    set_CODEN("j-TOCE",					"")
    set_CODEN("j-TOCH",					"????")
    set_CODEN("j-TOCHI",				"ATCIF4")
    set_CODEN("j-TOCL",					"????")
    set_CODEN("j-TOCS",					"ACSYEC")
    set_CODEN("j-TOCT",					"????")
    set_CODEN("j-TODAES",				"ATASFO")
    set_CODEN("j-TODS",					"ATDSD3")
    set_CODEN("j-TOG",					"ATGRDF")
    set_CODEN("j-TOIS",					"ATISET")
    set_CODEN("j-TOIT",					"????")
    set_CODEN("j-TOKYO-J-MATH",				"????")
    set_CODEN("j-TOMACS",				"ATMCEZ")
    set_CODEN("j-TOMCCAP",				"")
    set_CODEN("j-TOMM",					"", 1)
    set_CODEN("j-TOMPECS",				"????")
    set_CODEN("j-TOMS",					"ACMSCU")
    set_CODEN("j-TOOIS",				"ATOSDO")
    set_CODEN("j-TOPC",					"????")
    set_CODEN("j-TOPLAS",				"ATPSDT")
    set_CODEN("j-TOPOI",				"????")
    set_CODEN("j-TOPOLOGY",				"TPLGAF")
    set_CODEN("j-TOPS",					"????")
    set_CODEN("j-TORS",					"????")
    set_CODEN("j-TOS",                                  "")
    set_CODEN("j-TOSEM",				"ATSMER")
    set_CODEN("j-TOSN",					"????")
    set_CODEN("j-TOXICOL-APPL-PHARMACOL",		"TXAPA9")
    set_CODEN("j-TQC",					"????")
    set_CODEN("j-TRAITE-SIGNAL",			"")
    set_CODEN("j-TRANS-AM-FISH-SOC",			"TAFSAI")
    set_CODEN("j-TRANS-AM-MATH-SOC",			"TAMTAM")
    set_CODEN("j-TRANS-AM-NUCL-SOC",			"TANSAO")
    set_CODEN("j-TRANS-AM-PHILOS-SOC-N-S",		"TAPSAY")
    set_CODEN("j-TRANS-AMER-INST-ELEC-ENG",		"TAEEA5")
    set_CODEN("j-TRANS-ASAE",				"TAAEAJ")
    set_CODEN("j-TRANS-ASME-C",				"????")
    set_CODEN("j-TRANS-ASME-D",				"????")
    set_CODEN("j-TRANS-BOSE-RES-INST-CALCUTTA",		"TBICAQ")
    set_CODEN("j-TRANS-CAMBRIDGE-PHILOS-SOC",		"????")
    set_CODEN("j-TRANS-FARADAY-SOC",			"TFSOA4")
    set_CODEN("j-TRANS-GIS",				"????")
    set_CODEN("j-TRANS-IEICE-D-II",			"DTGDE7")
    set_CODEN("j-TRANS-INFO-PROCESSING-SOC-JAPAN",	"JSGRD5")
    set_CODEN("j-TRANS-IRE",				"????")
    set_CODEN("j-TRANS-IRE-PROF-GROUP-INF-THEORY",	"????")
    set_CODEN("j-TRANS-MATH-APPL",			"????")
    set_CODEN("j-TRANS-N-Y-ACAD-SCI-2",			"TNYAAE")
    set_CODEN("j-TRANS-PROC-N-Z-INST",			"TRNZAS")
    set_CODEN("j-TRANS-PROC-R-SOC-N-Z",			"TRNZAS")
    set_CODEN("j-TRANS-R-SOC-CAN",			"TRSCAI")
    set_CODEN("j-TRANS-R-SOC-EDINBURGH",		"TRSEAO")
    set_CODEN("j-TRANS-SAIEE",				"TSAEA9")
    set_CODEN("j-TRANS-SOC-COMP-SIM",			"TSCSEV")
    set_CODEN("j-TRANS-SOC-INST-CONTROL-ENG",		"TSICA9")
    set_CODEN("j-TRANS-SOC-RHEOLOGY",			"TSRHAZ")
    set_CODEN("j-TRANSP-DISTRIB",			"TRDIEX")
    set_CODEN("j-TRANSFUSION",				"TRANAT")
    set_CODEN("j-TRANSPORT-RES",			"TRREBK")
    set_CODEN("j-TRANSPORT-SCI",			"TRSCBJ")
    set_CODEN("j-TRAV-HUM",				"TRHUAH")
    set_CODEN("j-TRAVAUX-SCI",				"????")
    set_CODEN("j-TRENDS-BIOCHEM-SCI",			"TBSCDB, TBSRDM")
    set_CODEN("j-TRENDS-COGN-SCI",			"TCSCFK")
    set_CODEN("j-TRENDS-ECOL-EVOL",			"TREEEQ")
    set_CODEN("j-TRENDS-GENET",				"TRGEE2")
    set_CODEN("j-TRENDS-MICROBIOL",			"TRMIEA")
    set_CODEN("j-TRENDS-NEUROSCI",			"TNSCDR")
    set_CODEN("j-TRETS",				"????")
    set_CODEN("j-TSAS",					"")
    set_CODEN("j-TSC",					"????")
    set_CODEN("j-TSI",					"????")
    set_CODEN("j-TSLP",					"????")
    set_CODEN("j-TUGBOAT",				"????")
    set_CODEN("j-TUMORI",				"TUMOAB")
    set_CODEN("j-TURBOMACH-INT",			"TUINDP")
    set_CODEN("j-TWEB",					"????")
    set_CODEN("j-TWIO",					"????")
    set_CODEN("j-TWO-YEAR-COLL-MATH-J",			"????")
    set_CODEN("j-U-LC",					"ULCCDC")
    set_CODEN("j-UKR-MAT-Z",				"UMZHAA")
    set_CODEN("j-ULTIM-REAL-MEAN",			"????")
    set_CODEN("j-ULTRA-MIC",				"ULTRD6")
    set_CODEN("j-ULTRASONIC-IMAGING",			"ULIMD4")
    set_CODEN("j-UMAP",					"????")
    set_CODEN("j-UNESCO-COUR",				"????")
    set_CODEN("j-UNIV-COMP",				"UNCOET")
    set_CODEN("j-UNIVERSITAS",				"UNIVA8")
    set_CODEN("j-UNIX-DEVELOPER",			"")
    set_CODEN("j-UNIX-REVIEW",				"UNRED5", 1)
    set_CODEN("j-UNIX-WORLD",				"????")
    set_CODEN("j-UNIXWORLD-OPEN-COMP",			"OPCOEB", 1)
    set_CODEN("j-US-NEWS-WORLD-REP",			"XNWRAV")
    set_CODEN("j-USENIX-SCP",				"????")
    set_CODEN("j-USPEKHI-FIZ-NAUK",			"UFNAAG")
    set_CODEN("j-USPEHI-MAT-NAUK",			"UMANA5")
    set_CODEN("j-USP-MEH",				"USMEEG")
    set_CODEN("j-USSR-COMP-MATH-MATH-PHYS",		"CMMPA9")
    set_CODEN("j-UTIL-MATH",				"UTMADA")
    set_CODEN("j-UTNE-READER",				"????")
    set_CODEN("j-VAX-PROF",				"VAXPEN")
    set_CODEN("j-VEGETATIO",				"VGTOA4")
    set_CODEN("j-VERH-DTSCH-PHYS-GES",			"VDPEAZ")
    set_CODEN("j-VERH-DTSCH-PHYS-GES-3",		"VDPEAZ")
    set_CODEN("j-VERH-GES-DTSCH-NATURFORSCH-AERZTE",	"VGDNAN")
    set_CODEN("j-VERH-K-ACAD-GENEESKD-BELG",            "")
    set_CODEN("j-VERH-SCHWEIZ-NATURFORSCH-GES",		"VSNGAY")
    set_CODEN("j-VEROFF-UNIBIB-ESSEN",			"VUESE9")
    set_CODEN("j-VIC-LIT-CULT",				"????")
    set_CODEN("j-VIC-STUD",				"????")
    set_CODEN("j-VIE-SCI",				"????")
    set_CODEN("j-VIENNA-CIRCLE-INSTITUTE-YEARBOOK",	"????")
    set_CODEN("j-VIERTELJAHRESSCHR-NATURFORSCH-GES-ZURICH", "VNGZAL")
    set_CODEN("j-VIS-COMM-IMG-PROC",			"????")
    set_CODEN("j-VIS-RES",				"VISRAM")
    set_CODEN("j-VISIBLE-LANGUAGE",			"VSLGAO")
    set_CODEN("j-VISUAL-COMPUTER",			"VICOE5")
    set_CODEN("j-VLDB-J",				"VLDBFR")
    set_CODEN("j-VOPROSY-VYCHISL-PRIKL-MAT",		"????")
    set_CODEN("j-WALL-ST-COMPUT-REV",			"????")
    set_CODEN("j-WALL-ST-J",				"WSJOAF")
    set_CODEN("j-WALL-ST-TECH",				"WSTEE5")
    set_CODEN("j-WAR-HIST",				"????")
    set_CODEN("j-WASH-CRIME-NEWS-SERV-CORP-SECURITY-DIGEST", "????")
    set_CODEN("j-WASHINGTON-POST",			"????")
    set_CODEN("j-WASSERWIRTSCHAFT",			"WSWTAR")
    set_CODEN("j-WATER-AIR-SOIL-POLLUT",		"WAPLAC")
    set_CODEN("j-WATER-RESOUR-RES",			"WRERAQ")
    set_CODEN("j-WATER-SCI-TECHNOL",			"WSTED4")
    set_CODEN("j-WAVE-MOTION",				"WAMOD9")
    set_CODEN("j-WAVES-RANDOM-COMPLEX-MEDIA",		"")
    set_CODEN("j-WAVES-RANDOM-MEDIA",			"WRMEEV")
    set_CODEN("j-WEB-APPS",				"")
    set_CODEN("j-WEB-REVIEW",				"????")
    set_CODEN("j-WEB-WEEK",				"WEWEFP")
    set_CODEN("j-WEB-TECHNIQUES",			"WETEFA")
    set_CODEN("j-WEBSERVER",				"????")
    set_CODEN("j-WESCON-CONF-REC",			"WCREDI")
    set_CODEN("j-WHARTON-REPORT",			"WHREEK")
    set_CODEN("j-WHOLE-EARTH-REV",			"????")
    set_CODEN("j-WIEN-CHEM-ZTG",			"WICZAB")
    set_CODEN("j-WIRES",				"????")
    set_CODEN("j-WILSON-LIBR-BULL",			"????")
    set_CODEN("j-WILSON-Q",				"????")
    set_CODEN("j-WINDOWS-MAG",				"WINMEV")
    set_CODEN("j-WIRED",				"WREDEM")
    set_CODEN("j-WIRTSCHAFTSINFORMATIK",		"WIINE9")
    set_CODEN("j-WISS-Z-PAEDAGOG-HOCHSCH-K-F-W-WANDER-DRESDEN", "????")
    set_CODEN("j-WISS-Z-PAEDAGOG-HOCHSCH-KARL-LIEBKNECHT-POTSDAM","WPKLAO")
    set_CODEN("j-WISS-Z-TECH-HOCHSCH-KARL-MARX-STADT",	"WZTKAY")
    set_CODEN("j-WISS-Z-TECH-HOCHSCH-LEUNA-MERSEBURG",	"WZHLDE")
    set_CODEN("j-WISS-Z-TECH-UNIV-DRESDEN",		"WZTUAU")
    set_CODEN("j-WISS-Z-TECH-UNIV-DRESDEN-GESELLSCHAFT","????")
    set_CODEN("j-WOMENS-STUD-INT-FORUM",		"WSINDA")
    set_CODEN("j-WORD-WAYS",				"????")
    set_CODEN("j-WORK-PROC-IMPROV-TODAY",		"WPITE8")
    set_CODEN("j-WORK-PUB-SYS",				"????")
    set_CODEN("j-WORLD-MONIT",				"")
    set_CODEN("j-WORLD-WIDE-WEB-J",			"WWWFFI")
    set_CODEN("j-WORLD-PRESS-REV",			"????")
    set_CODEN("j-WSEAS-TRANS-MATH",			"????")
    set_CODEN("j-X-J",					"XJOUEA")
    set_CODEN("j-X-RESOURCE",				"XRESEA")
    set_CODEN("j-YAD-FIZ",				"IDFZA7")
    set_CODEN("j-YALE-LAW-POLICY-REV",			"????")
    set_CODEN("j-YEAST-CHICHESTER",			"YESTE3")
    set_CODEN("j-YEAST-DAVIS",				"YEASA8 (??)")
    set_CODEN("j-YUGO-J-OPER-RES",			"????")
    set_CODEN("j-Z-ALLG-WISSENSCHAFTSTHEOR",		"ZAWTA2")
    set_CODEN("j-Z-ANAL-ANWEND",			"????")
    set_CODEN("j-Z-ANAL-CHEM",				"ABCNBP")
    set_CODEN("j-Z-ANGE-CHEM",				"????")
    set_CODEN("j-Z-ANGE-MATH-MECH",			"ZAMMAX")
    set_CODEN("j-Z-ANGE-MATH-PHYS",			"ZAMPDB", 1)
    set_CODEN("j-Z-ASTROPHYSIK",			"ZEASAJ")
    set_CODEN("j-Z-BIOL",				"ZEBLA3")
    set_CODEN("j-Z-CHEM-STUTTGART",			"ZECEAL")
    set_CODEN("j-Z-EKSP-TEOR-FIZ",			"ZETFA7")
    set_CODEN("j-Z-ELEKTROCHEM",			"ZEELAI")
    set_CODEN("j-Z-ELEKTROCHEM-ANGEW-PHYS-CHEM",	"ZEAPAA")
    set_CODEN("j-Z-KRISTALLOGR",			"ZEKRDZ")
    set_CODEN("j-Z-MATH-LOGIK-GRUNDL-MATH",		"ZMLGAQ")
    set_CODEN("j-Z-NATURFORSCH",			"ZNTFA2")
    set_CODEN("j-Z-NATURFORSCH-A-ASTROPHYS-PHYS-PHYS-CHEM",	"ZENAAU")
    set_CODEN("j-Z-NATURFORSCH-A-PHYS-SCI",		"ZNASEI")
    set_CODEN("j-Z-NATURFORSCH-SECT-C-BIOSCI",		"ZNCBDA")
    set_CODEN("j-Z-OPER-RES",				"ZMMRFZ")
    set_CODEN("j-Z-PFLANZENKR-PFLANZENSCHUTZ",		"ZPFPAA")
    set_CODEN("j-Z-PHILOS-FORSCH",			"????")
    set_CODEN("j-Z-PHYS-CHEM-B",			"ZPCBAL")
    set_CODEN("j-Z-PHYS-CHEM-LEIPZIG",			"ZPCLAH")
    set_CODEN("j-Z-PHYS-CHEM-STOECHIOM-VERWANDTSCHAFTSL",	"ZEPCAC")
    set_CODEN("j-Z-PHYSIK",				"ZEPYAA")
    set_CODEN("j-Z-PHYSIK-A",				"ZPAADB")
    set_CODEN("j-Z-PHYSIK-A-HADRONS-NUCL",		"ZPAHEX")
    set_CODEN("j-Z-PHYSIK-B-CM",			"ZPCMDN")
    set_CODEN("j-Z-PHYSIK-B-CMQ",			"ZPBBDJ")
    set_CODEN("j-Z-PHYSIK-C",				"ZPCFD2")
    set_CODEN("j-Z-PHYSIK-D",				"ZDACE2")
    set_CODEN("j-Z-TECH-PHYS",				"ZTPHAU")
    set_CODEN("j-Z-TEH-FIZ",				"ZTEFA3")
    set_CODEN("j-Z-THEOL-KIRCHE",			"????")
    set_CODEN("j-Z-VERMESSUNGSWESEN",			"ZTVRAM")
    set_CODEN("j-Z-VYCISL-MAT-MAT-FIZ",			"ZVMFAN")
    set_CODEN("j-Z-WAHRSCHEINLICHKEITSTHEOR-VERW-GEB",	"ZWVGAA")
    set_CODEN("j-ZAP-NAUC-SEMIN-LENINGR-OTD-ORDENA",	"ZNSLAF")
    set_CODEN("j-ZASTOS-MAT",				"ZAMTAK")
    set_CODEN("j-ZH-RUSS-FIZ-KHIM-OBSHCH-CHAST-FIZ",	"ZRFFAS")
    set_CODEN("j-ZH-VYCHISL-MAT-MAT-FIZ",		"ZVMFAN")
    set_CODEN("j-ZOO-SCI",				"ZOSCEX")
    set_CODEN("j-ZOR-MATH-METHODS-OPER-RES",		"ZMRREP")
    set_CODEN("j-ZYGON-J-RELIG-SCI",			"????")

    for (coden in CODEN_to_journal)
	CODEN5_to_6[substr(coden, 1, 5)] = coden
}


function initialize_ISSN()
{
    # NB: A field value of "????" means that the journal has been
    # checked, and apparently has no ISSN.  An empty field value
    # means that library checks still need to be done.

    set_ISSN("j-16TH-CENT",				"0361-0160")
    set_ISSN("j-3X-400-SYST-MANAG",			"1070-6097")
    set_ISSN("j-A-PLUS",				"0740-1590")
    set_ISSN("j-AAICA",					"0020-594X")
    set_ISSN("j-AAPG-EXPLOR",				"0195-2986")
    set_ISSN("j-AAUP-BULL",				"0277-3945 (print), 1930-322X (electronic)")
    set_ISSN("j-ABACUS",				"0724-6722")
    set_ISSN("j-ABERDEEN-UNIV-REV",			"0001-320X")
    set_ISSN("j-ABH-MATH-SEMIN-UNIV-HAMBG",		"0025-5858 (print), 1865-8784 (electronic)")
    set_ISSN("j-ABSTR-APPL-ANAL",			"1085-3375 (print), 1687-0409 (electronic)")
    set_ISSN("j-ABSTR-PAP-AM-CHEM-SOC",			"0065-7727")
    set_ISSN("j-ACAD-COMPUT",				"0892-4694")
    set_ISSN("j-ACAPA",					"0569-4221")
    set_ISSN("j-ACCOUNTANCY",				"0001-4664")
    set_ISSN("j-ACCOUNT-HIST-J",			"0148-4184")
    set_ISSN("j-ACCOUNT-RES",				"0898-9621 (print), 1545-5815 (electronic)")
    set_ISSN("j-ACCOUNT-REV",				"0001-4826 (print), 1558-7967 (electronic)")
    set_ISSN("j-ACM-COMM-COMP-ALGEBRA",			"1932-2232 (print), 1932-2240 (electronic)")
    set_ISSN("j-ACM-J-EXP-ALGORITHMICS",		"1084-6654")
    set_ISSN("j-ACM-SIGCAS-COMPUT-SOC",			"0095-2737 (print), 2167-3055 (electronic)")
    set_ISSN("j-ACM-SIGMOBILE-MOBILE-COMPUT-COMMUN-REV", "1559-1662 (print), 1931-1222 (electronic)")
    set_ISSN("j-ACM-SIGSOFT",				"0163-5948 (print), 1943-5843 (electronic)")
    set_ISSN("j-ACOUSTICS-AUSTRALIA",			"0814-6039")
    set_ISSN("j-ACT-CONG-INT-MATH",			"????")
    set_ISSN("j-ACTA-ANAT",				"0001-5180 (print), 1421-9654 (electronic)")
    set_ISSN("j-ACTA-APPL-MATH",			"0167-8019 (print), 1572-9036 (electronic)")
    set_ISSN("j-ACTA-ARITHMETICA",			"0065-1036 (print), 1730-6264 (electronic)")
    set_ISSN("j-ACTA-ASTRONAUT",			"0094-5765 (print), 1879-2030 (electronic)")
    set_ISSN("j-ACTA-BIOTHEOR",				"0001-5342 (print), 1572-8358 (electronic)")
    set_ISSN("j-ACTA-CRYSTALLOGR",			"0365-110X (print), 1600-8642 (electronic)")
    set_ISSN("j-ACTA-CRYSTAL-A",			"0567-7394 (print), 1600-8596 (electronic)")
    set_ISSN("j-ACTA-CRYSTAL-A-FOUND-CRYST",		"0108-7673 (print), 1600-5724 (electronic)")
    set_ISSN("j-ACTA-CYBER",				"0324-721X")
    set_ISSN("j-ACTA-GEOD-GEOPHYS-HU",			"1217-8977 (print), 1587-1037 (electronic)")
    set_ISSN("j-ACTA-HISTOCHEM-SUPPL",			"0567-7556")
    set_ISSN("j-ACTA-INFO",				"0001-5903 (print), 1432-0525 (electronic)")
    set_ISSN("j-ACTA-LITT-SCI-SZEGED",			"????")
    set_ISSN("j-ACTA-MATER",				"1359-6454 (print), 1873-2453 (electronic)")
    set_ISSN("j-ACTA-MATH",				"0001-5962 (print), 1871-2509 (electronic)")
    set_ISSN("j-ACTA-MATH-HUNG",			"0001-5954")
    set_ISSN("j-ACTA-MATH-SINICA",			"1000-9574")
    set_ISSN("j-ACTA-MECH",				"0001-5970 (print), 1619-6937 (electronic)")
    set_ISSN("j-ACTA-MED-SCAND",			"0001-6101")
    set_ISSN("j-ACTA-METALL",				"0001-6160 (print), 1878-0768 (electronic)")
    set_ISSN("j-ACTA-METALL-MATER",			"0956-7151 (print), 1873-2879 (electronic)")
    set_ISSN("j-ACTA-NUMERICA",				"0962-4929 (print), 1474-0508 (electronic)")
    set_ISSN("j-ACTA-ONCOL",				"0284-186X (print), 1651-226X (electronic)")
    set_ISSN("j-ACTA-OPHTHALMOL",			"1755-375X (print), 1755-3768 (electronic)")
    set_ISSN("j-ACTA-PADIATR-SCAND",			"0001-656X")
    set_ISSN("j-ACTA-PHYS-ACAD-SCI-HUNG",		"0001-6705")
    set_ISSN("j-ACTA-PHYS-AUSTRIACA",			"0001-6713")
    set_ISSN("j-ACTA-PHYS-HUNG-A",			"????")
    set_ISSN("j-ACTA-PHYS-HUNG-NEW-SERIES-HEAVY-ION-PHYS",	"1219-7580 (print), 1588-2675 (electronic)")
    set_ISSN("j-ACTA-PHYS-POL",				"0001-673X")
    set_ISSN("j-ACTA-PHYS-POL-A",			"0587-4246 (print), 1898-794X (electronic)")
    set_ISSN("j-ACTA-PHYS-POL-B",			"0587-4254 (print), 1509-5770 (electronic)")
    set_ISSN("j-ACTA-POLYTECH-HUNG",			"1785-8860")
    set_ISSN("j-ACTA-POLYTECH-SCAND-ELECTR-ENG-SER",	"0001-6845")
    set_ISSN("j-ACTA-PROTOZOO",				"0065-1583 (print), 1689-0027 (electronic)")
    set_ISSN("j-ACTA-SCI-MATH-SZEGED",			"0001-6969 (print), 2064-8316 (electronic)")
    set_ISSN("j-ACTA-SCI-NATUR-UNIV-SUNYATSENI",	"0529-6579")
    set_ISSN("j-ACTA-SOC-BOT-POL",			"0001-6977")
    set_ISSN("j-ACTA-SOCIOL",				"0001-6993 (print), 1502-3869 (electronic)")
    set_ISSN("j-ADA-USER",				"0268-652X")
    set_ISSN("j-ADA-USER-J",				"1381-6551")
    set_ISSN("j-ADV-APPL-MATH",				"0196-8858 (print), 1090-2074 (electronic)")
    set_ISSN("j-ADV-APPL-MECH",				"0065-2156")
    set_ISSN("j-ADV-APPL-PROB",				"0001-8678 (print), 1475-6064 (electronic)")
    set_ISSN("j-ADV-APPL-STAT",				"0972-3617")
    set_ISSN("j-ADV-APPL-STAT-SCI",			"0974-6811")
    set_ISSN("j-ADV-BIOPHYS",				"0065-227X (print), 1873-4618 (electronic)")
    set_ISSN("j-ADV-CARDIOL",				"0065-2326 (print), 1662-2839 (electronic)")
    set_ISSN("j-ADV-CHEM-PHYS",				"0065-2385 (print), 1934-4791 (electronic)")
    set_ISSN("j-ADV-COMPLEX-SYST",			"0219-5259")
    set_ISSN("j-ADV-COMPUT-MATH",			"1019-7168 (print), 1572-9044 (electronic)")
    set_ISSN("j-ADV-CYCLIC-NUCLEOTIDE-RES",		"0084-5930")
    set_ISSN("j-ADV-DIFFERENCE-EQU",			"1687-1847")
    set_ISSN("j-ADV-ENG-SOFTWARE",			"0965-9978 (print), 0141-1195 (electronic)")
    set_ISSN("j-ADV-ENG-SOFTWARE-WORKSTATIONS",		"0961-3552 (print), 1878-3074 (electronic)")
    set_ISSN("j-ADV-ENZYMOL",				"0065-258X")
    set_ISSN("j-ADV-EXP-MED-BIO",                       "0065-2598")
    set_ISSN("j-ADV-GEOPHYS",				"0065-2687")
    set_ISSN("j-ADV-HIST-STUD",				"2327-0438 (print), 2327-0446 (electronic)")
    set_ISSN("j-ADV-IMAGING",				"1042-0711 (print), 1930-6555 (electronic)")
    set_ISSN("j-ADV-MATER",				"0935-9648 (print), 1521-4095 (electronic)")
    set_ISSN("j-ADV-MATH",				"0001-8708 (print), 1090-2082 (electronic)")
    set_ISSN("j-ADV-MORPHOGENESIS",			"0065-2962")
    set_ISSN("j-ADV-NEURAL-INF-PROCESS-SYST",		"1049-5258")
    set_ISSN("j-ADV-NONLINEAR-ANAL",			"2191-9496 (print), 2191-950X (electronic)")
    set_ISSN("j-ADV-PHYS",				"0001-8732 (print), 1460-6976 (electronic)")
    set_ISSN("j-ADV-PROTEIN-PHOSPHATASES",		"0775-051X")
    set_ISSN("j-ADV-PURE-APPL-MATH",			"1867-1152 (print), 1869-6090 (electronic)")
    set_ISSN("j-ADV-QUANTUM-CHEM",			"0065-3276")
    set_ISSN("j-ADV-SCI",				"0001-866X")
    set_ISSN("j-ADV-SCI-LETT",				"1936-6612 (print), 1936-7317 (electronic)")
    set_ISSN("j-ADV-SOFT-SCI-TECH",			"1044-7997")
    set_ISSN("j-ADV-SPACE-RES",				"0273-1177 (print), 1879-1948 (electronic)")
    set_ISSN("j-ADV-THEORY-SIMUL",			"2513-0390")
    set_ISSN("j-ADV-WATER-RESOURCES",			"0309-1708 (print), 1872-9657 (electronic)")
    set_ISSN("j-AEDS-J",				"0001-1037")
    set_ISSN("j-AEQUATIONES-MATHEMATICAE",		"0001-9054 (print), 1420-8903 (electronic)")
    set_ISSN("j-AEROBIOLOGIA",				"0393-5965 (print), 1573-3025 (electronic)")
    set_ISSN("j-AEROSPACE-AMERICA",			"0740-722X")
    set_ISSN("j-AEU",					"0001-1096")
    set_ISSN("j-AFTERIMAGES",                           "1073-2101")
    set_ISSN("j-AGAINST-GRAIN",				"1043-2094")
    set_ISSN("j-AGRIC-EDUC-MAG",			"0732-4677")
    set_ISSN("j-AI-EXPERT",				"0888-3785")
    set_ISSN("j-AI-MAGAZINE",				"0738-4602")
    set_ISSN("j-AI-SOC",				"0951-5666 (print), 1435-5655 (electronic)")
    set_ISSN("j-AIAA-ASME-ASCE-AHS-STRUCT-STRUCT-DYN-MAT-CONF","0273-4508")
    set_ISSN("j-AIAA-J",				"0001-1452")
    set_ISSN("j-AIAA-PAPER",				"0146-3705")
    set_ISSN("j-AICHE-SYMP-SER",			"0065-8812")
    set_ISSN("j-AIP-ADV",				"2158-3226")
    set_ISSN("j-AIP-CONF-PROC",				"0094-243X (print), 1551-7616 (electronic), 1935-0465")
    set_ISSN("j-AIR-FORCE-MAG",				"0730-6784 (print), 1943-4782 (electronic)")
    set_ISSN("j-AIR-TRANSP-WORLD",			"0002-2543")
    set_ISSN("j-AISB-Q",				"0268-4179")
    set_ISSN("j-AIXTRA",				"")
    set_ISSN("j-ALGEBRA-LOGIC",				"0002-5232 (print), 1573-8302 (electronic)")
    set_ISSN("j-ALGOL-BULLETIN",			"0084-6198")
    set_ISSN("j-ALGORITHMICA",				"0178-4617 (print), 1432-0541 (electronic)")
    set_ISSN("j-ALGORITHMS-BASEL",			"1999-4893 (electronic)")
    set_ISSN("j-ALLC-BULL",				"0951-1474")
    set_ISSN("j-ALMAGEST",				"1792-2593")
    set_ISSN("j-ALTA-FREQ",				"0002-6557")
    set_ISSN("j-ALTERNATIVES",                          "0300-9734 (print), 2000-1967 (electronic)")
    set_ISSN("j-AM-ANTHROPOL",				"0002-7294 (print), 1548-1433 (electronic)")
    set_ISSN("j-AM-BIOL-TEACH",				"0002-7685 (print), 0002-8444 (electronic), 1938-4211, 1938-422X")
    set_ISSN("j-AM-CRAFT",				"0194-8008")
    set_ISSN("j-AM-DOC",				"0096-946X")
    set_ISSN("j-AM-EDUC",				"0148-432X")
    set_ISSN("j-AM-HEART-J",				"0002-8703 (print), 1097-6744 (electronic)")
    set_ISSN("j-AM-HIST-REV",				"0002-8762 (print), 1937-5239 (electronic)")
    set_ISSN("j-AM-J-ANAT",				"0002-9106 (print), 1553-0795 (electronic)")
    set_ISSN("j-AM-J-APPL-SCI",				"1546-9239 (print), 1554-3641 (electronic)")
    set_ISSN("j-AM-J-ARCHAEOL",				"0002-9114 (print), 1939-828X (electronic)")
    set_ISSN("j-AM-J-CARDIOL",				"0002-9149 (print), 1879-1913 (electronic)")
    set_ISSN("j-AM-J-ECON-SOCIOL",			"0002-9246 (print), 1536-7150 (electronic)")
    set_ISSN("j-AM-J-HUM-GENET",			"0002-9297 (print), 1537-6605 (electronic)")
    set_ISSN("j-AM-J-MATH",				"0002-9327 (print), 1080-6377 (electronic)")
    set_ISSN("j-AM-J-MATH-MANAGE-SCI",			"0196-6324")
    set_ISSN("j-AM-J-MED",				"0002-9343 (print), 1555-7162 (electronic)")
    set_ISSN("j-AM-J-MED-SCI",				"0002-9629 (print), 1538-2990 (electronic)")
    set_ISSN("j-AM-J-OPHTHALMOL",			"0002-9394 (print), 1879-1891 (electronic)")
    set_ISSN("j-AM-J-PHYS-ANTHROPOL",			"0002-9483 (print), 1096-8644 (electronic)")
    set_ISSN("j-AM-J-PHYSIOL",				"0002-9513 (print), 2163-5773 (electronic)")
    set_ISSN("j-AM-J-PSYCHIATRY",			"0002-953X (print), 1535-7228 (electronic)")
    set_ISSN("j-AM-J-SCI",				"0002-9599 (print), 1945-452X (electronic)")
    set_ISSN("j-AM-J-SOCIOL",				"0002-9602 (print), 1537-5390 (electronic)")
    set_ISSN("j-AM-NAT",				"0003-0147 (print), 1537-5323 (electronic)")
    set_ISSN("j-AM-PHOTO",				"1046-8986")
    set_ISSN("j-AM-PROG",				"1048-5600")
    set_ISSN("j-AM-PROSPECT",				"1049-7285")
    set_ISSN("j-AM-Q",					"0003-0678 (print), 1080-6490 (electronic)")
    set_ISSN("j-AM-SCH",				"0003-0937 (print), 2162-2892 (electronic)")
    set_ISSN("j-AM-SCI",				"0003-0996 (print), 1545-2786 (electronic)")
    set_ISSN("j-AM-STUD",				"0026-3079 (print), 2153-6856 (electronic)")
    set_ISSN("j-AMBIX",					"0002-6980 (print), 1745-8234 (electronic)")
    set_ISSN("j-AMER-AGR-ECON",				"0002-9092 (print), 1467-8276 (electronic)")
    set_ISSN("j-AMER-J-CLIN-PATH",			"0002-9173 (print), 1943-7722 (electronic)")
    set_ISSN("j-AMER-J-PHYSICS",			"0002-9505 (print), 1943-2909 (electronic)")
    set_ISSN("j-AMER-J-PSYCHOLOGY",			"0002-9556 (print), 1939-8298 (electronic)")
    set_ISSN("j-AMER-LIBRARIES",			"0002-9769")
    set_ISSN("j-AMER-MATH-MONTHLY",			"0002-9890 (print), 1930-0972 (electronic)")
    set_ISSN("j-AMER-MATH-MONTHLY-SLAUGHT",		"????")
    set_ISSN("j-AMER-PSYCHOLOGIST",			"0003-066X (print), 1935-990X (electronic)")
    set_ISSN("j-AMER-SOC-MECH-ENG-AESD",		"1071-6947")
    set_ISSN("j-AMER-STAT",				"0003-1305 (print), 1537-2731 (electronic)")
    set_ISSN("j-AMERICAS-NETWORK",			"1075-5292")
    set_ISSN("j-AMERIKASTUDIEN",			"0340-2827")
    set_ISSN("j-AMS-COLL-PUB",				"0065-9258")
    set_ISSN("j-AN-R-ACAD-NAC-MED-MADR",                "0034-0634")
    set_ISSN("j-ANAESTHESIA",				"0003-2409 (print), 1365-2044 (electronic)")
    set_ISSN("j-ANAL-CHEM",				"0003-2700 (print), 1520-6882 (electronic)")
    set_ISSN("j-ANAL-MATH-PHYS",			"1664-235X (print), 1664-2368 (electronic)")
    set_ISSN("j-ANALYST",				"0003-2654 (print), 1364-5528 (electronic)")
    set_ISSN("j-ANALYT-BIOCHEM",			"0003-2697 (print), 1096-0309 (electronic)")
    set_ISSN("j-ANAT-EMBRYOL",                    	"0340-2061 (print), 1432-0568 (electronic)")
    set_ISSN("j-ANESTHESIA-ANALGESIA-CURR-RESEARCHES",	"0003-2999")
    set_ISSN("j-ANESTHESIOL-HAGERSTOWN",		"0003-3022 (print), 1528-1175 (electronic)")
    set_ISSN("j-ANG-INFO-ELEK-DATEN",			"0013-5704")
    set_ISSN("j-ANGEW-CHEM-INT-ED",			"1433-7851 (print), 1521-3773 (electronic)")
    set_ISSN("j-ANGEW-CHEM-INT-ED-ENGL",		"0570-0833")
    set_ISSN("j-ANIM-BEHAV",				"0003-3472 (print), 1095-8282 (electronic)")
    set_ISSN("j-ANN-ACAD-REGIAE-SCI-UPS",		"0504-0736")
    set_ISSN("j-ANN-AM-ACAD-POLIT-SOC-SCI",		"0002-7162 (print), 1552-3349 (electronic)")
    set_ISSN("j-ANN-APPL-BIOL",				"0003-4746 (print), 1744-7348 (electronic)")
    set_ISSN("j-ANN-APPL-PROBAB",			"1050-5164 (print), 2168-8737 (electronic)")
    set_ISSN("j-ANN-APPL-STAT",				"1932-6157 (print), 1941-7330 (electronic)")
    set_ISSN("j-ANN-BIOMED-ENG",			"0090-6964")
    set_ISSN("j-ANN-CHIM-PHYS",				"0365-1444 (print), 2437-3621 (electronic)")
    set_ISSN("j-ANN-EUGENICS",				"2050-1420 (print), 2050-1439 (electronic)")
    set_ISSN("j-ANN-FAC-SCI-UNIV-CLERMONT",		"0069-4673")
    set_ISSN("j-ANN-FINANCE",				"1614-2446 (print), 1614-2454 (electronic)")
    set_ISSN("j-ANN-FOURIER",				"0373-0956 (print), 1777-5310 (electronic)")
    set_ISSN("j-ANN-FOND-LOUIS-DE-BROGLIE",		"0182-4295 (print), 2108-6397 (electronic)")
    set_ISSN("j-ANN-FUNCT-ANAL",			"2008-8752")
    set_ISSN("j-ANN-HIST-COMPUT",			"0164-1239")
    set_ISSN("j-ANN-HUM-GENET",				"0003-4800 (print), 1469-1809 (electronic)")
    set_ISSN("j-ANN-INST-HENRI-POINCARE-ANAL-NON-LINEAIRE", "0294-1449 (print), 1873-1430 (electronic)")
    set_ISSN("j-ANN-INST-HENRI-POINCARE",		"0365-320X (print), 2400-4855 (electronic)")
    set_ISSN("j-ANN-INST-HENRI-POINCARE-A",		"0020-2339 (print), 2400-4863 (electronic)")
    set_ISSN("j-ANN-INST-HENRI-POINCARE-B",		"0020-2347")
    set_ISSN("j-ANN-INST-HENRI-POINCARE-PROBAB-STATIST","0246-0203 (print), 1778-7017 (electronic)")
    set_ISSN("j-ANN-INST-STAT-MATH-TOKYO",		"0020-3157 (print), 1572-9052 (electronic)")
    set_ISSN("j-ANN-INTERN-MED",			"0003-4819 (print), 1539-3704 (electronic)")
    set_ISSN("j-ANN-MAT-PURA-APPL-4",			"0373-3114")
    set_ISSN("j-ANN-MATH",				"0003-486X (print), 1939-8980 (electronic)")
    set_ISSN("j-ANN-MATH-2",				"0003-486X", 1)
    set_ISSN("j-ANN-MATH-ARTIF-INTELL",			"1012-2443 (print), 1573-7470 (electronic)")
    set_ISSN("j-ANN-MATH-STAT",				"0003-4851 (print), 2168-8990 (electronic)")
    set_ISSN("j-ANN-MATH-STUDIES",			"0066-2313")
    set_ISSN("j-ANN-NUCL-ENERGY",			"0306-4549 (print), 1873-2100 (electronic)")
    set_ISSN("j-ANN-NUM-MATH",				"1021-2655")
    set_ISSN("j-ANN-NY-ACAD-SCI",			"0077-8923 (print), 1749-6632 (electronic)")
    set_ISSN("j-ANN-OPER-RESEARCH",			"0254-5330 (print), 1572-9338 (electronic)")
    set_ISSN("j-ANN-PHYS",				"0003-4916 (print), 1096-035X (electronic)")
    set_ISSN("j-ANN-PHYS-1900",				"1521-3889")
    set_ISSN("j-ANN-PHYS-1900-4",			"0003-3804 (print), 1521-3889 (electronic)")
    set_ISSN("j-ANN-PHYS-5",				"0003-3804 (print), 1521-3889 (electronic)")
    set_ISSN("j-ANN-PHYS-6",				"0003-3804 (print), 1521-3889 (electronic)")
    set_ISSN("j-ANN-PHYS-8",				"0003-3804 (print), 1521-3889 (electronic)")
    set_ISSN("j-ANN-PHYS-BERLIN",			"0003-3804 (print), 1521-3889 (electronic)")
    set_ISSN("j-ANN-PHYS-CHEM",				"0003-3804 (print), 1521-3889 (electronic)")
    set_ISSN("j-ANN-PHYS-PHYS-CHEM",			"0003-3804 (print), 1521-3889 (electronic)")
    set_ISSN("j-ANN-PROBAB",				"0091-1798 (print), 2168-894X (electronic)")
    set_ISSN("j-ANN-REG-SCI",				"0570-1864 (print), 1432-0592 (electronic)")
    set_ISSN("j-ANN-REV-BIOCHEM",			"0066-4154 (print), 1545-4509 (electronic)")
    set_ISSN("j-ANN-REV-BIOPHYS-BIOPHYS-CHEM",		"0084-6589")
    set_ISSN("j-ANN-REV-CELL-BIOL",			"0743-4634")
    set_ISSN("j-ANN-REV-ECOLOG-SYST",			"0066-4162")
    set_ISSN("j-ANN-REV-FLUID-MECH",			"0066-4189 (print), 1545-4479 (electronic)")
    set_ISSN("j-ANN-REV-GENET",				"0066-4197 (print), 1545-2948 (electronic)")
    set_ISSN("j-ANN-REV-MATERIAL-SCI",			"0084-6600")
    set_ISSN("j-ANN-REV-NEURO",				"0147-006X (print), 1545-4126 (electronic)")
    set_ISSN("j-ANN-REV-PHYS-CHEM",			"0066-426X (print), 1545-1593 (electronic)")
    set_ISSN("j-ANN-REV-PHYSIOL",			"0066-4278 (print), 1545-1585 (electronic)")
    set_ISSN("j-ANN-SC-NORM-SUPER-PISA-CL-SCI",		"0391-173X (print), 2036-2145 (electronic)")
    set_ISSN("j-ANN-SCI-MATH-QUEBEC",			"0707-9109")
    set_ISSN("j-ANN-SCIENCE",				"0003-3790 (print), 1464-505X (electronic)")
    set_ISSN("j-ANN-SENS",				"????")
    set_ISSN("j-ANN-STAT",				"0090-5364 (print), 2168-8966 (electronic)")
    set_ISSN("j-ANN-SYMP-FOCS",				"0272-5428")
    set_ISSN("j-ANN-TELECOMMUN",			"0003-4347 (print), 1958-9395 (electronic)")
    set_ISSN("j-ANN-THEOR-PSYCHOL",			"0747-5241")
    set_ISSN("j-ANNALES-ACAD-SCIENT-FENNICAE-A-I",	"0355-0087")
    set_ISSN("j-ANNU-REP-PROG-CHEM",			"0365-6217 (print), 1754-7512 (electronic)")
    set_ISSN("j-ANNU-REV-ASTRON-ASTROPHYS",		"0066-4146 (print), 1545-4282 (electronic)")
    set_ISSN("j-ANNU-REV-AUTOM-PROGRAM",		"0066-4138 (print), 1878-545X (electronic)")
    set_ISSN("j-ANNU-REV-NUCL-PART-SCI",		"0163-8998 (print), 1545-4134 (electronic)")
    set_ISSN("j-ANNU-REV-NUCL-SCI",			"0066-4243")
    set_ISSN("j-ANNUAL-ACM-SYMP-PAR-ALG-ARCH",		"????")
    set_ISSN("j-ANRITSU-TECHNICAL-BULL",		"0003-5211")
    set_ISSN("j-ANTIMICROB-AGENTS-CHEMOTHER",		"0066-4804")
    set_ISSN("j-ANTIOCH-REV",				"0003-5769 (print), 2326-9707 (electronic)")
    set_ISSN("j-ANTISENSE-RES-DEV",			"1050-5261")

    ## The Journal of the Australian Mathematical Society. Series B, Applied mathematics.
    ## Vol. 19, pt. 1 (June 1975)-v. 41, pt. 4 (Apr. 2000).
    ## ISSN 0334-2700, Linking ISSN 0334-2700
    ##
    ## The ANZIAM journal : the Australian & New Zealand industrial and applied mathematics journal.
    ## Formerly J. Austral. Math. Soc. Ser. B
    ## Vol. 42, pt. 1 (July 2000)-
    ## ISSN 1446-1811 Linking ISSN 1446-1811
    ## Australian & New Zealand industrial and applied mathematics
    ## journal. Electronic supplement [electronic resource].
    ## ISSN 1445-8810, Linking ISSN 1445-8810
    ## US MARC: 022 |a 1446-1811  |l 1446-1811  |y 1442-4436  |y 0344-2700
    ##                 ISSN          ISSN-L        bad-ISSN      canceled ISSN
    ## set_ISSN("j-ANZIAM-J",				"1442-4436, 0344-2700")
    set_ISSN("j-ANZIAM-J",				"1446-1811 (print), 1446-8735 (electronic)")

    set_ISSN("j-ANZJS",					"1369-1473 (print), 1467-842X (electronic)")
    set_ISSN("j-AP",					"????")
    set_ISSN("j-APL-MAT",				"0373-6725")
    set_ISSN("j-APL-QUOTE-QUAD",			"0163-6006 (print), 1558-3392 (electronic)")
    set_ISSN("j-APPL-ALGEBRA-ENG-COMMUN-COMPUT",	"0938-1279 (print), 1432-0622 (electronic)")
    set_ISSN("j-APPL-ANAL",				"0003-6811")
    set_ISSN("j-APPL-COMPUT-HARMON-ANAL",		"1063-5203 (print), 1096-603X (electronic)")
    set_ISSN("j-APPL-ECON-LETT",			"1350-4851 (print), 1466-4291 (electronic)")
    set_ISSN("j-APPL-ENV-MICROBIOL",			"0099-2240")
    set_ISSN("j-APPL-FINANC-ECON",			"0960-3107 (print), 1466-4305 (electronic)")
    set_ISSN("j-APPL-INTELL",				"0924-669X (print), 1573-7497 (electronic)")
    set_ISSN("j-APPL-MATH",				"0862-7940 (print), 1572-9109 (electronic)")
    set_ISSN("j-APPL-MATH-COMP-SCI",			"0867-857X")
    set_ISSN("j-APPL-MATH-COMP",			"0096-3003 (print), 1873-5649 (electronic)")
    set_ISSN("j-APPL-MATH-LETT",			"0893-9659 (print), 1873-5452 (electronic)")
    set_ISSN("j-APPL-MATH-MECH-ENGL-ED",		"0253-4827 (print), 1573-2754 (electronic)")
    set_ISSN("j-APPL-MATH-MODEL",			"0307-904X (print), 1872-8480 (electronic)")
    set_ISSN("j-APPL-MATH-NOTES",			"0700-9224")
    set_ISSN("j-APPL-MATH-OPTIM",			"0095-4616 (print), 1432-0606 (electronic)")
    set_ISSN("j-APPL-MATH-SCI-RUSE",			"1312-885X (print), 1314-7552 (electronic)")
    set_ISSN("j-APPL-MATH-SER-NBS",			"1049-4685")
    set_ISSN("j-APPL-MECH-REV",				"0003-6900 (print), 1088-8535 (electronic)")
    set_ISSN("j-APPL-MICROBIOL-BIOTECHNOL",		"0175-7598 (print), 1432-0614 (electronic)")
    set_ISSN("j-APPL-NUM-ANA",				"????")
    set_ISSN("j-APPL-NUM-ANAL-COMPUT-MATH",		"1611-8170 (print), 1611-8189 (electronic)")
    set_ISSN("j-APPL-NUM-MATH",				"0168-9274 (print), 1873-5460 (electronic)")
    set_ISSN("j-APPL-OPTICS",				"0003-6935")
    set_ISSN("j-APPL-PHYS-A",				"0947-8396 (print), 1432-0630 (electronic)")
    set_ISSN("j-APPL-PHYS-LET",				"0003-6951 (print), 1077-3118 (electronic), 1520-8842")
    set_ISSN("j-APPL-PHYS-EXPRESS",			"1882-0778 (print), 1882-0786 (electronic)")
    set_ISSN("j-APPL-PSYCH-MEASUREMENT",		"0146-6216 (print), 1552-3497 (electronic)")
    set_ISSN("j-APPL-SCI-RES",				"0003-6994 (print), 2212-0939 (electronic)")
    set_ISSN("j-APPL-SCI-RES-SECT-B",			"0365-7140 (print), 1872-8065 (electronic)")
    set_ISSN("j-APPL-STAT",				"0035-9254 (print), 1467-9876 (electronic)")
    set_ISSN("j-APPL-SURF-SCI",				"0169-4332 (print), 1873-5584 (electronic)")
    set_ISSN("j-APPL-SURF-SCI-1977-1985",		"0378-5963 (print), 1878-1071 (electronic)")
    set_ISSN("j-APPROX-THEORY-APPL",			"1000-9221")
    set_ISSN("j-AQUAC-FISH-FISH",			"2693-8847")
    set_ISSN("j-AQUAT-BOT",				"0304-3770 (print), 1879-1522 (electronic)")
    set_ISSN("j-AQUAT-TOXICOL",				"0166-445X (print), 1879-1514 (electronic)")
    set_ISSN("j-ARCH-APPL-MECH",			"0939-1533 (print), 1432-0681 (electronic)")
    set_ISSN("j-ARCH-BIOCHEM-BIOPHYS",			"0003-9861 (print), 1096-0384 (electronic)")
    set_ISSN("j-ARCH-ENTWICKLUNGSMECH",			"????")
    set_ISSN("j-ARCH-HIST-EXACT-SCI",			"0003-9519 (print), 1432-0657 (electronic)")
    set_ISSN("j-ARCH-INEQUAL-APPL",			"1542-6149")
    set_ISSN("j-ARCH-MATH",				"0003-889X (print), 1420-8938 (electronic)")
    set_ISSN("j-ARCH-MECH",				"0373-2029")
    set_ISSN("j-ARCH-MED-RES",				"0188-0128")
    set_ISSN("j-ARCH-MICROBIOL",			"0302-8933 (print), 1432-072X (electronic)")
    set_ISSN("j-ARCH-NEERL-SCI-EXACTES-NAT",		"0365-5059")
    set_ISSN("j-ARCH-NEUROL",				"0003-9942 (print), 1538-3687 (electronic)")
    set_ISSN("j-ARCH-NUM-SOFT",				"2197-8263")
    set_ISSN("j-ARCH-PHARM-WEINHEIM",			"0365-6233 (print), 1521-4184 (electronic)")
    set_ISSN("j-ARCH-PHILOS",				"0003-9632 (print), 1769-681X (electronic)")
    set_ISSN("j-ARCH-RAT-MECH-ANAL",			"0003-9527 (print), 1432-0673 (electronic)")
    set_ISSN("j-ARCH-SCI-PHYS-NAT",			"0365-7116")
    set_ISSN("j-ARCHIMEDE",				"0390-5543")
    set_ISSN("j-ARITH-TEACHER",				"0004-136X")
    set_ISSN("j-ARKHIMEDES",				"0004-1920")
    set_ISSN("j-ARKIV-MAT-ASTRON-FYSIK",		"0365-4133")
    set_ISSN("j-ARKIV-MATH",				"0004-2080 (print), 1871-2487 (electronic)")
    set_ISSN("j-ARKIV-MATH-NATUR",			"????")
    set_ISSN("j-ARKIV-FYSIK",				"0365-2440")
    set_ISSN("j-ARM-J-PHYS",				"1829-1171")
    set_ISSN("j-ARMS",					"2374-2348 (print), 2374-2356 (electronic)")
    set_ISSN("j-ARMS-CONTROL-TODAY",			"0196-125X (print), 1943-5754 (electronic)")
    set_ISSN("j-ARS-COMB",				"0381-7032")
    set_ISSN("j-ARSP-ARCH-RECHTS-SOZIALPHILOS",		"0001-2343")
    set_ISSN("j-ART-BULL",				"0004-3079 (print), 1559-6478 (electronic)")
    set_ISSN("j-ART-INTELL",				"0004-3702 (print), 1872-7921 (electronic)")
    set_ISSN("j-ART-LIFE-ROBOT",			"1433-5298 (print), 1614-7456 (electronic)")
    set_ISSN("j-ARTIF-LIFE",				"1064-5462 (print), 1530-9185 (electronic)")
    set_ISSN("j-ARTISTS-MAG",				"0741-3351")
    set_ISSN("j-ASEAN-PROPRINT",			"1036-9112")
    set_ISSN("j-ASIAWEEK",				"1012-6244 (print), 1560-7046 (electronic)")
    set_ISSN("j-ASIA-PAC-MATH-NEWSL",			"2010-3484")
    set_ISSN("j-ASLIB-PROC",				"0001-253X (print), 1758-3748 (electronic)")
    set_ISSN("j-ASPECTS-APPL-BIOL",			"0265-1491")
    set_ISSN("j-ASTA-ADV-STAT-ANAL",			"1863-8171 (print), 1863-818X (electronic)")
    set_ISSN("j-ASTERISK",				"0731-1001")
    set_ISSN("j-ASTM-SPEC-TECH-PUB",			"0066-0558")
    set_ISSN("j-ASTRO-NACHR",				"0004-6337 (print), 1521-3994 (electronic)")
    set_ISSN("j-ASTROBIOLOGY",				"1531-1074 (print), 1557-8070 (electronic)")
    set_ISSN("j-ASTRON-ASTROPHYS",			"0004-6361 (print), 1432-0746 (electronic)")
    set_ISSN("j-ASTRON-ASTROPHYS-REV",			"0935-4956 (print), 1432-0754 (electronic)")
    set_ISSN("j-ASTRON-ASTROPHYS-SUPPL-SER",		"0365-0138 (print), 1286-4846 (electronic)")
    set_ISSN("j-ASTRON-ASTROPHYS-TRANS",		"1055-6796 (print), 1476-3540 (electronic)")
    set_ISSN("j-ASTRON-GEOPHYS",			"1366-8781 (print), 1468-4004 (electronic)")
    set_ISSN("j-ASTRON-J",				"0004-6256 (print), 1538-3881 (electronic)")
    set_ISSN("j-ASTRON-Q",				"0364-9229 (print), 1878-0865 (electronic)")
    set_ISSN("j-ASTROPART-PHYS",			"0927-6505 (print), 1873-2852 (electronic)")
    set_ISSN("j-ASTROPHYS-LETT",			"0004-6388")
    set_ISSN("j-ASTROPHYS-SPACE-SCI",			"0004-640X (print), 1572-946X (electronic)")
    set_ISSN("j-ASTROPHYSICAL-J",			"0004-637X (print), 1538-4357 (electronic)")
    set_ISSN("j-ASTROPHYSICAL-J-SUPPL-SER",		"0067-0049 (print), 1538-4365 (electronic)")
    set_ISSN("j-ASYMP-STAT",				"????")
    set_ISSN("j-ASYMPTOT-ANAL",				"0921-7134 (print), 1875-8576 (electronic)")
    set_ISSN("j-AT-DATA-NUCL-DATA-TABLES",		"0092-640X (print), 1090-2090 (electronic)")
    set_ISSN("j-ATLANTIC-MONTHLY",			"1072-7825 (print), 2151-9463 (electronic)")
    set_ISSN("j-ATMOS-ENV",				"0004-6981 (print), 1878-2442 (electronic)")
    set_ISSN("j-ATMOS-SCI-LETT",			"1530-261X")
    set_ISSN("j-ATOMS",					"2218-2004")
    set_ISSN("j-ATT-BELL-LABORATORIES-RECORD",		"0749-8152")
    set_ISSN("j-ATT-BELL-LAB-TECH-J",			"0748-612X")
    set_ISSN("j-ATT-TECH-J",				"8756-2324")
    set_ISSN("j-ATTEN-PERCEPT-PSYCHOPHYS",		"1943-3921 (print), 1943-393X (electronic)")
    set_ISSN("j-AUDIO-VISUAL",				"0305-2249")
    set_ISSN("j-AUDITING",				"0278-0380 (print), 1558-7991 (electronic)")
    set_ISSN("j-AUST-J-AGRIC-RES",			"0004-9409 (print), 1444-9838 (electronic)")
    set_ISSN("j-AUST-J-MATH-ANAL-APPL",			"1449-5910")
    set_ISSN("j-AUST-J-STAT",				"0004-9581")
    set_ISSN("j-AUSTRALIAN-COMP-J",			"0004-8917")
    set_ISSN("j-AUSTRALIAN-COMP-SCI-COMM",		"0157-3055")
    set_ISSN("j-AUSTRALIAN-J-PHYS",			"0004-9506 (print), 1446-5582 (electronic)")
    set_ISSN("j-AUSTRALIAN-J-STAT",			"0004-9581")
    set_ISSN("j-AUSTRALIAN-LIBR-REV",			"1034-8042")
    set_ISSN("j-AUSTRALIAN-MATH-SOC-GAZ",		"0311-0729 (print), 1326-2297 (electronic)")
    set_ISSN("j-AUSTRALIAN-MATH-SOC-SERIES-A",		"Journal of the Australian Mathematical Society. Series A: Pure mathematics")
    set_ISSN("j-AUSTRALIAN-MATH-SOC-SERIES-A",		"Journal of the Australian Mathematical Society. Series A: Pure mathematics")

    set_ISSN("j-AUSTRALIAN-MATH-TEACHER",		"0045-0685")
    set_ISSN("j-AUSTRALIAN-PERSONAL-COMP",		"0725-4415 (print), 1445-0909 (electronic)")
    set_ISSN("j-AUTO-CTL-COMP-SCI",			"0146-4116 (print), 1558-108X (electronic)")
    set_ISSN("j-AUTOM-REMOTE-CONTROL",			"0005-2310 (print), 2413-9777 (electronic)")
    set_ISSN("j-AUTOMATIC-REMOTE-CTL",			"0538-7361")
    set_ISSN("j-AUTOMATICA",				"0005-1098 (print), 1873-2836 (electronic)")
    set_ISSN("j-AUTOMATION-REMOTE-CTL",			"0005-1179 (print), 1608-3032 (electronic)")
    set_ISSN("j-AUTOMOTIVE-ENG",			"0097-711X")
    set_ISSN("j-AV-VIDEO",				"0747-1335")
    set_ISSN("j-AVIAT-WEEK-SPACE-TECHNOL",		"0005-2175")
    set_ISSN("j-AXIOMS-BASEL",				"2075-1680")
    set_ISSN("j-AXIS",					"1352-8971")
    set_ISSN("j-BANK-SYST-TECHNOL",			"1045-9472")
    set_ISSN("j-BANKING-TECH",                          "0266-0865")
    set_ISSN("j-BASIC-LIFE-SCI",			"0090-5542")
    set_ISSN("j-BASIC-RES-CARDIOL",			"0300-8428 (print), 1435-1803 (electronic)")
    set_ISSN("j-BAYESIAN-ANAL",				"1931-6690 (print), 1931-6690 (electronic)")
    set_ISSN("j-BEHAV-BRAIN-SCI",			"0140-525X (print), 1469-1825 (electronic)")
    set_ISSN("j-BEHAV-INF-TECH",			"0144-929X (print), 1362-3001 (electronic)")
    set_ISSN("j-BEHAV-RES-METH-INSTR",			"0005-7878")
    set_ISSN("j-BEHAV-RES-METH-INSTR-COMP",		"0743-3808 (print), 1532-5970 (electronic)")
    set_ISSN("j-BEHAV-SCI",				"0005-7940 (print), 1932-300X (electronic)")
    set_ISSN("j-BEHAVIOUR",				"0005-7959 (print), 1568-539X (electronic)")
    set_ISSN("j-BEIBL-ANN-PHYS",			"0375-846X")
    set_ISSN("j-BEITRAGE-NUMER-MATH",			"????")
    set_ISSN("j-BELL-LABS-RECORD",			"0005-8564")
    set_ISSN("j-BELL-LABS-TECH-J",			"1538-7305")
    set_ISSN("j-BELL-SYST-TECH-J",			"0005-8580")
    set_ISSN("j-BELLCORE-EXCHANGE",			"1040-2020")
    set_ISSN("j-BER-BUNSENGES-PHYS-CHEM",		"0005-9021")
    ## ?? set_ISSN("j-BER-BUNSENGES-PHYS-CHEM",		"0940-483X")
    set_ISSN("j-BER-DTSCH-CHEM-GES-A",			"0365-947X")
    set_ISSN("j-BER-DTSCH-CHEM-GES-ABT-A-B",		"1099-0682 (print), 1434-1948 (electronic)")
    set_ISSN("j-BER-DTSCH-CHEM-GES",			"0365-9496")
    set_ISSN("j-BER-WISSENSCHAFTGESCH",			"0170-6233 (print), 1522-2365 (electronic)")
    set_ISSN("j-BERICHTE-GMD-BONN",			"0533-9480")
    set_ISSN("j-BERNOULLI",				"1350-7265 (print), 1573-9759 (electronic)")
    set_ISSN("j-BESTS-REV-LIFE-HEALTH-INSUR-ED",	"0005-9706")
    set_ISSN("j-BIO-CHEM-HOPPE-SEYLER",			"0177-3593")
    set_ISSN("j-BIOCHEM",				"0006-2960")
    set_ISSN("j-BIOCHEM-BIOKHIM",			"0006-2979 (print), 1608-3040 (electronic)")
    set_ISSN("j-BIOCHEM-BIOPHYS-RES-COMMUN",		"0006-291X (print), 1090-2104 (electronic)")
    set_ISSN("j-BIOCHEM-CELL-BIOL",			"0829-8211 (print), 1208-6002 (electronic)")
    set_ISSN("j-BIOCHEM-INT",				"0158-5231")
    set_ISSN("j-BIOCHEM-J",				"0264-6021 (print), 1470-8728 (electronic)")
    set_ISSN("j-BIOCHEM-MOL-BIOL-INT",			"1039-9712, 1069-8302")
    set_ISSN("j-BIOCHEM-PHARM",				"0006-2952 (print), 1873-2968 (electronic)")
    set_ISSN("j-BIOCHEM-SER-MONOGR",			"0194-0538")
    set_ISSN("j-BIOCHEM-SOC-SYMP",			"0067-8694 (print), 1744-1439 (electronic)")
    set_ISSN("j-BIOCHEM-SOC-TRANS",			"0300-5127 (print), 1470-8752 (electronic)")
    set_ISSN("j-BIOCHEM-SYS-ECO",			"0305-1978 (print), 1873-2925 (electronic)")
    set_ISSN("j-BIOCHEM-Z",				"0366-0753")

    ## This journal is a mess: UC/Melvyl lists its ISSNs as 0005-2728,
    ## 0005-2736, 0005-2760, 0006-3002, 0167-4781, 0167-4838,
    ## 0167-4889, 0304-4157, 0304-4165, 0304-419X, 0925-4439,
    ## 1388-1981
    set_ISSN("j-BIOCHIM-BIOPHYS-ACTA",			"0006-3002 (print), 1878-2434 (electronic)")

    set_ISSN("j-BIOCHIM-BIOPHYS-ACTA-GENE-STRUCT-EXPRESS","0167-4781")
    set_ISSN("j-BIOCHIM-BIOPHYS-ACTA-HUNG",		"0001-5253, 0237-6261")
    set_ISSN("j-BIOCHIM-BIOPHYS-ACTA-MOL-CELL-RES",	"0167-4889 (print), 1879-2596 (electronic)")
    set_ISSN("j-BIOCHIMIE",				"0300-9084 (print), 1638-6183 (electronic)")
    set_ISSN("j-BIOELECTROCHEM-BIOENERG",		"0302-4598 (print), 1872-8049 (electronic)")
    set_ISSN("j-BIOENERGETICS",				"0005-2728 (print), 1879-2650 (electronic)")
    set_ISSN("j-BIOESSAYS",				"0265-9247 (print), 1521-1878 (electronic)")
    set_ISSN("j-BIOFIZIKA",				"0006-3029")
    set_ISSN("j-BIOGR-MEM-NAT-ACAD-SCI",		"0077-2933")
    set_ISSN("j-BIOGRAPH-MEMOIRS-FELLOWS-ROY-SOC",	"0080-4606 (print), 1748-8494 (electronic)")
    set_ISSN("j-BIOGRAPHY-HONOLULU",			"0162-4962 (print), 1529-1456 (electronic)")
    set_ISSN("j-BIOINFORMATICS",			"1367-4803 (print), 1367-4811 (electronic)")
    set_ISSN("j-BIOL-BULL",				"0006-3185 (print), 1939-8697 (electronic)")
    set_ISSN("j-BIOL-CYBERN",				"0340-1200 (print), 1432-0770 (electronic)")
    set_ISSN("j-BIOL-J-LINNEAN-SOC",			"0024-4066 (print), 1095-8312 (electronic)")
    set_ISSN("j-BIOL-REPROD",                           "0006-3363 (print), 1529-7268 (electronic)")
    set_ISSN("j-BIOL-REV-CAMB-PHIL-SOC",		"0006-3231")
    set_ISSN("j-BIOMED-BIOCHIM-ACTA",			"0232-766X")
    set_ISSN("j-BIOMEMBRANES",				"0067-8864")
    set_ISSN("j-BIOMETRIC-BULL",			"0006-341X (print), 1541-0420 (electronic)")
    set_ISSN("j-BIOMETRICAL-J",				"0323-3847")
    set_ISSN("j-BIOMETRICS",				"0006-341X (print), 1541-0420 (electronic)", 1)
    set_ISSN("j-BIOMETRIKA",				"0006-3444 (print), 1464-3510 (electronic)")
    set_ISSN("j-BIOMETRISCHE-Z",			"0006-3452")
    set_ISSN("j-BIOPHYS",				"0006-3509 (print), 1555-6654 (electronic)")
    set_ISSN("j-BIOPHYS-CHEM",				"0301-4622 (print), 1873-4200 (electronic)")
    set_ISSN("j-BIOPHYS-J",				"0006-3495 (print), 1542-0086 (electronic)")
    set_ISSN("j-BIOPHYS-STRUCT-MECH",			"0340-1057")
    set_ISSN("j-BIOPOLYMERS-SYMPOSIA",			"0523-6827")
    set_ISSN("j-BIORHEOLOGY",				"0006-355X (print), 1878-5034 (electronic)")
    set_ISSN("j-BIOSCI",				"0006-3568 (print), 1525-3244 (electronic)")
    set_ISSN("j-BIOSCI-REP",				"0144-8463 (print), 1573-4935 (electronic)")
    set_ISSN("j-BIOSYSTEMS",				"0303-2647 (print), 1872-8324 (electronic)")
    set_ISSN("j-BIOTECH",				"0733-222X")

    # Do NOT include 0006-3843 in j-BIT; that corresponds to the
    # German journal "Buro + Informationsteknik".
    set_ISSN("j-BIT",					"0006-3835 (print), 1572-9125 (electronic)")

    set_ISSN("j-BLOOD",					"0006-4971 (print), 1528-0020 (electronic)")
    set_ISSN("j-BLOOD-CELLS",				"0340-4684")
    set_ISSN("j-BLOOD-REV",				"0268-960X (print), 1532-1681 (electronic)")
    set_ISSN("j-BLUT",					"0006-5242")
    set_ISSN("j-BMC-BIOINFORMATICS",			"1471-2105")
    set_ISSN("j-BOL-MAT-SAO-PAULO",			"????")
    set_ISSN("j-BOL-SOC-PORT-MAT",			"0872-3672")
    set_ISSN("j-BOLL-STOR-SCI-MAT",			"0392-4432 (print), 1724-1650 (electronic)")
    set_ISSN("j-BOLL-UNIONE-MAT-ITAL",			"0041-7084")
    set_ISSN("j-BOLL-UNIONE-MAT-ITAL-A",		"0392-4033")
    set_ISSN("j-BONE-MINERAL",				"0169-6009 (print), 1878-0628 (electronic)")
    set_ISSN("j-BOSTON-GLOBE",				"0743-1791")
    set_ISSN("j-BOSTON-PHOENIX",			"0163-3015")
    set_ISSN("j-BOUND-VALUE-PROBL",			"1687-2770")
    set_ISSN("j-BOUNDARY-LAYER-METEOROL",		"0006-8314 (print), 1573-1472 (electronic)")
    set_ISSN("j-BR-ASSOC-ADV-SCI-REP",			"0365-8694")
    set_ISSN("j-BR-J-APPL-PHYS",			"0508-3443 (print), 2057-7656 (electronic)")
    set_ISSN("j-BR-J-HAEMATOL",				"0007-1048 (print), 1365-2141 (electronic)")
    set_ISSN("j-BR-J-PHOTOGR",				"0007-1196")
    set_ISSN("j-BR-J-NEUROSURG",			"0268-8697 (print), 1360-046X (electronic)")
    set_ISSN("j-BR-MED-J",				"0007-1447")
    set_ISSN("j-BRAIN-COGN",				"0278-2626 (print), 1090-2147 (electronic)")
    set_ISSN("j-BRAIN-RES",                             "0006-8993 (print), 1872-6240 (electronic)")
    set_ISSN("j-BRAIN-RES-REV",				"0165-0173 (print), 1872-6321 (electronic)")
    set_ISSN("j-BRAZ-J-PHYS",				"0103-9733 (print), 1678-4448 (electronic)")
    set_ISSN("j-BRAZILIAN-J-MED-BIOL-RES",		"0100-879X (print), 1414-431X (electronic)")
    set_ISSN("j-BRITISH-DENTAL-J",			"0007-0610 (print), 1476-5373 (electronic)")
    set_ISSN("j-BRITISH-HEART-J",			"0007-0769")
    set_ISSN("j-BRITISH-J-CANCER",			"0007-0920 (print), 1532-1827 (electronic)")
    set_ISSN("j-BRITISH-J-HIST-MATH",			"2637-5451")
    set_ISSN("j-BRITISH-J-HIST-SCI",			"0007-0874 (print), 1474-001X (electronic)")
    set_ISSN("j-BRITISH-J-MATH-STATIST-PSYCHOL",	"0007-1102")
    set_ISSN("j-BRITISH-J-PHILOS-SCI",			"0007-0882 (print), 1464-3537 (electronic)")
    set_ISSN("j-BRITISH-LIBRARY-RDR",			"0308-2385")
    set_ISSN("j-BRITISH-PRINTER",			"0007-1684")
    set_ISSN("j-BROADCAST-CABLE",			"0007-2028")
    set_ISSN("j-BSHM-BULL",				"1749-8430 (print), 1749-8341 (electronic)")
    set_ISSN("j-BSHM-NEWSLETTER",			"0962-9416")
    set_ISSN("j-BT-TECH-J",				"0265-0193")
    set_ISSN("j-BUL-ACAD-STIINTE-REPUB-MOD-MAT",	"1024-7696")
    set_ISSN("j-BULL-ACAD-POL-SCI-CL-3",		"0554-5897")
    set_ISSN("j-BULL-ACAD-POL-SCI-SER-SCI-MATH-ASTRON-PHYS",	"0001-4117")
    set_ISSN("j-BULL-AM-SOC-INF-SCI",			"0095-4403")
    set_ISSN("j-BULL-AMER-PHYS-SOC",			"0003-0503")
    set_ISSN("j-BULL-AMS",				"0002-9904 (print), 1936-881X (electronic)")
    set_ISSN("j-BULL-AMS-N-S",				"0273-0979 (print), 1088-9485 (electronic)")
    set_ISSN("j-BULL-ASSOC-SUISE-ELECTRICIENS",		"0004-587X")
    set_ISSN("j-BULL-ASTRON-SOC-INDIA",			"0304-9523")
    set_ISSN("j-BULL-AT-SCI",				"0096-3402 (print), 1938-3282 (electronic)")
    set_ISSN("j-BULL-AUSTRAL-MATH-SOC",			"0004-9727 (print), 1755-1633 (electronic)")
    set_ISSN("j-BULL-CALCUTTA-MATH-SOC",		"0008-0659")
    set_ISSN("j-BULL-EATCS",				"0252-9742")
    set_ISSN("j-BULL-ENV-CONTAM-TOXIC",			"0007-4861 (print), 1432-0800 (electronic)")
    set_ISSN("j-BULL-GEODESIQUE",			"0007-4632")
    set_ISSN("j-BULL-HIST-CHEM",			"1053-4385")
    set_ISSN("j-BULL-INFO-CYBER",			"0286-522X")
    set_ISSN("j-BULL-INST-MATH-APPL",			"0950-5628")
    set_ISSN("j-BULL-INST-MATH-STAT",			"0146-3942")
    set_ISSN("j-BULL-KNOB",				"0166-0470")
    set_ISSN("j-BULL-LOND-MATH-SOC",			"0024-6093 (print), 1469-2120 (electronic)")
    set_ISSN("j-BULL-MATH-BIOL",			"0092-8240 (print), 1522-9602 (electronic)")
    set_ISSN("j-BULL-MATH-BIOPHYS",			"0007-4985 (print), 2376-8398 (electronic)")
    set_ISSN("j-BULL-MATH-SOC-SCI-MATH-ROUMANIE",	"0007-4691")
    set_ISSN("j-BULL-PLANKTON-SOC-JAPAN",		"0387-8961")
    set_ISSN("j-BULL-SANTA-FE-INST",			"1058-7608")
    set_ISSN("j-BULL-SCHWEIZ-ELEKTROTECH",		"0036-1321")
    set_ISSN("j-BULL-SCI-ASSOC-INGEN-ELECTRICIENS-MONTEFIORE","0302-2676")
    set_ISSN("j-BULL-SOC-MATH-FRANCE",			"0037-9484 (print), 2102-622X (electronic)")
    set_ISSN("j-BULL-SOC-R-SCI-LIEGE",			"0037-9565")
    set_ISSN("j-BULL-SYMB-LOG",				"1079-8986 (print), 1943-5894 (electronic)")
    set_ISSN("j-BUS-AM",				"0190-6275")
    set_ISSN("j-BUS-COMMUN-REV",			"0162-3885")
    set_ISSN("j-BUS-INDIA",				"0254-5268")
    set_ISSN("j-BUSINESS-INFO-REV",                     "0266-3821 (print), 1741-6450 (electronic)")
    set_ISSN("j-BUSINESS-MARKETING",                    "0745-5933")
    set_ISSN("j-BUSINESS-PUBLISHING",			"1060-2208")
    set_ISSN("j-BUSINESS-REVIEW-WEEKLY",		"0727-758X")
    set_ISSN("j-BUSINESS-WEEK",				"0007-7135")
    set_ISSN("j-BYTE",					"0360-5280 (print), 1082-7838 (electronic)")
    set_ISSN("j-C-JET",					"0198-6554")
    set_ISSN("j-C-PLUS-PLUS-REPORT",			"1040-6042")
    set_ISSN("j-C-R-ACAD-BULGARE-SCI",			"0366-8681")
    set_ISSN("j-C-R-ACAD-BULGARE-SCI-SCI-MATH-NAT",	"0861-1459")
    set_ISSN("j-C-R-ACAD-SCI",				"????")
    set_ISSN("j-C-R-ACAD-SCI-CANADA",			"????")
    set_ISSN("j-C-R-ACAD-SCI-I",			"0764-4442 (print), 1778-3577 (electronic)")
    set_ISSN("j-C-R-ACAD-SCI-III",			"0764-4469 (print), 1878-5565 (electronic)")
    set_ISSN("j-C-R-ACAD-SCI-PARIS",			"????")
    set_ISSN("j-C-R-ACAD-SCI-PARIS-SER-A",		"0366-6034")
    set_ISSN("j-C-R-ACAD-SCI-PARIS-SER-B",		"0366-6077")
    set_ISSN("j-C-R-ACAD-SCI-PARIS-SER-AB",		"0151-0509")
    set_ISSN("j-C-R-ACAD-SCI-PARIS-SER-I-MATH",		"0249-6291")
    set_ISSN("j-C-R-ACAD-SCI-SER-GEN-VIE-SCI",		"0762-0969 (print), 2419-8730 (electronic)")
    set_ISSN("j-C-R-ACAD-SCI-URSS",			"0002-3264")
    set_ISSN("j-C-R-BIOL",				"1631-0691 (print), 1768-3238 (electronic)")
    set_ISSN("j-C-R-DAS-URSS",				"????")
    set_ISSN("j-C-R-HEBD-SEANCES-ACAD-SCI",		"0001-4036 (print), 2419-6304 (electronic)")
    ## set_ISSN("j-C-R-MATH-I",				"0764-4442 (print), 1778-3577 (electronic)")
    set_ISSN("j-C-R-MATH-ACAD-SCI-PARIS",		"1631-073X (print), 1778-3569 (electronic)")
    set_ISSN("j-C-R-MEC",				"1631-0721 (print), 1873-7234 (electronic)")
    set_ISSN("j-C-R-PHYS",				"1631-0705 (print), 1878-1535 (electronic)")
    set_ISSN("j-CABLE-TRANS",				"0007-9308")
    set_ISSN("j-CACM",					"0001-0782 (print), 1557-7317 (electronic)")
    ## set_ISSN("j-CAD",				"0010-4485 (print), 1879-2685 (electronic)")
    set_ISSN("j-CADALYST",				"0820-5450")
    set_ISSN("j-CAGD",					"0167-8396 (print), 1879-2332 (electronic)")	# <-- alternate 0167-8369 seems to be wrong
    set_ISSN("j-CAH-PHYS",				"0366-5291")
    set_ISSN("j-CAHIERS-CENTRE-ETUDES-RECH-OPER",	"0008-9737")
    set_ISSN("j-CALCOLO",				"0008-0624 (print), 1126-5434 (electronic)")
    set_ISSN("j-CALC-VAR-PARTIAL-DIFFER-EQU",		"0944-2669 (print), 1432-0835 (electronic)")
    set_ISSN("j-CALIF-MANAGE-REV",			"0008-1256")
    set_ISSN("j-CALPHAD",				"0364-5916 (print), 1873-2984 (electronic)")
    set_ISSN("j-CAMBRIDGE-STUDIES-ADV-MATH",		"0950-6330")
    set_ISSN("j-CAMPUS-WIDE-INF-SYST",			"1065-0741")
    set_ISSN("j-CAN-APPL-MATH-Q",			"1073-1849 (print), 1938-2634 (electronic)")
    set_ISSN("j-CAN-ELECTR-ENG-J",			"0700-9216")
    set_ISSN("j-CAN-J-ARCHAEO",				"0705-2006")
    set_ISSN("j-CAN-J-BIOCHEM-CELL-BIOL",		"0714-7511")
    set_ISSN("j-CAN-J-CARDIOL",				"0828-282X")
    set_ISSN("j-CAN-J-CHEM",				"0008-4042 (print), 1480-3291 (electronic)")
    set_ISSN("j-CAN-J-EARTH-SCI",			"0008-4077 (print), 1480-3313 (electronic)")
    set_ISSN("j-CAN-J-ELECT-COMP-ENG",			"0840-8688")
    set_ISSN("j-CAN-J-FOR-RES",				"0045-5067 (print), 1208-6037 (electronic)")
    set_ISSN("j-CAN-J-INFO-SCIENCE",			"0380-9218")
    set_ISSN("j-CAN-J-FISH-AQUAT-SCI",			"0706-652X (print), 1205-7533 (electronic)")
    set_ISSN("j-CAN-J-HIGHER-ED",			"0316-1218 (print), 2293-6602 (electronic)")
    set_ISSN("j-CAN-J-MATH",				"0008-414X")
    set_ISSN("j-CAN-J-MICROBIOL",			"0008-4166 (print), 1480-3275 (electronic)")
    set_ISSN("j-CAN-J-PHYS",				"0008-4204 (print), 1208-6045 (electronic)")
    set_ISSN("j-CAN-J-PHYSIOL-PHARMACOL",		"0008-4212 (print), 1205-7541 (electronic)")
    set_ISSN("j-CAN-J-RES-SECT-A",			"0366-7383")
    set_ISSN("j-CAN-J-STAT",				"0319-5724 (print), 1708-945X (electronic)")
    set_ISSN("j-CAN-MATH-BULL",				"0008-4395")
    set_ISSN("j-CANCER-METASTASIS-REV",			"0891-9992, 0167-7659")
    set_ISSN("j-CAPACITY-MANAGEMENT-REVIEW",		"1049-2194")
    set_ISSN("j-CARBOHYDR-RES",				"0008-6215 (print), 1873-426X (electronic)")
    set_ISSN("j-CARBON",				"0008-6223 (print), 1873-3891 (electronic)")
    set_ISSN("j-CARDIOSCIENCE",                         "1015-5007")
    set_ISSN("j-CARDIOVASC-RES",			"0008-6363 (print), 1755-3245 (electronic)")
    set_ISSN("j-CART-GIS",				"1050-9844")
    set_ISSN("j-CARTOGRAPHICA",				"0317-7173")
    set_ISSN("j-CAS-PEST-MAT",				"0008-7394, 0528-2195")
    set_ISSN("j-CAT-CLASSIF-Q",				"0163-9374 (print), 1544-4554 (electronic)")
    set_ISSN("j-CCCUJ",					"1075-2838")
    set_ISSN("j-CCPE",					"1532-0626 (print), 1532-0634 (electronic)")
    set_ISSN("j-CD-ROM-PROF",				"1049-0833")
    set_ISSN("j-CD-ROM-WORLD",				"1066-274X")
    set_ISSN("j-CEE",					"0009-2479")
    set_ISSN("j-CELEST-MECH",				"0008-8714 (print), 2214-7284 (electronic)")
    set_ISSN("j-CELEST-MECH-DYN-ASTR",			"0923-2958 (print), 1572-9478 (electronic)")
    set_ISSN("j-CELL",					"0092-8674 (print), 1097-4172 (electronic)")
    set_ISSN("j-CELL-BIOL-INT",				"1065-6995 (print), 1095-8355 (electronic)")
    set_ISSN("j-CELL-BIOL-INT-REP",			"0309-1651 (print), 1878-240X (electronic)")
    set_ISSN("j-CELL-BIOPHYS",				"0163-4992")
    set_ISSN("j-CELL-CALCIUM",				"0143-4160 (print), 1532-1991 (electronic)")
    set_ISSN("j-CELL-DIFFER",				"0045-6039 (print), 1878-2396 (electronic)")
    set_ISSN("j-CELL-DIFFER-DEV",			"0922-3371 (print), 1878-738X (electronic)")
    set_ISSN("j-CELL-MOTIL",				"0271-6585")
    set_ISSN("j-CELL-MOTIL-CYTOSKEL",			"0886-1544 (print), 1097-0169 (electronic)")
    set_ISSN("j-CELL-REGUL",				"1044-2030")
    set_ISSN("j-CELL-SIGNAL",				"0898-6568 (print), 1873-3913 (electronic)")
    set_ISSN("j-CELL-STRUCT-FUNCT",			"0386-7196 (print), 1347-3700 (electronic)")
    set_ISSN("j-CELL-SYST",				"2405-4712")
    set_ISSN("j-CELL-TISSUE-RES",                       "0302-766X (print), 1432-0878 (electronic)")
    set_ISSN("j-CELL-TISSUE-KINET",			"0008-8730")
    set_ISSN("j-CENTAURUS",				"0008-8994 (print), 1600-0498 (electronic)")
    set_ISSN("j-CERN-COURIER",				"0304-288X (print), 2077-9550 (electronic)")
    set_ISSN("j-CESK-CAS-FYZ",				"0009-0700 (print), 1804-8536 (electronic)")
    set_ISSN("j-CESK-CAS-FYZ-SEK-A",			"0009-0700 (print), 1804-8536 (electronic)")
    set_ISSN("j-CG-WORLD",				"0271-4159")
    set_ISSN("j-CGF",					"0167-7055 (print), 1467-8659 (electronic)")
    set_ISSN("j-CGIP",					"0146-664X (print), 1557-9697 (electronic)")    # CGIP: V.1-20, April 1972-December 1982: see CVGIP* for later years
    set_ISSN("j-CHANCE",				"0933-2480 (print), 1867-2280 (electronic)")
    set_ISSN("j-CHAOS",					"1054-1500")
    set_ISSN("j-CHAOS-SOLITONS-FRACTALS",		"0960-0779 (print), 1873-2887 (electronic)")
    set_ISSN("j-CHEM-BRITAIN",				"0009-3106")
    set_ISSN("j-CHEM-ENG",				"0302-0797")
    set_ISSN("j-CHEM-ENG-COMMUN",			"0098-6445 (print), 1563-5201 (electronic)")
    set_ISSN("j-CHEM-ENG-NEWS",				"0009-2347 (print), 1520-605X (electronic)")
    set_ISSN("j-CHEM-ENG-NEWS-ARCHIVE",			"????")
    set_ISSN("j-CHEM-ENG-PROG",				"0360-7275 (print), 1945-0710 (electronic)")
    set_ISSN("j-CHEM-ENG-SCI",				"0009-2509 (print), 1873-4405 (electronic)")
    set_ISSN("j-CHEM-IND-CHICHESTER-UK",		"0009-3068 (print), 2047-6329 (electronic)")
    set_ISSN("j-CHEM-INTELL",				"0947-0662")
    set_ISSN("j-CHEM-MATER",				"0897-4756 (print), 1520-5002 (electronic)")
    set_ISSN("j-CHEM-NEWS-J-IND-SCI",			"????")
    set_ISSN("j-CHEM-NEWS-J-PHYS-SCI",			"????")
    set_ISSN("j-CHEM-PHARM-BULL",			"0009-2363 (print), 1347-5223 (electronic)")
    set_ISSN("j-CHEM-PHYS",				"0301-0104 (print), 1873-4421 (electronic)")
    set_ISSN("j-CHEM-PHYS-LETT",			"0009-2614 (print), 1873-4448 (electronic)")
    set_ISSN("j-CHEM-REV",				"0009-2665 (print), 1520-6890 (electronic)")
    set_ISSN("j-CHEMINFORM",				"1522-2667")
    set_ISSN("j-CHEMO-INTELL-LAB",			"0169-7439 (print), 1873-3239 (electronic)")
    set_ISSN("j-CHEMOSPHERE",				"0045-6535 (print), 1879-1298 (electronic)")
    set_ISSN("j-CHEMPHYSCHEM",				"1439-4235 (print), 1439-7641 (electronic)")
    set_ISSN("j-CHEMTECH",				"0009-2703")
    set_ISSN("j-CHIC-J-THEOR-COMPUT-SCI",		"1073-0486")
    set_ISSN("j-CHIC-REV",				"0009-3696 (print), 2327-5804 (electronic)")
    set_ISSN("j-CHIFFRES",				"0245-9922")
    set_ISSN("j-CHILTONS-AUTOMOT-IND",			"0273-656X")
    set_ISSN("j-CHIN-J-COMPUTERS",			"0254-4164")
    set_ISSN("j-CHIN-J-LASERS",				"0258-7025")
    set_ISSN("j-CHIN-PHYS-LETT",			"0256-307X (print), 1741-3540 (electronic)")
    set_ISSN("j-CHIRALITY",				"0899-0042 (print), 1520-636X (electronic)")
    set_ISSN("j-CHR-SCI-MON",				"0882-7729 (print), 1540-4617 (electronic)")
    set_ISSN("j-CHRON-HIGHER-ED",			"0009-5982 (print), 1931-1362 (electronic)")
    set_ISSN("j-CHYMIA",				"0095-9367")
    set_ISSN("j-CIBA-FOUND-SYMP",                       "0300-5208")
    set_ISSN("j-CIEL-TERRE",				"0009-6709")
    set_ISSN("j-CIENC-INVEST",				"0009-6733 (print), 2314-3134 (electronic)")
    set_ISSN("j-CIRC-ARRHYTHM-ELECTROPHYSIOL",		"1941-3084 (print), 1941-3149 (electronic)")
    set_ISSN("j-CIRC-RES",				"0009-7330 (print), 1524-4571 (electronic)")
    set_ISSN("j-CIRCULATION",				"0009-7322 (print), 1524-4539 (electronic)")
    set_ISSN("j-CISCO-WORLD",				"1081-3187")
    set_ISSN("j-CIVILIZ",				"1077-9795")
    set_ISSN("j-CLASS-COMP-LEARN",			"0746-4223")
    set_ISSN("j-CLASS-QUANTUM-GRAV",			"0264-9381 (print), 1361-6382 (electronic)")
    set_ISSN("j-CLIENT-SERVER-ECONOMICS-LETT",          "1074-3138")
    set_ISSN("j-CLIN-EXP-IMMUNOL",			"0009-9104 (print), 1365-2249 (electronic)")
    set_ISSN("j-CLIN-HAEMATOL",				"0308-2261 (print), 1878-7495 (electronic)")
    set_ISSN("j-CLIN-LAB-HAEMOTOLOGY",			"0141-9854 (print), 1365-2257 (electronic)")
    set_ISSN("j-CLIN-PHARMACOL-THER",			"0009-9236")
    set_ISSN("j-CLIN-PLAST-SURG",			"0094-1298 (print), 1558-0504 (electronic)")
    set_ISSN("j-CLIN-SCI",				"0143-5221, 0323-5084, 0009-9287")
    set_ISSN("j-CLNET",					"????")
    set_ISSN("j-CMCM",					"1076-027X")
    set_ISSN("j-CMG-PROC",				"????")
    set_ISSN("j-CMS-NOTES",				"0045-5164")
    set_ISSN("j-COAL-NEWSLETTER",			"????")	# 0376-7787 = C.C.A.I. (Coal Consumers Association of India) Monthly Newsletter
    set_ISSN("j-COASTAL-ZONE",				"????")
    set_ISSN("j-COED",					"0736-8607")
    set_ISSN("j-COGN-SCI",				"0364-0213 (print), 1551-6709 (electronic)")
    set_ISSN("j-COGNITION",				"0010-0277 (print), 1873-7838 (electronic)")
    set_ISSN("j-COLD-SPRING-HARBOR-SYMP-QUANT-BIOL",	"0091-7451 (print), 1943-4456 (electronic)")
    set_ISSN("j-COLL-ALGOR-ACM",			"0149-1989")
    set_ISSN("j-COLL-ENGL",				"0010-0994 (print), 2161-8178 (electronic)")
    set_ISSN("j-COLL-MICRO",				"0731-4213")
    set_ISSN("j-COLL-OCEAN-WORKS",			"0253-245X")
    set_ISSN("j-COLL-RESEARCH-LIB",			"0010-0870 (print), 2150-6701 (electronic)")
    set_ISSN("j-COLL-RESEARCH-LIB-NEWS",		"0099-0086 (print), 2150-6698 (electronic)")
    set_ISSN("j-COLLECT-CZECH-CHEM-COMMUN",		"0010-0765 (print), 1212-6950 (electronic)")
    set_ISSN("j-COLLEGE-MATH-J",			"0746-8342 (print), 1931-1346 (electronic)")
    set_ISSN("j-COLLNET-J-SCIENTOMETRICS-INF-MANAGE",	"0973-7766 (print), 2168-930X (electronic)")
    set_ISSN("j-COLLOQ-GER",				"0010-1338")
    set_ISSN("j-COLLOQ-MATH",				"0010-1354 (print), 1730-6302 (electronic)")
    set_ISSN("j-COLLOQ-MATH-BOLYAI",			"0139-3383")
    set_ISSN("j-COLO-LAWYER",				"0363-7867")
    set_ISSN("j-COLO-LIBR",				"0147-9733 (print), 2159-2861 (electronic)")
    set_ISSN("j-COLUMBIA-LAW-REV",			"0010-1958 (print), 1945-2268 (electronic)")
    set_ISSN("j-COMBINATORICA",				"0209-9683 (print), 1439-6912 (electronic)")
    set_ISSN("j-COMM-APPL-ANAL",			"1083-2564")
    set_ISSN("j-COMM-APPL-NUM-METH",			"0748-8025 (print), 1555-2047 (electronic)")
    set_ISSN("j-COMM-NONLIN-SCI-NUM-SIM",		"1007-5704 (print), 1878-7274 (electronic)")
    set_ISSN("j-COMM-NUMER-METHODS-ENGRG",		"1069-8299 (print), 1099-0887 (electronic)")
    set_ISSN("j-COMM-PARTIAL-DIFF-EQNS",		"0360-5302 (print), 1532-4133 (electronic)")
    set_ISSN("j-COMM-PURE-APPL-MATH",			"0010-3640 (print), 1097-0312 (electronic)")
    set_ISSN("j-COMM-THEOR-PHYS",			"0253-6102 (print), 1572-9494 (electronic)")
    set_ISSN("j-COMMENT-MATH-HELV",			"0010-2571 (print), 1420-8946 (electronic)")
    set_ISSN("j-COMMENT-MATH-UNIV-CAROLINEA",		"0010-2628 (print), 1213-7243 (electronic)")
    set_ISSN("j-COMMENT-PONTIF-ACAD-SCI",		"0554-6648")
    set_ISSN("j-COMMENTS-AT-MOL-PHYS",			"0010-2687")
    set_ISSN("j-COMMENTS-NUCL-PART-PHYS",		"0010-2709")
    set_ISSN("j-COMMENTS-THEOR-BIOL",			"0894-8550 (print), 1543-5210 (electronic)")
    set_ISSN("j-COMMON-CAUSE",				"0271-9592")
    set_ISSN("j-COMMON-CAUSE-MAGAZINE",			"0884-6537")
    set_ISSN("j-COMMUN-ALGEBRA",			"0092-7872 (print), 1532-4125 (electronic)")
    set_ISSN("j-COMMUN-APPL-MATH-COMPUT-SCI",		"1559-3940 (print), 2157-5452 (electronic)")
    set_ISSN("j-COMMUN-BOOKNOTES-Q",			"1094-8007 (print), 1532-6896 (electronic)")
    set_ISSN("j-COMMUN-COMPUT-PHYS",			"1815-2406 (print), 1991-7120 (electronic)")
    set_ISSN("j-COMMUN-CONTEMP-MATH",			"0219-1997 (print), 1793-6683 (electronic)")
    set_ISSN("j-COMMUN-DESIGN-Q-REVIEW",		"2166-1200 (print), 2166-1642 (electronic)")
    set_ISSN("j-COMMUN-INF-SYST",			"1526-7555")
    set_ISSN("j-COMMUN-KOREAN-MATH-SOC",		"1225-1763 (print), 2234-3024 (electronic)")
    set_ISSN("j-COMMUN-MATH-PHYS",			"0010-3616 (print), 1432-0916 (electronic)")
    set_ISSN("j-COMMUN-MATH-SCI",			"1539-6746 (print), 1945-0796 (electronic)")
    set_ISSN("j-COMMUN-MATH-STAT",			"2194-6701 (print), 2194-671X (electronic)")
    set_ISSN("j-COMMUN-NEWS",				"0010-3632")
    set_ISSN("j-COMMUN-Q",				"0146-3373 (print), 1746-4102 (electronic)")
    set_ISSN("j-COMMUN-STAT",				"0090-3272 (print), 2332-3965 (electronic)")
    set_ISSN("j-COMMUN-STAT-SIMUL-COMPUT",		"0361-0918")
    set_ISSN("j-COMMUN-STAT-THEORY-METH",		"0361-0926 (print), 1532-415X (electronic)")
    set_ISSN("j-COMMUNICATION-ARTS",			"0010-3519")
    set_ISSN("j-COMP-APPLIC-BIOSCI",			"0266-7061 (print), 1460-2059 (electronic)")
    set_ISSN("j-COMP-ARCH-NEWS",			"0163-5964 (print), 1943-5851 (electronic)")
    set_ISSN("j-COMP-ART-INTELL",			"0232-0274")
    set_ISSN("j-COMP-AUTO",				"0010-4795, 0887-4549")
    set_ISSN("j-COMP-AUTO-PEOPLE",			"0090-9548")
    set_ISSN("j-COMP-BIOCHEM-PHYSIOL",			"0010-406X (print), 1879-3029 (electronic)")
    set_ISSN("j-COMP-BIOCHEM-PHYSIOL-B",		"0305-0491")
    set_ISSN("j-COMP-CHEM-ENG",				"0098-1354 (print), 1873-4375 (electronic)")
    set_ISSN("j-COMP-CIVIL-ENG",			"0887-3801 (print), 1943-5487 (electronic)")
    set_ISSN("j-COMP-COMM",				"0140-3664 (print), 1873-703X (electronic)")
    set_ISSN("j-COMP-COMM-REV",				"0146-4833 (print), 1943-5819 (electronic)")
    set_ISSN("j-COMP-CONTROL-ENG-J",			"0956-3385 (print), 1741-0460 (electronic)")
    set_ISSN("j-COMP-DESIGN",				"0010-4566")
    set_ISSN("j-COMP-ECONOMICS",			"0927-7099 (print), 1572-9974 (electronic)")
    set_ISSN("j-COMP-ECONOMICS-REP",                    "0739-0874")
    set_ISSN("j-COMP-EDU",				"0360-1315 (print), 1873-782X (electronic)")
    set_ISSN("j-COMP-EDU-J",				"1069-3769")
    set_ISSN("j-COMP-FLUIDS",				"0045-7930 (print), 1879-0747 (electronic)")
    set_ISSN("j-COMP-FRAUD-SECURITY-BULL",		"0142-0496 (print), 1878-3856 (electronic)")
    set_ISSN("j-COMP-GEOLOGY",				"0271-0420")
    set_ISSN("j-COMP-GEOM",				"0925-7721 (print), 1879-081X (electronic)")
    set_ISSN("j-COMP-GEOSCI",				"0098-3004 (print), 1873-7803 (electronic)")
    set_ISSN("j-COMP-GRAPHICS",				"0097-8930 (print), 1558-4569 (electronic)")
    set_ISSN("j-COMP-GRAPHICS-PROC",			"1069-529X")
    set_ISSN("j-COMP-HUM",				"0010-4817 (print), 1572-8412 (electronic)")
    set_ISSN("j-COMP-INDUSTRY",				"0166-3615 (print), 1872-6194 (electronic)")
    set_ISSN("j-COMP-J",				"0010-4620 (print), 1460-2067 (electronic)")
    set_ISSN("j-COMP-LANG-MAG",				"0749-2839")
    set_ISSN("j-COMP-LANGS",				"0096-0551 (print), 1873-6742 (electronic)")
    set_ISSN("j-COMP-LANGS-SYS-STRUCT",			"1477-8424 (print), 1873-6866 (electronic)")
    set_ISSN("j-COMP-LAW-J",				"0164-8756")
    set_ISSN("j-COMP-LAW-SECURITY-REP",			"0267-3649 (print), 1873-6734 (electronic)")
    set_ISSN("j-COMP-LAWYER",				"0742-1192")
    set_ISSN("j-COMP-LIB",				"1041-7915")
    set_ISSN("j-COMP-LING",				"0891-2017 (print), 1530-9312 (electronic)")
    set_ISSN("j-COMP-MATH",				"????")
    set_ISSN("j-COMP-MATH-APP",				"????")

    ## NB: [14-Jun-2011] Do NOT add 0097-4943 for j-COMP-MATH-APPL: it is wrong!
    ## (see Library of Congress MARC record: the y subfield means INCORRECT)
    ## 022 	0_ |a 0898-1221 |l 0898-1221 |y 0097-4943 |2 z
#    set_ISSN("j-COMP-MATH-APPL",			"0898-1221 (print), 1873-7668 (electronic)")

#    set_ISSN("j-COMP-MATH-APPL-A",			"0886-9553")
#    set_ISSN("j-COMP-MATH-APPL-B",			"0886-9561")
    set_ISSN("j-COMP-MATH-SCI-TEACHING",		"0731-9258 (print), 1943-5908 (electronic)")
    set_ISSN("j-COMP-MUSIC-J",				"0148-9267 (print), 1531-5169 (electronic)")
    set_ISSN("j-COMP-NET",				"0376-5075 (print), 1878-3120 (electronic)")
    set_ISSN("j-COMP-NET-ISDN",				"0169-7552 (print), 1879-2324 (electronic)")
    set_ISSN("j-COMP-NET-AMSTERDAM",			"1389-1286 (print), 1872-7069 (electronic)")
    set_ISSN("j-COMP-OP-RES",				"0305-0548 (print), 1873-765X (electronic)")
    set_ISSN("j-COMP-OPTIM-APPL",			"0926-6003 (print), 1573-2894 (electronic)")
    set_ISSN("j-COMP-PERSONNEL",			"0160-2497 (print), 1558-3414 (electronic)")
    set_ISSN("j-COMP-PHYS-COMM",			"0010-4655 (print), 1879-2944 (electronic)")
    # set_ISSN("j-COMP-PHYSICS",				"0894-1866 (print), 1558-4208 (electronic)")
    set_ISSN("j-COMP-PHYSIOL-C",			"0742-8413 (print), 1878-1942 (electronic)")
    set_ISSN("j-COMP-PICTURES",				"0883-5683")
    set_ISSN("j-COMP-RESELLER-NEWS",			"0893-8377")
    set_ISSN("j-COMP-RETAIL-WEEK",			"1066-7598")
    set_ISSN("j-COMP-REV",				"0010-4884, 0149-1202")
    set_ISSN("j-COMP-SCI-INFO",				"0254-7813")
    set_ISSN("j-COMP-SCI-REV",				"1574-0137 (print), 1876-7745 (electronic)")
    set_ISSN("j-COMP-SCI-SCI-COMP",			"????")
    set_ISSN("j-COMP-SPEECH-LANG",			"0885-2308 (print), 1095-8363 (electronic)")
    set_ISSN("j-COMP-SPEECH-PROC",			"????")
    set_ISSN("j-COMP-STANDARDS-INTERFACES",		"0920-5489 (print), 1872-7018 (electronic)")
    set_ISSN("j-COMP-STAT",				"0943-4062 (print), 1613-9658 (electronic)")
    ## DUPLICATE: set_ISSN("j-COMP-STAT-DATA-ANA",			"0167-9473 (print), 1872-7352 (electronic)")
    set_ISSN("j-COMP-STRUCTURES",			"0045-7949 (print), 1879-2243 (electronic)")
    set_ISSN("j-COMP-SURV",				"0360-0300 (print), 1557-7341 (electronic)")
    set_ISSN("j-COMP-SYS",				"0895-6340")
    set_ISSN("j-COMP-SYS-NEWS",				"0164-9981")
    # [03-Feb-1999]: j-COMP-SYS-SCI-ENG replaced by j-COMPUT-SYST-SCI-ENG
    # set_ISSN("j-COMP-SYS-SCI-ENG",			"0267-6192")
    set_ISSN("j-COMP-TECH-REV",				"0278-9647")
    set_ISSN("j-COMP-VIS-IMAGE-UNDERSTANDING",		"1077-3142 (print), 1090-235X (electronic)")
    set_ISSN("j-COMPCON-SPRING89",			"????")
    set_ISSN("j-COMPLEX-SYSTEMS",			"0891-2513")
    set_ISSN("j-COMPLEX-VAR-ELLIPTIC-EQU",		"1747-6933 (print), 1747-6941 (electronic)")
    set_ISSN("j-COMPLEX-VARIABLES-THEORY-APPL",		"0278-1077")
    set_ISSN("j-COMPLEXITY",				"1076-2787 (print), 1099-0526 (electronic)")
    set_ISSN("j-COMPOS-ENG",				"0961-9526 (print), 1878-6359 (electronic)")
    set_ISSN("j-COMPOS-MATH",				"0010-437X (print), 1570-5846 (electronic)")
    set_ISSN("j-COMPOS-SCI-TECH",			"0266-3538 (print), 1879-1050 (electronic)")
    set_ISSN("j-COMPOS-STRUCT",				"0263-8223 (print), 1879-1085 (electronic)")
    set_ISSN("j-COMPUT-ACOUSTICS",			"0218-396X")
    set_ISSN("j-COMPUT-AIDED-CIVIL-INFRASTRUCT-ENG",	"1093-9687 (print), 1467-8667 (electronic)")
    set_ISSN("j-COMPUT-AIDED-DES",			"0010-4485 (print), 1879-2685 (electronic)")
    set_ISSN("j-COMPUT-AIDED-ENG",			"0733-3536 (print), 2162-1365 (electronic)")

    ## NB: j-COMPUT-AND-BIOMED-RES and j-COMPUT-BIOMED-RES are
    ## DIFFERENT, but both published by Academic Press:
    ##     Computers and biomedical research 1967--2000
    ##     Computers in biomedical research  Vol. 1(1965)-Vol. 4 (1974)
    ## The former is succeeded by Journal of Biomedical Informatics.
    set_ISSN("j-COMPUT-AND-BIOMED-RES",			"0010-4809 (print), 1090-2368 (electronic)")

    set_ISSN("j-COMPUT-ANIM-VIRTUAL-WORLDS",		"1546-427X")
    set_ISSN("j-COMPUT-APPL-ENG-EDUC",			"1061-3773 (print), 1099-0542 (electronic)")
    set_ISSN("j-COMPUT-BIOL-MED",			"0010-4825 (print), 1879-0534 (electronic)")

    ## NB: j-COMPUT-AND-BIOMED-RES and j-COMPUT-BIOMED-RES are
    ## DIFFERENT, but both published by Academic Press:
    ##     Computers and biomedical research 1967--2000
    ##     Computers in biomedical research  Vol. 1(1965)-Vol. 4 (1974)
    ## The former is succeeded by Journal of Biomedical Informatics.
    set_ISSN("j-COMPUT-BIOMED-RES",			"0090-1865, 0573-2107")

    set_ISSN("j-COMPUT-BULL",				"0010-4531 (print), 1464-357X (electronic)")
    set_ISSN("j-COMPUT-CARDIOL",			"0276-6574 (print), 1947-7872 (electronic)")
    set_ISSN("j-COMPUT-CHEM",				"0097-8485 (print), 1879-0763 (electronic)")
    set_ISSN("j-COMPUT-CHEM-INSTRUM",			"0146-7115")
    set_ISSN("j-COMPUT-COMPLEX",			"1016-3328 (print), 1420-8954 (electronic)")
    set_ISSN("j-COMPUT-DECIS",				"0010-4558, 0898-1825")
    ## set_ISSN("j-COMPUT-EDGE",				"2376-113X")
    set_ISSN("j-COMPUT-EDGE",				"2469-7087")
    set_ISSN("j-COMPUT-ELECTRON-AGRIC",			"0168-1699 (print), 1872-7107 (electronic)")
    set_ISSN("j-COMPUT-ELECTR-ENG",			"0045-7906 (print), 1879-0755 (electronic)")
    set_ISSN("j-COMPUT-GEOSCI",				"1420-0597 (print), 1573-1499 (electronic)")
    set_ISSN("j-COMPUT-HUM-BEHAV",			"0747-5632 (print), 1873-7692 (electronic)")
    set_ISSN("j-COMPUT-IND-ENG",			"0360-8352 (print), 1879-0550 (electronic)")
    set_ISSN("j-COMPUT-INTELL",				"0824-7935 (print), 1467-8640 (electronic)")
    set_ISSN("j-COMPUT-MATER-SCI",			"0927-0256 (print), 1879-0801 (electronic)")
    ## NB: [14-Jun-2011] Do NOT add 0097-4943 for j-COMPUT-MATH-APPL: it is wrong!
    ## (see Library of Congress MARC record: the y subfield means INCORRECT)
    ## 022 	0_ |a 0898-1221 |l 0898-1221 |y 0097-4943 |2 z
    set_ISSN("j-COMPUT-MATH-APPL",			"0898-1221 (print), 1873-7668 (electronic)")

    set_ISSN("j-COMPUT-MATH-APPL-A",			"0886-9553")
    set_ISSN("j-COMPUT-MATH-APPL-B",			"0886-9561")
    set_ISSN("j-COMPUT-MATH-MATH-PHYS",			"0965-5425 (print), 1555-6662 (electronic)")
    set_ISSN("j-COMPUT-MECH",				"0178-7675 (print), 1432-0924 (electronic)")
    set_ISSN("j-COMPUT-METH-APPL-MATH",			"1609-4840 (print), 1609-9389 (electronic)")
    set_ISSN("j-COMPUT-METH-APPL-MECH-ENG",		"0045-7825 (print), 1879-2138 (electronic)")
    set_ISSN("j-COMPUT-METH-FUNCT-THEORY",		"1617-9447 (print), 2195-3724 (electronic)")
    set_ISSN("j-COMPUT-METH-PROG-BIOMED",		"0169-2607 (print), 1872-7565 (electronic)")
    set_ISSN("j-COMPUT-PHYS",				"0894-1866 (print), 1558-4208 (electronic)")
    set_ISSN("j-COMPUT-PHYS-REP",			"0167-7977 (print), 1878-1004 (electronic)")
    set_ISSN("j-COMPUT-PROGRAMS-BIOMED",		"0010-468X (print), 1878-3139 (electronic)")
    set_ISSN("j-COMPUT-RES-NEWS",			"1069-384X")
    set_ISSN("j-COMPUT-SCH",				"0738-0569 (print), 1528-7033 (electronic)")
    set_ISSN("j-COMPUT-SCI-ECON-MANAG",			"0921-2736")
    set_ISSN("j-COMPUT-SCI-ENG",			"1521-9615 (print), 1558-366X (electronic)")
    set_ISSN("j-COMPUT-SECUR",				"0167-4048 (print), 1872-6208 (electronic)")
    set_ISSN("j-COMPUT-SECUR-J",			"0277-0865")
    set_ISSN("j-COMPUT-SOFTW-BIG-SCI",			"2510-2036 (print), 2510-2044 (electronic)")
    set_ISSN("j-COMPUT-STAND",				"0167-8051 (print), 1878-3090 (electronic)")
    set_ISSN("j-COMPUT-STAT-Q",				"0723-712X")
    set_ISSN("j-COMPUT-STAT-DATA-ANAL",			"0167-9473 (print), 1872-7352 (electronic)")
    set_ISSN("j-COMPUT-SUPPORTED-COOP-WORK",		"0925-9724 (print), 1573-7551 (electronic)")
    set_ISSN("j-COMPUT-SYST-ENG",			"0956-0521 (print), 1873-6211 (electronic)")
    set_ISSN("j-COMPUT-SYST-SCI-ENG",			"0267-6192")
    set_ISSN("j-COMPUT-TEACH",				"0278-9175")
    set_ISSN("j-COMPUT-THEOR-CHEM",			"2210-271X")
    set_ISSN("j-COMPUT-VIS-SCI",			"1432-9360 (print), 1433-0369 (electronic)")
    set_ISSN("j-COMPUTABILITY",				"2211-3568 (print), 2211-3576 (electronic)")
    set_ISSN("j-COMPUTE",				"0194-357X")
    set_ISSN("j-COMPUTER",				"0018-9162 (print), 1558-0814 (electronic)")
    set_ISSN("j-COMPUTER-PROC-CHINESE-ORIENTAL-LANG",	"0715-9048")
    set_ISSN("j-COMPUTER-SHOPPER",			"0886-0556")
    set_ISSN("j-COMPUTERS-AND-GRAPHICS",		"0097-8493 (print), 1873-7684 (electronic)")
    set_ISSN("j-COMPUTERWOCHE",				"0170-5121")
    set_ISSN("j-COMPUTERWORLD",				"0010-4841")
    set_ISSN("j-COMPUTING",				"0010-485X (print), 1436-5057 (electronic)")
    set_ISSN("j-COMPUTING-SUPPLEMENTUM",		"0344-8029")
    set_ISSN("j-COMUN-ESTAD",				"2027-3355 (print), 2339-3076 (electronic)")
    set_ISSN("j-CONCEPTS-NEUROSCI",			"0129-0568")
    set_ISSN("j-CONF-LOCAL-COMPUT-NETW",		"0742-1303")
    set_ISSN("j-CONFIGURATIONS",			"1063-1801 (print), 1080-6520 (electronic)")
    set_ISSN("j-CONG-NUM",				"0384-9864")
    set_ISSN("j-CONGR-Q-WKLY-REP",			"0010-5910")
    set_ISSN("j-CONN-LAW-REVIEW",			"0010-6151 (print), 1930-9813 (electronic)")
    set_ISSN("j-CONSERV-BIOL",				"0888-8892 (print), 1523-1739 (electronic)")
    set_ISSN("j-CONSPECTUS",                            "1351-0908")
    set_ISSN("j-CONST-APPROX",				"0176-4276 (print), 1432-0940 (electronic)")
    set_ISSN("j-CONTACT-CONTEXT",			"1547-8890")
    set_ISSN("j-CONTEMP-BR-HIST",			"1361-9462 (print), 1743-7997 (electronic)")
    set_ISSN("j-CONTEMP-MATH",				"0271-4132 (print), 1098-3627 (electronic)")
    set_ISSN("j-CONTEMP-PHYS",				"0010-7514 (print), 1366-5812 (electronic)")
    set_ISSN("j-CONTEMP-SOCIOL",			"0094-3061 (print), 1939-8638 (electronic)")
    set_ISSN("j-CONTIN-MECH-THERMODYN",			"0935-1175 (print), 1432-0959 (electronic)")
    set_ISSN("j-CONTRACT-DES",				"1053-5632")
    set_ISSN("j-CONTROL-CYBERN",			"0324-8569")
    set_ISSN("j-CONTROL-ENG",				"0010-8049")
    set_ISSN("j-CONTROL-ENG-PRACT",			"0967-0661 (print), 1873-6939 (electronic)")
    set_ISSN("j-CONTROLLED-CLIN-TRIALS",		"0197-2456 (print), 1879-050X (electronic)")
    set_ISSN("j-CORMOSEA-BULL",				"0734-449X")
    set_ISSN("j-CORNELL-ENG",				"0010-8790")
    set_ISSN("j-CORNELL-REV",				"0160-0893")
    set_ISSN("j-CPE",					"1040-3108 (print), 1096-9128 (electronic)")
    set_ISSN("j-CPSR",					"????")
    set_ISSN("j-CQ-RES",				"1056-2036 (print), 1942-5635 (electronic)")
    set_ISSN("j-CRAS",					"????")
    set_ISSN("j-CRAY-CHANNELS",				"????")
    set_ISSN("j-CREAT-COMPUT",				"0097-8140")
    set_ISSN("j-CRC-CRIT-REV-BIOCHEM",			"0045-6411")
    set_ISSN("j-CRC-CRIT-REV-BIOMED-ENG",		"0278-940X (print), 1943-619X (electronic)")
    set_ISSN("j-CRIT-CARE-MED",				"1530-0293 (print), 1530-0293 (electronic)")
    set_ISSN("j-CRIT-REV-MICROBIOL",			"1040-841X (print), 1549-7828 (electronic)")
    set_ISSN("j-CRITICA-MEXICO",			"0011-1503")
    set_ISSN("j-CROAT-CHEM-ACTA",			"0011-1643 (print), 1334-417X (electronic)")
    set_ISSN("j-CROSSROADS",				"1528-4972 (print), 1528-4980 (electronic)")
    set_ISSN("j-CRYPTOBYTES",				"????")
    set_ISSN("j-CRYPTOGR-COMMUN",			"1936-2447 (print), 1936-2455 (electronic)")
    set_ISSN("j-CRYPTOLOGIA",				"0161-1194 (print), 1558-1586 (electronic)")
    set_ISSN("j-CRYST-LATTICE-DEFECTS",			"0011-2305")
    set_ISSN("j-CRYST-RES-TECHNOL",			"0232-1300 (print), 1521-4079 (electronic)")
    set_ISSN("j-CRYSTAL-GROWTH",			"0144-1965")
    set_ISSN("j-CSGD",					"????")
    set_ISSN("j-CSSP",					"0278-081X (print), 1531-5878 (electronic)")
    set_ISSN("j-CT",					"0724-8679")
    set_ISSN("j-CUJ",					"0898-9788")
    set_ISSN("j-CURR-BIOL",				"0960-9822 (print), 1879-0445 (electronic)")
    set_ISSN("j-CURR-CONTENTS-PHYS-CHEM-EARTH-SCI",	"0163-2574")
    set_ISSN("j-CURR-CONTENTS-ENG-TECH-APPL-SCI",	"0095-7917")
    set_ISSN("j-CURR-GEN",				"0172-8083 (print), 1432-0983 (electronic)")
    set_ISSN("j-CURR-MICROBIOL",			"0343-8651 (print), 1432-0991 (electronic)")
    set_ISSN("j-CURR-OPIN-BIOTECH",			"0958-1669 (print), 1879-0429 (electronic)")
    set_ISSN("j-CURR-OPIN-CELL-BIOL",			"0955-0674 (print), 1879-0410 (electronic)")
    set_ISSN("j-CURR-OPIN-GENET-DEV",			"0959-437X (print), 1879-0380 (electronic)")
    set_ISSN("j-CURR-OPIN-HEMATOL",			"1065-6251")
    set_ISSN("j-CURR-OPIN-IMMUNOL",			"0952-7915 (print), 1879-0372 (electronic)")
    set_ISSN("j-CURR-SCI",				"0011-3891")
    set_ISSN("j-CURR-TOP-CELL-REGUL",			"0070-2137")
    set_ISSN("j-CURR-TOP-DEV-BIOL",			"0070-2153 (print), 1557-8933 (electronic)")
    set_ISSN("j-CURR-TOPICS-MEMBRANES-TRANSPORT",	"0070-2161")
    set_ISSN("j-CVGIP",					"0734-189X (print), 1557-895X (electronic)")
    set_ISSN("j-CVGIP-GMIP",				"1049-9652 (print), 1557-7643 (electronic)")
    set_ISSN("j-CVGIP-IU",				"1049-9660 (print), 1557-7635 (electronic)")
    set_ISSN("j-CWI-QUARTERLY",				"0922-5366")
    set_ISSN("j-CYBER",					"0011-4235 (print), 2375-0189 (electronic)")
    set_ISSN("j-CYBERNETICS-SYSTEMS",			"0196-9722 (print), 1087-6553 (electronic)")
    set_ISSN("j-CYTOBIOLOGIE",				"0070-2463")
    set_ISSN("j-CYTOLOGIA",				"0011-4545")
    set_ISSN("j-CYTOMETRY",				"0196-4763 (print), 1097-0320 (electronic)")
    set_ISSN("j-CZECH-J-PHYS",				"0011-4626 (print), 1572-9486 (electronic)")
    set_ISSN("j-CZECH-MATH-J",				"0528-9181")
    set_ISSN("j-D-LIB-MAGAZINE",			"1082-9873")
    set_ISSN("j-DAEDALUS",				"0011-5266 (print), 1548-6192 (electronic)")
    set_ISSN("j-DANCE-TEACHER-NOW",                     "0199-1795")
    set_ISSN("j-DATA-COMMUNICATIONS",			"0363-6399")
    set_ISSN("j-DATA-HANDLING-SCI-TECH",		"0922-3487 (print), 2212-1250 (electronic)")
    set_ISSN("j-DATA-KNOWLEDGE-ENG",			"0169-023X (print), 1872-6933 (electronic)")
    set_ISSN("j-DATA-PROCESS",				"0011-684X (print), 1878-3058 (electronic)")
    set_ISSN("j-DATABASE",				"0162-4105")
    set_ISSN("j-DATABASE-DIRECTORY",			"0740-5200")
    set_ISSN("j-DATABASES-J",                           "????")
    set_ISSN("j-DATAMATION",				"0011-6963")
    set_ISSN("j-DBMS",					"1041-5173")
    set_ISSN("j-DDDU",					"1079-8595")
    set_ISSN("j-DDJ",					"1044-789X")
    set_ISSN("j-DDJ-SOURCEBOOK",			"1077-9019")
    set_ISSN("j-DEC-PROFESSIONAL",			"0744-9216")
    set_ISSN("j-DEC-SUPP-SYS",				"0167-9236 (print), 1873-5797 (electronic)")
    set_ISSN("j-DEC-TECH-J",				"0898-901X")
    set_ISSN("j-DEEP-SEA-RES-PART-2-TOP-STUD-OCEANOGR",	"0967-0645 (print), 1879-0100 (electronic)")
    set_ISSN("j-DELFT-PROG-REP",			"0304-985X")
    set_ISSN("j-DELTA-KAPPA-GAMMA-BULL",		"0011-8044")
    set_ISSN("j-DEMOGRAPHY",				"0070-3370 (print), 1533-7790 (electronic)")
    set_ISSN("j-DEMONSTRATIO-MATHEMATICA",		"0420-1213")
    set_ISSN("j-DESIGN-NEWS",				"0011-9407")
    set_ISSN("j-DESIGNS-CODES-CRYPTOGR",		"0925-1022 (print), 1573-7586 (electronic)")
    set_ISSN("j-DESKTOP-PUB-COMM",			"0957-3178")
    set_ISSN("j-DEUTSCH-MATH-V",			"????")
    set_ISSN("j-DEV-CELL",				"1534-5807 (print), 1878-1551 (electronic)")
    set_ISSN("j-DEV-DYNAMICS",                          "1058-8388 (print), 1097-0177 (electronic)")
    set_ISSN("j-DEVEL",					"0950-1991 (print), 1477-9129 (electronic)")
    set_ISSN("j-DEVEL-BIOL",				"0012-1606 (print), 1095-564X (electronic)")
    set_ISSN("j-DEVEL-BIOL-N-Y",			"????")
    set_ISSN("j-DEVEL-GENETICS",			"0192-253X (print), 1520-6408 (electronic)")
    set_ISSN("j-DEVEL-GROWTH-DIFF",			"0012-1592")
    set_ISSN("j-DEVEL-SUPPL",				"0950-1991", 1)
    set_ISSN("j-DGOV",					"2691-199X (print), 2639-0175 (electronic)")
    set_ISSN("j-DIABETOLOGIA",				"0012-186X (print), 1432-0428 (electronic)")
    set_ISSN("j-DIALECTICA",				"0012-2017 (print), 1746-8361 (electronic)")
    set_ISSN("j-DIALOGUE",				"0012-2173 (print), 1759-0949 (electronic)")
    set_ISSN("j-DIFF-EQ",				"0012-2661 (print), 1608-3083 (electronic)")
    set_ISSN("j-DIFFER-URAVN-MINSK-1965",		"0374-0641")
    set_ISSN("j-DIFFERENTIATION",			"0301-4681 (print), 1432-0436 (electronic)")
    set_ISSN("j-DIGEST-PAPERS-IEEE-SYMP-MASS-STOR-SYS",	"1051-9173")
    set_ISSN("j-DIGITAL-AGE",				"1084-9076")
    set_ISSN("j-DIGITAL-MEDIA",				"1056-7038")
    set_ISSN("j-DIGITAL-NEWS-REVIEW",			"1065-7452")
    set_ISSN("j-DIGITAL-REVIEW",			"0739-4314")
    set_ISSN("j-DIGITAL-SYS-J",				"1067-7224")
    set_ISSN("j-DIGITAL-SYS-REP",                       "1086-9638")
    set_ISSN("j-DIN-SPLOS-SREDY",			"0420-0497")
    set_ISSN("j-DIPL-HIST",				"0145-2096 (print), 1467-7709 (electronic)")
    set_ISSN("j-DISCRETE-APPL-MATH",			"0166-218X (print), 1872-6771 (electronic)")
    set_ISSN("j-DISCRETE-COMPUT-GEOM",			"0179-5376 (print), 1432-0444 (electronic)")
    set_ISSN("j-DISCRETE-CONTIN-DYN-SYST",		"1078-0947 (print), 1553-5231 (electronic)")
    set_ISSN("j-DISCRETE-DYN-NAT-SOC",			"1026-0226 (print), 1607-887X (electronic)")
    set_ISSN("j-DISCRETE-MATH",				"0012-365X (print), 1872-681X (electronic)")
    set_ISSN("j-DISCRETE-MATH-APPL",			"0924-9265 (print), 1569-3929 (electronic)")
    set_ISSN("j-DISCRETE-MATH-THEOR-COMPUT-SCI",	"1365-8050 (print), 1462-7264 (electronic)")
    set_ISSN("j-DISTRIB-COMPUT",			"0178-2770 (print), 1432-0452 (electronic)")
    set_ISSN("j-DISTRIBUTION",				"1066-8489")
    set_ISSN("j-DLT",					"2769-6480 (print), 2769-6472 (electronic)")
    set_ISSN("j-DNA",					"0198-0238")
    set_ISSN("j-DNA-CELL-BIOL",				"1044-5498 (print), 1557-7430 (electronic)")
    set_ISSN("j-DNA-SEQ",				"1042-5179")
    set_ISSN("j-DOC-MATH",				"1431-0643")
    set_ISSN("j-DOCUMENTALISTE-SCI-INFO",		"0012-4508 (print), 1777-5868 (electronic)")
    set_ISSN("j-DOKL-AKAD-NAUK",			"0002-3264", 1)
    set_ISSN("j-DOKL-MATH",				"1064-5624 (print), 1531-8362 (electronic)")
    set_ISSN("j-DOOPS",					"0167-0441")
    set_ISSN("j-DRUG-DISCOVERY-TODAY",			"1359-6446 (print), 1878-5832 (electronic)")
    set_ISSN("j-DTRAP",					"2692-1626 (print), 2576-5337 (electronic)")
    set_ISSN("j-DUKE-MATH-J",				"0012-7094 (print), 1547-7398 (electronic)")
    set_ISSN("j-DYN-CONTIN-DISCR-IMPULS-B",		"1492-8760")
    set_ISSN("j-DYNAMICS-CONTROL",			"")
    set_ISSN("j-EARTH-SURF-PROCESSES",			"0360-1269 (print), 1931-8065 (electronic)")
    set_ISSN("j-EARTH-SURF-PROCESSES-LANDFORMS",	"0197-9337 (print), 1096-9837 (electronic)")
    set_ISSN("j-EARTHQUAKE-ENG-STRUCT-DYN",		"0098-8847 (print), 1096-9845 (electronic)")
    set_ISSN("j-ECOL-MODELL",				"0304-3800 (print), 1872-7026 (electronic)")
    set_ISSN("j-ECOL-MONOGR",				"0012-9615 (print), 1557-7015 (electronic)")
    set_ISSN("j-ECOLOGY",				"0012-9658 (print), 1939-9170 (electronic)")
    set_ISSN("j-ECON-GEOL",				"0361-0128 (print), 1554-0774 (electronic)")
    set_ISSN("j-ECON-QUAL-CONTROL",			"0940-5151 (print), 1869-6147 (electronic)")
    set_ISSN("j-ECONOM-J",				"1368-4221 (print), 1368-423X (electronic)")
    set_ISSN("j-ECONOM-LETT",				"0165-1765 (print), 1873-7374 (electronic)")
    set_ISSN("j-ECONOM-STAT",				"2452-3062")
    set_ISSN("j-ECONOMIST",				"0013-0613 (print), 1476-8860 (electronic)")
    set_ISSN("j-ECONOMETRICA",				"0012-9682")
    set_ISSN("j-ED-PUBL",				"0013-094X (print), 1943-7234 (electronic)")
    set_ISSN("j-EDN",					"0012-7515, 0364-6637")
    set_ISSN("j-EDPACS",                                "0736-6981 (print), 1936-1009 (electronic)")
    set_ISSN("j-EDU-CHEM",				"0013-1350 (print), 1749-5326 (electronic)")
    set_ISSN("j-EDU-PSYCH-MEASUREMENT",			"0013-1644 (print), 1552-3888 (electronic)")
    set_ISSN("j-EDU-TRAINING-TECH",			"0954-7304")
    set_ISSN("j-EDUC-STUD-MATH",			"0013-1954 (print), 1573-0816 (electronic)")
    set_ISSN("j-EDUCOM-REV",				"1045-9146")
    set_ISSN("j-ELECT-COMM-ENG-J",			"0954-0695")
    set_ISSN("j-ELECT-COMM-JAPAN-3-FUND-ELECT-SCI",	"1042-0967 (print), 1520-6440 (electronic)")
    set_ISSN("j-ELECT-COMPOSITION-IMAGING",		"0838-9535")
    set_ISSN("j-ELECT-J-COMB",				"1077-8926 (print), 1097-1440 (electronic)")
    set_ISSN("j-ELECT-LETTERS",				"0013-5194 (print), 1350-911X (electronic)")
    set_ISSN("j-ELECT-NOTES-THEOR-COMP-SCI",		"1571-0661")
    set_ISSN("j-ELECT-STUDIES",				"0261-3794 (print), 1873-6890 (electronic)")
    set_ISSN("j-ELECTR-COMMUN",				"0013-4252")
    set_ISSN("j-ELECTR-ENG",				"0095-9197")
    set_ISSN("j-ELECTR-REV",				"0013-4384")
    set_ISSN("j-ELECTRICIAN",				"0367-0805")
    set_ISSN("j-ELECTRO",				"")
    set_ISSN("j-ELECTROMAGNETICS",			"0272-6343 (print), 1532-527X (electronic)")
    set_ISSN("j-ELECTRON-COMMUN-JPN",			"0424-8368")
    set_ISSN("j-ELECTRON-COMMUN-JPN-PART-1-COMMUN",	"1520-6424 (print), 8756-6621 (electronic)")
    set_ISSN("j-ELECTRON-COMMUN-PROBAB",		"1083-589X")
    set_ISSN("j-ELECTRON-ENG",				"0013-4902")
    set_ISSN("j-ELECTRON-J-BOUND-ELEM",			"1542-3891")
    set_ISSN("j-ELECTRON-J-LINEAR-ALGEBRA",		"1081-3810 (print), 1537-9582 (electronic)")
    set_ISSN("j-ELECTRON-J-PROBAB",			"1083-6489")
    set_ISSN("j-ELECTRON-J-THEOR-PHYS",			"1729-5254")
    set_ISSN("j-ELECTRON-MICROSC-REV",			"0892-0354 (print), 1878-1136 (electronic)")
    set_ISSN("j-ELECTRON-POWER",			"0013-5127 (print), 2053-7883 (electronic)")
    set_ISSN("j-ELECTRON-TRANS-NUMER-ANAL",		"1068-9613 (print), 1097-4067 (electronic)")
    set_ISSN("j-ELECTRONIC-DESIGN",			"0013-4872 (print), 1944-9550 (electronic)")
    set_ISSN("j-ELECTRONIC-ENG-TIMES",			"0192-1541")
    set_ISSN("j-ELECTRONIC-LEARNING",			"0278-3258")
    set_ISSN("j-ELECTRONIC-LIBRARY",			"0264-0473 (print), 1758-616X (electronic)")
    set_ISSN("j-ELECTRONIC-MUSICIAN",			"0884-4720 (print), 2161-9867 (electronic)")
    set_ISSN("j-ELECTRONIC-PRODUCTS",			"0013-4953")
    set_ISSN("j-ELECTRONICS",				"0883-4989")
    set_ISSN("j-ELECTRONICS-WORLD-WIRELESS-WORLD",	"0959-8332, 0266-3244")
    set_ISSN("j-ELECTRONIK",				"0013-5658")
    set_ISSN("j-ELECTROPHORESIS",			"0173-0835 (print), 1522-2683 (electronic)")
    set_ISSN("j-ELEK-INFO-KYBER",			"0013-5712")
    set_ISSN("j-ELEK-RECHENANLAGEN",			"0013-5720")
    set_ISSN("j-ELEKTRONIKER",				"0531-9218")
    set_ISSN("j-ELEM-MATH",				"0013-6018 (print), 1420-8962 (electronic)")
    set_ISSN("j-ELEMENTA-TMFK",				"0013-5933")
    set_ISSN("j-ELET-IRODALOM",				"0424-8848 (print), 1588-0362 (electronic)")
    set_ISSN("j-ELET-TUDOMANY",				"????")
    set_ISSN("j-ELETTRONICA-OGGI",                      "0391-6391")
    set_ISSN("j-ELETTROTECNICA",			"0013-6131")
    set_ISSN("j-EMBED-SYS-PROG",			"1040-3272")
    set_ISSN("j-EMBEDDED-LINUX-J",			"1534-083X")
    set_ISSN("j-EMBO-J",				"0261-4189 (print), 1460-2075 (electronic)")
    set_ISSN("j-EMORY-LAW",				"0094-4076")
    set_ISSN("j-EMPIR-SOFTWARE-ENG",			"1382-3256 (print), 1573-7616 (electronic)")
    set_ISSN("j-EMPIRICA",				"0340-8744 (print), 1573-6911 (electronic)")
    set_ISSN("j-ENCYCL-LIB-INFO-SCI",			"????")
    # set_ISSN("j-ENDEAVOUR",				"0141-3058, 0013-7162, 0160-9327")
    set_ISSN("j-ENDEAVOUR",				"0160-9327 (print), 1873-1929 (electronic)")
    set_ISSN("j-ENDOCRINE",				"0969-711X")
    set_ISSN("j-ENDOCRINOL",				"0013-7227 (print), 1945-7170 (electronic)")
    set_ISSN("j-ENERGY-RES",				"0167-692X")
    set_ISSN("j-ENERGY-TECHNOL-REV",			"0884-5050")
    set_ISSN("j-ENEWS",					"0013-4937, 1061-6624")
    set_ISSN("j-ENG-ANAL-BOUND-ELEM",			"0955-7997 (print), 1873-197X (electronic)")
    set_ISSN("j-ENG-AUTOMATION",			"0931-6221")
    set_ISSN("j-ENG-COMP",				"0264-4401 (print), 1758-7077 (electronic)")
    set_ISSN("j-ENG-COMPUT",				"0177-0667 (print), 1435-5663 (electronic)")
    set_ISSN("j-ENG-CORNELL-Q",				"0013-7871")
    set_ISSN("j-ENG-DESIGN-GRAPHICS-J",			"0046-2012 (print), 1949-9167 (electronic)")
    set_ISSN("j-ENG-FRACTURE-MECH",			"0013-7944 (print), 1873-7315 (electronic)")
    set_ISSN("j-ENG-MAT",				"????")
    set_ISSN("j-ENG-SCI",				"0013-7812")
    set_ISSN("j-ENG-SCI-REP-KYUSHU",			"0388-1717")
    set_ISSN("j-ENG-TRANS",				"0035-9408")
    set_ISSN("j-ENGINEER",				"0013-7758")
    set_ISSN("j-ENGLISH-LANGUAGE-TEACHING",		"0013-8290")
    set_ISSN("j-ENSEIGN-MATH",				"0013-8584 (print), 2309-4672 (electronic)")
    set_ISSN("j-ENSEIGN-MATH-2",			"0013-8584 (print), 2309-4672 (electronic)")
    set_ISSN("j-ENTROPY",				"1099-4300")
    set_ISSN("j-ENV-POLLUTION",				"0269-7491 (print), 1873-6424 (electronic)")
    set_ISSN("j-ENV-POLLUTION-A",			"0143-1471 (print), 1878-0709 (electronic)")
    set_ISSN("j-ENV-SCI-TECH",				"0013-936X (print), 1520-5851 (electronic)")
    set_ISSN("j-ENVIRON-HIST",				"1084-5453 (print), 1930-8892 (electronic)")
    set_ISSN("j-ENVIRON-MONIT-ASSESS",			"0167-6369 (print), 1573-2959 (electronic)")
    set_ISSN("j-EPILEPSIA",				"0013-9580 (print), 1528-1167 (electronic)")
    set_ISSN("j-EPJ-APPL-PHYS",				"1286-0042 (print), 1286-0050 (electronic)")
    set_ISSN("j-EPODD",					"0894-3982")
    set_ISSN("j-ERGEB-EXAKTEN-NATURWISS",		"0367-0325")
    set_ISSN("j-ERGEB-MATH-GRENZGEBIETE",		"0071-1136")
    set_ISSN("j-ERGOD-THEORY-DYN-SYST",			"0143-3857 (print), 1469-4417 (electronic)")
    set_ISSN("j-ERGONOMICS",				"0014-0139 (print), 1366-5847 (electronic)")
    set_ISSN("j-ERKENNTNIS",				"1876-2514")
    set_ISSN("j-ERKENNTNIS-1975",			"0165-0106 (print), 1572-8420 (electronic)")
    set_ISSN("j-ESAIM-PROBAB-STATIST",			"1292-8100 (print), 1262-3318 (electronic)")
    set_ISSN("j-ESSAYS-BIOCHEM",			"0071-1365 (print), 1744-1358 (electronic)")
    set_ISSN("j-ETT",					"1124-318X (print), 1541-8251 (electronic)")
    set_ISSN("j-EUGEN-REV",				"0374-7573")
    set_ISSN("j-EULERIANA",				"2693-9908")
    set_ISSN("j-EUR-J-APPL-MATH",			"0956-7925 (print), 1469-4425 (electronic)")
    set_ISSN("j-EUR-J-BIOCHEM",				"0014-2956")
    set_ISSN("j-EUR-J-CELL-BIOL",			"0171-9335 (print), 1618-1298 (electronic)")
    set_ISSN("j-EUR-J-CLIN-CHEM-CLIN-BIOCHEM",		"0939-4974")
    set_ISSN("j-EUR-J-COMB",				"0195-6698 (print), 1095-9971 (electronic)")
    set_ISSN("j-EUR-J-INORG-CHEM",			"1099-0682 (print), 1434-1948 (electronic)")
    set_ISSN("j-EUR-J-MECH-A-SOLIDS",			"0997-7538 (print), 1873-7285 (electronic)")
    set_ISSN("j-EUR-J-OPER-RES",			"0377-2217 (print), 1872-6860 (electronic)")
    set_ISSN("j-EUR-J-PHYS",				"0143-0807 (print), 1361-6404 (electronic)")
    set_ISSN("j-EUR-J-PROTIST",				"0932-4739 (print), 1618-0429 (electronic)")
    set_ISSN("j-EUR-MATH-SOC-NEWSL",			"1027-488X")
    set_ISSN("j-EUR-PHYS-J-A",				"1434-6001 (print), 1434-601X (electronic)")
    set_ISSN("j-EUR-PHYS-J-B",				"1434-6028 (print), 1434-6036 (electronic)")
    set_ISSN("j-EUR-PHYS-J-C",				"1434-6044 (print), 1434-6052 (electronic)")
    set_ISSN("j-EUR-PHYS-J-D",				"1434-6060 (print), 1434-6079 (electronic)")
    set_ISSN("j-EUR-PHYS-J-E",				"1292-8941 (print), 1292-895X (electronic)")
    set_ISSN("j-EUR-PHYS-J-H",				"2102-6459 (print), 2102-6467 (electronic)")
    set_ISSN("j-EUR-PHYS-J-PLUS",			"2190-5444")
    set_ISSN("j-EUR-PHYS-J-SPEC-TOP",			"1951-6355 (print), 1951-6401 (electronic)")
    set_ISSN("j-EUR-PSYCH",				"0924-9338 (print), 1778-3585 (electronic)")
    set_ISSN("j-EUR-REV-HIST",				"1350-7486 (print), 1469-8293 (electronic)")
    set_ISSN("j-EUR-SCI-EDIT",				"0950-1835")
    set_ISSN("j-EUR-TRANS-TELECOMMUN-RELAT-TECHNOL",	"1120-3862")
    set_ISSN("j-EURASIP-J-ADV-SIGNAL-PROCESS",		"1687-6172 (print), 1687-6180 (electronic)")
    set_ISSN("j-EURASIP-J-EMBED-SYS",			"1687-3955 (print), 1687-3963 (electronic)")
    set_ISSN("j-EUROMATH-BULL",				"????")
    set_ISSN("j-EUROPEN-NEWSLETTER",			"1011-4211")
    set_ISSN("j-EUROPHYS-LETT",				"0295-5075 (print), 1286-4854 (electronic)")
    set_ISSN("j-EUROPHYS-NEWS",				"0531-7479 (print), 1432-1092 (electronic)")
    set_ISSN("j-EUUG-NEWSLETTER",			"1011-4211", 1)
    set_ISSN("j-EVOLUTION",				"0014-3820 (print), 1558-5646 (electronic)")
    set_ISSN("j-EVOL-COMPUT",				"1063-6560 (print), 1530-9304 (electronic)")
    set_ISSN("j-EVOL-ECOL",				"0269-7653 (print), 1573-8477 (electronic)")
    set_ISSN("j-EVOL-INTEL",				"1864-5909 (print), 1864-5917 (electronic)")
    set_ISSN("j-EW-J-NUM-MATH",				"0928-0200")
    set_ISSN("j-EXE",					"0268-6872")
    set_ISSN("j-EXEC-EDUC",				"0161-9500")
    set_ISSN("j-EXP-CELL-RES",				"0014-4827 (print), 1090-2422 (electronic)")
    set_ISSN("j-EXP-HEMATOL",				"0301-472X (print), 1873-2399 (electronic)")
    set_ISSN("j-EXP-HEMATOL-TODAY",			"0251-0170")
    set_ISSN("j-EXP-MATH",				"1058-6458 (print), 1944-950X (electronic)")
    set_ISSN("j-EXP-MYCO",				"0147-5975 (print), 1878-4399 (electronic)")
    set_ISSN("j-EXP-NEUROL",				"0014-4886 (print), 1090-2430 (electronic)")
    set_ISSN("j-EXP-PARASITOL",				"0014-4894 (print), 1090-2449 (electronic)")
    set_ISSN("j-EXPEDITION",				"0014-4738")
    set_ISSN("j-EXPERIENTIA",				"0014-4754")
    set_ISSN("j-EXPERIENTIA-SUPPL",			"0071-335X")
    set_ISSN("j-EXPERT-SYST-APPL",			"0957-4174 (print), 1873-6793 (electronic)")
    set_ISSN("j-EXPO-MATH",				"0723-0869 (print), 1878-0792 (electronic)")
    set_ISSN("j-EXS",					"0071-335X", 1)
    set_ISSN("j-EYE",					"0950-222X (print), 1476-5454 (electronic)")
    set_ISSN("j-FACTA-PHILOS",				"1424-0602 (print), 2296-4231 (electronic)")
    set_ISSN("j-FAR-EAST-J-APPL-MATH",			"0972-0960")
    set_ISSN("j-FAR-EAST-J-THEOR-STAT",			"0972-0863")
    set_ISSN("j-FASEB-J",				"0892-6638 (print), 1530-6860 (electronic)")
    set_ISSN("j-FEBS",					"????")
    set_ISSN("j-FEBS-LETT",				"0014-5793 (print), 1873-3468 (electronic)")
    set_ISSN("j-FED",					"0888-8116")
    set_ISSN("j-FED-COMPUTER-WEEK",			"0893-052X")
    set_ISSN("j-FED-PROC",				"0014-9446")
    set_ISSN("j-FED-REGIST",				"0097-6326")
    set_ISSN("j-FEMS-MICROBIOL-LETT",			"0378-1097 (print), 1574-6968 (electronic)")
    set_ISSN("j-FEMS-MICROBIOL-REV",			"0168-6445 (print), 1574-6976 (electronic)")
    set_ISSN("j-FERROELECTRICS",			"0015-0193 (print), 1563-5112 (electronic)")
    set_ISSN("j-FIB-QUART",				"0015-0517")
    set_ISSN("j-FINANC-ANAL-J",				"0015-198X (print), 1938-3312 (electronic)")
    set_ISSN("j-FINANC-TECH-INT-BULL",			"0265-1661")
    set_ISSN("j-FINITE-ELEMENTS-ANAL-DESIGN",		"0168-874X (print), 1872-6925 (electronic)")
    set_ISSN("j-FINITE-FIELDS-APPL",			"1071-5797 (print), 1090-2465 (electronic)")
    set_ISSN("j-FIRST-MONDAY",                          "1396-0466")
    set_ISSN("j-FISH-AQUACULT-J",			"2150-3508")
    set_ISSN("j-FISH-BULL",				"0090-0656 (print), 1937-4518 (electronic)")
    set_ISSN("j-FISH-FISH",				"1467-2960 (print), 1467-2979 (electronic)")
    set_ISSN("j-FISH-OCEANOGR",				"1054-6006 (print), 1365-2419 (electronic)")
    set_ISSN("j-FISH-PHYSIOL-BIOCHEM",			"0920-1742 (print), 1573-5168 (electronic)")
    set_ISSN("j-FISH-RES",				"0165-7836 (print), 1872-6763 (electronic)")
    set_ISSN("j-FISHERIES",				"0363-2415 (print), 1548-8446 (electronic)")
    set_ISSN("j-FISHES",				"2410-3888")
    set_ISSN("j-FIZ-SZ",				"0015-3257 (print), 1588-0540 (electronic)")
    set_ISSN("j-FIZMAT-SPIS-BULGAR-AKAD-NAUK",		"0015-3265")
    set_ISSN("j-FJCC",					"????")
    set_ISSN("j-FLEX-TECH-J",				"0734-6980")
    set_ISSN("j-FLUCT-NOISE-LETT",			"0219-4775 (print), 1793-6780 (electronic)")
    set_ISSN("j-FOLIA-HAEMATOL",			"0323-4347")
    set_ISSN("j-FOLIO",					"0046-4333")
    set_ISSN("j-FORBES",				"0015-6914")
    set_ISSN("j-FOREFRONTS",				"0889-4833")
    set_ISSN("j-FOREIGN-AFFAIRS",			"0015-7120")
    set_ISSN("j-FORMA",					"0911-6036")
    set_ISSN("j-FORM-ASP-COMPUT",			"0934-5043 (print), 1433-299X (electronic)")
    set_ISSN("j-FORM-METHODS-SYST-DES",			"0925-9856 (print), 1572-8102 (electronic)")
    set_ISSN("j-FORSCH-FORTSCHR",			"0367-2794")
    set_ISSN("j-FORSKNINGSNYTT",			"0015-7929")
    set_ISSN("j-FORTEC-FORUM",				"0735-3731")
    set_ISSN("j-FORTH-DIMENSIONS",			"0884-0822")
    set_ISSN("j-FORTRAN-FORUM",				"1061-7264 (print), 1931-1311 (electronic)")
    set_ISSN("j-FORTRAN-J",				"1060-0221")
    set_ISSN("j-FORTSCHR-PHYS",				"0015-8208 (print), 1521-3978 (electronic)")
    set_ISSN("j-FORTUNE",				"0015-8259")
    set_ISSN("j-FORUM-MATH",				"0933-7741 (print), 1435-5337 (electronic)")
    set_ISSN("j-FOUND-CHEM",				"1386-4238 (print), 1572-8463 (electronic)")
    set_ISSN("j-FOUND-COMPUT-MATH",			"1615-3375 (print), 1615-3383 (electronic)")
    set_ISSN("j-FOUND-PHYS",				"0015-9018 (print), 1572-9516 (electronic)")
    set_ISSN("j-FOUND-PHYS-LETT",			"0894-9875 (print), 1572-9524 (electronic)")
    set_ISSN("j-FOUND-SCI",				"1233-1821 (print), 1572-8471 (electronic)")
    set_ISSN("j-FOURIER-ANAL-APPL",			"1069-5869 (print), 1531-5851 (electronic)")
    set_ISSN("j-FRACTALS",				"0218-348X")
    set_ISSN("j-FREE-INQUIRY",				"0272-0701")
    set_ISSN("j-FRONTIERS-EDU-CONF",			"0190-5848")
    set_ISSN("j-FRONTIERS-MAR-SCI",			"2296-7745")
    set_ISSN("j-FRONTIERS-MASS-PAR-COMP-CONF-PROC",	"????")
    set_ISSN("j-FSTTCS",				"????")
    set_ISSN("j-FUJITSU",				"0016-2515")
    set_ISSN("j-FUJITSU-SCI-TECH-J",			"0016-2523")
    set_ISSN("j-FUNCT-ANAL-APPL",			"0016-2663 (print), 1573-8485 (electronic)")
    set_ISSN("j-FUNCT-ECOL",				"0269-8463 (print), 1365-2435 (electronic)")
    set_ISSN("j-FUNCT-SPACES",				"2314-8888 (print), 2314-8896 (electronic)")
    set_ISSN("j-FUND-INFO",				"0169-2968 (print), 1875-8681 (electronic)")
    set_ISSN("j-FUND-SCI",				"0160-7847")
    set_ISSN("j-FUNDAM-MATH",				"0016-2736 (print), 1730-6329 (electronic)")
    set_ISSN("j-FUNKCIAL-EKVAC",			"0532-8721")
    set_ISSN("j-FUNKT-BIOL-MED",			"0722-3684")
    set_ISSN("j-FUSION-SCI-TECHNOL",			"1536-1055 (print), 1943-7641 (electronic)")
    set_ISSN("j-FUSION-TECHNOL",			"0748-1896")
    set_ISSN("j-FUT-GEN-COMP-SYS",			"0167-739X (print), 1872-7115 (electronic)")
    set_ISSN("j-FUTURE-INTERNET",			"1999-5903")
    set_ISSN("j-FUTURES",				"0016-3287 (print), 1873-6378 (electronic)")
    set_ISSN("j-FUZZY-SETS-SYSTEMS",			"0165-0114 (print), 1872-6801 (electronic)")
    set_ISSN("j-G-FIS",					"0017-0283 (print), 1827-6156 (electronic)")
    set_ISSN("j-GAKUJUTSU-GEPPO",			"0387-2440")
    set_ISSN("j-GAMES",					"2073-4336")
    set_ISSN("j-GAMM-MIT",				"0936-7195")
    set_ISSN("j-GAZ-MATH",				"0224-8999")
    set_ISSN("j-GEN",					"0016-6731 (print), 1943-2631 (electronic)")
    set_ISSN("j-GEN-RELATIVITY-GRAV",			"0001-7701 (print), 1572-9532 (electronic)")
    set_ISSN("j-GENE",					"0378-1119 (print), 1879-0038 (electronic)")
    set_ISSN("j-GENERAL-SUBJ",				"0304-4165 (print), 1872-8006 (electronic)")
    set_ISSN("j-GENES-DEVEL",				"0890-9369 (print), 1549-5477 (electronic)")
    set_ISSN("j-GENIE-LOGICIEL-SYS-EXPERTS",		"0295-6322, 1166-4738")	# ??? check both
    set_ISSN("j-GENOME-BIOL",				"1465-6914 (print), 1465-6914 (electronic)")
    set_ISSN("j-GENOME-RES",				"1088-9051 (print), 1549-5469 (electronic)")
    set_ISSN("j-GENOMICS",				"0888-7543 (print), 1089-8646 (electronic)")
    set_ISSN("j-GENUS",					"0016-6987 (print), 2035-5556 (electronic)")
    set_ISSN("j-GEOBYTE",				"0885-6362")
    set_ISSN("j-GEODERMA",				"0016-7061 (print), 1872-6259 (electronic)")
    set_ISSN("j-GEOGR-J",				"0016-7398 (print), 1475-4959 (electronic)")
    set_ISSN("j-GEOPHYS-J-INT",				"0956-540X (print), 1365-246X (electronic)")
    set_ISSN("j-GEOPHYS-J-R-ASTRON-SOC",		"0956-540X (print), 1365-246X (electronic)")
    set_ISSN("j-GEOPHYS-MONOGR",			"0065-8448")
    set_ISSN("j-GEOPHYS-RES-LETT",			"0094-8276 (print), 1944-8007 (electronic)")
    set_ISSN("j-GEOPHYSICS",				"0016-8033 (print), 1942-2156 (electronic)")
    set_ISSN("j-GEOSCI-MODEL-DEV",			"1991-959X (print), 1991-9603 (electronic)")
    set_ISSN("j-GER-ECON-REV",				"1465-6485 (print), 1468-0475 (electronic)")
    set_ISSN("j-GER-STUD-REV",				"0149-7952 (print), 2164-8646 (electronic)")
    set_ISSN("j-GERMAN-RES-REP-DFG",			"0172-1526 (print), 1619-8174 (electronic)")
    set_ISSN("j-GLASG-MATH-J",				"0017-0895 (print), 1469-509X (electronic)")
    set_ISSN("j-GLIA",                                  "0894-1491 (print), 1098-1136 (electronic)")
    set_ISSN("j-GLOB-ECOL-BIOGEOGRAPHY",		"1466-822X (print), 1466-8238 (electronic)")
    set_ISSN("j-GLOB-FINANCE-J",			"1044-0283 (print), 1873-5665 (electronic)")
    set_ISSN("j-GLYCOBIOLOGY",				"0959-6658 (print), 1460-2423 (electronic)")
    set_ISSN("j-GOV-COMP-NEWS",				"0738-4300")
    set_ISSN("j-GRAPH-MODELS-IMAGE-PROC",		"1077-3169 (print), 1090-2481 (electronic)")
    set_ISSN("j-GRAPH-MODELS",				"1524-0703 (print), 1524-0711 (electronic)")
    set_ISSN("j-GRAPHIC-ARTS-MONTHLY",			"1047-9325 (print), 1558-1411 (electronic)")
    set_ISSN("j-GROUND-WATER",				"0017-467X (print), 1745-6584 (electronic)")
    set_ISSN("j-GROUPS-COMPLEX-CRYPTOL",		"1867-1144 (print), 1869-6104 (electronic)")
    set_ISSN("j-GSA-TODAY",				"1052-5173 (print), 1943-2690 (electronic)")
    set_ISSN("j-GUARDIAN",				"0261-3077 (print), 1756-3224 (electronic)")
    set_ISSN("j-GUTENBERG",				"1140-9304")
    set_ISSN("j-HADRONIC-J",				"0162-5519")
    set_ISSN("j-HAEMATOLOGICA",				"0390-6078 (print), 1592-8721 (electronic)")
    set_ISSN("j-HARPERS-MAG",				"1045-7143")
    set_ISSN("j-HARVARD-BUS-REV",			"0017-8012")
    set_ISSN("j-HARVARD-EDUC-REV",			"0017-8055 (print), 1943-5045 (electronic)")
    set_ISSN("j-HARVARD-INT-REV",			"0739-1854")
    set_ISSN("j-HARVARD-LAW-REV",			"0017-811X (print), 2161-976X (electronic)")
    set_ISSN("j-HARVARD-REV",				"1077-2901")
    set_ISSN("j-HARVEY-LECTURES",			"0073-0874")
    set_ISSN("j-HEALTH-PHYSICS",			"0017-9078 (print), 1538-5159 (electronic)")
    set_ISSN("j-HEBREW-LINGUISTICS",			"0334-3472")
    set_ISSN("j-HELV-CHIM-ACTA",			"0018-019X")
    set_ISSN("j-HELV-PHYS-ACTA",			"0018-0238")
    set_ISSN("j-HEREDITY",				"0018-067X (print), 1365-2540 (electronic)")
    set_ISSN("j-HERMIS",				"1108-7609")
    set_ISSN("j-HEWLETT-PACKARD-J",			"0018-1153")
    set_ISSN("j-HEXAGON",				"0164-6109")
    set_ISSN("j-HEYTHROP-J",				"0018-1196 (print), 1468-2265 (electronic)")
    set_ISSN("j-HIGH-PERFORM-SYST",			"1043-7282")
    set_ISSN("j-HIGH-PRESSURE-RES",			"0895-7959 (print), 1477-2299 (electronic)")
    set_ISSN("j-HIGH-TECH-LETT",			"1002-0470")
    # set_ISSN("j-HIGHER-ORDER-SYMB-COMPUT",		"1388-3690 (print), 2212-0793 (electronic)")
    set_ISSN("j-HIGHER-ORDER-SYMB-COMPUT",		"1388-3690 (print), 1573-0557 (electronic)")
    set_ISSN("j-HIST-GEO-SPACE-SCI",			"2190-5010 (print), 2190-5029 (electronic)")
    set_ISSN("j-HIST-MATH",				"0315-0860 (print), 1090-249X (electronic)")
    set_ISSN("j-HIST-PHILOS-LOGIC",			"0144-5340 (print), 1464-5149 (electronic)")
    set_ISSN("j-HIST-REC-AUSTRAL-SCI",			"0727-3061 (print), 1448-5508 (electronic)")
    set_ISSN("j-HIST-SCI",				"0285-4821")
    set_ISSN("j-HIST-SCI-2",				"0285-4821")
    set_ISSN("j-HIST-SCI-UK",				"0073-2753 (print), 1753-8564 (electronic)")
    set_ISSN("j-HIST-STUD-NAT-SCI",			"1939-1811 (print), 1939-182X (electronic)")
    set_ISSN("j-HIST-STUD-PHYS-BIOL-SCI",		"0890-9997 (print), 1533-8355 (electronic)")
    set_ISSN("j-HIST-STUD-PHYS-SCI",			"0073-2672")
    set_ISSN("j-HIST-TEACH",				"0018-2745 (print), 1945-2292 (electronic)")
    set_ISSN("j-HIST-TECHNOL",				"0734-1512 (print), 1477-2620 (electronic)")
    set_ISSN("j-HISTOCHEMISTRY",			"0301-5564")
    set_ISSN("j-HISTORIAN",				"0018-2370 (print), 1540-6563 (electronic)")
    set_ISSN("j-HOCHFREQUENZTECH-ELEKTROAKUST",		"0018-2958")
    set_ISSN("j-HOKKAIDO-MATH-J",			"0385-4035")
    set_ISSN("j-HOME-OFF-COMPUT",			"0899-7373")
    set_ISSN("j-HONEYWELL-COMP-J",			"0046-7847")
    set_ISSN("j-HOOVER-DIG",				"1088-5161")
    set_ISSN("j-HORM-METAB-RES-SUPPL",			"0170-5903")
    set_ISSN("j-HOUSTON-J-MATH",			"0340-9422")
    set_ISSN("j-HP-CHRONICLE",				"0892-2829")
    set_ISSN("j-HP-PROF",				"0896-145X")
    set_ISSN("j-HUM-BIOL",				"0018-7143 (print), 1534-6617 (electronic)")
    set_ISSN("j-HUM-FACTORS",				"0018-7208 (print), 1547-8181 (electronic)")
    set_ISSN("j-HUM-NEUROBIOL",				"0721-9075")
    set_ISSN("j-HUMAN-HEREDITY",			"0001-5652 (print), 1423-0062 (electronic)")
    set_ISSN("j-HUNG-J-INDUSTRIAL-CHEM",		"0133-0276")
    set_ISSN("j-HYDROBIOLOGIA",				"0018-8158 (print), 1573-5117 (electronic)")
    set_ISSN("j-HYDROCARBON-PROC-INT",			"0018-8190 (print), 1944-6063 (electronic)")
    set_ISSN("j-HYDROCARBON-PROC-US",			"0887-0284")
    set_ISSN("j-HYDROMETALLURGY",			"0304-386X (print), 1879-1158 (electronic)")
    set_ISSN("j-HYPERMEDIA",				"0955-8543")
    set_ISSN("j-I-CHUAN-HSUEH-PAO",			"0379-4172")
    set_ISSN("j-I-S-ANALYZER",				"0896-3231")
    set_ISSN("j-IAEA-BULL",				"0020-6067 (print), 1564-2690 (electronic)")
    set_ISSN("j-IBM-JRD",				"0018-8646 (print), 2151-8556 (electronic)")
    set_ISSN("j-IBM-SYS-J",				"0018-8670")
    set_ISSN("j-IBM-TDB",				"0018-8689")
    set_ISSN("j-ICARUS-IJSSS",				"0019-1035 (print), 1090-2643 (electronic)")
    set_ISSN("j-ICC-BULL",				"0536-1222")
    set_ISSN("j-ICES-J-MAR-SCI",			"1054-3139 (print), 1095-9289 (electronic)")
    set_ISSN("j-IECON-PROC-IND-ELEC-CONF",		"")
    set_ISSN("j-IEE-CONF-PUBL",				"0537-9989")
    set_ISSN("j-IEE-PROC",				"????")
    set_ISSN("j-IEE-PROC-A",				"0143-702X")
    set_ISSN("j-IEE-PROC-B",				"0143-7038")
    set_ISSN("j-IEE-PROC-C",				"0143-7046")
    set_ISSN("j-IEE-PROC-D",				"0143-7054")
    set_ISSN("j-IEE-PROC-E",				"0143-7062")
    set_ISSN("j-IEE-PROC-COMPUT-DIGIT-TECH",		"1350-2387 (print), 1359-7027 (electronic)")
    set_ISSN("j-IEE-PROC-VIS-IMAGE-SIGNAL-PROCESS",	"1350-245X (print), 1359-7108 (electronic)")
    set_ISSN("j-IEE-REV",				"0953-5683 (print), 1741-0495 (electronic)")
    set_ISSN("j-IEEE-ACCESS",				"2169-3536")
    set_ISSN("j-IEEE-ACM-TASLP",			"2329-9290")
    set_ISSN("j-IEEE-ANN-HIST-COMPUT",			"1058-6180 (print), 1934-1547 (electronic)")
    set_ISSN("j-IEEE-ANTENNAS-WIREL-PROPAG-LETT",	"1536-1225 (print), 1548-5757 (electronic)")
    set_ISSN("j-IEEE-APM",				"1045-9243 (print), 1558-4143 (electronic)")
    set_ISSN("j-IEEE-ASIA-PACIFIC-CONF-CIRCUITS-SYS-PROC","????")
    set_ISSN("j-IEEE-ASSP-MAG",				"0740-7467 (print), 1558-1284 (electronic)")
    set_ISSN("j-IEEE-CAP",				"0895-0156 (print), 1558-4151 (electronic)")
    set_ISSN("j-IEEE-CGA",				"0272-1716 (print), 1558-1756 (electronic)")
    set_ISSN("j-IEEE-COMM-MAG",				"0163-6804 (print), 1558-1896 (electronic)")
    set_ISSN("j-IEEE-COMMUN-LET",			"1089-7798 (print), 1558-2558 (electronic)")
    set_ISSN("j-IEEE-COMPUT-ARCHIT-LETT",		"1556-6056 (print), 1556-6064 (electronic)")
    set_ISSN("j-IEEE-COMPUT-SCI-ENG",			"1070-9924 (print), 1558-190X (electronic)")
    set_ISSN("j-IEEE-CONCURR",				"1092-3063 (print), 1558-0849 (electronic)")
#    set_ISSN("j-IEEE-CONTROL-SYST-MAG",			"0272-1708")
    set_ISSN("j-IEEE-CONTROL-SYST-MAG",			"1066-033X (print), 1941-000X (electronic)")
    set_ISSN("j-IEEE-CONF-CONTROL-APPL",		"1085-1992")
    set_ISSN("j-IEEE-DES-TEST-COMPUT",			"0740-7475 (print), 1558-1918 (electronic)")
    set_ISSN("j-IEEE-DISTRIB-SYST-ONLINE",		"1541-4922 (print), 1558-1683 (electronic)")
    set_ISSN("j-IEEE-ENG-MED-BIOL-MAG",			"0739-5175 (print), 1937-4186 (electronic)")
    set_ISSN("j-IEEE-EXPERT",				"0885-9000")
    set_ISSN("j-IEEE-INT-CONF-ALG-ARCH-PAR-PROC",	"????")
    set_ISSN("j-IEEE-INT-PROFL-COMM-CONF",		"????")
    set_ISSN("j-IEEE-INT-SYMP-HIGH-PERF-DIST-COMP-PROC","1082-8907")
    set_ISSN("j-IEEE-INT-SYMP-INF-THEORY",		"0271-4655 (print), 2157-8125 (electronic)")
    set_ISSN("j-IEEE-INTELL-SYST",			"1541-1672 (print), 1941-1294 (electronic)")
    set_ISSN("j-IEEE-INTERNET-COMPUT",			"1089-7801 (print), 1941-0131 (electronic)")
    set_ISSN("j-IEEE-J-QUANT-ELECT",			"0018-9197 (print), 1558-1713 (electronic)")
    set_ISSN("j-IEEE-J-ROBOTICS-AUTOMATION",		"0882-4967")
    set_ISSN("j-IEEE-J-SEL-AREAS-COMMUN",		"0733-8716 (print), 1558-0008 (electronic)")
    set_ISSN("j-IEEE-J-SOLID-STATE-CIRCUITS",		"0018-9200 (print), 1558-173X (electronic)")
    set_ISSN("j-IEEE-LTS",				"1055-6877 (print), 1558-2604 (electronic)")
    set_ISSN("j-IEEE-MICRO",				"0272-1732 (print), 1937-4143 (electronic)")
    set_ISSN("j-IEEE-MICROW-GUIDED-WAVE-LETT",		"1051-8207 (print), 1558-2329 (electronic)")
    set_ISSN("j-IEEE-MICROW-WIREL-COMPON-LETT",		"1531-1309 (print), 1558-1764 (electronic)")
    set_ISSN("j-IEEE-MULTIMEDIA",			"1070-986X (print), 1941-0166 (electronic)")
    set_ISSN("j-IEEE-NETWORK",				"0890-8044 (print), 1558-156X (electronic)")
    set_ISSN("j-IEEE-PACIFIC-RIM-CONF-COMM-COMPUT-SIGNAL-PROC-PROC","????")
    set_ISSN("j-IEEE-PAR-DIST-TECH",			"1063-6552 (print), 1558-1861 (electronic)")
    set_ISSN("j-IEEE-POT",				"0278-6648 (print), 1558-1772 (electronic)")
    set_ISSN("j-IEEE-PHOTONICS-TECHNOL-LETT",		"1041-1135 (print), 1941-0174 (electronic)")
    set_ISSN("j-IEEE-ROBOTICS-AUTOMATION-MAG",		"1070-9932 (print), 1558-223X (electronic)")
    set_ISSN("j-IEEE-SEC-PRIV",				"1540-7993 (print), 1558-4046 (electronic)")
    set_ISSN("j-IEEE-SIGNAL-PROCESS-LETT",		"1070-9908 (print), 1558-2361 (electronic)")
    set_ISSN("j-IEEE-SIGNAL-PROCESS-MAG",		"1053-5888 (print), 1558-0792 (electronic)")
    set_ISSN("j-IEEE-SOFTWARE",				"0740-7459 (print), 1937-4194 (electronic)")
    set_ISSN("j-IEEE-SPECTRUM",				"0018-9235 (print), 1939-9340 (electronic)")
    set_ISSN("j-IEEE-SPEECH-SIGNAL-PROC",		"????")
    set_ISSN("j-IEEE-SYMP-PAR-DIST-PROC-PROC",		"1063-6374")
    set_ISSN("j-IEEE-TECHNOL-SOC-MAG",			"0278-0097 (print), 1937-416X (electronic)")
    set_ISSN("j-IEEE-TRANS-ACOUST-SPEECH",		"0096-3518")
    set_ISSN("j-IEEE-TRANS-AEROSP-ELECTRON-SYST",	"0018-9251 (print), 1557-9603 (electronic)")
    set_ISSN("j-IEEE-TRANS-ANTENNAS-PROPAG",		"0018-926X (print), 1558-2221 (electronic)")
    set_ISSN("j-IEEE-TRANS-APPL-SUPERCOND",		"1051-8223 (print), 1558-2515 (electronic)")
    set_ISSN("j-IEEE-TRANS-AUDIO-ELECTROACOUST",	"0018-9278 (print), 1558-2582 (electronic)")
    set_ISSN("j-IEEE-TRANS-AUTOMAT-CONTR",		"0018-9286 (print), 1558-2523 (electronic)")
    set_ISSN("j-IEEE-TRANS-BIG-DATA",			"2332-7790")
    set_ISSN("j-IEEE-TRANS-BIOMED-ENG",			"0018-9294 (print), 1558-2531 (electronic)")
    set_ISSN("j-IEEE-TRANS-BROADCAST",			"0018-9316 (print), 1557-9611 (electronic)")
    set_ISSN("j-IEEE-TRANS-CAD-ICS",			"0278-0070 (print), 1937-4151 (electronic)")
    set_ISSN("j-IEEE-TRANS-CIRCUIT-THEORY",		"0018-9324")
    set_ISSN("j-IEEE-TRANS-CIRCUITS-SYST",		"0098-4094 (print), 1558-1276 (electronic)")
    set_ISSN("j-IEEE-TRANS-CIRCUITS-SYST-1",		"1549-8328 (print), 1558-0806 (electronic)")
    set_ISSN("j-IEEE-TRANS-CIRCUITS-SYST-2",		"1057-7130 (print), 1558-125X (electronic)")
    set_ISSN("j-IEEE-TRANS-CIRCUITS-SYST-I-FUNDAM-THEORY-APPL", "1057-7122 (print), 1558-1268 (electronic)")
    set_ISSN("j-IEEE-TRANS-CIRCUITS-SYST-II-EXPRESS-BRIEFS", "1549-7747 (print), 1558-3791 (electronic)")
    set_ISSN("j-IEEE-TRANS-CIRCUITS-SYST-VIDEO-TECH",	"1051-8215 (print), 1558-2205 (electronic)")
    set_ISSN("j-IEEE-TRANS-COMM",			"0090-6778 (print), 1558-0857 (electronic)")
    set_ISSN("j-IEEE-TRANS-COMMUN-TECHNOL",		"????")
    set_ISSN("j-IEEE-TRANS-COMPUT",			"0018-9340 (print), 1557-9956 (electronic)")
    set_ISSN("j-IEEE-TRANS-COMPONENTS-HYBRIDS-MANUF-TECHNOL",	"0148-6411 (print), 1558-3082 (electronic)")
    set_ISSN("j-IEEE-TRANS-COMPONENTS-PACK-MANUF-TECHNOL-A",	"1070-9886 (print), 1558-3678 (electronic)")
    set_ISSN("j-IEEE-TRANS-CONSUMER-ELECTRONICS",	"0098-3063 (print), 1558-4127 (electronic)")
    set_ISSN("j-IEEE-TRANS-CONTROL-SYST-TECHNOL",	"1063-6536 (print), 1558-0865 (electronic)")
    set_ISSN("j-IEEE-TRANS-EDUC",			"0018-9359 (print), 1557-9638 (electronic)")
    set_ISSN("j-IEEE-TRANS-ELEC-COMP",			"0367-7508")
    set_ISSN("j-IEEE-TRANS-ELEC-INSUL",			"0018-9367 (print), 1557-962X (electronic)")
    set_ISSN("j-IEEE-TRANS-ELECTROMAGN-COMPAT",		"0018-9375 (print), 1558-187X (electronic)")
    set_ISSN("j-IEEE-TRANS-ELECTRON-DEVICES",		"0018-9383 (print), 1557-9646 (electronic)")
    set_ISSN("j-IEEE-TRANS-EMERG-TOP-COMPUT",		"2168-6750 (print), 2376-4562 (electronic)")
    set_ISSN("j-IEEE-TRANS-ENG-WRIT-SPEECH",		"0018-9405 (print), 2331-3706 (electronic)")
    set_ISSN("j-IEEE-TRANS-FUZZY-SYSTEMS",		"1063-6706 (print), 1941-0034 (electronic)")
    set_ISSN("j-IEEE-TRANS-GEOSCI-REMOTE-SENSING",	"0196-2892 (print), 1558-0644 (electronic)")
    set_ISSN("j-IEEE-TRANS-IMAGE-PROCESS",		"1057-7149 (print), 1941-0042 (electronic)")
    set_ISSN("j-IEEE-TRANS-IND-ELECTRON",		"0278-0046 (print), 1557-9948 (electronic)")
    set_ISSN("j-IEEE-TRANS-INF-FOREN-SEC",		"1556-6013")
    set_ISSN("j-IEEE-TRANS-INF-THEORY",			"0018-9448 (print), 1557-9654 (electronic)")
    set_ISSN("j-IEEE-TRANS-INSTRUM-MEAS",		"0018-9456 (print), 1557-9662 (electronic)")
    set_ISSN("j-IEEE-TRANS-KNOWL-DATA-ENG",		"1041-4347 (print), 1558-2191 (electronic)")
    set_ISSN("j-IEEE-TRANS-MAGNETICS",			"0018-9464 (print), 1941-0069 (electronic)")
    set_ISSN("j-IEEE-TRANS-MED-IMAG",			"0278-0062 (print), 1558-254X (electronic)")
    set_ISSN("j-IEEE-TRANS-MICROWAVE-THEORY-TECH",	"0018-9480 (print), 1557-9670 (electronic)")
    set_ISSN("j-IEEE-TRANS-NETWORKING",			"1063-6692 (print), 1558-2566 (electronic)")
    set_ISSN("j-IEEE-TRANS-NEURAL-NETW",		"1045-9227 (print), 1941-0093 (electronic)")
    set_ISSN("j-IEEE-TRANS-NUCL-SCI",			"0018-9499 (print), 1558-1578 (electronic)")
    set_ISSN("j-IEEE-TRANS-PAR-DIST-SYS",		"1045-9219 (print), 1558-2183 (electronic)")
    set_ISSN("j-IEEE-TRANS-PATT-ANAL-MACH-INTEL",	"0162-8828")
    set_ISSN("j-IEEE-TRANS-POWER-DELIV",		"0885-8977 (print), 1937-4208 (electronic)")
    set_ISSN("j-IEEE-TRANS-POWER-SYSTEMS",		"0885-8950 (print), 1558-0679 (electronic)")
    set_ISSN("j-IEEE-TRANS-PLASMA-SCI",			"0093-3813 (print), 1939-9375 (electronic)")
    set_ISSN("j-IEEE-TRANS-PROF-COMMUN",		"0361-1434 (print), 1558-1500 (electronic)")
    set_ISSN("j-IEEE-TRANS-REHABIL-ENG",		"1063-6528 (print), 1558-0024 (electronic)")
    set_ISSN("j-IEEE-TRANS-RELIAB",			"0018-9529 (print), 1558-1721 (electronic)")
    set_ISSN("j-IEEE-TRANS-ROBOT",			"1552-3098 (print), 1941-0468 (electronic)")
    set_ISSN("j-IEEE-TRANS-ROBOT-AUTOM",		"1042-296X")
    set_ISSN("j-IEEE-TRANS-SIG-PROC",			"1053-587X (print), 1941-0476 (electronic)")
    set_ISSN("j-IEEE-TRANS-SOFTW-ENG",			"0098-5589 (print), 1939-3520 (electronic)")
    set_ISSN("j-IEEE-TRANS-SYST-MAN-CYBERN",		"0018-9472 (print), 2168-2909 (electronic)")
    set_ISSN("j-IEEE-TRANS-VEH-TECHNOL",		"0018-9545 (print), 1939-9359 (electronic)")
    set_ISSN("j-IEEE-TRANS-VIS-COMPUT-GRAPH",		"1077-2626")
    set_ISSN("j-IEEE-TRANS-VLSI-SYST",			"1063-8210 (print), 1557-9999 (electronic)")
    set_ISSN("j-IEEE-TRANS-WIREL-COMMUN",		"1536-1276 (print), 1558-2248 (electronic)")
    set_ISSN("j-IEICE-TCEIS",				"0917-1673")
    set_ISSN("j-IEICE-TRANS-COMMUN",			"0916-8516 (print), 1745-1345 (electronic)")
    set_ISSN("j-IEICE-TRANS-ELECT",			"0916-8524 (print), 1745-1353 (electronic)")
    set_ISSN("j-IEICE-TRANS-FUND-ELECT",		"0916-8508 (print), 1745-1337 (electronic)")
    set_ISSN("j-IETE-TECH-REV",				"0256-4602 (print), 0974-5971 (electronic)")
    set_ISSN("j-IFIP-TRANS-A",				"0926-5473")
    set_ISSN("j-IFIP-TRANS-B",				"0926-5481")
    set_ISSN("j-IFLA-J",				"0340-0352 (print), 1745-2651 (electronic)")
    set_ISSN("j-IIE-TRANS",				"0740-817X (print), 1573-9724 (electronic)")
    set_ISSN("j-IJCSS",					"1985-1553")
    set_ISSN("j-IJQC",					"0020-7608 (print), 1097-461X (electronic)")
    set_ISSN("j-IJQC-BIO-SYMP",				"0360-8832")
    set_ISSN("j-IJQC-QC-SYMP",				"0161-3642")
    set_ISSN("j-IJQC-SYMP",				"0538-821X")
    set_ISSN("j-IJSA",					"0890-2720")
    set_ISSN("j-IJSAHPC",				"1078-3482")
    set_ISSN("j-ILL-J-MATH",				"0019-2082 (print), 1945-6581 (electronic)")
    set_ISSN("j-IM-INFORMATION-MANAGEMENT",		"0930-5181")
    set_ISSN("j-IMA-BULL",				"????")
    set_ISSN("j-IMA-J-APPL-MATH",			"0272-4960 (print), 1464-3634 (electronic)")
    set_ISSN("j-IMA-J-MATH-CONTROL-INF",		"0265-0754 (print), 1471-6887 (electronic)")
    set_ISSN("j-IMA-J-MATH-APPL-MED-BIOL",              "0265-0746 (print), 1471-6879 (electronic)")
    set_ISSN("j-IMA-J-NUMER-ANAL",			"0272-4979 (print), 1464-3642 (electronic)")
    set_ISSN("j-IMA-NUM-ANA-NEWSLETTER",		"????")
    set_ISSN("j-IMAGE-VIDEO-PROCESS",			"1088-0356")
    set_ISSN("j-IMAGE-VIS-COMPUT",			"0262-8856 (print), 1872-8138 (electronic)")
    set_ISSN("j-IMAGING-MAGAZINE",                      "1063-4320")
    set_ISSN("j-IMMUNOL-HEMATOL-RES-MONOGR",		"0890-0191")
    set_ISSN("j-IMP-COMP-SCI-ENG",			"0899-8248 (print), 1557-7678 (electronic)")
    set_ISSN("j-IMS-BULL",				"1544-1881")
    set_ISSN("j-IMWUT",					"2474-9567")
    set_ISSN("j-IN-PLANT-REPROD",			"0198-9065")
    set_ISSN("j-IN-VITRO-CEL-DEV-BIO-ANIM",		"1071-2690 (print), 1543-706X (electronic)")
    set_ISSN("j-INC",                                   "0162-8968")
    set_ISSN("j-INCIDER",				"0740-0101")
    set_ISSN("j-INCIDER-A",				"1054-6456")
    set_ISSN("j-IND-ENG-CHEM-RES",			"0888-5885 (print), 1520-5045 (electronic)")
    set_ISSN("j-IND-MATH",				"0019-8528")
    set_ISSN("j-IND-WEEK",				"0039-0895 (print), 1930-8957 (electronic)")
    set_ISSN("j-INDAG-MATH",				"0019-3577, 0023-3358")
    set_ISSN("j-INDAG-MATH-PROC",			"1385-7258 (print), 1878-5972 (electronic)")
    set_ISSN("j-INDEXER",				"0019-4131 (print), 1756-0632 (electronic)")
    set_ISSN("j-INDIAN-J-BIOCHEM-BIOPHYS",		"0301-1208 (print), 0975-0959 (electronic)")
    set_ISSN("j-INDIAN-J-EXP-BIO",			"0019-5189 (print), 0975-1009 (electronic)")
    set_ISSN("j-INDIAN-J-HIST-SCI",			"0019-5235")
    set_ISSN("j-INDIAN-J-MATH",				"0019-5324")
    set_ISSN("j-INDIANA-U-MATH",			"0022-2518")
    set_ISSN("j-INF-COMM-TECH-LAW",			"1360-0834 (print), 1469-8404 (electronic)")
    set_ISSN("j-INF-COMPUT",				"0890-5401 (print), 1090-2651 (electronic)")
    set_ISSN("j-INF-CONTROL",				"0019-9958 (print), 1878-2981 (electronic)")
    set_ISSN("j-INF-INTELL-ONLINE-LIB-MICROCOMPUT",	"0737-7770")
    set_ISSN("j-INF-INTELL-ONLINE-NEWSL",		"0194-0694")
    set_ISSN("j-INF-PROC",				"0074-3127")
    set_ISSN("j-INF-PROCESS-MACH",			"0373-885X")
    set_ISSN("j-INF-RETR",				"1386-4564 (print), 1573-7659 (electronic)")
    set_ISSN("j-INF-SOC",				"0197-2243 (print), 1087-6537 (electronic)")
    set_ISSN("j-INF-STAND-Q",				"1041-0031 (print), 2161-6205 (electronic)")
    set_ISSN("j-INF-STORAGE-RETR",			"0020-0271 (print), 1878-4089 (electronic)")
    set_ISSN("j-INF-TECH-RES-DEV-APPL",			"0144-817X")
    set_ISSN("j-INFECT-IMMUN",				"0019-9567")
    set_ISSN("j-INFO-CANADA",				"1187-7081")

    # Replaced by j-INF-COMPUT
    # set_ISSN("j-INFO-COMP",				"0890-5401 (print), 1090-2651 (electronic)")

    set_ISSN("j-INFO-DB",				"0891-6004")
    set_ISSN("j-INFO-DECISION-TECHNOLOGIES",		"0923-0408")
    set_ISSN("j-INFO-FERNSPRECH-VERMITT",		"????")
    set_ISSN("j-INFO-MANAGEMENT-COMP-SECURITY",		"0968-5227 (print), 1758-5805 (electronic)")
    set_ISSN("j-INFO-MANAGEMENT-TECH",			"0266-6960")
    set_ISSN("j-INFO-PROC-LETT",			"0020-0190 (print), 1872-6119 (electronic)")
    set_ISSN("j-INFO-PROC-MAN",				"0306-4573 (print), 1873-5371 (electronic)")
    set_ISSN("j-INFO-RETRIEVAL-LIB-AUTO",		"0020-0220")
    set_ISSN("j-INFO-SCI",				"0020-0255 (print), 1872-6291 (electronic)")
    set_ISSN("j-INFO-SEC-TECH-REP",			"1363-4127 (print), 1873-605X (electronic)")
    set_ISSN("j-INFO-SERVICES-USE",			"0167-5265 (print), 1875-8789 (electronic)")
    set_ISSN("j-INFO-SOFTWARE-TECH",			"0950-5849 (print), 1873-6025 (electronic)")
    set_ISSN("j-INFO-SYS",				"0306-4379 (print), 1873-6076 (electronic)")
    set_ISSN("j-INFO-SYST-J",				"1350-1917 (print), 1365-2575 (electronic)")
    set_ISSN("j-INFO-TECH-HUMAN",			"????")
    set_ISSN("j-INFO-TECH-LIB",				"0730-9295")
    set_ISSN("j-INFO-TECH-NURSING",			"0956-5159")
    set_ISSN("j-INFOR",					"0315-5986")
    set_ISSN("j-INFORM-DIR",				"0390-0975")
    set_ISSN("j-INFORM-THEOR-APPL",			"0988-3754 (print), 1290-385X (electronic)")
    set_ISSN("j-INFORMACNE-SYSTEMY",			"0323-1984")
    set_ISSN("j-INFORMATICA",				"0350-5596 (print), 1854-3871 (electronic)")
    set_ISSN("j-INFORMATIE",				"0019-9907")
    set_ISSN("j-INFORMATIK-FACHBERICHTE",		"0343-3005")
    set_ISSN("j-INFORMATIK-INFORMATIONEN-REPORTE",	"0233-2582")
    set_ISSN("j-INFORMATIK-SPEKTRUM",			"0170-6012 (print), 1432-122X (electronic)")
    set_ISSN("j-INFORMATION-WEEK",			"8750-6874")
    set_ISSN("j-INFORMATIONS-TECHNIK",			"0179-9738")
    set_ISSN("j-INFORMS-J-COMPUT",			"1091-9856 (print), 1526-5528 (electronic)")
    set_ISSN("j-INFOWORLD",				"0199-6649")
    set_ISSN("j-INSECT-BIOCHEM-MOL-BIOL",		"0965-1748 (print), 1879-0240 (electronic)")
    set_ISSN("j-INST-PHYS-CONF-SER",			"030a5-2346")
    set_ISSN("j-INSTANT-SMALL-COMMERCIAL-PRINTER",	"1044-3746")
    set_ISSN("j-INSTRUCTOR",				"1049-5851") # <- New York; alternate 0892-9122 (Cleveland, OH) not in Ulrich's

    ## NB: j-INSTRUM-CONTROL-SYST is different from
    ## Instruments and Control Systems (INCSA7, 0020-4404)
    set_ISSN("j-INSTRUM-CONTROL-SYST",			"1074-2328")

    set_ISSN("j-INSUR-MATH-ECON",			"0167-6687 (print), 1873-5959 (electronic)")
    set_ISSN("j-INT-AFF",				"0020-5850 (print), 1468-2346 (electronic)")
    set_ISSN("j-INT-AQUAT-RES",				"2008-4935 (print), 2008-6970 (electronic)")
    set_ISSN("j-INT-COMMUN-HEAT-MASS-TRANSF",		"0735-1933 (print), 1879-0178 (electronic)")
    set_ISSN("j-INT-ECON-REV",				"0020-6598 (print), 1468-2354 (electronic)")
    set_ISSN("j-INT-EQN-OP-TH",				"0378-620X (print), 1420-8989 (electronic)")
    set_ISSN("j-INT-GEOSCIENCE-REMOTE-SENSING-SYMPOSIUM","????")
    set_ISSN("j-INT-INFO-COMM-EDU",			"0970-1850")
    set_ISSN("j-INT-J-ACCOUNT-INFO-SYS",		"1467-0895 (print), 1873-4723 (electronic)")
    set_ISSN("j-INT-J-AMBIENT-ENERGY",			"0143-0750")
    set_ISSN("j-INT-J-ANDROL",				"0105-6263 (print), 1365-2605 (electronic)")
    set_ISSN("j-INT-J-APPL-CRYPTOGR",			"1753-0563 (print), 1753-0571 (electronic)")
    set_ISSN("j-INT-J-APPL-ELECTROMAGN-MATER",		"0925-2096 (print), 1878-6774 (electronic)")
    set_ISSN("j-INT-J-APPL-MATH",			"1311-1728 (print), 1314-8060 (electronic)")
    set_ISSN("j-INT-J-APPL-MATH-STAT",			"0973-1377 (print), 0973-7545 (electronic)")
    set_ISSN("j-INT-J-APPROX-REASONING",		"0888-613X (print), 1873-4731 (electronic)")
    set_ISSN("j-INT-J-ASTROBIOL",			"1473-5504 (print), 1475-3006 (electronic)")
    set_ISSN("j-INT-J-BIFURC-CHAOS-APPL-SCI-ENG",	"0218-1274")
    set_ISSN("j-INT-J-BIOCHEM",				"0020-711X (print), 1878-6014 (electronic)")
    set_ISSN("j-INT-J-BIOCHEM-CELL-BIOL",		"1357-2725 (print), 1878-5875 (electronic)")
    set_ISSN("j-INT-J-BIOMED-COMPUT",			"0020-7101 (print), 1878-366X (electronic)")
    set_ISSN("j-INT-J-CIRCUIT-THEORY-APPL",		"0098-9886 (print), 1097-007X (electronic)")
    set_ISSN("j-INT-J-COMP-APPL-TECH",			"0952-8091 (print), 1741-5047 (electronic)")
    set_ISSN("j-INT-J-COMP-INTEG-MANUFACTURING",	"0951-192X (print), 1362-3052 (electronic)")
    set_ISSN("j-INT-J-COMP-PROC-LANG",			"2151-3848")
    set_ISSN("j-INT-J-COMP-PROC-ORIENTAL-LANG",		"0219-4279")
    set_ISSN("j-INT-J-COMP-RESEARCH",			"1535-6698")
    set_ISSN("j-INT-J-COMP-MATH-APPL",			"????")
    # [03-Feb-1999] Renamed from old j-INT-J-COMP-SYS-SCI-ENG to
    # j-INT-J-COMPUT-SYST-SCI-ENG to match journal name abbreviation.
    set_ISSN("j-INT-J-COMPUT-SYST-SCI-ENG",		"0267-6192", 1)
    set_ISSN("j-INT-J-COMP-VISION",			"0920-5691 (print), 1573-1405 (electronic)")
    set_ISSN("j-INT-J-COMPUT-APPL",			"1206-212X (print), 1925-7074 (electronic)")
    set_ISSN("j-INT-J-COMPUT-ENG-SCI",			"1465-8763 (print), 2047-6086 (electronic)")
    set_ISSN("j-INT-J-COMPUT-FLUID-DYN",		"1061-8562 (print), 1029-0257 (electronic)")
    set_ISSN("j-INT-J-COMPUT-INF-SCI",			"0091-7036")
    set_ISSN("j-INT-J-COMPUT-GEOM-APPL",		"0218-1959")
    set_ISSN("j-INT-J-COMPUT-MATH",			"0020-7160")
    set_ISSN("j-INT-J-COMPUT-METHODS-ENG-SCI-MECH",	"1550-2287 (print), 1550-2295 (electronic)")
    set_ISSN("j-INT-J-CONTROL",				"0020-7179 (print), 1366-5820 (electronic)")
    set_ISSN("j-INT-J-DAMAGE-MECH",			"1056-7895 (print), 1530-7921 (electronic)")
    set_ISSN("j-INT-J-DEV-BIOL",			"0214-6282 (print), 1696-3547 (electronic)")
    set_ISSN("j-INT-J-EEE",				"0020-7209")
    set_ISSN("j-INT-J-ELECTRON",			"0020-7217 (print), 1362-3060 (electronic)")
    set_ISSN("j-INT-J-ENERGY-RES",			"0363-907X (print), 1099-114X (electronic)")
    set_ISSN("j-INT-J-ENG-EDUC",			"0742-0269")
    set_ISSN("j-INT-J-ENG-SCI",				"0020-7225 (print), 1879-2197 (electronic)")
    set_ISSN("j-INT-J-EPIDEMIOL",			"0300-5771 (print), 1464-3685 (electronic)")
    set_ISSN("j-INT-J-FOUND-COMP-SCI",			"0129-0541 (print), 1793-6373 (electronic)")
    set_ISSN("j-INT-J-FRACTURE",			"0376-9429 (print), 1573-2673 (electronic)")
    set_ISSN("j-INT-J-GEN-SYST",			"0308-1079 (print), 1563-5104 (electronic)")
    set_ISSN("j-INT-J-HEALTH-SERV",			"0020-7314 (print), 1541-4469 (electronic)")
    set_ISSN("j-INT-J-HEAT-MASS-TRANSFER",		"0017-9310 (print), 1879-2189 (electronic)")
    set_ISSN("j-INT-J-HIGH-SPEED-COMPUTING",		"0129-0533")
    set_ISSN("j-INT-J-HOSP-MANAGEMENT",			"0278-4319 (print), 1873-4693 (electronic)")
    set_ISSN("j-INT-J-HYPERTHERMIA",			"0265-6736 (print), 1464-5157 (electronic)")
    set_ISSN("j-INT-J-IMAGE-GRAPHICS",			"0219-4678")
    set_ISSN("j-INT-J-INFO-SEC",			"1615-5262 (print), 1615-5270 (electronic)")
    set_ISSN("j-INT-J-INFO-TECH",                       "0218-7957")
    set_ISSN("j-INT-J-INTELL-SYSTEMS",			"0884-8173 (print), 1098-111X (electronic)")
    set_ISSN("j-INT-J-MAN-MACHINE-STUDIES",		"0020-7373")
    set_ISSN("j-INT-J-MANAGEMENT-SYS",			"0970-7328")
    set_ISSN("j-INT-J-MASS-SPECT-ION-PROC",		"0168-1176 (print), 1873-2801 (electronic)")
    set_ISSN("j-INT-J-MATH",				"0129-167X")
    set_ISSN("j-INT-J-MATH-COMP-MODELLING",		"????")
    set_ISSN("j-INT-J-MATH-EDU-SCI-TECH",		"0020-739X (print), 1464-5211 (electronic)")
    set_ISSN("j-INT-J-MATH-MATH-SCI",			"0161-1712 (print), 1687-0425 (electronic)")
    set_ISSN("j-INT-J-MECH-ENG-EDU",			"0306-4190")
    set_ISSN("j-INT-J-MECH-SCI",			"0020-7403")
    set_ISSN("j-INT-J-MINI-MICROCOMPUTERS",		"0702-0481")
    set_ISSN("j-INT-J-MOD-PHYS-A",			"0217-751X")
    set_ISSN("j-INT-J-MOD-PHYS-B",			"0217-9792 (print), 1793-6578 (electronic)")
    set_ISSN("j-INT-J-MOD-PHYS-C",			"0129-1831 (print), 1793-6586 (electronic)")
    set_ISSN("j-INT-J-MOD-PHYS-D",			"0218-2718")
    set_ISSN("j-INT-J-MOD-PHYS-E",			"0218-3013")
    set_ISSN("j-INT-J-MODELLING-SIMUL",			"0228-6203 (print), 1925-7082 (electronic)")
    set_ISSN("j-INT-J-NEURAL-SYST",			"0129-0657")
    set_ISSN("j-INT-J-NUMBER-THEORY",			"1793-0421 (print), 1793-7310 (electronic)")
    set_ISSN("j-INT-J-NUMER-ANAL-METHODS-GEOMECH",	"0363-9061 (print), 1096-9853 (electronic)")
    set_ISSN("j-INT-J-NUMER-MODEL",			"0894-3370 (print), 1099-1204 (electronic)")
    set_ISSN("j-INT-J-NUMER-METHODS-BIOMED-ENG",	"2040-7947")
    set_ISSN("j-INT-J-NUMER-METHODS-ENG",		"0029-5981 (print), 1097-0207 (electronic)")
    set_ISSN("j-INT-J-NUMER-METHODS-FLUIDS",		"0271-2091 (print), 1097-0363 (electronic)")
    set_ISSN("j-INT-J-OPTOELECTRON",			"0952-5432")
    set_ISSN("j-INT-J-PARALLEL-PROG",			"0885-7458 (print), 1573-7640 (electronic)")
    set_ISSN("j-INT-J-PATTERN-RECOGNITION-ARTIFICIAL-INTELLIGENCE","0218-0014")
    set_ISSN("j-INT-J-PLAST"				"0749-6419 (print), 1879-2154 (electronic)")
    set_ISSN("j-INT-J-PROD-ECON",			"0925-5273 (print), 1873-7579 (electronic)")
    set_ISSN("j-INT-J-PSYCHOPHYSIOL",                   "0167-8760 (print), 1872-7697 (electronic)")
    set_ISSN("j-INT-J-PURE-APPL-MATH",			"1311-8080 (print), 1314-3395 (electronic)")
    set_ISSN("j-INT-J-RADIAT-BIOL",			"0955-3002 (print), 1362-3095 (electronic)")
    set_ISSN("j-INT-J-RADIAT-ONCOL-BIOL-PHYS",		"0360-3016 (print), 1879-355X (electronic)")
    set_ISSN("j-INT-J-RES-MARK",			"0167-8116 (print), 1873-8001 (electronic)")
    set_ISSN("j-INT-J-ROBOTICS-AUTOMATION",		"0826-8185 (print), 1925-7090 (electronic)")
    set_ISSN("j-INT-J-ROBOTICS-RES",			"0278-3649 (print), 1741-3176 (electronic)")
    set_ISSN("j-INT-J-ROCK-MECH-MINING-SCI-GEOMECH-ABS","0148-9062")
    set_ISSN("j-INT-J-SATELL-COMMUN",			"0737-2884 (print), 1099-1247 (electronic)")
    set_ISSN("j-INT-J-SCI-COMP-MOD",			"0971-4863")
    set_ISSN("j-INT-J-SCI-ENG-RESEARCH",		"2229-5518")
    set_ISSN("j-INT-J-SCI-MATH-EDUC",			"1571-0068 (print), 1573-1774 (electronic)")
    set_ISSN("j-INT-J-SOFTW-TOOLS-TECHNOL-TRANSFER",	"1433-2779 (print), 1433-2787 (electronic)")
    set_ISSN("j-INT-J-SOLIDS-STRUCT",			"0020-7683 (print), 1879-2146 (electronic)")
    set_ISSN("j-INT-J-STAT-PROBAB",			"1927-7032 (print), 1927-7040 (electronic)")
    set_ISSN("j-INT-J-SYST-SCI",			"0020-7721 (print), 1464-5319 (electronic)")
    set_ISSN("j-INT-J-THEOR-PHYS",			"0020-7748 (print), 1572-9575 (electronic)")
    set_ISSN("j-INT-J-THERMOPHYS",			"0195-928X (print), 1572-9567 (electronic)")
    set_ISSN("j-INT-J-TOMOGR-STAT",			"0972-9976 (print), 0973-7294 (electronic)")
    set_ISSN("j-INT-J-UNITY-SCI",			"0896-2294")
    set_ISSN("j-INT-J-WAVELETS-MULTIRESOLUT-INF-PROCESS", "0219-6913 (print), 1793-690X (electronic)")
    set_ISSN("j-INT-PHILOS-Q",				"0019-0365 (print), 2153-8077 (electronic)")
    set_ISSN("j-INT-PHOENIX-CONF-COMPUT-COMM",		"0896-582X")
    set_ISSN("j-INT-REV-CYTOLOGY",			"0074-7696")
    set_ISSN("j-INT-REV-PHYS",				"1971-680X")
    set_ISSN("j-INT-REV-VICTIM",			"0269-7580 (print), 2047-9433 (electronic)")
    set_ISSN("j-INT-SCI-TECHNOL",			"0097-3777")
    set_ISSN("j-INT-SECUR",				"0162-2889 (print), 1531-4804 (electronic)")
    set_ISSN("j-INT-SER-NUMER-MATH",			"0539-0141")
    set_ISSN("j-INT-STAT-REV",				"0306-7734 (print), 1751-5823 (electronic)")
    set_ISSN("j-INT-STUD-PHILOS-SCI",			"0269-8595 (print), 1469-9281 (electronic)")
    set_ISSN("j-INT-SYMP-SYMB-COMPUT-ISSAS-PROC",	"????")
    set_ISSN("j-INT-TELEMETERING-CONFERENCE",		"0884-5123 (print), 1546-2188 (electronic)")
    set_ISSN("j-INT-TRANS-OPL-RES",			"0969-6016 (print), 1475-3995 (electronic)")
    set_ISSN("j-INT-YEARBOOK-LAW-COMP-TECH",		"0965-528X")
    set_ISSN("j-INTEGERS",				"1867-0652 (print), 1867-0660 (electronic)")
    set_ISSN("j-INTEGRAL-TRANSFORMS-SPEC-FUNCT",	"1065-2469 (print), 1476-8291 (electronic)")
    set_ISSN("j-INTEGRATION-VLSI-J",			"0167-9260 (print), 1872-7522 (electronic)")
    set_ISSN("j-INTEGR-ENVIRON-ASSES-MANAG",		"1551-3777 (print), 1551-3793 (electronic)")
    set_ISSN("j-INTELL-INSTR-COMP",			"0889-8308")
    set_ISSN("j-INTELL-NATL-SECUR",			"0268-4527 (print), 1743-9019 (electronic)")
    set_ISSN("j-INTELL-TUTORING-MEDIA",			"0957-9133")
    set_ISSN("j-INTERACTIONS",				"1072-5520 (print), 1558-3449 (electronic)")
    set_ISSN("j-INTERACTIVE-AGE",			"1080-4927")
    set_ISSN("j-INTERACTIVE-SYS-EXP-APPL-MATH",		"????")
    set_ISSN("j-INTERDISCIP-INFORM-SCI",		"1340-9050 (print), 1347-6157 (electronic)")
    set_ISSN("j-INTERFACE",				"0929-8215 (print), 1744-5027 (electronic)")
    set_ISSN("j-INTERFACE-CHICAGO",			"0270-6717")
    set_ISSN("j-INTERFACE-GHENT",			"0303-3902")
    set_ISSN("j-INTERFACE-SANTA-CRUZ",			"0163-6626")
    set_ISSN("j-INTERFACE-SCI",				"0927-7056 (print), 1573-2746 (electronic)")
    set_ISSN("j-INTERFACES",				"0092-2102 (print), 1526-551X (electronic)")
    set_ISSN("j-INTERLEND-DOC-SUPPLY",			"0264-1615 (print), 1758-5848 (electronic)")
    set_ISSN("j-INTERNET-HIST",				"2470-1483")
    set_ISSN("j-INTERNET-J-CHEM",			"1099-8292")
    set_ISSN("j-INTERNET-MATH",				"1542-7951 (print), 1944-9488 (electronic)")
    set_ISSN("j-INTERNET-RES",				"1066-2243")
    set_ISSN("j-INTERNET-WORLD",			"1064-3923")
    set_ISSN("j-INTERNETWORK",				"1079-0373")
    set_ISSN("j-INTERNETWORKING",			"1049-8915")
    set_ISSN("j-INTERVAL-COMP",				"0135-4868")
    set_ISSN("j-INTRANET-NETWORKING-STRATEGIES-REP",    "1069-126X")
    set_ISSN("j-INV-OP",				"????")
    set_ISSN("j-INVENT-MATH",				"0020-9910 (print), 1432-1297 (electronic)")
    set_ISSN("j-INVERSE-PROBLEMS",			"0266-5611 (print), 1361-6420 (electronic)")
    set_ISSN("j-INVERSE-PROBL-IMAGING",			"1930-8337 (print), 1930-8345 (electronic)")
    set_ISSN("j-INVERSE-PROBL-SCI-ENG",			"1741-5977 (print), 1741-5985 (electronic)")
    set_ISSN("j-IR-J-PSYCHOL-MED",			"0790-9667 (print), 2051-6967 (electronic)")
    set_ISSN("j-IRE-PROC",				"????")
    set_ISSN("j-IRE-TRANS-ELEC-COMPUT",			"0367-9950")
    set_ISSN("j-IRE-TRANS-ENG-WRIT-SPEECH",		"0893-7869 (print), 2331-3692 (electronic)")
    set_ISSN("j-IRE-TRANS-INF-THEORY",			"0096-1000")
    set_ISSN("j-IRISH-ASTRON-J",			"0021-1052")
    set_ISSN("j-IRISH-COMP",                            "0332-0197")
    set_ISSN("j-IRISH-MATH-SOC-BULL",			"0791-5578")
    set_ISSN("j-IRIS-UNIVERSE",				"1061-6608")
    set_ISSN("j-ISIS",					"0021-1753 (print), 1545-6994 (electronic)")
    set_ISSN("j-ISRAEL-J-CHEM",				"0021-2148")

    ## TO DO: Need to check the electronic ISSN: latest issn.org value is 1565-8511
    ## set_ISSN("j-ISRAEL-J-MATH",				"0021-2172 (print), 2223-8948 (electronic)")
    set_ISSN("j-ISRAEL-J-MATH",				"0021-2172 (print), 1565-8511 (electronic)")

    set_ISSN("j-ISRAEL-STUD",				"1084-9513 (print), 1527-201X (electronic)")
    set_ISSN("j-ISSUES-SCI-TECHNOL",			"0748-5492 (print), 1938-1557 (electronic)")
    set_ISSN("j-IT-IT",					"0944-2774")
    set_ISSN("j-IT-MAGAZINE",				"0008-3364")
    set_ISSN("j-IT-PRO",				"1520-9202 (print), 1941-045X (electronic)")
    set_ISSN("j-ITAL-J-PURE-APPL-MATH",			"1126-8042 (print), 2239-0227 (electronic)")
    set_ISSN("j-ITE-J",					"0162-8178")
    set_ISSN("j-ITNOW",					"1746-5710")
    set_ISSN("j-IZV-AKAD-ARM-SSR-MEH",			"0002-3051")
    set_ISSN("j-IZV-AKAD-NAUK-SSSR-MAT",		"????")
    set_ISSN("j-IZV-AKAD-NAUK-SSSR-MEH-TVERD-TELA",	"0572-3299")
    set_ISSN("j-IZV-SEKTS-ASTRON-BULG-AKAD-NAUK",	"0525-0897")
    set_ISSN("j-IZV-VYSS-UCEBN-ZAVED-MAT",		"0021-3446 (print), 2076-4626 (electronic)")
    set_ISSN("j-J-ACCOUNT-EDUC",			"0748-5751 (print), 1873-1996 (electronic)")
    set_ISSN("j-J-ACCOUNTANCY",				"0021-8448 (print), 1945-0729 (electronic)")
    set_ISSN("j-J-ACM",					"0004-5411 (print), 1557-735X (electronic)")
    set_ISSN("j-J-ACOUST-SOC-AM",			"0001-4966")
    set_ISSN("j-J-AERO-SPACE-SCI",			"0095-9820")
    set_ISSN("j-J-AEROSOL-SCI",				"0021-8502 (print), 1879-1964 (electronic)")
    set_ISSN("j-J-AGRIC-SCI",				"0021-8596 (print), 1469-5146 (electronic)")
    set_ISSN("j-J-ALG",					"0196-6774 (print), 1090-2678 (electronic)")
    set_ISSN("j-J-ALGEBRA",				"0021-8693 (print), 1090-266X (electronic)")
    set_ISSN("j-J-ALGEBR-COMB",				"0925-9899 (print), 1572-9192 (electronic)")
    set_ISSN("j-J-ALGORITHMS-COMPUT-TECHNOL",		"1748-3018 (print), 1748-3026 (electronic)")
    set_ISSN("j-J-AM-CERAM-SOC",			"0002-7820 (print), 1551-2916 (electronic)")
    set_ISSN("j-J-AM-COLL-CARDIOL",			"0735-1097 (print), 1558-3597 (electronic)")
    set_ISSN("j-J-AM-HIST",				"0021-8723 (print), 1945-2314 (electronic)")
    set_ISSN("j-J-AM-MATH-SOC",				"0894-0347 (print), 1088-6834 (electronic)")
    set_ISSN("j-J-AM-MED-ASSOC",			"0098-7484 (print), 1538-3598 (electronic)")
    set_ISSN("j-J-AM-SOC-INF-SCI",			"0002-8231 (print), 1097-4571 (electronic)")
    set_ISSN("j-J-AM-SOC-INF-SCI-TECHNOL",		"1532-2882 (print), 1532-2890 (electronic)")
    set_ISSN("j-J-AM-STAT-ASSOC",			"0162-1459 (print), 1537-274X (electronic)")
    set_ISSN("j-J-ANAL-MATH",				"0099-698X, 0021-7670")
    set_ISSN("j-J-ANIM-ECOL",				"0021-8790 (print), 1365-2656 (electronic)")
    set_ISSN("j-J-APPL-CRYSTAL",			"0021-8898 (print), 1600-5767 (electronic)")
    set_ISSN("j-J-APPL-ECOL",				"0021-8901 (print), 1365-2664 (electronic)")
    set_ISSN("j-J-APPL-ECONOMETRICS",			"0883-7252 (print), 1099-1255 (electronic)")
    set_ISSN("j-J-APPL-MATH",				"1110-757X (print), 1687-0042 (electronic)")
    set_ISSN("j-J-APPL-MATH-MECH",			"0021-8928 (print), 1873-4855 (electronic)")
    set_ISSN("j-J-APPL-MATH-PHYS",			"0044-2275 (print), 1420-9039 (electronic)")
    set_ISSN("j-J-APPL-MECH",				"0021-8936 (print), 1528-9036 (electronic)")
    set_ISSN("j-J-APPL-MECH-TECH-PHYS",			"0021-8944 (print), 1573-8620 (electronic)")
    set_ISSN("j-J-APPL-PHYS",				"0021-8979 (print), 1089-7550 (electronic), 1520-8850")
    set_ISSN("j-J-APPL-PROBAB",				"0021-9002 (print), 1475-6072 (electronic)")
    set_ISSN("j-J-APPL-PSYCHOL",			"0021-9010 (print), 1939-1854 (electronic)")
    set_ISSN("j-J-APPL-STAT",				"0266-4763 (print), 1360-0532 (electronic)")
    set_ISSN("j-J-APPL-TOXIC",				"0260-437X (print), 1099-1263 (electronic)")
    set_ISSN("j-J-APPROX-THEORY",			"0021-9045 (print), 1096-0430 (electronic)")
    set_ISSN("j-J-AQUACULT-RES-DEV",			"2155-9546")
    set_ISSN("j-J-ASSET-MANAGE",			"1470-8272 (print), 1479-179X (electronic)")
    set_ISSN("j-J-ASSOC-INF-SCI-TECHNOL",		"2330-1635 (print), 2330-1643 (electronic)")
    set_ISSN("j-J-ASTRONAUTICAL-SCIENCES",		"0021-9142")
    set_ISSN("j-J-ASTROPHYS-ASTRON",			"0250-6335 (print), 0973-7758 (electronic)")
    set_ISSN("j-J-ATMOS-SCI",				"0022-4928 (print), 1520-0469 (electronic)")
    set_ISSN("j-J-ATMOS-SOL-TERR-PHYS",			"1364-6826 (print), 1879-1824 (electronic)")
    set_ISSN("j-J-AUDIO-ENG-SOC",			"1549-4950")
    set_ISSN("j-J-AUSTRAL-MATH-SOC-SER-A",		"0263-6115 (print), 2396-8192 (electronic)")
    set_ISSN("j-J-AUSTRAL-MATH-SOC-SER-B",		"0334-2700")
    set_ISSN("j-J-AUSTRALIAN-MATH-SOC",			"0004-9735 (print), 2059-9234 (electronic)")
    set_ISSN("j-J-AUTOM-REASON",			"0168-7433 (print), 1573-0670 (electronic)")
    set_ISSN("j-J-BACTERIOL",				"0021-9193")
    set_ISSN("j-J-BIOCHEM",				"0021-924X (print), 1756-2651 (electronic)")
    set_ISSN("j-J-BIOCHEM-BIOPHYS-METH",		"0165-022X (print), 1872-857X (electronic)")
    set_ISSN("j-J-BIOINF-COMPUT-BIOL",			"0219-7200 (print), 1757-6334 (electronic)")
    set_ISSN("j-J-BIOL-CHEM",				"0021-9258")
    set_ISSN("j-J-BIOL-RHYTHMS",			"0748-7304 (print), 1552-4531 (electronic)")
    set_ISSN("j-J-BIOL-SYSTEMS",			"0218-3390")
    set_ISSN("j-J-BIOMECH",				"0021-9290 (print), 1873-2380 (electronic)")
    set_ISSN("j-J-BIOMED-ENG",				"0141-5425 (print), 2213-9478 (electronic)")
    set_ISSN("j-J-BIOMED-INF",				"1532-0464")
    set_ISSN("j-J-BIOMED-MATER-RES",			"0021-9304 (print), 1097-4636 (electronic)")
    set_ISSN("j-J-BIOMOL-STRUCT-DYNAMICS",		"0739-1102 (print), 1538-0254 (electronic)")
    set_ISSN("j-J-BIOSCI",				"0250-5991 (print), 0973-7138 (electronic)")
    set_ISSN("j-J-BIOTECH",				"0168-1656 (print), 1873-4863 (electronic)")
    set_ISSN("j-J-BONE-MINERAL-RES",			"0884-0431 (print), 1523-4681 (electronic)")
    set_ISSN("j-J-BR-ASTRON-ASSOC",			"0007-0297")
    set_ISSN("j-J-BR-INTERPLANET-SOC",			"0007-084X")
    set_ISSN("j-J-BRAZIL-COMPUT-SOC",			"0104-6500 (print), 1678-4804 (electronic)")
    set_ISSN("j-J-BUS-ECON-STAT",			"0735-0015 (print), 1537-2707 (electronic)")
    set_ISSN("j-J-BUS-UNIV-CHIC",			"0021-9398 (print), 1537-5374 (electronic)")
    set_ISSN("j-J-CARDIOVASC-PHARMACOL",                "0160-2446 (print), 1533-4023 (electronic)")
    set_ISSN("j-J-CARDIOVASC-ELECTROPHYSIOL",		"1045-3873 (print), 1540-8167 (electronic)")
    set_ISSN("j-J-CELL-BIOCHEM",			"0730-2312 (print), 1097-4644 (electronic)")
    set_ISSN("j-J-CELL-BIOL",				"0021-9525 (print), 1540-8140 (electronic)")
    set_ISSN("j-J-CELL-COMP-PHYSIOL",			"0021-9541 (print), 1097-4652 (electronic)")
    set_ISSN("j-J-CELL-PHYSIOL",			"0021-9541", 1)
    set_ISSN("j-J-CELL-SCI",				"0021-9533 (print), 1477-9137 (electronic)")
    set_ISSN("j-J-CELL-SCI-SUPPL",			"0269-3518")
    set_ISSN("j-J-CEREB-BLOOD-FLOW-METAB",		"0271-678X (print), 1559-7016 (electronic)")
    set_ISSN("j-J-CHEM-EDUC",				"0021-9584 (print), 1938-1328 (electronic)")
    set_ISSN("j-J-CHEM-INFO-COMP-SCI",			"0095-2338 (print), 1520-5142 (electronic)")
    set_ISSN("j-J-CHEM-INFO-MODEL",			"1549-9596 (print), 1549-960X (electronic)")
    set_ISSN("j-J-CHEM-PHYS",				"0021-9606 (print), 1089-7690 (electronic)")
    set_ISSN("j-J-CHEM-SOC",				"0368-1769 (print), 2050-5574 (electronic)")
    set_ISSN("j-J-CHEM-SOC-FARADAY-TRANS",		"0956-5000 (print), 1364-5455 (electronic)")
    set_ISSN("j-J-CHEM-SOC-FARADAY-TRANS-2",		"0300-9238 (print), 2050-5663 (electronic)")
    set_ISSN("j-J-CHEM-SOC-TRANS",			"0368-1645 (print), 2050-5450 (electronic)")
    set_ISSN("j-J-CHEM-THEORY-COMPUT",			"1549-9618 (print), 1549-9626 (electronic)")
    set_ISSN("j-J-CHEMOM",				"0886-9383 (print), 1099-128X (electronic)")
    set_ISSN("j-J-CHILD-MATH-BEHAV",			"0160-0133")
    set_ISSN("j-J-CHINESE-INST-ENG",			"0253-3839") # alternate 0368-7058 seems to be wrong
    set_ISSN("j-J-CHROMATOGR-A",			"0021-9673 (print), 1873-3778 (electronic)")
    set_ISSN("j-J-CIV-DEF",				"0740-5537")
    set_ISSN("j-J-CLIN-INVEST",				"0021-9738 (print), 1558-8238 (electronic)")
    set_ISSN("j-J-CLIN-PATHOL",				"0021-9746 (print), 1472-4146 (electronic)")
    set_ISSN("j-J-CLIN-PSYCHOL",			"0021-9762 (print), 1097-4679 (electronic)")
    set_ISSN("j-J-COLD-REG-ENG",			"0887-381X (print), 1943-5495 (electronic)")
    set_ISSN("j-J-COLD-WAR-STUD",			"1520-3972 (print), 1531-3298 (electronic)")
    set_ISSN("j-J-COLL-SCI-TEACH",			"0047-231X (print), 1943-4898 (electronic)")
    set_ISSN("j-J-COLLOID-INTERFACE-SCI",		"0021-9797 (print), 1095-7103 (electronic)")
    set_ISSN("j-J-COMB",				"2156-3527 (print), 2150-959X (electronic)")
    set_ISSN("j-J-COMB-DES",				"1063-8539 (print), 1520-6610 (electronic)")
    set_ISSN("j-J-COMB-OPTIM",				"1382-6905 (print), 1573-2886 (electronic)")
    set_ISSN("j-J-COMB-THEORY",				"0021-9800 (print), 1878-1756 (electronic)")
    set_ISSN("j-J-COMB-THEORY-A",			"0097-3165 (print), 1096-0899 (electronic)")
    set_ISSN("j-J-COMB-THEORY-B",			"0095-8956 (print), 1096-0902 (electronic)")
    set_ISSN("j-J-COMP-BASED-INST",			"0098-597X")
    set_ISSN("j-J-COMP-INFO",				"1180-3886")
    set_ISSN("j-J-COMP-INFO-SYS",			"0887-4417")
    set_ISSN("j-J-COMP-MATH",				"0254-9409 (print), 1991-7139 (electronic)")
    set_ISSN("j-J-COMP-NEUROL",                         "0021-9967 (print), 1096-9861 (electronic)")
    ## BAD:	set_ISSN("j-J-COMP-NEUROSCI",			"0923-5313")
    set_ISSN("j-J-COMP-NEUROSCI",			"0929-5313 (print), 1573-6873 (electronic)")	# [04-Jan-2006] corrected
    set_ISSN("j-J-COMP-PHYSIOL",			"0302-9824")
    set_ISSN("j-J-COMP-PHYSIOL-A",			"0340-7594 (print), 1432-1351 (electronic)")
    set_ISSN("j-J-COMP-PHYSIOL-B",			"0174-1578 (print), 1432-136X (electronic)")
    set_ISSN("j-J-COMP-SCI-TECH",			"1000-9000 (print), 1860-4749 (electronic)")
    set_ISSN("j-J-COMP-SECUR",				"0926-227X (print), 1875-8924 (electronic)")
    set_ISSN("j-J-COMP-SYS-SCI",			"0022-0000 (print), 1090-2724 (electronic)")
    set_ISSN("j-J-COMPLEX-NETWORKS",			"2051-1310 (print), 2051-1329 (electronic)")
    set_ISSN("j-J-COMPLEXITY",				"0885-064X (print), 1090-2708 (electronic)")
    set_ISSN("j-J-COMPOS-MATER",			"0021-9983 (print), 1530-793X (electronic)")
    set_ISSN("j-J-COMPUT-AIDED-MATER-DES",		"0928-1045 (print), 1573-4900 (electronic)")
    set_ISSN("j-J-COMPUT-APPL-MATH",			"0377-0427 (print), 1879-1778 (electronic)")
    set_ISSN("j-J-COMPUT-ASSIST-LEARNING",		"0266-4909 (print), 1365-2729 (electronic)")
    set_ISSN("j-J-COMPUT-ASSIST-MICROSC",		"1040-7286 (print), 1573-8671 (electronic)")
    set_ISSN("j-J-COMPUT-ASSIST-TOMOGRAPHY",		"0363-8715 (print), 1532-3145 (electronic)")
    set_ISSN("j-J-COMPUT-BIOL",				"1066-5277 (print), 1557-8666 (electronic)")
    set_ISSN("j-J-COMPUT-CHEM",				"0192-8651 (print), 1096-987X (electronic)")
    set_ISSN("j-J-COMPUT-FINANCE",			"1460-1559 (print), 1755-2850 (electronic)")
    set_ISSN("j-J-COMPUT-GEOM",				"1920-180X")
    set_ISSN("j-J-COMPUT-GRAPH-STAT",			"1061-8600 (print), 1537-2715 (electronic)")
    set_ISSN("j-J-COMPUT-METHODS-SCI-ENG",		"1472-7978 (print), 1875-8983 (electronic)")
    set_ISSN("j-J-COMPUT-PHYS",				"0021-9991 (print), 1090-2716 (electronic)")
    set_ISSN("j-J-COMPUT-SCI",				"1877-7503 (print), 1877-7511 (electronic)")	
    set_ISSN("j-J-COMPUT-SYST-SCI-INT",			"1064-2307 (print), 1555-6530 (electronic)")
    ## [29-Nov-2012] Preferred abbreviation changed to j-J-COMPUT-CHEM
    ## set_ISSN("j-J-COMPUTATIONAL-CHEM",			"0192-8651 (print), 1096-987X (electronic)")
    set_ISSN("j-J-CONFL-RESOLUT",			"0022-0027 (print), 1552-8766 (electronic)")
    set_ISSN("j-J-CONTEMP-HIST",			"0022-0094 (print), 1461-7250 (electronic)")
    set_ISSN("j-J-CONTROL-THEORY-APPL",			"1672-6340 (print), 1993-0623 (electronic)")
    set_ISSN("j-J-CONVEX-ANAL",				"0944-6532 (print), 2363-6394 (electronic)")
    set_ISSN("j-J-CRYPTO-ENG",				"2190-8508 (print), 2190-8516 (electronic)")
    set_ISSN("j-J-CRYPTOLOGY",				"0933-2790 (print), 1432-1378 (electronic)")
    set_ISSN("j-J-CRYSTAL-GROWTH",			"0022-0248 (print), 1873-5002 (electronic)")
    set_ISSN("j-J-CYCLIC-NUCLEOTIDE-PROTEIN-PHOSPHOR-RES","0746-3898")
    set_ISSN("j-J-DAIRY-SCI",				"0022-0302")
    set_ISSN("j-J-DATA-COMP-COMM",			"1054-089X")
    set_ISSN("j-J-DATABASE-ADM",			"1047-9430")
    set_ISSN("j-J-DES-HIST",				"0952-4649 (print), 1741-7279 (electronic)")
    set_ISSN("j-J-DIFFER-EQU",				"0022-0396 (print), 1090-2732 (electronic)")
    set_ISSN("j-J-DIFFER-GEOM",				"0022-040X (print), 1945-743X (electronic)")
    set_ISSN("j-J-DIFFERENCE-EQU-APPL",			"1023-6198 (print), 1563-5120 (electronic)")
    set_ISSN("j-J-DIGITAL-IMAGING",			"0897-1889 (print), 1618-727X (electronic)")
    set_ISSN("j-J-DIGITAL-INFO",			"1368-7506")
    set_ISSN("j-J-DISCRETE-ALGORITHMS",			"1570-8667 (print), 1570-8675 (electronic)")
    set_ISSN("j-J-DISCR-MATH-SCI-CRYPTO",		"0972-0529")
    set_ISSN("j-J-DOC",					"0022-0418 (print), 1758-7379 (electronic)")
    set_ISSN("j-J-DYN-CONTROL-SYST",			"1079-2724 (print), 1573-8698 (electronic)")
    set_ISSN("j-J-DYN-DIFFER-EQU",			"1040-7294 (print), 1572-9222 (electronic)")
    set_ISSN("j-J-DYN-SYST-MEAS-CONTROL",		"0022-0434")
    set_ISSN("j-J-ECON-DYN-CONTROL",			"0165-1889 (print), 1879-1743 (electronic)")
    set_ISSN("j-J-ECON-LIT",				"0022-0515 (print), 1547-1101 (electronic)")
    set_ISSN("j-J-ECON-THEORY",				"0022-0531 (print), 1095-7235 (electronic)")
    set_ISSN("j-J-ECONOMETRICS",			"0304-4076 (print), 1872-6895 (electronic)")
    set_ISSN("j-J-EDU-RESEARCH",			"0022-0671 (print), 1940-0675 (electronic)")
    set_ISSN("j-J-EDUC-BEHAV-STAT",			"1076-9986 (print), 1935-1054 (electronic)")
    set_ISSN("j-J-EDUC-SOCIOL-NEW-YORK",		"0885-3525 (print), 2326-4055 (electronic)")
    set_ISSN("j-J-ELAST",				"0374-3535 (print), 1573-2681 (electronic)")
    set_ISSN("j-J-ELECTROCARDIOL",			"0022-0736 (print), 1532-8430 (electronic)")
    set_ISSN("j-J-ELECTROCHEM-SOC",			"0013-4651 (print), 1945-7111 (electronic)")
    set_ISSN("j-J-ELECTROMAGN-WAVES-APPL",		"0920-5071 (print), 1569-3937 (electronic)")
    set_ISSN("j-J-ELECTRON-IMAGING",			"1017-9909 (print), 1560-229X (electronic)")
    set_ISSN("j-J-ELECTRON-MICROSC-TECH",		"0741-0581 (print), 1553-0817 (electronic)")
    set_ISSN("j-J-ELECTRON-SPECTROSC-RELAT-PHENOM",	"0368-2048 (print), 1873-2526 (electronic)")
    set_ISSN("j-J-ELECTROST",				"0304-3886 (print), 1873-5738 (electronic)")
    set_ISSN("j-J-ELISHA-MITCHELL-SCI-SOC",		"0013-6220")
    set_ISSN("j-J-EMBRYOL-EXP-MORPHOL",			"0022-0752")
    set_ISSN("j-J-EMPIR-FINANCE",			"0927-5398 (print), 1879-1727 (electronic)")
    set_ISSN("j-J-ENG-MATER-TECHNOL",			"0094-4289 (print), 1528-8889 (electronic)")
    set_ISSN("j-J-ENG-MATH",				"0022-0833 (print), 1573-2703 (electronic)")
    set_ISSN("j-J-ENG-MECH",				"0733-9399 (print), 1943-7889 (electronic)")
    set_ISSN("j-J-EUKARYOT-MICROBIOL",			"1066-5234 (print), 1550-7408 (electronic)")
    set_ISSN("j-J-EXP-BIOL",				"0022-0949 (print), 1477-9145 (electronic)")
    set_ISSN("j-J-EXP-MED",				"0022-1007 (print), 1540-9538 (electronic)")
    set_ISSN("j-J-EXP-PSYCH-GEN",			"0096-3445 (print), 1939-2222 (electronic)")
    set_ISSN("j-J-EXP-PSYCH-LMC",			"0278-7393 (print), 1939-1285 (electronic)")
    set_ISSN("j-J-EXP-THEOR-ARTIF-INTELL",		"0952-813X (print), 1362-3079 (electronic)")
    set_ISSN("j-J-EXP-THEOR-PHYS",			"1090-6509, 1063-7761")
    set_ISSN("j-J-EXP-ZOOL",				"0022-104X (print), 1097-010X (electronic)")
    set_ISSN("j-J-FINANC-ECON",				"0304-405X (print), 1879-2774 (electronic)")
    set_ISSN("j-J-FISH-BIOL",				"0022-1112 (print), 1095-8649 (electronic)")
    set_ISSN("j-J-FISH-DIS",				"0140-7775 (print), 1365-2761 (electronic)")
    set_ISSN("j-J-FISH-RES-BOARD-CAN",			"0015-296X")
    set_ISSN("j-J-FISHERIESCIENCES-COM",		"1307-234X")
    set_ISSN("j-J-FLUID-MECH",				"0022-1120 (print), 1469-7645 (electronic)")
    set_ISSN("j-J-FLUIDS-ENG",				"0098-2202 (print), 1528-901X (electronic)")
    set_ISSN("j-J-FORENSIC-ACCOUNT",			"1524-5586")
    set_ISSN("j-J-FORTH-APPL-RES",			"0738-2022")
    set_ISSN("j-J-FUNCT-PROGRAM",			"0956-7968 (print), 1469-7653 (electronic)")
    set_ISSN("j-J-FRANKLIN-INST",			"0016-0032 (print), 1879-2693 (electronic)")
    set_ISSN("j-J-FUNCT-ANAL",				"0022-1236 (print), 1096-0783 (electronic)")
    set_ISSN("j-J-FUNCT-LOGIC-PROG",			"1544-8878, 1080-5230")
    set_ISSN("j-J-GAMBL-STUD",				"1050-5350 (print), 1573-3602 (electronic)")
    set_ISSN("j-J-GEN-MICROBIOL",			"0022-1287")

    ## Springer Web site has this data, but it disagrees with Library
    ## of Congress and with issn.org data.  It seems that there are
    ## two print ISSNs and two CODENs as well!  The reason is that the
    ## journal had a German/English name for volumes 1 to 20, and an
    ## English/German name for volumes 21 to date, with changes in
    ## CODEN and ISSN values at the name change.  JSTOR has separate
    ## Web sites for the two journals, but Springer combines them into
    ## a single Web site.
    ## set_ISSN("j-J-GEN-PHILOS-SCI",			"0925-4560 (print), 1572-8587 (electronic)")
    set_ISSN("j-J-GEN-PHILOS-SCI",			"0925-4560 (print), 1572-8587 (electronic)")

    set_ISSN("j-J-GEN-PHYSIOL",				"0022-1295 (print), 1540-7748 (electronic)")
    set_ISSN("j-J-GEN-PSYCH",				"0022-1309 (print), 1940-0888 (electronic)")
    set_ISSN("j-J-GENET",				"0022-1333 (print), 0973-7731 (electronic)")
    set_ISSN("j-J-GEOCHEM-EXPLOR",			"0375-6742 (print), 1879-1689 (electronic)")
    set_ISSN("j-J-GEOL",				"0022-1376 (print), 1537-5269 (electronic)")
    set_ISSN("j-J-GEOM-ANAL",				"1050-6926 (print), 1559-002X (electronic)")
    set_ISSN("j-J-GEOM-PHYS",				"0393-0440 (print), 1879-1662 (electronic)")
    set_ISSN("j-J-GEOMAGN-GEOELEC",			"0022-1392 (print), 2185-5765 (electronic)")
    set_ISSN("j-J-GEOPHYS-RES",				"0148-0227 (print), 2156-2202 (electronic)")
    set_ISSN("j-J-GEOPHYS-RES-A",			"0196-6928")
    set_ISSN("j-J-GEOPHYS-RES-D",			"0747-7309")
    set_ISSN("j-J-GEOPHYS-RES-OCEAN",			"2169-9275 (print), 2169-9291 (electronic)")
    set_ISSN("j-J-GEOPHYS-RES-SOLID-EARTH",		"2169-9313 (print), 2169-9356 (electronic)")
    set_ISSN("j-J-GLOBAL-OPT",				"0925-5001 (print), 1573-2916 (electronic)")
    set_ISSN("j-J-GRAPH-TH",				"0364-9024 (print), 1097-0118 (electronic)")
    set_ISSN("j-J-GRAPHICS-TOOLS",			"1086-7651")
    set_ISSN("j-J-GRID-COMP",				"1570-7873 (print), 1572-9184 (electronic)")
    set_ISSN("j-J-HEREDITY",				"0022-1503 (print), 1465-7333 (electronic)")
    set_ISSN("j-J-HEURISTICS",				"1381-1231 (print), 1572-9397 (electronic)")
    set_ISSN("j-J-HIGH-ENERGY-PHYS",			"1126-6708")
    set_ISSN("j-J-HIGH-ENERGY-PHYS-ONLINE",		"1029-8479")
    set_ISSN("j-J-HIST-ASTRON",				"0021-8286 (print), 1753-8556 (electronic)")
    set_ISSN("j-J-HIST-BEHAV-SCI",			"0022-5061 (print), 1520-6696 (electronic)")
    set_ISSN("j-J-HIST-BIOL",				"0022-5010 (print), 1573-0387 (electronic)")
    set_ISSN("j-J-HIST-IDEAS",				"0022-5037 (print), 1086-3222 (electronic)")
    set_ISSN("j-J-HUM-HYPERTENS",			"0950-9240 (print), 1476-5527 (electronic)")
    set_ISSN("j-J-HUM-RESOUR",				"0022-166X (print), 1548-8004 (electronic)")
    set_ISSN("j-J-HUMANIST-MATH",			"2159-8118")
    set_ISSN("j-J-HYDRAULICS-DIV",			"0044-796X")
    set_ISSN("j-J-HYDROL",				"0022-1694 (print), 1879-2707 (electronic)")
    set_ISSN("j-J-IEEE",				"????")
    set_ISSN("j-J-IIEE-JAPAN",				"0285-9831 (print), 1348-0316 (electronic)")
    set_ISSN("j-J-IND-MICROBIOL",			"0169-4146")
    set_ISSN("j-J-INEQUAL-APPL",			"1025-5834")
    set_ISSN("j-J-INF-OPTIM-SCI",			"0252-2667")
    set_ISSN("j-J-INF-PROCESS",				"0387-6101")
    set_ISSN("j-J-INFO-ENG",				"????")
    set_ISSN("j-J-INFO-ORG-SCI",			"1846-3312 (print), 1846-9418 (electronic)")
    set_ISSN("j-J-INFO-PROC-CYBERNETICS-EIK",		"0863-0593")
    set_ISSN("j-J-INFO-SCI-PRINCIPLES-PRACTICE",	"0165-5515 (print), 1741-6485 (electronic)")
    set_ISSN("j-J-INFO-SCI-ENG",			"1016-2364")
    set_ISSN("j-J-INFO-SEC-APPL",			"2214-2126")
    set_ISSN("j-J-INFORMETRICS",			"1751-1577 (print), 1875-5879 (electronic)")
    set_ISSN("j-J-INST-ACTUARIES",			"0020-2681")
    set_ISSN("j-J-INST-ELEC-INFO-COMM-ENG",		"0913-5693")
    set_ISSN("j-J-INST-ELEC-TELECOMM-ENG",		"0377-2063 (print), 0974-780X (electronic)")
    set_ISSN("j-J-INST-ELECTR-ENG",			"0368-2692 (print), 2054-0574 (electronic)")
    set_ISSN("j-J-INST-MATH-APPL",			"0020-2932")
    set_ISSN("j-J-INST-PET",				"0020-3068")
    set_ISSN("j-J-INT-ASSOC-MATH-GEOL",			"0020-5958")
    set_ISSN("j-J-INT-ECON",				"0022-1996 (print), 1873-0353 (electronic)")
    set_ISSN("j-J-INT-FINANC-MANAG-ACCOUNT",		"0954-1314 (print), 1467-646X (electronic)")
    set_ISSN("j-J-INTEGER-SEQ",				"1530-7638")
    set_ISSN("j-J-INTEGRAL-EQU-APPL",			"0897-3962 (print), 1938-2626 (electronic)")
    set_ISSN("j-J-INTELL-MATER-SYST-STRUCT",		"1045-389X (print), 1530-8138 (electronic)")
    set_ISSN("j-J-INTERDISCIP-CYCLE-RES",		"0022-1945")
    set_ISSN("j-J-INTERDISCIP-HIST",			"0022-1953 (print), 1530-9169 (electronic)")
    set_ISSN("j-J-INVERSE-ILL-POSED-PROBL",		"0928-0219 (print), 1569-3945 (electronic)")
    set_ISSN("j-J-INVESTMENT-MANAGE",			"1545-9144 (print), 1545-9152 (electronic)")
    set_ISSN("j-J-IRREPROD-RESULTS",			"0022-2038")
    set_ISSN("j-J-KOREAN-PHYS-SOC",			"0374-4884 (print), 1976-8524 (electronic)")
    set_ISSN("j-J-LAB-CLIN-MED",			"0022-2143 (print), 1532-6543 (electronic)")
    set_ISSN("j-J-LINUX-TECH",				"1527-2761")
    set_ISSN("j-J-LOGIC-ALG-PROG",			"1567-8326 (print), 1873-5940 (electronic)")
    set_ISSN("j-J-LOGIC-LANGUAGE-INFO",			"0925-8531 (print), 1572-9583 (electronic)")
    set_ISSN("j-J-LOGIC-PROG",				"0743-1066 (print), 1873-5789 (electronic)")

    # series 1:  v. 1--44, 1926--1969
    set_ISSN("j-J-LOND-MATH-SOC",			"0024-6107 (print), 1469-7750 (electronic)")

    # series 2:  v. 1--93, 1969--2016 (and onward)
    set_ISSN("j-J-LOND-MATH-SOC-2",			"0024-6107 (print), 1469-7750 (electronic)")

    set_ISSN("j-J-MACH-LEARN-RES",			"1532-4435 (print), 1533-7928 (electronic)")
    set_ISSN("j-J-MAG-RES-A",				"1064-1858 (print), 1096-0864 (electronic)")
    set_ISSN("j-J-MANUFACTURING-SYS",                   "0278-6125 (print), 1878-6642 (electronic)")
    set_ISSN("j-J-MAR-SYST",				"0924-7963 (print), 1879-1573 (electronic)")
    set_ISSN("j-J-MATER",				"0022-2453")
    set_ISSN("j-J-MATER-RES",				"0884-2914")
    set_ISSN("j-J-MATER-SCI",				"0022-2461 (print), 1573-4803 (electronic)")
    set_ISSN("j-J-MATER-SCI-LETT",			"0261-8028 (print), 1573-4811 (electronic)")
    set_ISSN("j-J-MATH-ANAL-APPL",			"0022-247X (print), 1096-0813 (electronic)")
    set_ISSN("j-J-MATH-APPL-ANAL",			"????")
    set_ISSN("j-J-MATH-ARTS",				"1751-3472 (print), 1751-3480 (electronic)")
    set_ISSN("j-J-MATH-BEHAV",				"0732-3123 (print), 1873-8028 (electronic)")
    set_ISSN("j-J-MATH-BIOL",				"0303-6812 (print), 1432-1416 (electronic)")
    set_ISSN("j-J-MATH-CHEM",				"0259-9791 (print), 1572-8897 (electronic)")
    set_ISSN("j-J-MATH-CRYPTOL",			"1862-2976 (print), 1862-2984 (electronic)")
    set_ISSN("j-J-MATH-IMAG-VIS",			"0924-9907 (print), 1573-7683 (electronic)")
    set_ISSN("j-J-MATH-INEQUAL",			"1846-579X (print), 1848-9575 (electronic)")
    set_ISSN("j-J-MATH-KYOTO-UNIV",			"0023-608X")
    set_ISSN("j-J-MATH-MECH",				"0095-9057 (print), 1943-5274 (electronic)")
    set_ISSN("j-J-MATH-PHYS",				"0022-2488")
    set_ISSN("j-J-MATH-PHYS-MIT",			"0097-1421")
    set_ISSN("j-J-MATH-PSYCHOL",			"0022-2496 (print), 1096-0880 (electronic)")
    set_ISSN("j-J-MATH-PURES-APPL",			"0021-7824 (print), 1776-3371 (electronic)")
    set_ISSN("j-J-MATH-RES-APPL",			"2095-2651")
    set_ISSN("j-J-MATH-SCI-ADV-APPL",			"0974-5750")
    set_ISSN("j-J-MATH-SCI-NY-NY",			"1072-3374 (print), 1573-8795 (electronic)")
    set_ISSN("j-J-MATH-SOC-JPN",			"0025-5645")
    set_ISSN("j-J-MEC",					"0021-7832")
    set_ISSN("j-J-MECH-DESIGN",				"0161-8458, 1050-0472")
    set_ISSN("j-J-MECH-MATER-STRUCT",			"1559-3959")
    set_ISSN("j-J-MECH-PHYS-SOLIDS",			"0022-5096 (print), 1873-4782 (electronic)")
    set_ISSN("j-J-MED-CHEM",				"0022-2623 (print), 1520-4804 (electronic)")
    set_ISSN("j-J-MED-SYST",				"0148-5598 (print), 1573-689X (electronic)")
    set_ISSN("j-J-MEMBR-BIOL",				"0022-2631 (print), 1432-1424 (electronic)")
    set_ISSN("j-J-MICROELECTROMECHANICAL-SYSTEMS",	"1057-7157 (print), 1941-0158 (electronic)")
    set_ISSN("j-J-MICROCOMPUT-APPL",			"0745-7138 (print), 1096-374X (electronic)")
    set_ISSN("j-J-MIL-HIST",				"0899-3718 (print), 1543-7795 (electronic)")
    set_ISSN("j-J-MOD-APPL-STAT-METH",			"1538-9472")
    set_ISSN("j-J-MOD-ITAL-STUD",			"1354-571X (print), 1469-9583 (electronic)")
    set_ISSN("j-J-MOD-OPT",				"0950-0340 (print), 1362-3044 (electronic)")
    set_ISSN("j-J-MOD-HIST",				"0022-2801 (print), 1537-5358 (electronic)")
    set_ISSN("j-J-MOL-BIOL",				"0022-2836 (print), 1089-8638 (electronic)")
    set_ISSN("j-J-MOL-EVOL",				"0022-2844 (print), 1432-1432 (electronic)")
    set_ISSN("j-J-MOL-MODEL",				"0948-5023 (print), 1610-2940 (electronic)")
    set_ISSN("j-J-MOL-SPECTROSC",			"0022-2852 (print), 1096-083X (electronic)")
    set_ISSN("j-J-MOL-STRUCT",				"0022-2860 (print), 1872-8014 (electronic)")
    set_ISSN("j-J-MOL-STRUCT-THEOCHEM",			"0166-1280 (print), 1872-7999 (electronic)")
    set_ISSN("j-J-MULTIVAR-ANAL",			"0047-259X (print), 1095-7243 (electronic)")
    set_ISSN("j-J-MUSCLE-RES-CELL-MOTIL",		"0142-4319 (print), 1573-2657 (electronic)")
    set_ISSN("j-J-NANOMATER",				"1687-4110 (print), 1687-4129 (electronic)")
    set_ISSN("j-J-NANOSCI-NANOTECHNOL",			"1533-4880")
    set_ISSN("j-J-NAT-CANCER-INST",			"0027-8874 (print), 1460-2105 (electronic)")
    set_ISSN("j-J-NAT-CANCER-INST-1978-1987",		"0198-0157")
    set_ISSN("j-J-NAT-CANCER-INST-BETHESDA",		"0027-8874", 1)
    set_ISSN("j-J-NAT-CANCER-INST-MONOGR",		"1052-6773 (print), 1745-6614 (electronic)")
    set_ISSN("j-J-NETW-COMPUT-APPL",			"1084-8045 (print), 1095-8592 (electronic)")
    set_ISSN("j-J-NUCL-ENERGY-1954",			"0891-3919 (print), 1878-2051 (electronic)")
    set_ISSN("j-J-NUCL-MATER",				"0022-3115 (print), 1873-4820 (electronic)")
    set_ISSN("j-J-NEURAL-TRANSM-SUPPL",                 "0303-6995")
    set_ISSN("j-J-NEUROBIOL",                           "0022-3034 (print), 1097-4695 (electronic)")
    set_ISSN("j-J-NEUROCHEM",				"0022-3042 (print), 1471-4159 (electronic)")
    set_ISSN("j-J-NEUROCYTOL",				"0300-4864 (print), 1573-7381 (electronic)")
    set_ISSN("j-J-NEUROPHYSIOL",			"0022-3077 (print), 1522-1598 (electronic)")
    set_ISSN("j-J-NEUROSCI",				"0270-6474 (print), 1529-2401 (electronic)")
    set_ISSN("j-J-NEUROSCI-METHODS",			"0165-0270 (print), 1872-678X (electronic)")
    set_ISSN("j-J-NON-CRYST-SOLIDS",			"0022-3093 (print), 1873-4812 (electronic)")
    set_ISSN("j-J-NON-NEWTONIAN-FLUID-MECH",		"0377-0257 (print), 1873-2631 (electronic)")
    set_ISSN("j-J-NONMETALS",				"0090-3477")
    set_ISSN("j-J-NONLINEAR-CONVEX-ANAL",		"1345-4773 (print), 1880-5221 (electronic)")
    set_ISSN("j-J-NONLINEAR-SCI",			"0938-8974 (print), 1432-1467 (electronic)")
    set_ISSN("j-J-NUMBER-THEORY",			"0022-314X (print), 1096-1658 (electronic)")
    set_ISSN("j-J-NUMER-METHODS-COMPUT-APPL",		"1000-3266")
    set_ISSN("j-J-NUTR",                                "0022-3166 (print), 1541-6100 (electronic)")
    set_ISSN("j-J-OCCUP-MED",				"0022-3212, 0096-1736")
    set_ISSN("j-J-OOP",					"0896-8438")
    set_ISSN("j-J-OPEN-RES-SOFT",			"2049-9647")
    set_ISSN("j-J-OPER-MANAGE",				"0272-6963 (print), 1873-1317 (electronic)")
    set_ISSN("j-J-OPER-RES-SOC",			"0160-5682 (print), 1476-9360 (electronic)")
    set_ISSN("j-J-OPER-RES-SOC-JPN",			"0453-4514 (print), 1878-6871 (electronic)")
    set_ISSN("j-J-OPER-RESEARCH",			"????")
    set_ISSN("j-J-OPT-A",				"1464-4258 (print), 1741-3567 (electronic)")
    set_ISSN("j-J-OPT-B",				"1464-4266 (print), 1741-3575 (electronic)")
    ## BAD:	set_ISSN("j-J-OPT-SOC-AM",				"0039-3941")
    set_ISSN("j-J-OPT-SOC-AM",				"0030-3941")	# [04-Jan-2006] corrected
    set_ISSN("j-J-OPT-SOC-AM-1917",			"0093-5433")
    ## BAD: set_ISSN("j-J-OPT-SOC-AM",				"0093-5433")
    ## set_ISSN("j-J-OPT-SOC-AM-A",			"1084-7529, 0740-3232")
    set_ISSN("j-J-OPT-SOC-AM-A",			"1084-7529 (print), 1520-8532 (electronic)")
    ## BAD:	set_ISSN("j-J-OPT-SOC-AM-B",			"0740-3234")
    set_ISSN("j-J-OPT-SOC-AM-B",			"0740-3224 (print), 1520-8540 (electronic)")	# [04-Jan-2006] corrected
    set_ISSN("j-J-OPT-SOC-AM-REV-SCI-INSTRUM",		"0093-4119 (print), 2375-110X (electronic)")
    set_ISSN("j-J-OPT-THEORY-APPL",			"0022-3239 (print), 1573-2878 (electronic)")
    set_ISSN("j-J-ORG-CHEM",				"0022-3263 (print), 1520-6904 (electronic)")
    set_ISSN("j-J-PAR-DIST-COMP",			"0743-7315 (print), 1096-0848 (electronic)")
    set_ISSN("j-J-PARAPSYCHOL",				"0022-3387")
    set_ISSN("j-J-PAS-ADA",				"0735-1232")
    set_ISSN("j-J-PAS-ADA-MOD",				"0735-1232")
    set_ISSN("j-J-PATHOL",				"0022-3417 (print), 1096-9896 (electronic)")
    set_ISSN("j-J-PEACE-RES",				"0022-3433 (print), 1460-3578 (electronic)")
    set_ISSN("j-J-PERIODONTAL-RES",			"0022-3484 (print), 1600-0765 (electronic)")
    set_ISSN("j-J-PET-TECHNOL",				"0022-3522")
    set_ISSN("j-J-PHARMACOL-EXP-THER",			"0022-3565 (print), 1521-0103 (electronic)")
    set_ISSN("j-J-PHILOS",				"0022-362X (print), 1939-8549 (electronic)")
    set_ISSN("j-J-PHILOS-LOGIC",			"0022-3611 (print), 1573-0433 (electronic)")
    set_ISSN("j-J-PHON",				"0095-4470 (print), 1095-8576 (electronic)")
    set_ISSN("j-J-PHYS-A",				"0305-4470 (print), 1361-6447 (electronic)")
    set_ISSN("j-J-PHYS-A-MATH-THEOR",			"1751-8113 (print), 1751-8121 (electronic)")
    set_ISSN("j-J-PHYS-B",				"0953-4075 (print), 1361-6455 (electronic)")
    set_ISSN("j-J-PHYS-B-AT-MOL-OPT-PHYS",		"0953-4075 (print), 1361-6455 (electronic)")
    set_ISSN("j-J-PHYS-C",				"0022-3719")
    set_ISSN("j-J-PHYS-CHEM",				"0022-3654 (print), 1541-5740 (electronic)")
    set_ISSN("j-J-PHYS-CHEM-A",				"1089-5639 (print), 1520-5215 (electronic)")
    set_ISSN("j-J-PHYS-CHEM-B",				"1089-5647 (print), 1520-6106 (electronic)")
    set_ISSN("j-J-PHYS-CHEM-SOLIDS",			"0022-3697 (print), 1879-2553 (electronic)")
    set_ISSN("j-J-PHYS-COLLOQ",				"0449-1947")
    set_ISSN("j-J-PHYS-CONDENS-MATTER",			"0953-8984 (print), 1361-648X (electronic)")
    set_ISSN("j-J-PHYS-CONF-SER",			"1742-6588 (print), 1742-6596 (electronic)")
    set_ISSN("j-J-PHYS-D",				"0022-3727 (print), 1361-6463 (electronic)")

    ## The Library of Congress shows two ISSNs: 0950-1290 for
    ## 1968--1969 and 0022-3735 for 1970--1989, with similar journal
    ## names and publisher; the journal for the earlier ISSN is called
    ## "series 2"
    set_ISSN("j-J-PHYS-E-J-SCIENT-INSTRUM",		"0950-1290")
    set_ISSN("j-J-PHYS-E",				"0022-3735")

    set_ISSN("j-J-PHYS-F",				"0305-4608")
    set_ISSN("j-J-PHYS-IV-COLLOQUE",			"1155-4339 (print), 1764-7177 (electronic)")
    set_ISSN("j-J-PHYS-LETT",				"0302-072X")
    set_ISSN("j-J-PHYS-RADIUM",				"0368-3842")
    set_ISSN("j-J-PHYS-SOC-JAP",			"0031-9015 (print), 1347-4073 (electronic)")
    set_ISSN("j-J-PHYS-THEOR-APPL",			"0368-3893")
    set_ISSN("j-J-PHYSIOL",				"0022-3751 (print), 1469-7793 (electronic)")
    set_ISSN("j-J-PHYSIOLOGIE",				"0021-7948")
    set_ISSN("j-J-PHYSIQUE",				"0302-0738")
    set_ISSN("j-J-PLANKTON-RES",			"0142-7873 (print), 1464-3774 (electronic)")
    set_ISSN("j-J-PLASMA-PHYS",				"0022-3778 (print), 1469-7807 (electronic)")
    set_ISSN("j-J-POLITICS",				"1468-2508")
    set_ISSN("j-J-POLYM-SCI",				"0022-3832 (print), 1542-6238 (electronic)")
    set_ISSN("j-J-POLYM-SCI-POLYM-LETT-ED",		"0360-6384 (print), 1543-0472 (electronic)")
    set_ISSN("j-J-POLYM-SCI-C-POLYM-LETT",		"0887-6258 (print), 1556-0333 (electronic)")
    set_ISSN("j-J-POP-CULT",				"0022-3840 (print), 1540-5931 (electronic)")
    set_ISSN("j-J-PROD-BRAND-MANAG",			"1061-0421")
    set_ISSN("j-J-PROF-ISSUES-ENG",			"0733-9380")
    set_ISSN("j-J-PROF-ISSUES-ENG-EDUC-PRACT",		"1052-3928 (print), 1943-5541 (electronic)")
    set_ISSN("j-J-PROGRAM-LANG",			"0963-9306")
    set_ISSN("j-J-PROTEIN-CHEM",			"0277-8033 (print), 1573-4943 (electronic)")
    set_ISSN("j-J-PSYCHOL",				"0022-3980 (print), 1940-1019 (electronic)")
    set_ISSN("j-J-QUALITY-TECH",			"0022-4065")
    set_ISSN("j-J-QUANT-CRIMINOL",			"0748-4518 (print), 1573-7799 (electronic)")
    set_ISSN("j-J-QUANT-LINGUISTICS",			"0929-6174 (print), 1744-5035 (electronic)")
    set_ISSN("j-J-QUANT-SPECTROSC-RADIAT-TRANSFER",	"0022-4073 (print), 1879-1352 (electronic)")
    set_ISSN("j-J-R-AERONAUT-SOC",			"0368-3931")
    set_ISSN("j-J-R-ASTRON-SOC-CAN",			"0035-872X")
    set_ISSN("j-J-R-COLL-PHYSICANS-LOND",		"0035-8819")
    set_ISSN("j-J-R-SOC-ARTS",				"0035-9114")
    set_ISSN("j-J-R-STAT-SOC",				"0952-8385")
    set_ISSN("j-J-R-STAT-SOC-SER-A-GENERAL",		"0035-9238")
    set_ISSN("j-J-R-STAT-SOC-SER-A-STAT-SOC",		"0035-9238", 1)
    set_ISSN("j-J-R-STAT-SOC-SER-B-METHODOL",		"0035-9246")
    ## set_ISSN("j-J-R-STAT-SOC-SER-C-APPL-STAT",	"0035-9254", 1)
    set_ISSN("j-J-R-STAT-SOC-SER-D-STATISTICIAN",	"0039-0526 (print), 1467-9884 (electronic)")
    set_ISSN("j-R-SOC-OPEN-SCI",			"2054-5703")
    set_ISSN("j-J-RADIAT-RES",				"0449-3060")
    set_ISSN("j-J-RADIOANAL-NUCL-CHEM",			"0236-5731 (print), 1588-2780 (electronic)")
    set_ISSN("j-J-REC-MATH",				"0022-412X")
    set_ISSN("j-J-REG-SCI",				"0022-4146 (print), 1467-9787 (electronic)")
    set_ISSN("j-J-REINE-ANGEW-MATH",			"0075-4102 (print), 1435-5345 (electronic)")
    set_ISSN("j-J-REINF-PLAST-COMPOS",			"0731-6844 (print), 1530-7964 (electronic)")
    set_ISSN("j-J-RELIG-HEALTH",			"0022-4197 (print), 1573-6571 (electronic)")
    set_ISSN("j-J-RES-COMMUN-STUD",			"0378-5939")
    set_ISSN("j-J-RES-COMP-EDU",			"0888-6504")
    set_ISSN("j-J-RES-NATL-BUR-STAND-1934",		"0091-0635")
    set_ISSN("j-J-RES-NATL-BUR-STAND-1977",		"0160-1741")
    set_ISSN("j-J-RES-NATL-BUR-STAND-A",		"0022-4332 (print), 2376-5704 (electronic)")
    set_ISSN("j-J-RES-NATL-BUR-STAND-B",		"0022-4340")
    set_ISSN("j-J-RES-NATL-BUR-STAND-C",		"0022-4316")
    set_ISSN("j-J-RES-NATL-BUR-STAND-D",		"0502-2568")
    set_ISSN("j-J-RES-NATL-INST-STAND-TECHNOL",		"1044-677X (print), 2165-7254 (electronic)")
    set_ISSN("j-J-RES-SCI-TEACH",			"0022-4308 (print), 1098-2736 (electronic)")
    set_ISSN("j-J-RISK-UNCERT",				"0895-5646 (print), 1573-0476 (electronic)")
    set_ISSN("j-J-ROBOTIC-SYS",				"0741-2223 (print), 1097-4563 (electronic)")
    set_ISSN("j-J-SCH-PUBL",				"1198-9742")
    set_ISSN("j-J-SCI-COMPUT",				"0885-7474 (print), 1573-7691 (electronic)")
    set_ISSN("j-J-SCI-EDUC-TECHNOL",			"1059-0145 (print), 1573-1839 (electronic)")
    set_ISSN("j-J-SCI-IND-RES",				"0022-4456 (print), 0975-1084 (electronic)")
    set_ISSN("j-J-SCIENT-INSTR",			"0368-4253, 0950-7671")
    set_ISSN("j-J-SEISMIC-EXPLORATION",			"0963-0651")
    set_ISSN("j-J-SIAM",				"0368-4245")
    set_ISSN("j-J-SIMUL",				"1747-7778 (print), 1747-7786 (electronic)")
    set_ISSN("j-J-SOC-BIOL-STRUCT",			"0140-1750 (print), 1878-2787 (electronic)")
    set_ISSN("j-J-SOC-CHEM-IND-LONDON",			"0368-4075")
    set_ISSN("j-J-SOC-HIST",				"0022-4529 (print), 1527-1897 (electronic)")
    set_ISSN("j-J-SOC-IND-APPL-MATH-A-ON-CONTROL",	"0887-4603")
    set_ISSN("j-J-SOC-INSTR-CONTROL-ENG",		"0453-4662")
    set_ISSN("j-J-SOFTW-EVOL-PROC",			"2047-7473 (print), 2047-7481 (electronic)")
    set_ISSN("j-J-SOFTW-MAINT",				"1040-550X (print), 1096-908X (electronic)")
    set_ISSN("j-J-SOFTW-MAINT-EVOL",			"1532-060X (print), 1532-0618 (electronic)")
    set_ISSN("j-J-SOFTWARE-ALGEBRA-GEOM",		"1948-7916")
    set_ISSN("j-J-SOFTWARE-MAINT",			"1040-550X (print), 1096-908X (electronic)")
    set_ISSN("j-J-SOUND-VIB",				"0022-460X (print), 1095-8568 (electronic)")
    set_ISSN("j-J-SOV-MATH",				"0090-4104 (print), 2376-5798 (electronic)")
    set_ISSN("j-J-STAT-COMPUT-SIMUL",			"0094-9655 (print), 1026-7778 (electronic), 1563-5163")
    set_ISSN("j-J-STAT-MECH-THEORY-EXP",		"1742-5468")
    set_ISSN("j-J-STAT-PHYS",				"0022-4715 (print), 1572-9613 (electronic)")
    set_ISSN("j-J-STAT-PLANN-INFERENCE",		"0378-3758 (print), 1873-1171 (electronic)")
    set_ISSN("j-J-STAT-SOC-LONDON",			"0959-5341")
    set_ISSN("j-J-STAT-SOFT",				"1548-7660")
    set_ISSN("j-J-STAT-THEORY-PRACT",			"1559-8608 (print), 1559-8616 (electronic)")
    set_ISSN("j-J-STRATEG-STUD",			"0140-2390 (print), 1743-937X (electronic)")
    set_ISSN("j-J-STRUCT-BIO",				"1047-8477 (print), 1095-8657 (electronic)")
    set_ISSN("j-J-STRUCT-ENG",				"0970-0137")
    set_ISSN("j-J-STRUCT-ENG-NY",			"0733-9445 (print), 1943-541X (electronic)")
    set_ISSN("j-J-STRUCT-MECH",				"0360-1218")
    set_ISSN("j-J-SUPERCOMPUTING",			"0920-8542 (print), 1573-0484 (electronic)")
    set_ISSN("j-J-SUPERCOND",				"0896-1107 (print), 1572-9605 (electronic)")
    set_ISSN("j-J-SUPERCOND-NOVEL-MAGN",		"1557-1939 (print), 1557-1947 (electronic)")
    set_ISSN("j-J-SYMBOLIC-COMP",			"0747-7171 (print), 1095-855X (electronic)")
    set_ISSN("j-J-SYMBOLIC-LOGIC",			"0022-4812 (print), 1943-5886 (electronic)")
    set_ISSN("j-J-SYS-MANAGEMENT",			"0022-4839")
    set_ISSN("j-J-SYST-ARCH",				"1383-7621 (print), 1873-6165 (electronic)")
    set_ISSN("j-J-SYST-SOFTW",				"0164-1212 (print), 1873-1228 (electronic)")
    set_ISSN("j-J-THEOR-BIOL",				"0022-5193 (print), 1095-8541 (electronic)")
    set_ISSN("j-J-THEOR-PROBAB",			"0894-9840 (print), 1572-9230 (electronic)")
    set_ISSN("j-J-THERM-STRESS",			"0149-5739 (print), 1521-074X (electronic)")
    set_ISSN("j-J-THORAC-CARDIOVASC-SURG",		"0022-5223")
    set_ISSN("j-J-TIME-SER-ANAL",			"0143-9782 (print), 1467-9892 (electronic)")
    set_ISSN("j-J-TIME-SER-ECONOM",			"2194-6507 (print), 1941-1928 (electronic)")
    set_ISSN("j-J-TRANSPORT-ENG",			"0733-947X (print), 1943-5436 (electronic)")
    set_ISSN("j-J-UCS",					"0948-6968")
    set_ISSN("j-J-UNIV-SCI-TECHNOL-CHINA",		"0253-2778")
    set_ISSN("j-J-URBAN-ECON",				"0094-1190 (print), 1095-9068 (electronic)")
    set_ISSN("j-J-VAC-SCI-TECHNOL",			"0022-5355")
    set_ISSN("j-J-VAC-SCI-TECHNOL-A",			"0734-2101 (print), 1520-8559 (electronic)")
    set_ISSN("j-J-VAC-SCI-TECHNOL-B",			"1071-1023 (print), 1520-8567 (electronic)")
    set_ISSN("j-J-VIRO",				"0022-538X")
    set_ISSN("j-J-VIS-COMMUN-IMAGE-REPRESENT",		"1047-3203 (print), 1095-9076 (electronic)")
    set_ISSN("j-J-VIS-COMP-ANIMATION",			"1049-8907 (print), 1099-1778 (electronic)")
    set_ISSN("j-J-VIS-LANG-COMPUTING",			"1045-926X (print), 1095-8533 (electronic)")
    set_ISSN("j-J-VLSI-COMPUT-SYST",			"0733-5644")
    set_ISSN("j-J-VLSI-SIGNAL-PROC",			"0922-5773 (print), 1573-109X (electronic)")
    set_ISSN("j-J-WASH-ACAD-SCI",			"0043-0439")
    set_ISSN("j-JAARBOEKJE-LEIDEN",			"0922-6699")
    set_ISSN("j-JABES",					"1085-7117 (print), 1537-2693 (electronic)")
    set_ISSN("j-JACS",					"0002-7863 (print), 1520-5126 (electronic), 1943-2984")
    set_ISSN("j-JAHRB-BAYER-AKAD-WISS",			"0084-6090")
    set_ISSN("j-JAHRB-KGL-BAYER-AKAD-WISS",		"????")
    set_ISSN("j-JAHRB-RADIOAKT-ELECTRON",		"0368-1289")
    set_ISSN("j-JAHRESBER-DEUTSCH-MATH-VEREIN",		"0012-0456 (print), 1869-7135 (electronic)")
    set_ISSN("j-JAMA",					"0098-7484 (print), 1538-3598 (electronic)")
    set_ISSN("j-JAPAN-J-APPL-PHYS",			"0021-4922 (print), 1347-4065 (electronic)")
    set_ISSN("j-JAPAN-J-INDUST-APPL-MATH",		"0916-7005 (print), 1868-937X (electronic)")
    set_ISSN("j-JAPAN-J-MATH-N-S",			"0289-2316")
    set_ISSN("j-JARATAZA",				"0771-1107")
    set_ISSN("j-JAVA-REPORT",				"1086-4660")
    set_ISSN("j-JCD",					"1527-6805 (print), 1557-9441 (electronic)")
    set_ISSN("j-JCLT",					"1042-5721")
    set_ISSN("j-JDIQ",					"1936-1955")
    set_ISSN("j-JERIC",					"1531-4278")
    set_ISSN("j-JETC",					"1550-4832 (print), 1550-4840 (electronic)")
    set_ISSN("j-JETP-LETT",				"0021-3640 (print), 1090-6487 (electronic)")
    set_ISSN("j-JEWISH-SOCIAL-STUDIES",			"0021-6704 (print), 1527-2028 (electronic)")
    set_ISSN("j-JHAPLTD",				"0270-5214 (print), 1930-0530 (electronic)")
    set_ISSN("j-JIPAM-J-INEQUAL-PURE-APPL-MATH",	"1443-5756")
    set_ISSN("j-JNLAA",					"0129-3281")
    set_ISSN("j-JOCCH",					"1556-4673 (print), 1556-4711 (electronic)")
    set_ISSN("j-JOHN-HOPKINS-MAG",			"0021-7255")
    set_ISSN("j-JOHO-KANRI",				"0021-7298 (print), 1347-1597 (electronic)")
    set_ISSN("j-JOSA-COMM",				"????")
    set_ISSN("j-JOURNAL-Q",				"0196-3031")
    set_ISSN("j-JPN-HEART-J",				"0021-4868")
    set_ISSN("j-JPN-STUD-HIST-SCI",			"0090-0176")
    set_ISSN("j-KERNTECHNIK",				"0004-7198, 0932-3902, 0368-5276")
    set_ISSN("j-KIBERNETIKA",				"0023-1274")
    set_ISSN("j-KNOWL-ENG-REV",				"0269-8889 (print), 1469-8005 (electronic)")
    # NB: http://catalogue.bl.uk says that 0219-1377 is incorrect, and gives 0219-3116 instead
    # however, the publisher uses 0219-1377 at http://www.springerlink.com/content/0219-1377/open/
    set_ISSN("j-KNOWL-INFO-SYS",			"0219-1377")
    set_ISSN("j-KNOWL-ORGAN",				"0943-7444")
    set_ISSN("j-KOMOEDIE",				"????")
    set_ISSN("j-KOREA-INFO-SCI-SOC-REV",		"1015-9908")
    set_ISSN("j-KUNSTLICHE-INTELLIGENZ",		"0933-1875")
    set_ISSN("j-KVANT",					"0905-8893")
    set_ISSN("j-KYBER",					"0023-5946")
    set_ISSN("j-KYBERNETIKA",				"0023-5954")
    set_ISSN("j-LAB-MICROCOMP",				"0262-2955")
    set_ISSN("j-LAN",					"0898-0012, 1069-5621")
    set_ISSN("j-LAN-TIMES",				"1040-5917")
    set_ISSN("j-LANCET",				"0140-6736 (print), 1474-547X (electronic)")
    set_ISSN("j-LANG-SCI",				"0388-0001 (print), 1873-5746 (electronic)")
    set_ISSN("j-LANGMUIR",				"0743-7463 (print), 1520-5827 (electronic)")
    set_ISSN("j-LANGUAGE",				"0097-8507")
    set_ISSN("j-LANGUAGE-INT",				"0923-182X")
    set_ISSN("j-LARGE-SCALE-SYSTEMS",			"0167-420X, 0165-0777")
    set_ISSN("j-LASER-FOCUS-WORLD",			"1043-8092")
    set_ISSN("j-LASER-PART-BEAMS",			"0263-0346 (print), 1469-803X (electronic)")
    set_ISSN("j-LASER-PHYS-LETT",			"1612-2011 (print), 1612-202X (electronic)")
    set_ISSN("j-LATV-MAT-EZEG",				"0321-2270, 0458-8223")
    set_ISSN("j-LAW-COMP-AI",				"????")
    set_ISSN("j-LAW-LIBR-LONDON",			"0023-9275")
    set_ISSN("j-LAW-TECH",				"0278-3916 (print), 1930-3661 (electronic)")
    set_ISSN("j-LAWYERS-PC",				"0740-0942")
    set_ISSN("j-LEAD-EDGE",				"0732-989X")
    set_ISSN("j-LEARN-PUBL",				"0953-1513 (print), 1741-4857 (electronic)")
    set_ISSN("j-LEARNING",				"0090-3167")
    set_ISSN("j-LECT-APPL-MATH",			"0075-8485")
    set_ISSN("j-LECT-NOTES-BIOMATH",			"0341-633X")
    set_ISSN("j-LECT-NOTES-COMP-SCI",			"0302-9743 (print), 1611-3349 (electronic)")
    set_ISSN("j-LECT-NOTES-CONTROL-INF-SCI",		"0170-8643 (print), 1610-7411 (electronic)")
    set_ISSN("j-LECT-NOTES-MATH",			"0075-8434 (print), 1617-9692 (electronic)")
    set_ISSN("j-LECT-NOTES-PHYSICS",			"0075-8450 (print), 1616-6361 (electronic)")
    set_ISSN("j-LECT-NOTES-STAT",			"0930-0325")
    set_ISSN("j-LECT-SER-COMPUT-COMPUT-SCI",		"1573-4196")
    set_ISSN("j-LEGAL-MANAGE",				"1043-7355")
    set_ISSN("j-LEONARDO",				"0024-094X (print), 1530-9282 (electronic)")
    set_ISSN("j-LET-MATH-PHYS",				"0377-9017 (print), 1573-0530 (electronic)")
    set_ISSN("j-LETT-APPL-ENG-SCI",			"0090-6913")
    set_ISSN("j-LETT-NUOVO-CIMENTO",			"0024-1318, 0375-930X, 1827-613X")
    set_ISSN("j-LETT-NUOVO-CIMENTO-2",			"0375-930X (print), 1827-613X (electronic)")
    set_ISSN("j-LIB-COMP-SYS-EQUIP-REVIEW",		"0895-531X")
    set_ISSN("j-LIB-HI-TECH",				"0737-8831")
    set_ISSN("j-LIB-HI-TECH-NEWS",			"0741-9058")
    set_ISSN("j-LIB-RESOURCES-TECH-SERVICES",		"0024-2527 (print), 2159-9610 (electronic)")
    set_ISSN("j-LIB-SYSTEMS",				"0277-0288")
    set_ISSN("j-LIBERTAS-MATH",				"0278-5307")
    set_ISSN("j-LIBR-J",				"0000-0027, 0363-0277")
    set_ISSN("j-LIBR-SOFTW-REV",			"0742-5759")
    set_ISSN("j-LIBR-TRENDS",				"0024-2594 (print), 1559-0682 (electronic)")
    set_ISSN("j-LIFE-SUPPORT-SYST",			"0261-989X")
    set_ISSN("j-LIGHT-SCI-APPL",			"2047-7538 (print), 2095-5545 (electronic)")
    set_ISSN("j-LIGHTWAVE-TECHNOL",			"0733-8724 (print), 1558-2213 (electronic)")
    set_ISSN("j-LIMNOL-OCEANOGR",			"0024-3590")
    set_ISSN("j-LIMNOL-OCEANOGR-LETT",			"2378-2242")
    set_ISSN("j-LIN-AND-MULT-ALGEBRA",			"0308-1087 (print), 1563-5139 (electronic)")
    set_ISSN("j-LIN-MULT-ALGEBRA",			"0308-1087 (print), 1563-5139 (electronic)")
    set_ISSN("j-LINEAR-ALGEBRA-APPL",			"0024-3795 (print), 1873-1856 (electronic)")
    set_ISSN("j-LINUX-J",				"1075-3583 (print), 1938-3827 (electronic)")
    set_ISSN("j-LISP-SYMB-COMPUT",			"0892-4635 (print), 1573-0557 (electronic)")
    set_ISSN("j-LIT-LING-COMP",				"0268-1145 (print), 1477-4615 (electronic)")
    set_ISSN("j-LIVING-REV-RELATIVITY",			"1433-8351")
    set_ISSN("j-LMS-J-COMPUT-MATH",			"1461-1570")
    set_ISSN("j-LOG-INFO-MANAGEMENT",			"0957-6053 (print), 1758-7948 (electronic)")
    set_ISSN("j-LOGIC-PROG-ALP-NEWSLETTER",		"????")
    set_ISSN("j-LOGIN",					"1044-6397 (print), 2169-9364 (electronic)")
    set_ISSN("j-LONDON-REV-BOOKS",			"0260-9592")
    set_ISSN("j-LOPLAS",				"1057-4514 (print), 1557-7384 (electronic)")
    set_ISSN("j-LOS-ALAMOS-SCIENCE",			"0273-7116")
    set_ISSN("j-LOTUS",					"8756-7334") # 8756-7334 = Lotus, ...???; 0076-101X = Lotus (Milano), 0459-8261 = Lotus (Athens, OH)
    set_ISSN("j-M-COMPUTING",                           "1060-7684")
    set_ISSN("j-MAA-STUD-MATH",				"0081-8208")
    set_ISSN("j-MACH-GRAPH-VIS",			"1230-0535")
    set_ISSN("j-MACH-INTELL",				"0076-2032, 0541-6418")
    set_ISSN("j-MACH-TRANSL",				"0922-6567 (print), 1573-0573 (electronic)")
    set_ISSN("j-MACH-VIS-APPL",				"0932-8092 (print), 1432-1769 (electronic)")
    set_ISSN("j-MACHINE-DESIGN",			"0024-9114 (print), 1944-9577 (electronic)")
    set_ISSN("j-MACQUARIE-MATH-REP",			"????")
    set_ISSN("j-MACROMOLECULES",			"0024-9297 (print), 1520-5835 (electronic)")
    set_ISSN("j-MACUSER",				"0884-0997")
    set_ISSN("j-MACWEEK",				"0892-8118")
    set_ISSN("j-MACWORLD",				"0741-8647")
    set_ISSN("j-MAD",					"0024-9319")
    set_ISSN("j-MAGMA",					"0968-5243")
    set_ISSN("j-MAGN-MAGN-MATER",			"0304-8853 (print), 1873-4766 (electronic)")
    set_ISSN("j-MAGN-RESON",				"0022-2364 (print), 1557-8968 (electronic)")
    set_ISSN("j-MAGY-FIZ-FOLY",				"0025-0104")
    set_ISSN("j-MAGY-TUDOMANY",				"????")
    set_ISSN("j-MANAGEMENT-SCIENCE",			"0025-1909 (print), 1526-5501 (electronic)")
    set_ISSN("j-MANAGING-INFO",				"1352-0229")
    set_ISSN("j-MANCHESTER-GUARDIAN",			"0307-756X")
    set_ISSN("j-MANUFACTURING-SYSTEMS",			"0748-948X")
    set_ISSN("j-MANUSCR-MATH",				"0025-2611 (print), 1432-1785 (electronic)")
    set_ISSN("j-MAPLE-NEWS",				"1074-3790")
    set_ISSN("j-MAPLE-TECH-NEWS",			"1061-5733")
    set_ISSN("j-MAR-BIOL-RES",				"1745-1000 (print), 1745-1019 (electronic)")
    set_ISSN("j-MAR-BIOTECHNOL",			"1436-2228 (print), 1436-2236 (electronic)")
    set_ISSN("j-MAR-ECOL-PROG-SER",			"0171-8630 (print), 1616-1599 (electronic)")
    set_ISSN("j-MAR-POLICY",				"0308-597X (print), 1872-9460 (electronic)")
    set_ISSN("j-MARIN-RESOURC-ECON",			"0738-1360 (print), 2334-5985 (electronic)")
    set_ISSN("j-MARKETING-COMP",			"0895-5697")
    set_ISSN("j-MARKUP-LANG",				"1099-6621 (print), 1537-2626 (electronic)")
    set_ISSN("j-MAT-CONTEMP",				"0103-9059")
    set_ISSN("j-MAT-SB",				"1064-5616 (print), 1468-4802 (electronic)")
    set_ISSN("j-MAT-SB-MOSK",				"0368-8666")
    set_ISSN("j-MAT-TERMESZETTUD-ERT",			"????")
    set_ISSN("j-MAT-ZAMETKI",				"0025-567X")
    set_ISSN("j-MATER-RES-SOC-SYMP-PROC",		"0272-9172 (print), 1946-4274 (electronic)")
    set_ISSN("j-MATER-SCI-ENG",				"0025-5416 (print), 1873-4928 (electronic)")
    set_ISSN("j-MATER-SCI-ENG-A",			"0921-5093 (print), 1873-4936 (electronic)")
    set_ISSN("j-MATER-SCI-FORUM",			"0255-5476 (print), 1662-9752 (electronic), 1662-9760")
    set_ISSN("j-MATER-TODAY",				"1369-7021 (print), 1873-4103 (electronic)")
    set_ISSN("j-MATH-ANN",				"0025-5831 (print), 1432-1807 (electronic)")
    set_ISSN("j-MATH-APP-COMP",				"????")
    set_ISSN("j-MATH-BIOSCI",				"0025-5564 (print), 1879-3134 (electronic)")
    set_ISSN("j-MATH-CLUJ",				"0025-5505")
    ## set_ISSN("j-MATH-COMPUT",				"0025-5718 (print), 1088-6842 (electronic)")
    set_ISSN("j-MATH-COMPUT",				"0025-5718 (print), 1088-6842 (electronic)")
    set_ISSN("j-MATH-COMPUT-SCI",			"1661-8270 (print), 1661-8289 (electronic)")
    set_ISSN("j-MATH-COMP-EDU",				"0730-8639")
    set_ISSN("j-MATH-COMP-MODELLING",			"0895-7177 (print), 1872-9479 (electronic)")
    set_ISSN("j-MATH-COMP-SIM",				"0378-4754 (print), 1872-7166 (electronic)")
    set_ISSN("j-MATH-CONTROL-SIGNALS-SYST",		"0932-4194 (print), 1435-568X (electronic)")
    set_ISSN("j-MATH-GAZ",				"0025-5572 (print), 2056-6328 (electronic)")
    set_ISSN("j-MATH-GEOL",				"0882-8121 (print), 1573-8868 (electronic)")
    set_ISSN("j-MATH-GEOSCI",				"1874-8953 (print), 1874-8961 (electronic)")
    set_ISSN("j-MATH-INEQUAL-APPL",			"1331-4343 (print), 1848-9966 (electronic)")
    set_ISSN("j-MATH-INTEL",				"0343-6993 (print), 1866-7414 (electronic)")
    set_ISSN("j-MATH-JAPON",				"0025-5513")
    set_ISSN("j-MATH-LOGIC-QUART",			"0942-5616 (print), 1521-3870 (electronic)")
    set_ISSN("j-MATH-MAG",				"0025-570X")
    set_ISSN("j-MATH-MECH-COMPLEX-SYST",		"2325-3444 (print), 2326-7186 (electronic)")
    set_ISSN("j-MATH-MECH-SOLIDS",			"1081-2865 (print), 1741-3028 (electronic)")
    set_ISSN("j-MATH-MED-BIOL",				"1477-8599 (print), 1477-8602 (electronic)")
    set_ISSN("j-MATH-METHODS-APPL-SCI",			"0170-4214 (print), 1099-1476 (electronic)")
    set_ISSN("j-MATH-METHODS-STAT",			"1066-5307 (print), 1934-8045 (electronic)")
    set_ISSN("j-MATH-MODEL",				"1048-5082")
    set_ISSN("j-MATH-MODEL-NUM-ANA",			"0764-583X (print), 1290-3841 (electronic)")
    set_ISSN("j-MATH-MODELS-METHODS-APPL-SCI",		"0218-2025 (print), 1793-6314 (electronic)")
    set_ISSN("j-MATH-NACHR",				"0025-584X")
    set_ISSN("j-MATH-NATURWISS-UNTERR",			"0025-5866")
    set_ISSN("j-MATH-NOTES",				"1067-9073")
    set_ISSN("j-MATH-NOTES-ACAD-SCI-USSR",		"0001-4346 (print), 1573-8876 (electronic)")
    set_ISSN("j-MATH-OP-RES",				"0364-765X (print), 1526-5471 (electronic)")
    set_ISSN("j-MATH-OPERATIONSFORSCH-STAT",		"0047-6277")
    set_ISSN("j-MATH-PHYS-SEMESTERBERICHTE",		"0025-5823, 0340-4897")
    set_ISSN("j-MATH-PHYSICS",				"????")
    set_ISSN("j-MATH-PROC-CAMB-PHILOS-SOC",		"0305-0041 (print), 1469-8064 (electronic)")
    set_ISSN("j-MATH-PROG",				"0025-5610")
    set_ISSN("j-MATH-PROG-SOC-COAL-NEWSLETTER",		"????")
    set_ISSN("j-MATH-PROG-STUDY",			"0303-3929")
    set_ISSN("j-MATH-PROGRAM-COMPUT",			"1867-2949 (print), 1867-2957 (electronic)")
    set_ISSN("j-MATH-RECR-ESSAYS",			"????")
    set_ISSN("j-MATH-RES-LETT",				"1073-2780 (print), 1945-001X (electronic)")
    set_ISSN("j-MATH-REV",				"0025-5629")
    set_ISSN("j-MATH-SCAND",				"0025-5521 (print), 1903-1807 (electronic)")
    set_ISSN("j-MATH-SCHULE",				"0323-5114")
    set_ISSN("j-MATH-SCI",				"0312-3685 (print), 1475-6080 (electronic)")
    set_ISSN("j-MATH-SCI-ENG",				"0076-5392")
    set_ISSN("j-MATH-SEMESTERBER",			"0720-728X (print), 1432-1815 (electronic)")
    set_ISSN("j-MATH-SLOVACA",				"0139-9918 (print), 1337-2211 (electronic)")
    set_ISSN("j-MATH-SOC-SCI",				"0165-4896 (print), 1879-3118 (electronic)")
    set_ISSN("j-MATH-STOS",				"????")
    set_ISSN("j-MATH-STUDENT",				"0025-5742")
    set_ISSN("j-MATH-SYS-THEORY",			"0025-5661")
    set_ISSN("j-MATH-TABLES-OTHER-AIDS-COMPUT",		"0891-6837")
    set_ISSN("j-MATH-TEACH",				"0025-5769 (print), 2330-0582 (electronic)")
    set_ISSN("j-MATH-TODAY",				"1361-2042")
    set_ISSN("j-MATH-USSR-IZV",				"0025-5726 (print), 2169-5075 (electronic)")
    set_ISSN("j-MATH-USSR-SBORNIK",			"0025-5734")
    set_ISSN("j-MATH-Z",				"0025-5874 (print), 1432-1823 (electronic)")
    set_ISSN("j-MATHEMATECH",				"1354-4314")
    set_ISSN("j-MATHEMATICA-EDUC",			"1065-2965")
    set_ISSN("j-MATHEMATICA-J",				"1047-5974 (print), 1097-1610 (electronic)")
    set_ISSN("j-MATHEMATIKA",				"0025-5793")
    set_ISSN("j-MATHWORKS-NEWSLETTER",			"????")
    set_ISSN("j-MAYFLOWER-QUARTERLY",			"0148-5032")
    set_ISSN("j-MAYO-CLIN-PROC",			"0025-6196 (print), 1942-5546 (electronic)")
    set_ISSN("j-MC",					"0720-4442, 0941-777X , 0943-5409")
    set_ISSN("j-MD-COMPUTING-CMP",			"0724-6811")
    set_ISSN("j-MDMV",					"0942-5977, 0947-4471")
    set_ISSN("j-MEASUREMENT",				"0263-2241 (print), 1873-412X (electronic)")
    set_ISSN("j-MEASUREMENT-CONTROL",			"0020-2940")
    set_ISSN("j-MEASUREMENTS-CONTROL",			"0148-0057")
    set_ISSN("j-MECCANICA-MILAN",			"0025-6455 (print), 1572-9648 (electronic)")
    set_ISSN("j-MECH-AGEING-DEV",			"0047-6374 (print), 1872-6216 (electronic)")
    set_ISSN("j-MECH-DEVEL",				"0925-4773 (print), 1872-6356 (electronic)")
    set_ISSN("j-MECH-ENG",				"0025-6501 (print), 1943-5649 (electronic)")
    set_ISSN("j-MECH-ENG-BULL",				"0379-5527")
    set_ISSN("j-MECH-MATER",				"0167-6636 (print), 1872-7743 (electronic)")
    set_ISSN("j-MECH-RESEARCH-COMM",			"0093-6413 (print), 1873-3972 (electronic)")
    set_ISSN("j-MECH-SOLIDS",				"0025-6544 (print), 1934-7936 (electronic)")
    set_ISSN("j-MECHAN-STRUCT-MACH",			"0890-5452 (print), 1525-612X (electronic)")
    set_ISSN("j-MED-DECIS-MAKING",			"0272-989X (print), 1552-681X (electronic)")
    set_ISSN("j-MED-ELECT",				"0149-9734")
    set_ISSN("j-MED-BIOL-ENG-COMPUT",			"0140-0118 (print), 1741-0444 (electronic)")
    set_ISSN("j-MED-HYPOTH",				"0306-9877 (print), 1532-2777 (electronic)")
    set_ISSN("j-MED-INSTRUM",				"0090-6689")
    set_ISSN("j-MED-J-AUST",				"0025-729X (print), 1326-5377 (electronic)")
    set_ISSN("j-MED-OPIN-REV",				"????")
    set_ISSN("j-MED-PHYS",				"0094-2405 (print), 1522-8541 (electronic)")
    set_ISSN("j-MED-REF-SERV-Q",			"0276-3869 (print), 1540-9597 (electronic)")
    set_ISSN("j-MED-WAR",				"0748-8009 (print), 2378-9980 (electronic)")
    set_ISSN("j-MEDIA-HIST",				"1368-8804 (print), 1469-9729 (electronic)")
    set_ISSN("j-MEDIA-INF-AUST",			"0312-9616")
    set_ISSN("j-MEDIA-METHODS",				"0025-6897")
    set_ISSN("j-MEDIAWEEK",				"1055-176X")
    set_ISSN("j-MEDICINE",				"0025-7974 (print), 1536-5964 (electronic)")
    set_ISSN("j-MEM-AMS",				"0065-9266 (print), 1947-6221 (electronic)")
    set_ISSN("j-MEM-COG",				"0090-502X (print), 1532-5946 (electronic)")
    set_ISSN("j-MEM-FAC-SCI-KYUSHU-UNIV",		"????")
    set_ISSN("j-MEM-FAC-SCI-KYUSHU-UNIV-A",		"0373-6385 (print), 1883-2172 (electronic)")
    set_ISSN("j-MEM-PROC-MANCHESTER-LIT-PHILOS-SOC",	"0076-3721")
    set_ISSN("j-METAB-CLIN-EXP",			"0026-0495 (print), 1532-8600 (electronic)")
    set_ISSN("j-METALL-TRANS",				"0026-086X")
    set_ISSN("j-METALL-MATER-TRANS-A",			"1073-5623 (print), 1543-1940 (electronic)")
    set_ISSN("j-METALL-TRANS-A-PHYS-METALL-MATER-SCI",	"0360-2133")
    set_ISSN("j-METALLWIRTSCH-METALLWISS-METALLTECH",	"0368-9581")
    set_ISSN("j-METAPHILOSOPHY",			"0026-1068 (print), 1467-9973 (electronic)")
    set_ISSN("j-METH-INFO-MED",				"0026-1270")
    set_ISSN("j-METH-MOL-BIOL",				"0097-0816")
    set_ISSN("j-METH-MOL-BIOL-CLIFTON",			"1064-3745 (print), 1940-6029 (electronic)")
    set_ISSN("j-METHODS-APPL-ANAL",			"1073-2772 (print), 1945-0001 (electronic)")
    set_ISSN("j-METHODS-CELL-BIOL",			"0091-679X")
    set_ISSN("j-METHODS-ENZYMOL",			"0076-6879")
    set_ISSN("j-METRIKA",				"0026-1335 (print), 1435-926X (electronic)")
    set_ISSN("j-METRON",				"0026-1424 (print), 2281-695X (electronic)")
    set_ISSN("j-MICH-MATH-J",				"0026-2285 (print), 1945-2365 (electronic)")
    set_ISSN("j-MICRO-CORNUCOPIA",			"0747-587X")
    set_ISSN("j-MICROBIOL",				"1350-0872 (print), 1465-2080 (electronic)")
    set_ISSN("j-MICROBIOL-REV",				"0146-0749 (print), 1070-6275 (electronic)")
    set_ISSN("j-MICROBIOL-SCI",				"0265-1351")
    set_ISSN("j-MICROBIOLOGICA",			"0391-5352")
    set_ISSN("j-MICROBIOS",				"0026-2633")
    set_ISSN("j-MICROCHIM-ACTA",			"0026-3672 (print), 1436-5073 (electronic)")
    set_ISSN("j-MICROCOMP-CIVIL-ENG",			"0885-9507")
    set_ISSN("j-MICROCOMPUT-APPL",			"0820-0750")
    set_ISSN("j-MICROCOMPUT-INF-MANAGE",		"0742-2342")
    set_ISSN("j-MICROELECT-RELIABILITY",		"0026-2714 (print), 1872-941X (electronic)")
    set_ISSN("j-MICROELECT-J",				"0026-2692 (print), 1879-2391 (electronic)")
    set_ISSN("j-MICROPROC-MICROPROG",			"0165-6074 (print), 1878-7061 (electronic)")
    set_ISSN("j-MICROPROC-MICROSYS",			"0141-9331 (print), 1872-9436 (electronic)")
    set_ISSN("j-MICROPROC-REP",				"0899-9341 (print), 1943-5231 (electronic)")
    set_ISSN("j-MICROSC-RES-TECH",			"1059-910X (print), 1097-0029 (electronic)")
    set_ISSN("j-MICROSOFT-SYS-J",			"0889-9932")
    set_ISSN("j-MICROSYS-TECH",				"0946-7076 (print), 1432-1858 (electronic)")
    set_ISSN("j-MICROW-OPT-TECHNOL-LETT",		"0895-2477 (print), 1098-2760 (electronic)")
    set_ISSN("j-MIDDLE-EAST-STUDIES-ASSOC-BULL",	"0026-3184")
    set_ISSN("j-MIDWEST-STUD-PHILOS",			"0363-6550 (print), 1475-4975 (electronic)")
    set_ISSN("j-MIENTRAS-TANTO",			"0210-8259 (print), 2014-7317 (electronic)")
    set_ISSN("j-MIKROBIOLOGIIA",                        "0026-3656")
    set_ISSN("j-MIKROLAN",				"????")
    set_ISSN("j-MIND",					"0026-4423 (print), 1460-2113 (electronic)")
    set_ISSN("j-MINDS-MACH",				"0924-6495 (print), 1572-8641 (electronic)")
    set_ISSN("j-MINERALS-BASEL",			"2075-163X")
    set_ISSN("j-MINERVA-WASHINGTON",			"0026-4695 (print), 1573-1871 (electronic)")
    set_ISSN("j-MINI-MICRO-SYSTEMS",			"1000-1220")
    set_ISSN("j-MINI-REV-MED-CHEM",			"1389-5575 (print), 1875-5607 (electronic)")
    set_ISSN("j-MITT-MATH-GES-HAMBURG",			"0340-4358")
    set_ISSN("j-MMT",					"0541-4180")
    set_ISSN("j-MOD-HEALTHC",				"0093-7061, 0160-7480")
    set_ISSN("j-MOD-INTELL-HIST",			"1479-2443 (print), 1479-2451 (electronic)")
    set_ISSN("j-MOD-ITALY",				"1353-2944 (print), 1469-9877 (electronic)")
    set_ISSN("j-MOD-PHYS-LETT-A",			"0217-7323 (print), 1793-6632 (electronic)")
    set_ISSN("j-MOD-PHYS-LETT-B",			"0217-9849 (print), 1793-6640 (electronic)")
    set_ISSN("j-MOD-PLAST",				"0026-8275")
    set_ISSN("j-MODEL-SIMUL",				"0198-0092")
    set_ISSN("j-MODEL-SIMUL-SCI-ENG",			"0965-0393 (print), 1361-651X (electronic)")
    set_ISSN("j-MODELLING-MEASUREMENT-CONTROL-B",	"0761-2516")
    set_ISSN("j-MOL-BIO-CELL",				"1059-1524 (print), 1939-4586 (electronic)")
    set_ISSN("j-MOL-BIO-EVOL",				"0737-4038 (print), 1537-1719 (electronic)")
    set_ISSN("j-MOL-BIOCHEM-PARASITOL",			"0166-6851 (print), 1872-9428 (electronic)")
    set_ISSN("j-MOL-BIOL",				"0026-8933 (print), 1608-3245 (electronic)")
    set_ISSN("j-MOL-BIOSYST",				"1742-2051 (print), 1742-206X (electronic)")
    set_ISSN("j-MOL-CELL-BIOCHEM",			"0300-8177 (print), 1573-4919 (electronic)")
    set_ISSN("j-MOL-CELL-BIOL",				"0270-7306")
    set_ISSN("j-MOL-CELL-CARDIOL",			"0022-2828 (print), 1095-8584 (electronic)")
    set_ISSN("j-MOL-CELL-ENDOCRINOL",			"0303-7207 (print), 1872-8057 (electronic)")
    set_ISSN("j-MOL-ECOL",				"0962-1083 (print), 1365-294X (electronic)")
    set_ISSN("j-MOL-ENDOCRINOL",                        "0888-8809 (print), 1944-9917 (electronic)")
    set_ISSN("j-MOL-GENERAL-GENET",			"0026-8925 (print), 1432-1874 (electronic)")
    set_ISSN("j-MOL-INF",				"1868-1743 (print), 1868-1751 (electronic)")
    set_ISSN("j-MOL-MICROBIOL",				"0950-382X (print), 1365-2958 (electronic)")
    set_ISSN("j-MOL-PHARMACOL",				"0026-895X (print), 1521-0111 (electronic)")
    set_ISSN("j-MOL-PHYLOGENET-EVOL",			"1055-7903 (print), 1095-9513 (electronic)")
    set_ISSN("j-MOL-PHYS",				"0026-8976 (print), 1362-3028 (electronic)")
    set_ISSN("j-MOL-PSYCHIATRY",			"1359-4184 (print), 1476-5578 (electronic)")
    set_ISSN("j-MOL-SIM",				"0892-7022 (print), 1029-0435 (electronic)")
    set_ISSN("j-MOLECULES",				"1420-3049")
    set_ISSN("j-MON-BER-DTSCH-AKAD-WISS-BERL",		"0011-9814")
    set_ISSN("j-MONAT-MATH",				"0026-9255 (print), 1436-5081 (electronic)")
    set_ISSN("j-MONAT-MATH-PHYSIK",			"????")
    set_ISSN("j-MONIST",				"0026-9662 (print), 2153-3601 (electronic)")
    set_ISSN("j-MONTE-CARLO-METHODS-APPL",		"0929-9629 (print), 1569-3961 (electronic)")
    set_ISSN("j-MONTHLY-NOT-ASTRON-SOC-SOUTH-AFRICA",	"0024-8266 (print), 2224-8366 (electronic)")
    set_ISSN("j-MONTHLY-NOT-ROY-ASTRON-SOC",		"0035-8711 (print), 1365-2966 (electronic)")
    set_ISSN("j-MONTHLY-WEATHER-REVIEW",		"0027-0644")
    set_ISSN("j-MOSCOW-UNIV-MECH-BULL",			"0027-1330 (print), 1934-8452 (electronic)")
    set_ISSN("j-MOTHER-JONES",				"0362-8841")
    set_ISSN("j-MTNRCW",				"????")
    set_ISSN("j-MULTIBODY-SYST-DYN",			"1384-5640 (print), 1573-272X (electronic)")
    set_ISSN("j-MULTIMEDIA-SYSTEMS",			"0942-4962 (print), 1432-1882 (electronic)")
    set_ISSN("j-MULTIMEDIA-TOOLS-APPLIC",		"1380-7501 (print), 1573-7721 (electronic)")
    set_ISSN("j-MULTISCALE-MODELING-SIMUL",		"1540-3459 (print), 1540-3467 (electronic)")
    set_ISSN("j-MULTIVARIATE-BEHAV-RES",		"0027-3171 (print), 1532-7906 (electronic)")
    set_ISSN("j-MUSIC",					"0027-4208")
    set_ISSN("j-MUTAT-RES",				"0027-5107 (print), 1873-135X (electronic)")
    set_ISSN("j-MUTAT-RES-GENETIC-TOXIC-TEST-BIOMON-ENV-OCC-EXPOSURE","0165-1218")
    set_ISSN("j-N-AM-J-FISH-MANAG",			"0275-5947 (print), 1548-8675 (electronic)")
    set_ISSN("j-N-I-A-CR",				"????")
    set_ISSN("j-NA-DIGEST",				"????")
    set_ISSN("j-NACH-DOK",				"0027-7436")
    set_ISSN("j-NACH-ELEK",				"0323-4657")
    set_ISSN("j-NACHR-AKAD-WISS-GOTTINGEN-MATH-PHYS-KL-II",	"0065-5295")
    set_ISSN("j-NACHR-CHEM",				"1439-9598 (print), 1868-0054 (electronic)")
    set_ISSN("j-NACHR-CHEM-TECH",			"0027-738X")
    set_ISSN("j-NACHR-CHEM-TECH-LAB",			"0341-5163")
    set_ISSN("j-NACHR-GES-WISS-GOETTINGEN-MATH-PHYS-KL","0369-6650")
    set_ISSN("j-NAG-NEWSLETTER",			"0269-0780")
    set_ISSN("j-NAMS",					"0002-9920 (print), 1088-9477 (electronic)")
    set_ISSN("j-NANO-LETT",				"1530-6984 (print), 1530-6992 (electronic)")
    set_ISSN("j-NANOBIOL",				"0958-3165")
    set_ISSN("j-NANOTECHNOL",				"0957-4484 (print), 1361-6528 (electronic)")
    set_ISSN("j-NASA-CONF-PUBL",			"0191-7811")
    set_ISSN("j-NASA-TECH-BRIEFS",			"0145-319X")
    set_ISSN("j-NAT-COMPUT",				"1567-7818 (print), 1572-9796 (electronic)")
    set_ISSN("j-NAT-J",					"0360-4217 (print), 1943-4553 (electronic)")
    set_ISSN("j-NAT-INTEREST",				"0884-9382 (print), 1938-1573 (electronic)")
    set_ISSN("j-NAT-LAMPOON",				"0027-9587")
    set_ISSN("j-NAT-PHILOS",				"0547-9592")
    set_ISSN("j-NAT-RESOUR-MODEL",			"0890-8575 (print), 1939-7445 (electronic)")
    set_ISSN("j-NAT-REV",				"0028-0038")
    set_ISSN("j-NAT-VERDEN",				"0028-0895")
    set_ISSN("j-NAT-TECH-REP",				"0028-0291")
    set_ISSN("j-NATION",				"0027-8378")
    set_ISSN("j-NATL-BUR-STAND-CIRC",			"0096-9648")
    set_ISSN("j-NATL-CONF-PUBL-INST-ENG-AUST",		"0313-6922")
    set_ISSN("j-NATL-DEF-WASHINGTON",			"0092-1491 (print), 1943-3115 (electronic)")
    set_ISSN("j-NATL-SCI-REV",				"2053-714X (print), 2095-5138 (electronic)")
    set_ISSN("j-NATO-ASI-B",				"0258-1221")
    set_ISSN("j-NATO-ASI-F",				"0258-1248")
    set_ISSN("j-NATUR-SCI-J-XIANGTAN-UNIV",		"1000-5900")
    set_ISSN("j-NATURE",				"0028-0836 (print), 1476-4687 (electronic)")
    set_ISSN("j-NATURE-BIOTECH",			"1087-0156 (print), 1546-1696 (electronic)")
    set_ISSN("j-NATURE-CELL-BIOL",			"1465-7392 (print), 1476-4679 (electronic)")
    set_ISSN("j-NATURE-CHEM",				"1755-4330 (print), 1755-4349 (electronic)")
    set_ISSN("j-NATURE-COMMUN",				"2041-1723 (electronic)") # no print form!
    set_ISSN("j-NATURE-GENETICS",			"1061-4036 (print), 1546-1718 (electronic)")
    set_ISSN("j-NATURE-GEOSCI",				"1752-0894 (print), 1752-0908 (electronic)")
    set_ISSN("j-NATURE-MATER",				"1476-1122 (print), 1476-4660 (electronic)")
    set_ISSN("j-NATURE-METHODS",			"1548-7091 (print), 1548-7105 (electronic)")
    set_ISSN("j-NATURE-NANOTECHNOL",			"1748-3387 (print), 1748-3395 (electronic)")
    set_ISSN("j-NATURE-NEW-BIOL",			"0369-4887, 0090-0028")
    set_ISSN("j-NATURE-PHOTONICS",			"1749-4885 (print), 1749-4893 (electronic)")
    set_ISSN("j-NATURE-PHYS-SCI",			"0300-8746 (print), 2058-1106 (electronic)")
    set_ISSN("j-NATURE-PHYSICS",			"1745-2473 (print), 1745-2481 (electronic)")
    set_ISSN("j-NATURE-REV-CARDIOL",			"1759-5002 (print), 1759-5010 (electronic)")
    set_ISSN("j-NATURE-REV-GENET",			"1471-0056 (print), 1471-0064 (electronic)")
    set_ISSN("j-NATURE-REV-MOL-CELL-BIOL",		"1471-0072 (print), 1471-0080 (electronic)")
    set_ISSN("j-NATURE-REV-NEUROSCI",			"1471-003X (print), 1471-0048 (electronic)")
    set_ISSN("j-NATURE-REV-PHYS",			"2522-5820")
    set_ISSN("j-NATURWISS-RUNDSCH",			"0028-1050")
    set_ISSN("j-NATURWISSENSCHAFTEN",			"0028-1042 (print), 1432-1904 (electronic)")
    set_ISSN("j-NEC-RES-DEV",				"0048-0436")
    set_ISSN("j-NEC-TECH-J",				"0285-4139")
    set_ISSN("j-NED-TIJDSCHR-NATUURKD",			"0926-4264")
    set_ISSN("j-NEDERLAND-ARCH",			"????")
    set_ISSN("j-NEDERLAND-KUNST-JAARBOEK",		"0169-6726")
    set_ISSN("j-NETW-HETEROG-MEDIA",			"1556-1801 (print), 1556-181X (electronic)")
    set_ISSN("j-NETWORK-COMPUTING",			"1046-4468")
    set_ISSN("j-NETWORK-SECURITY",			"1353-4858 (print), 1872-9371 (electronic)")
    set_ISSN("j-NETWORK-MANAGE",			"1052-049X")
    set_ISSN("j-NETWORK-WEEK",                          "")
    set_ISSN("j-NETWORK-WORLD",				"0887-7661 (print), 1944-7655 (electronic)")
    set_ISSN("j-NETWORKS",				"0028-3045 (print), 1097-0037 (electronic)")
    set_ISSN("j-NEURAL-COMP",				"0899-7667 (print), 1530-888X (electronic)")
    set_ISSN("j-NEURAL-NETWORKS",			"0893-6080 (print), 1879-2782 (electronic)")
    set_ISSN("j-NEURAL-PAR-SCI-COMPUT",			"1061-5369")
    set_ISSN("j-NEUROCOMPUTING",			"0925-2312 (print), 1872-8286 (electronic)")
    set_ISSN("j-NEUROIMAGE",				"1053-8119 (print), 1095-9572 (electronic)")
    set_ISSN("j-NEUROCHEM-RES",				"0364-3190 (print), 1573-6903 (electronic)")
    set_ISSN("j-NEUROREPORT",                           "0959-4965 (print), 1473-558X (electronic)")
    set_ISSN("j-NEUROSCI-LETT",				"0304-3940 (print), 1872-7972 (electronic)")
    set_ISSN("j-NEUROSCI-LETT-SUPPL",			"0167-6253 (print), 1872-8316 (electronic)")
    set_ISSN("j-NEUROSCIENCE",				"0306-4522 (print), 1873-7544 (electronic)")
    set_ISSN("j-NEUROSURGERY",				"0148-396X")
    set_ISSN("j-NEW-ASTRON",				"1384-1076 (print), 1384-1092 (electronic)")
    set_ISSN("j-NEW-BIO",				"1043-4674")
    set_ISSN("j-NEW-BLACKFRIARS",			"0028-4289 (print), 1741-2005 (electronic)")
    set_ISSN("j-NEW-ENGLAND-HIST",			"0028-4785")
    set_ISSN("j-NEW-ENGLAND-J-MED",			"0028-4793 (print), 1533-4406 (electronic)")
    set_ISSN("j-NEW-GEN-COMP",				"0288-3635 (print), 1882-7055 (electronic)")
    set_ISSN("j-NEW-IDEAS-PSYCHOL",			"0732-118X (print), 1873-3522 (electronic)")
    set_ISSN("j-NEW-J-PHYS",				"1367-2630")
    set_ISSN("j-NEW-HUNG-Q",				"0028-5390")
    set_ISSN("j-NEW-ORLEANS-REV",			"0028-6400")
    set_ISSN("j-NEW-PERSPECT-Q",			"0893-7850 (print), 1540-5842 (electronic)")
    set_ISSN("j-NEW-REPUBLIC",				"0028-6583")
    ## set_ISSN("j-NEW-SCIENTIST",				"0262-4079, 0028-6664")
    set_ISSN("j-NEW-SCIENTIST",				"0262-4079 (print), 1364-8500 (electronic)")
    set_ISSN("j-NEW-STATESMAN-SOC",			"0954-2361")
    set_ISSN("j-NEW-TECH-WORK-EMPLOYMENT",		"0268-1072 (print), 1468-005X (electronic)")
    set_ISSN("j-NEW-YORK",				"0028-7369")
    set_ISSN("j-NEW-YORK-REV-BOOKS",			"0028-7504 (print), 1944-7744 (electronic)")
    set_ISSN("j-NEW-YORK-TIMES-BOOK-REVIEW",		"0028-7806")
    set_ISSN("j-NEW-YORK-TIMES-MAGAZINE",		"0362-1308")
    set_ISSN("j-NEW-YORK-TIMES-SYNDICATE",		"????")
    set_ISSN("j-NEW-YORKER",				"0028-792X")
    set_ISSN("j-NEW-ZEALAND-J-MATH",			"1171-6096 (print), 1179-4984 (electronic)")
    set_ISSN("j-NEW-ZEALAND-MATH-MAG",			"0549-0510")
    set_ISSN("j-NEW-ZEALAND-SCI-REV",			"0028-8667")
    set_ISSN("j-NEWS-3X-400",				"1040-6093")
    set_ISSN("j-NEWS-PHYSIOL-SCI",			"0886-1714 (print), 1522-161X (electronic)")
    set_ISSN("j-NEWSWEEK",				"0028-9604")
    set_ISSN("j-NEWSL-SCI-TECHNOL-HUMAN-VALUES",	"2328-2436")
    set_ISSN("j-NIEMAN-REP",				"0028-9817")
    set_ISSN("j-NIEUW-ARCHIEF-WISKUNDE",		"0028-9825")
    set_ISSN("j-NIEUW-ARCHIEF-WISKUNDE-4",		"0028-9825")
    set_ISSN("j-NIEUW-ARCHIEF-WISKUNDE-5",		"0028-9825")
    set_ISSN("j-NIKKEI-ELECTRONICS",			"0385-1680")
    set_ISSN("j-NIST-SPEC-PUBL",			"1048-776X")
    set_ISSN("j-NONLINEAR-ANAL",			"0362-546X (print), 1873-5215 (electronic)")
    set_ISSN("j-NONLINEAR-DYN",				"0924-090X (print), 1573-269X (electronic)")
    set_ISSN("j-NONLINEAR-THEORY-APPL",			"2185-4106")
    set_ISSN("j-NONLINEARITY",				"0951-7715 (print), 1361-6544 (electronic)")
    set_ISSN("j-NORDIC-J-COMPUT",			"1236-6064")
    set_ISSN("j-NORDISK-MATH-TIDSKR",			"0029-1412")
    set_ISSN("j-NORMAT",				"0801-3500") # 0029-1412 == N.M.T., 0801-3500 == Normat
    set_ISSN("j-NORSK-MAT-TIDSSKR",			"2387-2187")
    set_ISSN("j-NOTES-CRAS",				"????")
    set_ISSN("j-NOTES-MLA",				"0027-4380 (print), 1534-150X (electronic)")
    set_ISSN("j-NOTES-REC-R-SOC-LOND",			"0035-9149 (print), 1743-0178 (electronic)")
    set_ISSN("j-NOTRE-DAME-J-FORM-LOG",			"0029-4527 (print), 1939-0726 (electronic)")
    set_ISSN("j-NOUS",					"0029-4624 (print), 1468-0068 (electronic)")
    set_ISSN("j-NOUV-REV-FR-HEMATOL",			"0029-4810")
    set_ISSN("j-NRL",					"0894-069X (print), 1520-6750 (electronic)")
    set_ISSN("j-NRLQ",					"0028-1441 (print), 1931-9193 (electronic)")
    set_ISSN("j-NTG",					"????")
    set_ISSN("j-NTM",					"0036-6978 (print), 1420-9144 (electronic)")
    set_ISSN("j-NTT-R-D",                               "0915-2326")
    set_ISSN("j-NUCL-ENERGY",				"0891-3919 (print), 1878-2051 (electronic)")
    set_ISSN("j-NUCL-ENERGY-PART-A",			"0368-3265 (print), 1878-2116 (electronic)")
    set_ISSN("j-NUCL-GEOPHYS",				"0969-8086 (print), 1878-6383 (electronic)")
    set_ISSN("j-NUCL-INSTR-METH",			"0029-554X (print), 1878-3759 (electronic)")
    set_ISSN("j-NUCL-INSTRUM-METHODS-PHYS-RES",		"0167-5087 (print), 1872-9606 (electronic)")
    set_ISSN("j-NUCL-INSTRUM-METHODS-PHYS-RES-SECT-A",	"0168-9002 (print), 1872-9576 (electronic)")
    set_ISSN("j-NUCL-INSTRUM-METHODS-PHYS-RES-SECT-B",	"0168-583X (print), 1872-9584 (electronic)")
    set_ISSN("j-NUCL-MED",				"0161-5505 (print), 1535-5667 (electronic)")
    set_ISSN("j-NUCL-NEWS",				"0029-5574")
    set_ISSN("j-NUCL-PHYS",				"0029-5582 (print), 1873-1546 (electronic)")
    set_ISSN("j-NUCL-PHYS-A",				"0375-9474 (print), 1873-1554 (electronic)")
    set_ISSN("j-NUCL-PHYS-B",				"0550-3213 (print), 1873-1562 (electronic)")
    set_ISSN("j-NUCL-PHYS-B-PROC-SUPPL",		"0920-5632 (print), 1873-3832 (electronic)")
    set_ISSN("j-NUCL-SCI-ENG",				"0029-5639 (print), 1943-748X (electronic)")
    set_ISSN("j-NUCL-TECHNOL",				"0029-5450 (print), 1943-7471 (electronic)")
    set_ISSN("j-NUCLEAR-INSTR-METH-PHYS-RES-A",		"0168-9002, 0167-5087")
    set_ISSN("j-NUCLEAR-SAFETY",			"0029-5604")
    set_ISSN("j-NUCLEIC-ACIDS-RES",			"0305-1048")
    set_ISSN("j-NUM-LIN-ALG-APPL",			"1070-5325 (print), 1099-1506 (electronic)")
#   set_ISSN("j-NUM-MATH",				"0029-599X (print), 0945-3245 (electronic)")
    set_ISSN("j-NUM-MATH",				"0029-599X (print), 0945-3245 (electronic)")
    set_ISSN("j-NUM-MATH-THEORY-METHODS-APPL",		"1004-8979 (print), 2079-7338 (electronic)")
    set_ISSN("j-NUMER-ALGEBRA-CONTROL-OPTIM",		"2155-3289 (print), 2155-3297 (electronic)")
    set_ISSN("j-NUMER-ALGORITHMS",			"1017-1398 (print), 1572-9265 (electronic)")
    set_ISSN("j-NUMER-FUNCT-ANAL-OPTIM",		"0163-0563")
    set_ISSN("j-NUMER-HEAT-TRANSFER-B",			"1040-7790 (print), 1521-0626 (electronic)")
    set_ISSN("j-NUMER-METHODS-PARTIAL-DIFFER-EQU",	"0749-159X (print), 1098-2426 (electronic)")
    set_ISSN("j-NUNCIUS",				"0394-7394 (print), 1825-3911 (electronic)")
    set_ISSN("j-NUOVO-CIMENTO-1",			"0029-6341 (print), 1827-6121 (electronic)")
    set_ISSN("j-NUOVO-CIMENTO-2",			"0029-6341 (print), 1827-6121 (electronic)")
    set_ISSN("j-NUOVO-CIMENTO-3",			"0029-6341 (print), 1827-6121 (electronic)")
    set_ISSN("j-NUOVO-CIMENTO-4",			"0029-6341 (print), 1827-6121 (electronic)")
    set_ISSN("j-NUOVO-CIMENTO-5",			"0029-6341 (print), 1827-6121 (electronic)")
    set_ISSN("j-NUOVO-CIMENTO-6",			"0029-6341 (print), 1827-6121 (electronic)")
    set_ISSN("j-NUOVO-CIMENTO-7",			"0029-6341 (print), 1827-6121 (electronic)")
    set_ISSN("j-NUOVO-CIMENTO-8",			"0029-6341 (print), 1827-6121 (electronic)")
    set_ISSN("j-NUOVO-CIMENTO-9",			"0029-6341 (print), 1827-6121 (electronic)")
    set_ISSN("j-NUOVO-CIMENTO-10",			"0029-6341 (print), 1827-6121 (electronic)")
    set_ISSN("j-NUOVO-CIMENTO-1955-1965",		"1827-6121")
    set_ISSN("j-NUOVO-CIMENTO-A",			"0369-3546 (print), 1826-9869 (electronic)")
    set_ISSN("j-NUOVO-CIMENTO-B",			"0369-3554 (print), 1826-9877 (electronic)")
    set_ISSN("j-NUOVO-CIMENTO-B-11",			"0369-3554 (print), 1826-9877 (electronic)")
    set_ISSN("j-NUOVO-CIMENTO-D",			"0392-6737 (print), 1826-9893 (electronic)")
    set_ISSN("j-NUOVO-CIMENTO-SOC-ITAL-FIS-B",		"1594-9982, 1826-9877, 2037-4895")
    set_ISSN("j-NUOVO-CIMENTO-SUPPL",			"0550-3868")
    set_ISSN("j-NUOVO-SAGGIATORE",			"0393-4578 (print), 1827-6148 (electronic)")
    set_ISSN("j-NY-TIMES",				"0362-4331 (print), 1542-667X, 1553-8095")
    set_ISSN("j-OAK-RIDGER",				"0890-6009")
    set_ISSN("j-OBIT-NOTICES-FELLOWS-ROY-SOC",		"1479-571X")
    set_ISSN("j-OBJECT-EXPERT",				"1360-3426")
    set_ISSN("j-OBJECT-MAG",				"1055-3614")
    set_ISSN("j-OBSERVATORY",				"0029-7704")
    set_ISSN("j-OBZORNIK-MAT-FIZ",			"0473-7466")
    set_ISSN("j-OCEAN",					"0197-7385")
    set_ISSN("j-OCLC-MICRO",				"8756-5196")
    set_ISSN("j-OCLC-NEWSLETTER",			"0163-898X (print), 1931-6704 (electronic)")
    set_ISSN("j-OCTOBER",				"0162-2870")
    set_ISSN("j-OCTOGON-MATH-MAG",			"1222-5657 (print), 2248-1893 (electronic)")
    set_ISSN("j-OECOLOGIA",				"0029-8549 (print), 1432-1939 (electronic)")
    set_ISSN("j-OFF-OUR-BACKS",				"0030-0071")
    set_ISSN("j-OFFICE-SYS",				"8750-3441")
    set_ISSN("j-OIKOS",					"0030-1299 (print), 1600-0706 (electronic)")
    set_ISSN("j-OIL-GAS-INVESTOR",			"0744-5881")
    set_ISSN("j-OIL-GAS-J",				"0030-1388 (print), 1944-9151 (electronic)")
    set_ISSN("j-OHIO-J-SCI",				"0030-0950")
    set_ISSN("j-OMEGA",					"0305-0483 (print), 1873-5274 (electronic)")
    set_ISSN("j-ONCOGENE",				"0950-9232 (print), 1476-5594 (electronic)")
    set_ISSN("j-ONLINE",				"0146-5422")
    set_ISSN("j-ONLINE-CDROM-REV",			"0309-314X")
    set_ISSN("j-OOPS-MESSENGER",			"1055-6400 (print), 1558-0253 (electronic)")
    set_ISSN("j-OPEN-COMPUTING",			"1078-2370")
    set_ISSN("j-OPEN-J-DISCRETE-MATH",			"2161-7635 (print), 2161-7643 (electronic)")
    set_ISSN("j-OPEN-SYSTEMS-TODAY",			"1061-0839")
    set_ISSN("j-OPER-MATRICES",				"1846-3886 (print), 1848-9974 (electronic)")
    set_ISSN("j-OPER-RES",				"0030-364X (print), 1526-5463 (electronic)")
    set_ISSN("j-OPER-RES-LETT",				"0167-6377 (print), 1872-7468 (electronic)")
    set_ISSN("j-OPER-RES-VERFAHREN",			"0078-5318")
    set_ISSN("j-OPER-SYS-REV",				"0163-5980 (print), 1943-586X (electronic)")
    set_ISSN("j-OPT-COMM",				"0030-4018 (print), 1873-0310 (electronic)")
    set_ISSN("j-OPT-CTL-APPL-METH",			"0143-2087 (print), 1099-1514 (electronic)")
    set_ISSN("j-OPT-EXPRESS",				"1094-4087")
    set_ISSN("j-OPT-LET",				"0146-9592")
    set_ISSN("j-OPT-METH-APPL",				"????")
    set_ISSN("j-OPTICA",				"2334-2536")
    set_ISSN("j-OPTICA-ACTA",				"0030-3909")
    set_ISSN("j-OPTICAL-ENG",				"0091-3286 (print), 1560-2303 (electronic)")
    set_ISSN("j-OPTICS-NEWS",				"0098-907X")
    set_ISSN("j-OPTICS-PHOTONICS-NEWS",			"1047-6938 (print), 1541-3721 (electronic)")
    set_ISSN("j-OPTICAL-QUANTUM-ELECT",			"0306-8919, 0030-4077")
    set_ISSN("j-OPTIK",					"0030-4026 (print), 1618-1336 (electronic)")
    set_ISSN("j-OPTIM-ENG",				"1389-4420 (print), 1573-2924 (electronic)")
    set_ISSN("j-OPTIM-LETT",				"1862-4472 (print), 1862-4480 (electronic)")
    set_ISSN("j-OPTIM-METHODS-SOFTW",			"1055-6788")
    set_ISSN("j-OPTIMIZATION",				"0233-1934, 0323-3898")
    set_ISSN("j-OPTIMIZATSIIA",				"0134-3998")
    set_ISSN("j-OPUSCULA-ROMANA",			"0471-7309")
    set_ISSN("j-ORACLE-INTEGRATOR",			"1068-5537")
    set_ISSN("j-ORDER-DORDRECHT",			"0167-8094 (print), 1572-9273 (electronic)")
    set_ISSN("j-ORG-BEHAV-HUM-DECIS-PROCESS",		"0749-5978 (print), 1095-9920 (electronic)")
    set_ISSN("j-ORG-GEOCHEM",				"0146-6380 (print), 1873-5290 (electronic)")
    set_ISSN("j-ORGAN-DYN",				"0090-2616 (print), 1873-3530 (electronic)")
    set_ISSN("j-ORIG-LIFE-EVOL-BIOSPH",			"0169-6149 (print), 1573-0875 (electronic)")
    set_ISSN("j-ORSA-J-COMPUT",				"0899-1499 (print), 2326-3245 (electronic)")
    set_ISSN("j-OSIRIS",				"0369-7827 (print), 1933-8287 (electronic)")
    set_ISSN("j-OSIRIS-2",				"0369-7827 (print), 1933-8287 (electronic)")
    set_ISSN("j-OTOLARYNGOL-CLIN-NORTH-AM",		"0030-6665 (print), 1557-8259 (electronic)")
    set_ISSN("j-OUD-HOLLAND",				"0030-672X (print), 1875-0176 (electronic)")
    set_ISSN("j-OVERS-DAN-VIDENSK-SELSK-VIRKS",		"0368-7201")
    set_ISSN("j-OXF-SURV-EVOL-BIOL",			"0265-072X")
    set_ISSN("j-PAC-HIST-REV",				"0030-8684 (print), 1533-8584 (electronic)")
    set_ISSN("j-PAC-J-APPL-MATH",			"1941-3963")
    set_ISSN("j-PAC-J-MATH",				"0030-8730 (print), 1945-5844 (electronic)")
    set_ISSN("j-PAC-NORTHWEST-Q",			"0030-8803")
    set_ISSN("j-PACE",					"0147-8389 (print), 1540-8159 (electronic)")
    set_ISSN("j-PACMPL",				"2475-1421")
    set_ISSN("j-PAMM",					"1617-7061")
    set_ISSN("j-PAP-REG-SCI",				"1056-8190 (print), 1435-5957 (electronic)")
    set_ISSN("j-PARALLEL-ALGORITHMS-APPL",		"1063-7192")
    set_ISSN("j-PARALLEL-COMPUTING",			"0167-8191 (print), 1872-7336 (electronic)")
    set_ISSN("j-PARALLEL-DIST-COMP-PRACT",		"1097-2803")
    set_ISSN("j-PARALLEL-PROCESS-LETT",			"0129-6264")
    set_ISSN("j-PARALLELOGRAM",				"0953-7252")
    set_ISSN("j-PATTERN-RECOGN",			"0031-3203 (print), 1873-5142 (electronic)")
    set_ISSN("j-PATTERN-RECOGN-LETT",			"0167-8655 (print), 1872-7344 (electronic)")
    set_ISSN("j-PC-COMPUTING",				"0899-1847 (print), 1081-8642 (electronic)")
    set_ISSN("j-PC-KURIER",				"0867-0153 (print), 1689-3735 (electronic)")
    set_ISSN("j-PC-MAGAZINE",				"0888-8507 (print), 1078-8085 (electronic)")
    set_ISSN("j-PC-PUB",				"0896-8209")
    set_ISSN("j-PC-PUBL-PRESENT",			"1056-540X")
    set_ISSN("j-PC-TECH-J",				"0738-0194")
    set_ISSN("j-PC-TECH",				"1053-6205")
    set_ISSN("j-PC-USER",                               "0263-5720")
    set_ISSN("j-PC-WEEK",				"0740-1604")
    set_ISSN("j-PC-WORLD",				"0737-8939 (print), 1944-9143 (electronic)")
    ## OBSOLETE: set_ISSN("j-PDCP",					"1097-2803")
    set_ISSN("j-PEDIATRIC-RES",				"0031-3998 (print), 1530-0447 (electronic)")
    set_ISSN("j-PENTAGON",				"0031-4870")
    set_ISSN("j-PERCEPTION-PSYCHOPHYSICS",		"0031-5117 (print), 1532-5962 (electronic)")
    set_ISSN("j-PERCEPTUAL-MOTOR-SKILLS",		"0031-5125 (print), 1558-688X (electronic)")
    set_ISSN("j-PERF-EVAL",				"0166-5316 (print), 1872-745X (electronic)")
    set_ISSN("j-PERF-EVAL-REV",				"0163-5999 (print), 1557-9484 (electronic)")
    set_ISSN("j-PERFORM-COMPUT",			"0742-3136")
    set_ISSN("j-PERFORM-INSTR",				"0884-1985 (print), 1932-0116 (electronic)")
    set_ISSN("j-PERFORM-INSTR-J",			"8750-0191")
    set_ISSN("j-PERIOD-MATH-HUNGAR",			"0031-5303 (print), 1588-2829 (electronic)")
    set_ISSN("j-PERS-COMP",				"0192-5490")
    set_ISSN("j-PERS-COMPUT-WORLD",			"0142-0232")
    set_ISSN("j-PERSPECT-SCI",				"1063-6145 (print), 1530-9274 (electronic)")
    set_ISSN("j-PERSPECT-SCI-CHRIST-FAITH",		"0892-2675")
    set_ISSN("j-PERSPECTIVES-BIO-MED",			"0031-5982 (print), 1529-8795 (electronic)")
    set_ISSN("j-PESC-RECORD",				"0275-9306")
    set_ISSN("j-PFLUGERS-ARCH",				"0031-6768")
    set_ISSN("j-PHARM-J",				"0031-6873")
    set_ISSN("j-PHARM-RES",				"0724-8741 (print), 1573-904X (electronic)")
    set_ISSN("j-PHARMACOL-THER-OXF",                    "0163-7258 (print), 1879-016X (electronic)")
    set_ISSN("j-PHARMAZIE",				"0031-7144")
    set_ISSN("j-PHASE-TRANSIT",				"0141-1594")
    set_ISSN("j-PHILOS-MAG",				"0031-8086")
    set_ISSN("j-PHIL-MAGAZINE-5",			"1941-5982 (print), 1941-5990 (electronic)")
    set_ISSN("j-PHIL-MAGAZINE-6",			"")
    set_ISSN("j-PHILIPS-J-RES",				"0165-5817 (print), 1878-5468 (electronic)")
    set_ISSN("j-PHILOS-MAG-4",				"0031-8086")
    set_ISSN("j-PHILOS-MAG-6",				"1941-5982 (print), 1941-5990 (electronic)")
    set_ISSN("j-PHILOS-MAG-7",				"0031-8086")
    set_ISSN("j-PHILOS-MAG-8",				"0031-8086")
    set_ISSN("j-PHILOS-MAG-A",				"0141-8610 (print), 1460-6992 (electronic)")

    # Warning: j-PHILOS-MAG-B also has incorrect ISSN 0141-8637
    set_ISSN("j-PHILOS-MAG-B",				"1364-2812 (print), 1463-6417 (electronic)")

    set_ISSN("j-PHILOS-MAG-LETT",			"0950-0839 (print), 1362-3036 (electronic)")
    set_ISSN("j-PHILOS-MATH-3",				"0031-8019 (print), 1744-6406 (electronic)")
    set_ISSN("j-PHILOS-NATUR",				"0031-8027")
    set_ISSN("j-PHILOS-PHENOMENOL-RES",			"0031-8205 (print), 1933-1592 (electronic)")
    set_ISSN("j-PHILOS-PSYCHOL",			"0951-5089 (print), 1465-394X (electronic)")
    set_ISSN("j-PHILOS-SCI",				"0031-8248 (print), 1539-767X (electronic)")
    set_ISSN("j-PHILOS-SOC-SCI",			"0048-3931 (print), 1552-7441 (electronic)")
    set_ISSN("j-PHILOS-STUD",				"0031-8116 (print), 1573-0883 (electronic)")
    set_ISSN("j-PHILOS-TOP",				"0276-2080 (print), 2154-154X (electronic)")
    set_ISSN("j-PHILOS-TRANS-R-SOC-LOND",		"0370-2316 (print), 2053-9207 (electronic)")
    set_ISSN("j-PHILOS-TRANS-R-SOC-LOND-A-CONTAIN-PAP-MATH-PHYS-CHARACTER",	"0264-3952 (print), 2053-9258 (electronic)")
    set_ISSN("j-PHILOS-TRANS-R-SOC-LOND-PHYS-SCI-ENG",	"0962-8428 (print), 2054-0299 (electronic)")
    set_ISSN("j-PHILOS-TRANS-R-SOC-LOND-SER-A",		"1364-503X (print), 1471-2962 (electronic)")
    set_ISSN("j-PHILOS-TRANS-R-SOC-LOND-SER-A-MATH-PHYS-SCI",	"0080-4614 (print), 2054-0272 (electronic)")
    set_ISSN("j-PHILOS-TRANS-R-SOC-LOND-SER-B-BIO-SCI",	"0962-8436 (print), 1471-2970 (electronic)")
    set_ISSN("j-PHOTO-ELECTRON-IMAGING",		"1060-4936")
    set_ISSN("j-PHOTOCHEM-PHOTOBIO",			"0031-8655 (print), 1751-1097 (electronic)")
    set_ISSN("j-PHOTOGR-SCI-ENG",			"0031-8760")
    set_ISSN("j-PHOTOMETHODS",				"0146-0153")
    set_ISSN("j-PHOTONICS-NANOSTRUCT",			"1569-4410")
    set_ISSN("j-PHOTONIQUES",				"1629-4475 (print), 2269-8418 (electronic)")
    set_ISSN("j-PHYS-AT-NUCL",				"1063-7788 (print), 1562-692X (electronic)")
    set_ISSN("j-PHYS-BL",				"0031-9279 (print), 1521-3722 (electronic)")
    set_ISSN("j-PHYS-BULL",				"0031-9112")
    set_ISSN("j-PHYS-CANADA",				"0031-9147")
    set_ISSN("j-PHYS-CHEM-CHEM-PHYS",			"1463-9076 (print), 1463-9084 (electronic)")
    set_ISSN("j-PHYS-CHEM-LIQ",				"0031-9104, 0031-9104, 1026-7727, 1029-0451")
    set_ISSN("j-PHYS-CHEM-MINERALS",			"0342-1791 (print), 1432-2021 (electronic)")
    set_ISSN("j-PHYS-EARTH-PLANET-INTER",		"0031-9201 (print), 1872-7395 (electronic)")
    set_ISSN("j-PHYS-EDUC",				"0031-9120 (print), 1361-6552 (electronic)")
    set_ISSN("j-PHYS-ESSAYS",				"0836-1398")
    set_ISSN("j-PHYS-FLUIDS",				"1070-6631")
    set_ISSN("j-PHYS-FLUIDS-1958",			"0031-9171")
    set_ISSN("j-PHYS-FLUIDS-A",				"0899-8213 (print), 2163-5013 (electronic)")
    set_ISSN("j-PHYS-J",				"1617-9439 (print), 1619-6597 (electronic)")
    set_ISSN("j-PHYS-LET",				"0031-9163 (print), 1873-2410 (electronic)")
    set_ISSN("j-PHYS-LET-A",				"0375-9601 (print), 1873-2429 (electronic)")
    set_ISSN("j-PHYS-LET-B",				"0370-2693 (print), 1873-2445 (electronic)")
    set_ISSN("j-PHYS-MED-BIOL",				"0031-9155 (print), 1361-6560 (electronic)")
    set_ISSN("j-PHYS-NORVEG",				"0031-8930")
    set_ISSN("j-PHYS-PART-NUCL",			"1063-7796 (print), 1090-6495 (electronic)")
    set_ISSN("j-PHYS-PERSPECT",				"1422-6944 (print), 1422-6960 (electronic)")
    set_ISSN("j-PHYS-PLASMAS",				"1070-664X (print), 1089-7674 (electronic), 1527-2419")
    set_ISSN("j-PHYS-PROCEDIA",				"1875-3892")
    set_ISSN("j-PHYS-REP",				"0370-1573 (print), 1873-6270 (electronic)")
    set_ISSN("j-PHYS-REV",				"0031-899X (print), 1536-6065 (electronic)")
    set_ISSN("j-PHYS-REV-1",				"0031-899X (print), 1536-6065 (electronic)")
    set_ISSN("j-PHYS-REV-2",				"0031-899X (print), 1536-6065 (electronic)", 1)
    set_ISSN("j-PHYS-REV-A",				"1050-2947 (print), 1094-1622, 1538-4446, 1538-4519")
    set_ISSN("j-PHYS-REV-A-3",				"0556-2791")
    set_ISSN("j-PHYS-REV-B",				"2469-9969")
    set_ISSN("j-PHYS-REV-B-CMMP",			"1098-0121")
    set_ISSN("j-PHYS-REV-B-SS",				"0556-2805")
    set_ISSN("j-PHYS-REV-C",				"0556-2813 (print), 1089-490X, 1538-4497")
    set_ISSN("j-PHYS-REV-D",				"0556-2821 (print), 1089-4918 (electronic), 1538-4500 (CD-ROM)")
    ## Library of Congress MARC record flags 1063-651X as an incorrect ISSN
    ## set_ISSN("j-PHYS-REV-E",				"1063-651X (print), 1095-3787 (electronic)")
    set_ISSN("j-PHYS-REV-E",				"1539-3755 (print), 1550-2376 (electronic)")
    set_ISSN("j-PHYS-REV-FOCUS",			"1539-0748")
    set_ISSN("j-PHYS-REV-LET",				"0031-9007 (print), 1079-7114 (electronic), 1092-0145")
    set_ISSN("j-PHYS-REV-X",				"2160-3308")
    set_ISSN("j-PHYS-STATUS-SOLIDI",			"0031-8957")
    set_ISSN("j-PHYS-STATUS-SOLIDI-A-APPL-RES",		"0031-8965 (print), 1521-396X (electronic)")
    set_ISSN("j-PHYS-STATUS-SOLIDI-B-BASIC-RES",	"0370-1972 (print), 1521-3951 (electronic)")
    set_ISSN("j-PHYS-STATUS-SOLIDI-RAPID-RES-LETT",	"1862-6254 (print), 1862-6270 (electronic)")
    set_ISSN("j-PHYS-TEACHER",				"0031-921X (print), 1943-4928 (electronic)")
    set_ISSN("j-PHYS-TODAY",				"0031-9228 (print), 1945-0699 (electronic)")
    set_ISSN("j-PHYS-UNSERER-ZEIT",			"0031-9252")
    set_ISSN("j-PHYS-USPEKHI",				"1063-7869 (print), 1468-4780 (electronic)")
    set_ISSN("j-PHYS-WORLD",				"0953-8585 (print), 2058-7058 (electronic)")
    set_ISSN("j-PHYS-Z-SOWJETUNION",			"0369-9811")
    set_ISSN("j-PHYSICA",				"0031-8914 (print), 1873-1767 (electronic)")
    set_ISSN("j-PHYSICA-A",				"0378-4371 (print), 1873-2119 (electronic)")
    set_ISSN("j-PHYSICA-B",				"0921-4526 (print), 1873-2135 (electronic)")
    set_ISSN("j-PHYSICA-B-PLUS-C",			"0378-4363 (print), 1873-2127 (electronic)")
    set_ISSN("j-PHYSICA-C",				"0921-4534 (print), 1873-2143 (electronic)")
    set_ISSN("j-PHYSICA-D",				"0167-2789 (print), 1872-8022 (electronic)")
    set_ISSN("j-PHYSICA-SCRIPTA",			"0031-8949 (print), 1402-4896 (electronic)")
    set_ISSN("j-PHYSICA-THE-HAGUE",			"0370-2707")
    set_ISSN("j-PHYSICS",				"????")
    set_ISSN("j-PHYSIKAL-Z",				"0369-982X")
    set_ISSN("j-PHYSIS",				"0031-9414 (print), 2038-6265 (electronic)")
    set_ISSN("j-PHYSIS-NS",				"0031-9414 (print), 2038-6265 (electronic)")
    set_ISSN("j-PHYSIOL-CHEM-PHYS",			"0031-9325")
    set_ISSN("j-PHYSIOL-REV",				"0031-9333 (print), 1522-1210 (electronic)")
    set_ISSN("j-PI-MU-EPSILON-J",			"0031-952X")
    set_ISSN("j-PITMAN-RES-NOTES-MATH-SER",		"0269-3674")
    set_ISSN("j-PLANET-SPACE-SCI",			"0032-0633 (print), 1873-5088 (electronic)")
    set_ISSN("j-PLANT-J",				"0960-7412 (print), 1365-313X (electronic)")
    set_ISSN("j-PLANT-MOL-BIO",				"0167-4412 (print), 1573-5028 (electronic)")
    set_ISSN("j-PLANTA",				"0032-0935 (print), 1432-2048 (electronic)")
    set_ISSN("j-PLASMA-IONS",				"1288-3255 (print), 1879-3436 (electronic)")
    set_ISSN("j-PLASMA-PHYS",				"0032-1028 (print), 1879-2979 (electronic)")
    set_ISSN("j-PLASMA-PHYS-CONTROL-FUSION",		"0741-3335 (print), 1361-6587 (electronic)")
    set_ISSN("j-PLASMID",				"0147-619X (print), 1095-9890 (electronic)")
    set_ISSN("j-PLATIN-MET-REV",			"0032-1400")
    set_ISSN("j-PLI-BULL",				"????")
    set_ISSN("j-PLISKA-STUD-MATH-BULGAR",		"0204-9805")
    set_ISSN("j-PLOS-COMPUT-BIOL",			"1553-734X (print), 1553-7358 (electronic)")
    set_ISSN("j-PLOS-MED",				"1549-1277 (print), 1549-1676 (electronic)")
    set_ISSN("j-PLOS-ONE",				"1932-6203")
    set_ISSN("j-POKROKY-MAT-FYS-ASTRON",		"0032-2423")
    set_ISSN("j-POLIT-ANAL",				"1047-1987 (print), 1476-4989 (electronic)")
    set_ISSN("j-POLITY",				"0032-3497 (print), 1744-1684 (electronic)")
    set_ISSN("j-POLYMER",				"0032-3861 (print), 1873-2291 (electronic)")
    set_ISSN("j-POLYMER-J-TOKYO",			"0032-3896 (print), 1349-0540 (electronic)")
    set_ISSN("j-POMACS",				"2476-1249")
    set_ISSN("j-POP-COMP",				"0279-4721")
    set_ISSN("j-POP-COMP-CALABASAS",			"0090-6611")
    set_ISSN("j-PORT-MATH",				"0032-5155 (print), 1662-2758 (electronic)")
    set_ISSN("j-POSITIVITY",				"1385-1292 (print), 1572-9281 (electronic)")
    set_ISSN("j-POSTSCRIPT-LANG-J",			"0891-5873")
    set_ISSN("j-POTENTIAL-ANAL",			"0926-2601 (print), 1572-929X (electronic)")
    set_ISSN("j-POWDER-DIFF",				"0885-7156 (print), 1945-7413 (electronic)")
    set_ISSN("j-PRAGMATICS-COGNITION",			"0929-0907 (print), 1569-9943 (electronic)")
    set_ISSN("j-PRAMANA",				"0304-4289 (print), 0973-7111 (electronic)")
    set_ISSN("j-PRIKL-MAT-MEH",				"0032-8235")
    set_ISSN("j-PRIKL-PROBLEMY-PROCH-I-PLAST",		"0132-7186")
    set_ISSN("j-PRIMUS",				"1051-1970 (print), 1935-4053 (electronic)")
    set_ISSN("j-PRINT",					"0032-8510")
    set_ISSN("j-PRINTING-PRODUCTION",			"0191-7749")
    set_ISSN("j-PRINTING-WORLD",			"0032-8715")
    set_ISSN("j-PRIRODA-MOSCOW",			"0032-874X")
    set_ISSN("j-PROB-ENG-MECH",				"0266-8920 (print), 1878-4275 (electronic)")
    set_ISSN("j-PROB-ENG-INFO-SCI",			"0269-9648 (print), 1469-8951 (electronic)")
    set_ISSN("j-PROBAB-SURV",				"1549-5787")
    set_ISSN("j-PROBAB-ENGRG-INFORM-SCI",		"0269-9648 (print), 1469-8951 (electronic)")
    set_ISSN("j-PROBAB-THEORY-RELAT-FIELDS",		"0178-8051 (print), 1432-2064 (electronic)")
    set_ISSN("j-PROBL-INF-TRANSM",			"0032-9460 (print), 1608-3253 (electronic)")
    set_ISSN("j-PROBL-PEREDA-INF",			"0555-2923")
    set_ISSN("j-PROC-ACM-SYMP-APPL-COMPUTING",		"????")
    set_ISSN("j-PROC-AM-ACAD-ARTS-SCI",			"0065-6836")
    set_ISSN("j-PROC-AM-CONTROL-CONF",			"0743-1619")
    set_ISSN("j-PROC-AM-MATH-SOC",			"0002-9939 (print), 1088-6826 (electronic)")
    set_ISSN("j-PROC-AMER-PHIL-SOC",			"0003-049X (print), 2326-9243 (electronic)")
    ### BAD:	set_ISSN("j-PROC-ANN-SYMP-COMPUT-APPL-MED-CARE",	"0194-4210")
    set_ISSN("j-PROC-ANN-SYMP-COMPUT-APPL-MED-CARE",	"0195-4210")	# [04-Jan-2006] corrected
    set_ISSN("j-PROC-ANNUAL-SOUTHEAST-CONFERENCE",	"????")
    set_ISSN("j-PROC-ASEE-ANNU-CONF",			"0190-1052")
    set_ISSN("j-PROC-ASIS-AM",				"0044-7870")
    set_ISSN("j-PROC-CAMBRIDGE-PHIL-SOC",		"0008-1981")
    set_ISSN("j-PROC-CHEM-SOC-LONDON",			"0369-8718 (print), 2050-5612 (electronic)")
    set_ISSN("j-PROC-CMAANU",				"????")
    set_ISSN("j-PROC-CONTROL-AUTOMATION",		"0552-234X")
    set_ISSN("j-PROC-EDINBURGH-MATH-SOC",		"0013-0915 (print), 1464-3839 (electronic)")
    set_ISSN("j-PROC-EDINBURGH-MATH-SOC-2",		"0013-0915 (print), 1464-3839 (electronic)")
    set_ISSN("j-PROC-GRAPHICS-INTERFACE",		"0713-5424")
    set_ISSN("j-PROC-ICASSP",				"0736-7791")
    set_ISSN("j-PROC-IEE",				"0020-3270 (print), 2053-7891 (electronic)")
    set_ISSN("j-PROC-IEEE",				"0018-9219 (print), 1558-2256 (electronic)")
    set_ISSN("j-PROC-IEEE-INT-COMP-SOFTWARE-APPL-CONF",	"0730-6512")
    set_ISSN("j-PROC-IEEE-CONF-DECISION-CONTROL",	"0191-2216")
    set_ISSN("j-PROC-IEEE-CONF-SYST-MAN-CYBERN",	"0884-3627")
    set_ISSN("j-PROC-IEEE-INT-SOFTWARE-ENG-STAND-SYMP",	"1082-3670")
    set_ISSN("j-PROC-IEEE-WORK-REAL-TIME-OPER-SYS-SOFTWARE","????")
    set_ISSN("j-PROC-IMP-ACAD-TOKYO",			"????")
    set_ISSN("j-PROC-INDIAN-ACAD-SCI-CHEM-SCI",		"0253-4134")
    set_ISSN("j-PROC-INDIAN-ACAD-SCI-SECT-A",		"0370-0089")
    set_ISSN("j-PROC-INST-STATIST-MATH",		"0912-6112")
    set_ISSN("j-PROC-INT-CONF-DIST-COMPUT-SYS",		"1063-6927")
    set_ISSN("j-PROC-INT-CONF-PAR-PROC",		"0190-3918")
    set_ISSN("j-PROC-INT-CONF-REQUIREMENTS-ENG",	"????")
    set_ISSN("j-PROC-INT-CONF-SOFTWARE-ENG",		"0270-5257 (print), 1558-1225 (electronic)")
    set_ISSN("j-PROC-INT-CONF-SUPERCOMPUTING",		"????")
    set_ISSN("j-PROC-INT-MEETING-PETROLEUM-ENG",	"????")
    set_ISSN("j-PROC-INT-TEST-CONF",			"????")
    set_ISSN("j-PROC-IRE",				"0096-8390 (print), 2162-6634 (electronic)")
    set_ISSN("j-PROC-J-MATH",				"????")
    set_ISSN("j-PROC-JAPAN-ACAD-SER-A-MATH-SCI",	"0386-2194")
    set_ISSN("j-PROC-LINN-SOC-LONDON",			"0370-0461 (print), 1747-2741 (electronic)")
    set_ISSN("j-PROC-LONDON-MATH-SOC-1",		"0024-6115 (print), 1460-244X (electronic)")
    set_ISSN("j-PROC-LONDON-MATH-SOC-2",		"0024-6115 (print), 1460-244X (electronic)")
    set_ISSN("j-PROC-LONDON-MATH-SOC-3",		"0024-6115 (print), 1460-244X (electronic)")
    set_ISSN("j-PROC-MANCHESTER-LIT-PHILOS-SOC",	"0076-3721")
    set_ISSN("j-PROC-NATL-ACAD-SCI-USA",		"0027-8424 (print), 1091-6490 (electronic)")
    set_ISSN("j-PROC-NATL-ONLINE-MEET",			"0739-1471")
    set_ISSN("j-PROC-PETROLEUM-COMPUT-CONF",		"????")
    set_ISSN("j-PROC-PHYS-SOC",				"0959-5309 (print), 2051-2171 (electronic)")
    set_ISSN("j-PROC-PHYS-SOC-LONDON-SECT-A",		"0370-1298 (print), 1747-3829 (electronic)")
    set_ISSN("j-PROC-PHYS-SOC-LONDON-SECT-B",		"0370-1301 (print), 1747-3837 (electronic)")
    set_ISSN("j-PROC-R-INST-G-B",			"0035-8959")
    set_ISSN("j-PROC-R-IR-ACAD-SECT-A",			"0035-8975")
    set_ISSN("j-PROC-R-SOC-B",				"0080-4649 (print), 2053-9193 (electronic)")
    set_ISSN("j-PROC-R-SOC-EDINB",			"0080-4541 (print), 2053-5902 (electronic)")
    ## set_ISSN("j-PROC-R-SOC-EDINB-A",			"0080-4541, 1")
    set_ISSN("j-PROC-R-SOC-EDINB-SECT-A-MATH",		"0308-2105 (print), 1473-7124 (electronic)")
    set_ISSN("j-PROC-R-SOC-EDINB-SECT-A-MATH-PHYS-SCI",	"0080-4541 (print), 2053-5902 (electronic)")
    set_ISSN("j-PROC-R-SOC-EDINB-SECT-B-BIOL-SCI",	"0269-7270 (print), 2053-5910 (electronic)")
    set_ISSN("j-PROC-R-SOC-EDINB-SECT-B-NAT-ENVIRON",	"0308-2113 (print), 2053-5929 (electronic)")
    set_ISSN("j-PROC-R-PHILOS-SOC-GLASGOW",		"0031-8078")
    set_ISSN("j-PROC-R-SOC-LOND",			"0370-1662 (print), 2053-9126 (electronic)")
    set_ISSN("j-PROC-R-SOC-LOND-SER-A",			"1364-5021 (print), 1471-2946 (electronic)")
    set_ISSN("j-PROC-R-SOC-LOND-SER-A-MATH-PHYS",	"0950-1207 (print), 2053-9150 (electronic)")
    set_ISSN("j-PROC-R-SOC-LOND-SER-A-MATH-PHYS-ENG-SCI", "1364-5021 (print), 1471-2946 (electronic)")

    ## ISSN 0080-4630: Proceedings of the Royal Society of London. Series A. Mathematical and physical sciences (1905--1989)
    ##                 [76(1905)-146(1934) med underserietittel: Containing papers of a mathematical and physical character]
    ## ISSN 0962-8444: Proceedings of the Royal Society of London. Series A. (1990--1995)
    ## ISSN 1364-5021: Proceedings. Mathematical, physical and engineering sciences (the Royal Society) (1996--date)
    set_ISSN("j-PROC-R-SOC-LOND-SER-A-MATH-PHYS-SCI",	"0080-4630 (print), 2053-9169 (electronic)")

    set_ISSN("j-PROC-R-SOC-LOND-SER-B",			"0950-1193 (print), 2053-9185 (electronic)")
    set_ISSN("j-PROC-R-SOC-LOND-SER-B-BIO-SCI",		"0962-8452 (print), 1471-2954 (electronic)")
    set_ISSN("j-PROC-REAL-TIME-SYS-SYMP",		"????")
    set_ISSN("j-PROC-SID",				"0734-1768, 0036-1496")
    set_ISSN("j-PROC-SOC-EXP-BIOL-MED",			"0037-9727")
    set_ISSN("j-PROC-SOC-PSYCH-RES",			"0081-1475")
    set_ISSN("j-PROC-SOIL-SCI-SOC-AM",			"0038-0776")
    set_ISSN("j-PROC-SPIE",				"0277-786X (print), 1996-756X (electronic)")
    set_ISSN("j-PROC-STEKLOV-INST-MATH",		"0081-5438")
    set_ISSN("j-PROC-SUPERCOMPUT",			"1063-9535")
    set_ISSN("j-PROC-SYMP-APPL-MATH",			"0160-7634")
    set_ISSN("j-PROC-SYMP-PURE-MATH",			"0082-0717")
    set_ISSN("j-PROC-VLDB-ENDOWMENT",			"2150-8097")
    set_ISSN("j-PROCEDIA-SOC-BEHAV-SCI",		"1877-0428")
    set_ISSN("j-PROG-ASTRONAUT-AERONAUT",		"0079-6050")
    set_ISSN("j-PROG-BIOPHYS-BIOPHYS-CHEM",		"0096-4174")
    set_ISSN("j-PROG-BIOPHYS-MOL-BIOL",                 "0079-6107 (print), 1873-1732 (electronic)")
    set_ISSN("j-PROG-CELL-CYCLE-RES",			"1087-2957")
    set_ISSN("j-PROG-CLIN-BIO-RES",			"0361-7742")
    set_ISSN("j-PROG-COMP-SOFT",			"0361-7688 (print), 1608-3261 (electronic)")
    set_ISSN("j-PROG-ELECTROMAGN-RES",			"1070-4698 (print), 1559-8985 (electronic)")
    set_ISSN("j-PROG-NUCL-PHYS",			"0079-659X")
    set_ISSN("j-PROG-NUCLEIC-ACID-RES-MOL-BIO",		"0079-6603 (print), 2211-9108 (electronic)")
    set_ISSN("j-PROG-PART-NUCL-PHYS",			"0146-6410 (print), 1873-2224 (electronic)")
    set_ISSN("j-PROG-SURF-SCI",				"0079-6816 (print), 1878-4240 (electronic)")
    set_ISSN("j-PROG-THEOR-PHYS",			"0033-068X (print), 1347-4081 (electronic)")
    set_ISSN("j-PROGR-OCEANOGR",			"0079-6611 (print), 1873-4472 (electronic)")
    set_ISSN("j-PROGRAM",				"0033-0337 (print), 1758-7301 (electronic)")
    set_ISSN("j-PROGRAM-J",				"0747-5861")
    set_ISSN("j-PROGRAMMIROVANIE",			"0132-3474")
    set_ISSN("j-PROGRESS-NUCLEAR-ENERGY",		"0149-1970 (print), 1878-4224 (electronic)")
    set_ISSN("j-PROLOGUE",				"0033-1031")
    set_ISSN("j-PROTEIN-SEQ-DATA-ANAL",			"0931-9506")
    set_ISSN("j-PROTEIN-STRUCT-FUNCT-BIOINF",		"0887-3585 (print), 1097-0134 (electronic)")
    set_ISSN("j-PROTEIN-STRUCT-MOL-ENZYM",		"0167-4838", 1)
    set_ISSN("j-PROTEINS",				"0887-3585 (print), 1097-0134 (electronic)")
    set_ISSN("j-PROTOPLASMA",				"0033-183X (print), 1615-6102 (electronic)")
    set_ISSN("j-PSYCH-WOMEN",				"0361-6843")
    set_ISSN("j-PSYCHIATRY",				"0033-2747 (print), 1943-281X (electronic)")
    set_ISSN("j-PSYCHOL-METHODS",			"1082-989X (print), 1939-1463 (electronic)")
    set_ISSN("j-PSYCHOL-REP",				"0033-2941 (print), 1558-691X (electronic)")
    set_ISSN("j-PSYCHOL-REV",				"0033-295X (print), 1939-1471 (electronic)")
    set_ISSN("j-PSYCHOMETRIKA",				"0033-3123 (print), 1860-0980 (electronic)")
    set_ISSN("j-PTERIDINES",				"0933-4807")
    set_ISSN("j-PUB-AFFAIRS-QUART",			"0887-0373 (print), 2152-0542 (electronic)")
    set_ISSN("j-PUB-CENTRE-EUR-ETUDES-BURGONDO-MEDIANES", "0069-1895")
    set_ISSN("j-PUB-MAT",				"0214-1493")
    set_ISSN("j-PUB-RELATIONS-REV",			"0363-8111 (print), 1873-4537 (electronic)")
    set_ISSN("j-PUBL-ASTRON-SOC-JPN",			"0004-6264")
    set_ISSN("j-PUBL-ASTRON-SOC-PAC",			"0004-6280 (print), 1538-3873 (electronic)")
    set_ISSN("j-PUBL-MATH-DEBRECEN",			"0033-3883 (print), 2064-2849 (electronic)")
    set_ISSN("j-PUBL-RELAT-J",				"0033-3670")
    set_ISSN("j-PUBLIC-ACCESS-COMPUT-SYST-REV",		"1063-164X")
    set_ISSN("j-PUBLIC-MANAGE",				"0033-3611")
    set_ISSN("j-PUBLISH",				"0897-6007")
    set_ISSN("j-PUBLISHING",				"")
    set_ISSN("j-PUBLISHERS-WEEKLY",			"0000-0019 (print), 2150-4008 (electronic)")
    set_ISSN("j-PUBLISHING-PROD-EXEC",			"1048-3055")
    set_ISSN("j-PUGET-SOUND-BUS-J",			"8750-7757")
    set_ISSN("j-PURE-APPL-CHEM",			"0033-4545 (print), 1365-3075 (electronic)")
    set_ISSN("j-PURE-APPL-GEOPHYS",			"0033-4553 (print), 1420-9136 (electronic)")
    set_ISSN("j-PYRODYNAMICS",				"0555-8344")
    set_ISSN("j-Q-J-ECON",				"0033-5533 (print), 1531-4650 (electronic)")
    set_ISSN("j-Q-J-R-ASTRON-SOC",			"0035-8738")
    set_ISSN("j-Q-REV-BIOL",				"0033-5770 (print), 1539-7718 (electronic)")
    set_ISSN("j-QCPE",					"0889-7514")
    set_ISSN("j-QJM",					"1460-2393 (print), 1460-2725 (electronic)")
    set_ISSN("j-QRB",					"0097-5990")
    set_ISSN("j-QSAR",					"0931-8771 (print), 1521-3838 (electronic)")
    set_ISSN("j-QUAD-STORIA-FISICA",			"1594-9974 (print), 1827-6164 (electronic)")
    set_ISSN("j-QUAD-UNIONE-MAT-ITAL",			"????")
    set_ISSN("j-QUAERENDO",				"0014-9527 (print), 1570-0690 (electronic)")
    set_ISSN("j-QUAL-QUANT",				"0033-5177 (print), 1573-7845 (electronic)")
    set_ISSN("j-QUANT-FINANCE",				"1469-7688 (print), 1469-7696 (electronic)")
    set_ISSN("j-QUANTUM-INF-PROCESS",			"1570-0755 (print), 1573-1332 (electronic)")
    set_ISSN("j-QUART-APPL-MATH",			"0033-569X (print), 1552-4485 (electronic)")
    set_ISSN("j-QUART-J-MATH",				"0033-5606 (print), 1464-3847 (electronic)")
    set_ISSN("j-QUART-J-MATH-OXFORD",			"0033-5606", 1)
    set_ISSN("j-QUART-J-MECH-APPLIED-MATH",		"0033-5614 (print), 1464-3855 (electronic)")
    set_ISSN("j-QUART-J-MICROSCOP-SCI",			"0370-2952")
    set_ISSN("j-QUART-J-ROY-METEOROL-SOC",		"0035-9009 (print), 1477-870X (electronic)")
    set_ISSN("j-QUEUE",					"1542-7730 (print), 1542-7749 (electronic)")
    set_ISSN("j-QUILL",					"0033-6475")
    set_ISSN("j-RADIAT-PHYS-CHEM",			"0969-806X (print), 1879-0895 (electronic)")
    set_ISSN("j-RADIAT-RES",				"0033-7587 (print), 1938-5404 (electronic)")
    set_ISSN("j-RADIO-ELECTRON-ENG",			"0033-7722")
    set_ISSN("j-RADIO-SCI",				"0048-6604 (print), 1944-799X (electronic)")
    set_ISSN("j-RADIOCHIM-ACTA",			"0033-8230")
    set_ISSN("j-RADIOLOGY",				"0033-8419 (print), 1527-1315 (electronic)")
    set_ISSN("j-RADIUM-PARIS",				"0370-3223 (print), 2437-2455 (electronic)")
    set_ISSN("j-RAIRO-AUTOMATIQUE-SYSTEMS-ANA-CONTROL",	"0035-3035, 0399-0524")
    set_ISSN("j-RAIRO-NUM-ANA",				"0399-0516")
    set_ISSN("j-RAIRO-RECH-OPER",			"0399-0559 (print), 1290-3868 (electronic)")
    set_ISSN("j-RAMANUJAN-J",				"1382-4090 (print), 1572-9303 (electronic)")
    set_ISSN("j-RAND-COMP-DYN",				"1061-835X")
    set_ISSN("j-RAND-STRUCT",				"1042-9832 (print), 1098-2418 (electronic)")
    set_ISSN("j-RAPP-RECH",				"0085-2643")
    set_ISSN("j-RCA-REV",				"0033-6831")
    set_ISSN("j-READERS-DIGEST",			"0034-0375")
    set_ISSN("j-REAL-TIME-IMAGING",			"1077-2014 (print), 1096-116X (electronic)")
    set_ISSN("j-REAL-TIME-SYST",			"0922-6443 (print), 1573-1383 (electronic)")
    set_ISSN("j-REC-MATH-MAG",				"0486-1876")
    set_ISSN("j-RECHENTECH-DATENVERARB",		"0300-3450")
    set_ISSN("j-RECHERCHE",				"0029-5671 (print), 1625-9955 (electronic)")
    set_ISSN("j-REF-LIBR",				"0276-3877 (print), 1541-1117 (electronic)")
    set_ISSN("j-REG-SCI-URBAN-ECON",			"0166-0462 (print), 1879-2308 (electronic)")
    set_ISSN("j-REGISTER",				"????")
    set_ISSN("j-RELIABLE-COMPUTING",			"1385-3139 (print), 1573-1340 (electronic)")
    set_ISSN("j-RENAISSANCE-Q",				"0034-4338 (print), 1935-0236 (electronic)")
    set_ISSN("j-REND-CIRC-MAT",				"0009-725X (print), 1973-4409 (electronic)")
    set_ISSN("j-REND-CIRC-MAT-II",			"????")
    set_ISSN("j-REND-LINCEI",				"0001-4435")
    set_ISSN("j-REND-MAT-APPL-1981",			"1120-7183")
    set_ISSN("j-REP-BRIT-ASSOC-ADV-SCI",		"????")
    set_ISSN("j-REP-MATH-PHYS",				"0034-4877 (print), 1879-0674 (electronic)")
    set_ISSN("j-REP-OBJECT-ANA-DESIGN",                 "1075-2528 (print), 1089-151X (electronic)")
    set_ISSN("j-REP-PROG-PHYS",				"0034-4885 (print), 1361-6633 (electronic)")
    set_ISSN("j-RES-DEV",				"0746-9179")
    set_ISSN("j-RES-MATH-SCI",				"2522-0144 (print), 2197-9847 (electronic)")
    set_ISSN("j-RES-MICROBIOL",				"0923-2508 (print), 1769-7123 (electronic)")
    set_ISSN("j-RES-NOTES-MATH",			"0743-0337")
    set_ISSN("j-RES-OP",				"????")
    set_ISSN("j-RES-POLICY",				"0048-7333 (print), 1873-7625 (electronic)")
    set_ISSN("j-RESONANCE",				"0971-8044 (print), 0973-712X (electronic)")
    set_ISSN("j-RESOUR-SHAR-INF-NETW",			"0737-7797 (print), 1541-1125 (electronic)")
    set_ISSN("j-RESULTS-MATH",				"0378-6218")
    set_ISSN("j-RESUSCITATION",				"0300-9572 (print), 1873-1570 (electronic)")
    set_ISSN("j-RETE",					"0340-4617")
    set_ISSN("j-REV-AM-HIST",				"0048-7511 (print), 1080-6628 (electronic)")
    set_ISSN("j-REV-ANAL-NUMER-TEORIA-APROX",		"0301-925X")
    set_ISSN("j-REV-BRAS-FIS",				"0374-4922")
    set_ISSN("j-REV-ECON-STAT",				"0034-6535 (print), 1530-9142 (electronic)")
    set_ISSN("j-REV-ECON-STUD",				"0034-6527 (print), 1467-937X (electronic)")
    set_ISSN("j-REV-ELECTR-COMMUN-LAB",			"0029-067X")
    set_ISSN("j-REV-ESP-ELECT",				"0482-6396")
    set_ISSN("j-REV-ESP-FISIOL",			"0034-9402")
    set_ISSN("j-REV-FINANCE",				"1572-3097 (print), 1875-824X (electronic)")
    set_ISSN("j-REV-FISH-BIOL-FISH",			"0960-3166 (print), 1573-5184 (electronic)")
    set_ISSN("j-REV-FISH-SCI-AQUAC",			"2330-8249")
    set_ISSN("j-REV-GEN-ELECTR",			"0035-3116 (print), 2419-6533 (electronic)")
    set_ISSN("j-REV-GEN-SCI-PURES-APPL",		"0370-7431")
    set_ISSN("j-REV-GEOPHYS-SPACE-PHYS",		"0034-6853")
    set_ISSN("j-REV-HIST-MATH",				"1262-022X (print), 1777-568X (electronic)")
    set_ISSN("j-REV-HIST-SCI-LEURS-APPL",		"0048-7996, 0151-4105, 1969-6582")
    set_ISSN("j-REV-HIST-SCI",				"0048-7996, 0151-4105, 1969-6582")
    set_ISSN("j-REV-INST-INT-STATIST",			"0373-1138")
    set_ISSN("j-REV-INT-ECON",				"0965-7576 (print), 1467-9396 (electronic)")
    set_ISSN("j-REV-MATH-IBER",				"0213-2230 (print), 2235-0616 (electronic)")
    set_ISSN("j-REV-MATH-PHYS",				"0129-055X (print), 1793-6659 (electronic)")
    set_ISSN("j-REV-METAPHYS",				"1549-4853 (print), 0034-6632 (electronic)")
    set_ISSN("j-REV-METAPHYS-MORALE",			"0035-1571 (print), 2102-5177 (electronic)")
    set_ISSN("j-REV-MEX-FIS",				"0035-001X")
    set_ISSN("j-REV-MOD-PHYS",				"0034-6861 (print), 1538-4527 (electronic), 1539-0756")
    set_ISSN("j-REV-NETW-ECON",				"2194-5993 (print), 1446-9022 (electronic)")
    set_ISSN("j-REV-PHILOS-FR-ETRANG",			"0035-3833 (print), 2104-385X (electronic)")
    set_ISSN("j-REV-PORT-PHILOS",			"0870-5283")
    set_ISSN("j-REV-QUEST-SCI",				"0035-2160")
    set_ISSN("j-REV-SCI-INSTRUM",			"0034-6748 (print), 1089-7623 (electronic)")
    set_ISSN("j-REV-SYMB-LOG",				"1755-0203 (print), 1755-0211 (electronic)")
    set_ISSN("j-REV-SYNTH",				"0035-1776 (print), 1955-2343 (electronic)")
    set_ISSN("j-REV-TUN",				"0330-809X")
    set_ISSN("j-RF-DESIGN",				"0163-321X (print), 1945-2535 (electronic)")
    set_ISSN("j-RHEOL-ACTA",				"0035-4511 (print), 1435-1528 (electronic)")
    set_ISSN("j-RHET-SOC-Q",				"0277-3945 (print), 1930-322X (electronic)")
    set_ISSN("j-RIC-MAT",				"0035-5038 (print), 1827-3491 (electronic)")
    set_ISSN("j-RIC-SCI",				"0035-5011")
    set_ISSN("j-RIC-SCI-PROG-TEC",			"????")
    set_ISSN("j-RISK-ANAL",				"0272-4332 (print), 1539-6924 (electronic)")
    set_ISSN("j-RISK-MANAGEMENT",			"0031-9228 (print), 1945-0699 (electronic)")
    set_ISSN("j-RISKNEWS",				"1612-8931 (print), 1616-0045 (electronic)")
    set_ISSN("j-RIV-INFO-FIRENZE",			"0390-668X")
    set_ISSN("j-RIV-INFO-MILANO",			"0390-668X", 1)
    set_ISSN("j-RIV-MAT-UNIV-PARMA",			"0035-6298")
    set_ISSN("j-RIV-NUOVO-CIMENTO",			"0393-697X (print), 1826-9850 (electronic)")
    set_ISSN("j-ROBOTICS-AGE",				"0197-1905")
    set_ISSN("j-ROCKY-MOUNTAIN-J-MATH",			"0035-7596 (print), 1945-3795 (electronic)")
    set_ISSN("j-ROCZ-FILOZ",				"0035-7685")
    set_ISSN("j-ROCZ-POL-TOW-MAT-SER-2",		"0373-8302")
    set_ISSN("j-ROUX-ARCH-DEV-BIOL",			"0930-035X")
    set_ISSN("j-RS-MAGAZINE",				"1088-0844, 1061-0030") # old 1061-0031 has bad checksum
    set_ISSN("j-RS-POWER-PC-MAGAZINE",			"1082-2313")
    set_ISSN("j-RSR",					"0090-7324")
    set_ISSN("j-RUSS-J-MATH-PHYS",			"1061-9208 (print), 1555-6638 (electronic)")
    set_ISSN("j-RUSS-J-NUM-ANAL-MATH-MODEL",		"0927-6467 (print), 1569-3988 (electronic)")
    set_ISSN("j-RUSS-J-PHYS-CHEM-A",			"0036-0244 (print), 1531-863X (electronic)")
    set_ISSN("j-RUSS-J-PHYS-CHEM-B",			"1990-7923 (print), 1990-7931 (electronic)")
    set_ISSN("j-RUSS-LIT",				"0304-3479 (print), 1878-3678 (electronic)")
    set_ISSN("j-RUSS-MATH",				"1066-369X (print), 1934-810X (electronic)")
    set_ISSN("j-RUSS-MATH-SURV",			"0036-0279")
    set_ISSN("j-RUTGERS-COMPUT-TECHNOL-LAW-J",		"0735-8938")
    set_ISSN("j-RUTGERS-J-COMP-TECH-LAW",		"0278-5633")
    set_ISSN("j-S-B-AKAD-WISS-WIEN-MATH-NATURWISS-KL-ABT-2A",	"0376-2629")
    set_ISSN("j-S-B-KAISERL-AKAD-WISS",			"0376-2629", 1)
    set_ISSN("j-S-B-KONIG-PREUSS-AKAD-WISS",		"0371-196X")
    set_ISSN("j-S-B-KONIG-PREUSS-AKAD-WISS-BERLIN",	"0371-196X")
    set_ISSN("j-S-B-MATH-NATURWISS-KL-KAISERL-AKAD-WISS", "0376-2629", 1)
    set_ISSN("j-S-B-PREUSS-AKAD-WISS",			"0371-196X")
    set_ISSN("j-S-B-PREUSS-AKAD-WISS-BERLIN",		"????")
    set_ISSN("j-S-B-PREUSS-AKAD-WISS-PHYS-MATH-KL",	"0371-2435")
    set_ISSN("j-SAMPL-THEORY-SIGNAL-IMAGE-PROCESS",	"1530-6429")
    set_ISSN("j-SAN-JOSE-MERCURY-NEWS",			"0747-2099")
    set_ISSN("j-SANKHYA",				"0036-4452")
    set_ISSN("j-SANKHYA-A",				"0036-4452")
    set_ISSN("j-SANKHYA-B",				"0581-5738")
    set_ISSN("j-SANTA-CLARA-COMP-HI-TECH-LAW-J",	"0882-3383")
    set_ISSN("j-SCAND-ACTUAR-J",			"0346-1238 (print), 1651-2030 (electronic)")
    set_ISSN("j-SCAND-J-HAEMATOL",			"0036-553X")
    set_ISSN("j-SCAND-J-STAT",				"0303-6898 (print), 1467-9469 (electronic)")
    set_ISSN("j-SCAND-J-THORAC-CARDIOVASC-SURG",	"0036-5580")
    set_ISSN("j-SCANNING-MICROSCOPY",			"0891-7035")
    set_ISSN("j-SCH-PUBL",				"0036-634X")
    set_ISSN("j-SCH-REV",				"0036-6773 (print), 1940-1213 (electronic)")
    set_ISSN("j-SCHOOL-LIBR-J",				"0362-8930")
    set_ISSN("j-SCHOOL-SCI-MATH",			"0036-6803 (print), 1949-8594 (electronic)")
    set_ISSN("j-SCHWEIZ-TECH-Z",			"0040-151X")
    set_ISSN("j-SCI-ADV",				"2375-2548")
    set_ISSN("j-SCI-AMER",				"0036-8733 (print), 1946-7087 (electronic)")
    set_ISSN("j-SCI-CHINA-MATH",			"1674-7283 (print), 1869-1862 (electronic)")
    set_ISSN("j-SCI-CHINA-SER-E-TECH-SCI",		"1006-9321 (print), 1862-281X (electronic)")
    set_ISSN("j-SCI-CITIZEN",				"2155-1278")
    set_ISSN("j-SCI-COMPUT",				"1930-5753 (print), 1930-6156 (electronic)")
    set_ISSN("j-SCI-COMPUT-PROGRAM",			"0167-6423 (print), 1872-7964 (electronic)")
    set_ISSN("j-SCI-CONTEXT",				"0269-8897 (print), 1474-0664 (electronic)")
    set_ISSN("j-SCI-CULT",				"0950-5431 (print), 1470-1189 (electronic)")
    set_ISSN("j-SCI-EDUC",				"0036-8326 (print), 1098-237X (electronic)")
    set_ISSN("j-SCI-EDUC-SPRINGER",			"0926-7220 (print), 1573-1901 (electronic)")
    set_ISSN("j-SCI-FICT-STUD",				"0091-7729 (print), 2327-6207 (electronic)")
    set_ISSN("j-SCI-INF-BULL",				"1048-5678")
    set_ISSN("j-SCI-LIGHT-TOKYO",			"0080-7583")
    set_ISSN("j-SCI-MATH-JPN",				"1346-0447 (print), 1346-0862 (electronic)")
    set_ISSN("j-SCI-MONTHLY",				"0096-3771 (print), 2327-7513 (electronic)")
    set_ISSN("j-SCI-NEWS-LETT",				"0096-4018 (print), 2326-1285 (electronic)")
    set_ISSN("j-SCI-PROC-ROY-DUBLIN-SOC",		"0371-2303")
    set_ISSN("j-SCI-PROG",				"1058-9244 (print), 1875-919X (electronic)")
    set_ISSN("j-SCI-PROG-RUSHDEN-UK",			"0036-8504 (print), 2047-7163 (electronic)")
    set_ISSN("j-SCI-PUBLIC-POL",			"0302-3427 (print), 1471-5430 (electronic)")
    set_ISSN("j-SCI-REP",				"2045-2322")
    set_ISSN("j-SCI-REV-MENT-HEALTH-PRAC",		"1538-4985")
    set_ISSN("j-SCI-SOC",				"0036-8237 (print), 1943-2801 (electronic)")
    set_ISSN("j-SCI-STUD",				"0036-8539")
    set_ISSN("j-SCI-TEACHER",				"0036-8547, 0036-8555")
    set_ISSN("j-SCI-TECHNOL-HUMAN-VALUES",		"0162-2439 (print),1552-8251 (electronic)")
    set_ISSN("j-SCI-TECHNOL-JPN",			"0286-0406")
    set_ISSN("j-SCI-TECHNOL-LIB",			"0194-262X (print), 1541-1109 (electronic)")
    set_ISSN("j-SCIENCE",				"0036-8075 (print), 1095-9203 (electronic)")
    set_ISSN("j-SCIENCE-NEWS",				"0036-8423 (print), 1943-0930 (electronic)")
    set_ISSN("j-SCIENCE-SOFTWARE",			"0893-9101")
    set_ISSN("j-SCIENCES",				"0036-861X")
    set_ISSN("j-SCIENTIA-MILAN",			"0036-8687 (print), 1825-4373 (electronic)")
    set_ISSN("j-SCIENTIST",				"0890-3670 (print), 1945-5127 (electronic)")
    set_ISSN("j-SCIENTOMETRICS",			"0138-9130 (print), 1588-2861 (electronic)")
    set_ISSN("j-SCITECH-J",				"1072-0995")
    set_ISSN("j-SCR-METALL",				"0036-9748 (print), 1878-2663 (electronic)")
    set_ISSN("j-SCR-METALL-MATER",			"0956-716X (print), 1873-2712 (electronic)")
    set_ISSN("j-SCREEN",				"0036-9543") # alternate 0036-1034 is not in Ulrich's
    set_ISSN("j-SEARCHER",				"1070-4795")
    set_ISSN("j-SECOND-MESSENGERS-PHOSPHOPROTEINS",	"0895-7479")
    set_ISSN("j-SECURITY",				"0890-8826")
    set_ISSN("j-SEJ",					"0268-6961")
    set_ISSN("j-SEM-CELL-BIOL",				"1043-4682 (print), 1522-967X (electronic)")
    set_ISSN("j-SEM-HOP-PARIS",				"0037-1777")
    set_ISSN("j-SEMIN-HEMATOL",				"0037-1963 (print), 1532-8686 (electronic)")
    set_ISSN("j-SEMIOTICA",				"0037-1998 (print), 1613-3692 (electronic)")
    set_ISSN("j-SENSORS-BASEL",				"1424-8220")
    set_ISSN("j-SER-REV",				"0098-7913 (print), 1879-095X (electronic)")
    set_ISSN("j-SERB-ASTRON-J",				"1450-698X (print), 1820-9289 (electronic)")
    set_ISSN("j-SERDICA-MATH-J",			"1310-6600")
    set_ISSN("j-SERIALS-LIBRARIAN",			"0361-526X")
    ## BAD: set_ISSN("j-SERIF",					"1080-2070")
    set_ISSN("j-SERIF",					"1080-2207")	# [04-Jan-2006] corrected
    set_ISSN("j-SERVICE-NEWS-CESSP",			"1046-1965")
    set_ISSN("j-SET-VALUED-ANAL",			"0927-6947 (print), 1572-932X (electronic)")
    set_ISSN("j-SET-VALUED-VAR-ANAL",			"1877-0533 (print), 1877-0541 (electronic)")
    set_ISSN("j-SEX-ROLES",				"0360-0025 (print), 1573-2762 (electronic)")
    set_ISSN("j-SEYBOLD-REP-DESKTOP-PUB",		"0889-9762")
    set_ISSN("j-SEYBOLD-REP-INTERNET-PUBLISHING",       "1090-4808")
    set_ISSN("j-SEYBOLD-REP-PUB-SYS",			"0736-7260")
    set_ISSN("j-SIAM-ASA-J-UNCERTAIN-QUANTIF",		"2166-2525")
    set_ISSN("j-SIAM-J-ALG-DISC-METH",			"0196-5212 (print), 2168-345X (electronic)")
    set_ISSN("j-SIAM-J-APPL-ALGEBR-GEOM",		"2470-6566")
    set_ISSN("j-SIAM-J-APPL-DYN-SYST",			"1536-0040")
#   set_ISSN("j-SIAM-J-APPL-MATH",			"0036-1399 (print), 1095-712X (electronic)")
    set_ISSN("j-SIAM-J-APPL-MATH",			"0036-1399 (print), 1095-712X (electronic)")
#   set_ISSN("j-SIAM-J-COMPUT",				"0097-5397 (print), 1095-7111 (electronic)")
    set_ISSN("j-SIAM-J-COMPUT",				"0097-5397 (print), 1095-7111 (electronic)")
    set_ISSN("j-SIAM-J-CONTROL",			"0036-1402 (print), 2469-4231 (electronic)")
#   set_ISSN("j-SIAM-J-CONTROL-OPTIM",			"0363-0129 (print), 1095-7138 (electronic)")
    set_ISSN("j-SIAM-J-CONTROL-OPTIM",			"0363-0129 (print), 1095-7138 (electronic)")
#   set_ISSN("j-SIAM-J-DISCR-MATH",			"0895-4801 (print), 1095-7146 (electronic)")
    set_ISSN("j-SIAM-J-DISCR-MATH",			"0895-4801 (print), 1095-7146 (electronic)")
    set_ISSN("j-SIAM-J-FINANCIAL-MATH",			"1945-497X")
    set_ISSN("j-SIAM-J-IMAGING-SCI",			"1936-4954")
#   set_ISSN("j-SIAM-J-MAT-ANA-APPL",			"0895-4798 (print), 1095-7162 (electronic)")
    set_ISSN("j-SIAM-J-MAT-ANA-APPL",			"0895-4798 (print), 1095-7162 (electronic)")
#   set_ISSN("j-SIAM-J-MATH-ANA",			"0036-1410 (print), 1095-7154 (electronic)")
    set_ISSN("j-SIAM-J-MATH-ANA",			"0036-1410 (print), 1095-7154 (electronic)")
    set_ISSN("j-SIAM-J-MATH-DATA-SCI",			"2577-0187")
#   set_ISSN("j-SIAM-J-NUMER-ANAL",			"0036-1429 (print), 1095-7170 (electronic)")
    set_ISSN("j-SIAM-J-NUMER-ANAL",			"0036-1429 (print), 1095-7170 (electronic)")
    set_ISSN("j-SIAM-J-NUM-ANALYSIS-B",			"0887-459X (print), 2168-3581 (electronic)")
    set_ISSN("j-SIAM-J-OPT",				"1052-6234 (print), 1095-7189 (electronic)")
    set_ISSN("j-SIAM-NEWS",				"0036-1437")
#   set_ISSN("j-SIAM-REVIEW",				"0036-1445 (print), 1095-7200 (electronic)")
    set_ISSN("j-SIAM-REVIEW",				"0036-1445 (print), 1095-7200 (electronic)")
    set_ISSN("j-SIAM-THEOR-PROB-APPL",			"????")
    set_ISSN("j-SIB-MAT-Z",				"0037-4474")
    set_ISSN("j-SIB-MATH-J",				"0037-4466 (print), 1573-9260 (electronic)")
    set_ISSN("j-SIBERIAN-ADV-MATH",			"1055-1344 (print), 1934-8126 (electronic)")
    set_ISSN("j-SID-DIG-TECH-PAP",			"0097-966X")
    set_ISSN("j-SIG-PROC",				"0165-1684 (print), 1872-7557 (electronic)")
    set_ISSN("j-SIGACT",				"0163-5700 (print), 1943-5827 (electronic)")
    set_ISSN("j-SIGADA-LETTERS",			"1094-3641 (print), 1557-9476 (electronic)")
    set_ISSN("j-SIGAPP",				"1559-6915 (print), 1931-0161 (electronic)")
    set_ISSN("j-SIGBIO-NEWSLETTER",			"0163-5697 (print), 1557-9506 (electronic)")
    set_ISSN("j-SIGCAPH",				"0163-5727")
    set_ISSN("j-SIGCHI",				"0736-6906 (print), 1558-1217 (electronic)")
    set_ISSN("j-SIGCSE",				"0097-8418 (print), 2331-3927 (electronic)")
    set_ISSN("j-SIGDOC",				"0731-1001", 1)
    set_ISSN("j-SIGIR-FORUM",				"0163-5840 (print), 1558-0229 (electronic)")
    set_ISSN("j-SIGKDD",				"1931-0145 (print), 1931-0153 (electronic)")
    set_ISSN("j-SIGMA-CHI-Q",				"0096-977X (print), 2327-7548 (electronic)")
    set_ISSN("j-SIGMAP-NEWSLETTER",			"0364-5509")
    set_ISSN("j-SIGMETRICS",				"0163-5999 (print), 1557-9484 (electronic)")
    set_ISSN("j-SIGMICRO",				"0163-5751, 1050-916X")
    set_ISSN("j-SIGMOD",				"0163-5808 (print), 1943-5835 (electronic)")
    set_ISSN("j-SIGNAL-PROCESS-IMAGE-COMMUN",		"0923-5965 (print), 1879-2677 (electronic)")
    set_ISSN("j-SIGNIF",				"1740-9705 (print), 1740-9713 (electronic)")
    set_ISSN("j-SIGNUM",				"0163-5778 (print), 1558-0237 (electronic)")
    set_ISSN("j-SIGOIS",				"0894-0819")

    ## SIGPLAN notices 1969-1991	0362-1340
    ## ACM SIGPLAN notices 1991-	1523-2867
    ## SIGPLAN notices (Online)		1558-1160
    ## ACM SIGPLAN notices linking	0362-1340
    set_ISSN("j-SIGPLAN",				"0362-1340 (print), 1523-2867 (print), 1558-1160 (electronic)")

    set_ISSN("j-SIGSAC-REVIEW",				"0277-920X (print), 1558-0261 (electronic)")
    set_ISSN("j-SIGSAM",				"0163-5824 (print), 1557-9492 (electronic)")
    set_ISSN("j-SIGSMALL-PC-NOTES",			"0893-2875 (print), 1558-285X (electronic)")
    set_ISSN("j-SIGSOFT",				"0163-5948 (print), 1943-5843 (electronic)")
    set_ISSN("j-SIGUCCS-NEWSL",				"0736-6892")
    set_ISSN("j-SILICON-GRAPHICS-WORLD",		"1057-7041")
    set_ISSN("j-SIM-MODEL-PRACT-THEORY",		"1569-190X (print), 1878-1462 (electronic)")
    set_ISSN("j-SIM-NEWS-EUROPE",			"0929-2268")
    set_ISSN("j-SIM-PRACT-THEORY",			"0928-4869 (print), 1879-1433 (electronic)")
    set_ISSN("j-SIM-SERIES",				"0735-9276")
    set_ISSN("j-SIMON-STEVIN",				"0037-5454")
    set_ISSN("j-SIMULATION",				"0037-5497 (print), 1741-3133 (electronic)")
    set_ISSN("j-SIMULETTER",				"0163-6103")
    set_ISSN("j-SJCC",					"????")
    set_ISSN("j-SKEPT-INQ",				"0194-6730")
    set_ISSN("j-SKY-TELESC",				"0037-6604")
    set_ISSN("j-SMART-MAT-STRUCT",			"0964-1726 (print), 1361-665X (electronic)")
    set_ISSN("j-SMITHSON-INST-ANNU-REP",		"0097-644X")
    set_ISSN("j-SMITHSONIAN",				"0037-7333 (print), 1930-5508 (electronic)")
    set_ISSN("j-SOC-INDIC-RES",				"0303-8300 (print), 1573-0921 (electronic)")
    set_ISSN("j-SOC-METH-RES",				"0049-1241 (print), 1552-8294 (electronic)")
    set_ISSN("j-SOC-PET-ENG-J",				"0197-7520")
    set_ISSN("j-SOC-PROBL",				"0037-7791 (print), 1533-8533 (electronic)")
    set_ISSN("j-SOC-SCI",				"0970-0293")
    set_ISSN("j-SOC-SCI-INFO",				"0539-0184 (print), 1461-7412 (electronic)")
    set_ISSN("j-SOC-STUD-SCI",				"0306-3127 (print), 1460-3659 (electronic)")
    set_ISSN("j-SOC-TEXT",				"0164-2472 (print), 1527-1951 (electronic)")
    set_ISSN("j-SOCIAL-SCI-COMP-REV",			"0894-4393 (print), 1552-8286 (electronic)")
    set_ISSN("j-SOCIO-ECON",				"1053-5357 (print), 1879-1239 (electronic)")
    set_ISSN("j-SOCIO-ECON-PLANN-SCI",			"0038-0121 (print), 1873-6041 (electronic)")
    set_ISSN("j-SOCIOL-METHODS-RES",			"0049-1241 (print), 1552-8294 (electronic)")
    set_ISSN("j-SOFT-COMP",				"1195-3934")
    set_ISSN("j-SOFT-PROT",				"0733-1274")
    set_ISSN("j-SOFTWARE-CONCEPTS-TOOLS",		"0945-8115 (print), 1432-2188 (electronic)")
    set_ISSN("j-SOFTWARE-ECONOMICS-LETTER",		"1065-6146")
    set_ISSN("j-SOFTWARE-ENG-WORKSTATIONS",		"0266-9463, 0952-8768")
    set_ISSN("j-SOFTWARE-LAW-J",			"0886-3628")
    set_ISSN("j-SOFTWARE-MAG",				"0897-8085")
    set_ISSN("j-SOFTWARE-NEWS",				"0279-9782")
    set_ISSN("j-SOFTWARE-SYST-MODEL",			"1619-1366 (print), 1619-1374 (electronic)")
    set_ISSN("j-SOGO-RINSHO",				"0560-7477")
    set_ISSN("j-SOLID-STATE-COMMUN",			"0038-1098 (print), 1879-2766 (electronic)")
    set_ISSN("j-SOLID-STATE-PHYS-N-Y-1955",		"0081-1947")
    set_ISSN("j-SOURCE-ART",				"0737-4453")
    set_ISSN("j-SOUTH-AFRICAN-COMP-J",			"1015-7999")
    set_ISSN("j-SOUTHCON",				"")
    set_ISSN("j-SOV-J-COMP-SYS-SCI",			"0882-4002")
    set_ISSN("j-SOV-J-NUM-ANA-MATH-MOD",		"0169-2895")
    set_ISSN("j-SOV-J-QUANTUM-ELECTRON",		"0049-1748")
    set_ISSN("j-SOV-MATH-NY",				"0197-7156")
    set_ISSN("j-SOV-MATH-PROVIDENCE",			"0038-5573")
    set_ISSN("j-SOV-PHYS-JETP",				"0038-5646")
    set_ISSN("j-SOV-PHYS-SOLID-STATE",			"0038-5654")
    set_ISSN("j-SOV-PHYS-USP",				"0038-5670")
    set_ISSN("j-SOVIET-J-DEVEL-BIO",			"0049-173X")
    set_ISSN("j-SOVIET-MATH-DOKL",			"0197-6788")
    set_ISSN("j-SOVIET-PHYS-DOKL",			"0038-5689")
    set_ISSN("j-SPACE-SCI-REV",				"0038-6308 (print), 1572-9672 (electronic)")
    set_ISSN("j-SPATIAL-VIS",				"0169-1015 (print), 1568-5683 (electronic)")
    set_ISSN("j-SPE",					"0038-0644 (print), 1097-024X (electronic)")
    set_ISSN("j-SPE-ASIA-PACIFIC-OIL-GAS-CONF",		"????")
    set_ISSN("j-SPEC-LIBR",				"0038-6723")
    set_ISSN("j-SPECTROCHIM-ACTA",			"0038-6987")
    set_ISSN("j-SPECTROCHIMICA-ACTA-A",			"0584-8539 (print), 1873-3824 (electronic)")
    set_ISSN("j-SPEECH",				"????")
    set_ISSN("j-SPEECH-COMM",				"0167-6393 (print), 1872-7182 (electronic)")
    set_ISSN("j-SPEKTRUM-WISSENSCHAFT",			"0170-2971")
    set_ISSN("j-SPELMAN-SCI-MATH-J",			"1098-4593")
    set_ISSN("j-SPIP",					"1077-4866 (print), 1099-1670 (electronic)")
    set_ISSN("j-SPONT-GEN",				"1913-0465")
    set_ISSN("j-SPRAY-TECHNOL-MARK",			"1055-2340")
    set_ISSN("j-SPRINGER-SER-CHEM-PHYS",		"0172-6218")
    set_ISSN("j-SPRINGERPLUS",				"2193-1801")
    set_ISSN("j-ST-PETERSBG-MATH-J",			"1061-0022")
    set_ISSN("j-STAG",					"????")	# Maybe: 0005-0628 : The Author : journal of the Society of Authors.
    set_ISSN("j-STANFORD-VIDEO-J",			"????")
    set_ISSN("j-STAT-COMPUT",				"0960-3174 (print), 1573-1375 (electronic)")
    set_ISSN("j-STAT-INTERFACE",			"1938-7989 (print), 1938-7997 (electronic)")
    set_ISSN("j-STAT-MED",				"0277-6715 (print), 1097-0258 (electronic)")
    set_ISSN("j-STAT-METHODOL",				"1572-3127 (print), 1878-0954 (electronic)")
    set_ISSN("j-STAT-NEERLANDICA",			"0039-0402 (print), 1467-9574 (electronic)")
    set_ISSN("j-STAT-PAPERS",				"0932-5026 (print), 1613-9798 (electronic)")
    set_ISSN("j-STAT-PROB-LETT",			"0167-7152 (print), 1879-2103 (electronic)")
    set_ISSN("j-STAT-SCI",				"0883-4237 (print), 2168-8745 (electronic)")
    set_ISSN("j-STAT-SINICA",				"1017-0405 (print), 1996-8507 (electronic)")
    set_ISSN("j-STATIST-PAPERS",			"0932-5026 (print), 1613-9798 (electronic)")
    set_ISSN("j-STATISTICA-BOLOGNA",			"0390-590X (print), 1973-2201 (electronic)")
    set_ISSN("j-STATISTICS",				"0233-1888 (print), 1029-4910 (electronic)")
    set_ISSN("j-STEREO-REV",				"0039-1220")
    set_ISSN("j-STERNE-WELTRAUM",			"0039-1263 (print), 1434-520X (electronic)")
    set_ISSN("j-STOCH-ANAL-APPL",			"0736-2994 (print), 1532-9356 (electronic)")
    set_ISSN("j-STOCH-DYNAM",				"0219-4937")
    set_ISSN("j-STOCH-MODELS",				"1532-6349")
    set_ISSN("j-STOCH-PROC-APPL",			"0304-4149 (print), 1879-209X (electronic)")
    set_ISSN("j-STOCH-STOCH-REP",			"1045-1129")
    set_ISSN("j-STOCH-SYS-APPL",			"????")
    set_ISSN("j-STRUCT",				"0969-2126 (print), 1878-4186 (electronic)")
    set_ISSN("j-STRUCT-CHEM",				"1040-0400 (print), 1572-9001 (electronic)")
    set_ISSN("j-STRUCT-MULTDISCIP-0PTIM",		"1615-147X (print), 1615-1488 (electronic)")
    set_ISSN("j-STRUCT-OPTIM",				"0934-4373 (print), 1436-2503 (electronic)")
    set_ISSN("j-STUD-APPL-MATH",			"0022-2526 (print), 1467-9590 (electronic)")
    set_ISSN("j-STUD-BIOPHYS",				"0081-6337")
    set_ISSN("j-STUD-CERCET-MAT",			"0039-4068, 0567-6401")
    set_ISSN("j-STUD-EAST-EUROPEAN-THOUGHT",		"0925-9392 (print), 1573-0948 (electronic)")
    set_ISSN("j-STUD-HIST-PHILOS-SCI",			"0039-3681 (print), 1879-2510 (electronic)")
    set_ISSN("j-STUD-HIST-PHILOS-SCI-B",		"0039-3681 (print), 1879-2510 (electronic)") # LC says this is incorrect, but publisher uses it
    set_ISSN("j-STUD-HIST-PHILOS-SCI-C",		"1369-8486 (print), 1879-2499 (electronic)")
    set_ISSN("j-STUD-HIST-PHILOS-MOD-PHYS",		"1355-2198 (print), 1879-2502 (electronic)")
    set_ISSN("j-STUD-LINGUIST",				"0039-3193 (print), 1467-9582 (electronic)")
    set_ISSN("j-STUD-LOGICA",				"0039-3215 (print), 1572-8730 (electronic)")
    set_ISSN("j-STUD-SOV-THOUGHT",			"0039-3797 (print), 2214-7136 (electronic)")
    set_ISSN("j-STUD-STOR",				"0039-3037 (print), 2036-458X (electronic)")
    set_ISSN("j-STUDIA-MATH",				"0039-3223 (print), 1730-6337 (electronic)")
    set_ISSN("j-STUDIA-ROSE",				"0039-3347")
    set_ISSN("j-STUDIES-COMP-SCI-ART-INTELL",		"0924-3542")
    set_ISSN("j-STUDIES-INTEGRO-DIFF-EQ",		"????")
    set_ISSN("j-STUDIUM-GEN",				"0039-4149")
    set_ISSN("j-SUDHOFFS-ARCH",				"0039-4564")
    set_ISSN("j-SUN-OBSERVER",				"1058-5400")
    set_ISSN("j-SUNEXPERT",				"1053-9239")
    set_ISSN("j-SUNSERVER",				"1091-4986")
    set_ISSN("j-SUNWORLD",				"0149-1938")
    set_ISSN("j-SUNWORLD-ONLINE",			"1091-8914")
    set_ISSN("j-SUPERCOMPUTER",				"0168-7875")
    set_ISSN("j-SUPERCOMPUTING-REVIEW",			"1048-6836")
    set_ISSN("j-SUPERCOND-SCI-TECHNOL",			"0953-2048 (print), 1361-6668 (electronic)")
    set_ISSN("j-SURF-INTERFACE-ANAL",			"0142-2421 (print), 1096-9918 (electronic)")
    set_ISSN("j-SURF-SCI",				"0039-6028 (print), 1879-2758 (electronic)")
    set_ISSN("j-SURF-SCI-LETT",				"0167-2584 (print), 1878-1047 (electronic)")
    set_ISSN("j-SURVIVAL",				"0039-6338 (print), 1468-2699 (electronic)")
    set_ISSN("j-SURVIVE",				"0039-6354")
    set_ISSN("j-SVENSK-KEMISK-TIDSKRIFT",		"0039-6605")
    set_ISSN("j-SVENSK-NATURVETENSKAP",			"0373-1359")
    set_ISSN("j-SWIAT-NAUKI",				"0867-6380 (print), 1689-0191 (electronic)")
    set_ISSN("j-SYMP-SOC-EXP-BIO",			"0081-1386")
    set_ISSN("j-SYMPOSIA-MATHEMATICA",			"0082-0725")
    set_ISSN("j-SYNTHESE",				"0039-7857 (print), 1573-0964 (electronic)")
    set_ISSN("j-SYS-ADMIN",				"1061-2688")
    set_ISSN("j-SYS-ANA-MODEL-SIM",			"0232-9298")
    set_ISSN("j-SYS-COMP-JAPAN",			"0882-1666 (print), 1520-684X (electronic)")
    set_ISSN("j-SYS-INTEGRATION",			"1044-4262")
    set_ISSN("j-SYST-CONTROL-INFO",			"0374-4507")
    set_ISSN("j-SYST-CONTROL-LETT",			"0167-6911 (print), 1872-7956 (electronic)")
    set_ISSN("j-SYST-RES",				"0731-7239 (print), 1099-1735 (electronic)")
    set_ISSN("j-SYST-RES-BEHAV-SCI",			"1092-7026 (print), 1099-1743 (electronic)")
    set_ISSN("j-SYSTEM",				"0346-251X (print), 1879-3282 (electronic)")
    set_ISSN("j-TAAS",					"????")
    set_ISSN("j-TACCESS",				"1936-7228 (print), 1936-7236 (electronic)")
    set_ISSN("j-TACO",					"1544-3566 (print), 1544-3973 (electronic)")
    set_ISSN("j-TAEHAN-HWAHAKHOE-CHI",			"0418-2472")
    set_ISSN("j-TALG",					"1549-6325 (print), 1549-6333 (electronic)")
    set_ISSN("j-TALIP",					"1530-0226 (print), 1558-3430 (electronic)")
    set_ISSN("j-TALLIP",				"2375-4699 (print), 2375-4702 (electronic)")
    set_ISSN("j-TAMKANG-J-MATH",			"0049-2930 (print), 2073-9826 (electronic)")
    set_ISSN("j-TAP",					"1544-3558 (print), 1544-3965 (electronic)")
    set_ISSN("j-TAPPI-J",				"0734-1415")
    set_ISSN("j-TAXON",					"0040-0262 (print), 1996-8175 (electronic)")
    set_ISSN("j-TCBB",					"1545-5963 (print), 1557-9964 (electronic)")
    set_ISSN("j-TCPS",					"2378-962X (print), 2378-9638 (electronic)")
    set_ISSN("j-TDS",					"2691-1922")
    set_ISSN("j-TEAC",					"2167-8375 (print), 2167-8383 (electronic)")
    set_ISSN("j-TEACHING-PSYCH",			"0098-6283 (print), 1532-8023 (electronic)")
    set_ISSN("j-TECH-COMMUN",				"0049-3155 (print), 1938-369X (electronic)")
    set_ISSN("j-TECH-CULTURE",				"0040-165X (print), 1097-3729 (electronic)")
    set_ISSN("j-TECH-LEARNING",				"1053-6728")
    set_ISSN("j-TECH-MITT-KRUPP-ENGL-ED",		"0930-9284")
    set_ISSN("j-TECH-REVIEW",				"0040-1692")
    set_ISSN("j-TECHNIQUE-SCI-INFORMATIQUES",		"0752-4072 (print), 2116-5920 (electronic)")
    set_ISSN("j-TECHNOL-FORECAST-SOC-CHANGE",		"0040-1625 (print), 1873-5509 (electronic)")
    set_ISSN("j-TECHNOL-SOC",				"0160-791X (print), 1879-3274 (electronic)")
    set_ISSN("j-TECHNOMETRICS",				"0040-1706 (print), 1537-2723 (electronic)")
    set_ISSN("j-TECHNOVATION",				"0166-4972 (print), 1879-2383 (electronic)")
    set_ISSN("j-TECHTRENDS",				"8756-3894")
    set_ISSN("j-TECS",					"1539-9087 (print), 1558-3465 (electronic)")
    set_ISSN("j-TELECOMM-RADIO-ENG",			"0040-2508 (print), 1943-6009 (electronic)")
    set_ISSN("j-TELECOMMUNICATIONS-AMERICAS-ED",	"0278-4831")
    set_ISSN("j-TELECOMMUNICATIONS-INT-ED",		"0040-2494, 0278-484X")
    set_ISSN("j-TELEMAT-INFORM",			"0736-5853 (print), 1879-324X (electronic)")
    set_ISSN("j-TELEPHONY",                             "0040-2656 (print), 2161-8690 (electronic)")
    set_ISSN("j-TEORET-MATH-FIZ",			"0564-6162")
    set_ISSN("j-TEST",					"1133-0686 (print), 1863-8260 (electronic)")
    set_ISSN("j-TETRAHEDRON-COMPUT-METH",		"0898-5529 (print), 1878-335X (electronic)")
    set_ISSN("j-TEX-J-SCI",				"0040-4403")
    set_ISSN("j-TEX-TUG-NEWS",				"1065-240X")
    set_ISSN("j-TEXHAX",				"????")
    set_ISSN("j-TEXLINE",				"????")
    set_ISSN("j-TEXNIQUES",				"????")
    set_ISSN("j-TEXTURES-MICROSTRUCT",			"0730-3300")
    set_ISSN("j-THE-J",					"0192-592X")
    set_ISSN("j-THEOR-BIOL-MED-MODEL",			"1742-4682")
    set_ISSN("j-THEOR-CHEM-ACCOUNTS",			"1432-881X (print), 1432-2234 (electronic)")
    set_ISSN("j-THEOR-CHEM-LONDON",			"0305-9995")
    set_ISSN("j-THEOR-CHIM-ACTA",			"0040-5744")
    set_ISSN("j-THEOR-COMP-SCI",			"0304-3975 (print), 1879-2294 (electronic)")
    set_ISSN("j-THEOR-MATH-PHYS",			"0040-5779 (print), 1573-9333 (electronic)")
    set_ISSN("j-THEOR-POPUL-BIOL",			"0040-5809 (print), 1096-0325 (electronic)")
    set_ISSN("j-THEOREMA",				"0210-1602")
    set_ISSN("j-THEORIA",				"0040-5825 (print), 1755-2567 (electronic)")
    set_ISSN("j-THEORIA-MADRID",			"0495-4548 (print), 2171-679X (electronic)")
    set_ISSN("j-THEORY-COMPUT-SYST",			"1432-4350 (print), 1433-0490 (electronic)")
    set_ISSN("j-THEORY-DECISION",			"0040-5833 (print), 1573-7187 (electronic)")
#   set_ISSN("j-THEORY-PROBAB-APPL",			"0040-585X (print), 1095-7219 (electronic)")
    set_ISSN("j-THEORY-PROBAB-APPL",			"0040-585X (print), 1095-7219 (electronic)")
    set_ISSN("j-THEORY-PROBAB-MATH-STAT",		"0094-9000 (print), 1547-7363 (electronic)")
    set_ISSN("j-THIN-WALLED-STRUCTURES",		"0263-8231 (print), 1879-3223 (electronic)")
    set_ISSN("j-THRI",					"2573-9522 (electronic)")
    set_ISSN("j-THROMB-DIATH-HAEMORRH",			"0340-5338")
    set_ISSN("j-TIME",					"0040-781X (print), 2169-1665 (electronic)")
    ## set_ISSN("j-TIMES",					"0140-0460, 0956-1382, 1363-7746")
    set_ISSN("j-TIMES",					"0140-0460, 0956-1382")
    set_ISSN("j-TIIS",					"2160-6455 (print), 2160-6463 (electronic)")
    set_ISSN("j-TIOT",					"2691-1914 (print), 2577-6207 (electronic)")
    set_ISSN("j-TISSEC",				"1094-9224 (print), 1557-7406 (electronic)")
    set_ISSN("j-TIST",					"2157-6904 (print), 2157-6912 (electronic)")
    set_ISSN("j-TKDD",					"1556-4681 (print), 1556-472X (electronic)")
    set_ISSN("j-TMIS",					"2158-656X")
    set_ISSN("j-TOCE",					"1946-6226")
    set_ISSN("j-TOCH",					"2691-1957 (print), 2637-8051 (electronic)")
    set_ISSN("j-TOCHI",					"1073-0516 (print), 1557-7325 (electronic)")
    set_ISSN("j-TOCL",					"1529-3785 (print), 1557-945X (electronic)")
    set_ISSN("j-TOCS",					"0734-2071 (print), 1557-7333 (electronic)")
    set_ISSN("j-TOCT",					"1942-3454 (print), 1942-3462 (electronic)")
    set_ISSN("j-TODAES",				"1084-4309 (print), 1557-7309 (electronic)")
    set_ISSN("j-TODS",					"0362-5915 (print), 1557-4644 (electronic)")
    set_ISSN("j-TOG",					"0730-0301 (print), 1557-7368 (electronic)")
    set_ISSN("j-TOIS",					"1046-8188")
    set_ISSN("j-TOIT",					"1533-5399 (print), 1557-6051 (electronic)")
    set_ISSN("j-TOKYO-J-MATH",				"0387-3870")
    set_ISSN("j-TOMACS",				"1049-3301 (print), 1558-1195 (electronic)")
    set_ISSN("j-TOMCCAP",				"1551-6857 (print), 1551-6865 (electronic)")
    set_ISSN("j-TOMM",					"1551-6857 (print), 1551-6865 (electronic)", 1)
    set_ISSN("j-TOMPECS",				"2376-3639 (print), 2376-3647 (electronic)")
    set_ISSN("j-TOMS",					"0098-3500 (print), 1557-7295 (electronic)")
    set_ISSN("j-TOOIS",					"0734-2047")
    set_ISSN("j-TOPC",					"2329-4949 (print), 2329-4957 (electronic)")
    set_ISSN("j-TOPLAS",				"0164-0925 (print), 1558-4593 (electronic)")
    set_ISSN("j-TOPOI",					"0167-7411 (print), 1572-8749 (electronic)")
    set_ISSN("j-TOPOLOGY",				"0040-9383 (print), 1879-3215 (electronic)")
    set_ISSN("j-TOPS",					"2471-2566 (print), 2471-2574 (electronic)")
    set_ISSN("j-TORS",					"2770-6699")
    set_ISSN("j-TOS",					"1553-3077 (print), 1553-3093 (electronic)")
    set_ISSN("j-TOSEM",					"1049-331X (print), 1557-7392 (electronic)")
    set_ISSN("j-TOSN",					"1550-4859 (print), 1550-4867 (electronic)")
    set_ISSN("j-TOXICOL-APPL-PHARMACOL",		"0041-008X (print), 1096-0333 (electronic)")
    set_ISSN("j-TQC",					"2643-6809 (print), 2643-6817 (electronic)")
    set_ISSN("j-TRAITE-SIGNAL",				"0765-0019 (print), 1958-5608 (electronic)")
    set_ISSN("j-TRANS-AM-FISH-SOC",			"0002-8487 (print), 1548-8659 (electronic)")
    set_ISSN("j-TRANS-AM-MATH-SOC",			"0002-9947 (print), 1088-6850 (electronic)")
    set_ISSN("j-TRANS-AM-NUCL-SOC",			"0003-018X")
    set_ISSN("j-TRANS-AM-PHILOS-SOC-N-S",		"0065-9746")
    set_ISSN("j-TRANS-AMER-INST-ELEC-ENG",		"0096-3860")
    set_ISSN("j-TRANS-ASAE",				"0001-2351 (print), 2151-0059 (electronic)")
    set_ISSN("j-TRANS-ASME-C",				"????")
    set_ISSN("j-TRANS-ASME-D",				"0021-9223")
    set_ISSN("j-TRANS-BOSE-RES-INST-CALCUTTA",		"0006-7903")
    set_ISSN("j-TRANS-CAMBRIDGE-PHILOS-SOC",		"????")
    set_ISSN("j-TRANS-FARADAY-SOC",			"0014-7672")
    set_ISSN("j-TRANS-GIS",				"1361-1682 (print), 1467-9671 (electronic)")
    set_ISSN("j-TRANS-IEICE-D-II",			"0915-1923")
    set_ISSN("j-TRANS-INFO-PROCESSING-SOC-JAPAN",	"0387-5806")
    set_ISSN("j-TRANS-IRE",				"????")
    set_ISSN("j-TRANS-IRE-PROF-GROUP-INF-THEORY",	"2168-2690")
    set_ISSN("j-TRANS-MATH-APPL",			"2398-4945")
    set_ISSN("j-TRANS-N-Y-ACAD-SCI-2",			"0028-7113 (print), 1939-2966 (electronic)")
    set_ISSN("j-TRANS-PROC-N-Z-INST",			"0035-9181")
    set_ISSN("j-TRANS-PROC-R-SOC-N-Z",			"0035-9181")
    set_ISSN("j-TRANS-R-SOC-CAN",			"0035-9122")
    set_ISSN("j-TRANS-R-SOC-EDINBURGH",			"0080-4568 (print), 2053-5945 (electronic)")
    set_ISSN("j-TRANS-SAIEE",				"0038-2221")
    set_ISSN("j-TRANS-SOC-COMP-SIM",			"0740-6797")
    set_ISSN("j-TRANS-SOC-INST-CONTROL-ENG",		"0453-4654")
    set_ISSN("j-TRANSP-DISTRIB",			"0895-8548")
    set_ISSN("j-TRANS-SOC-RHEOLOGY",			"0038-0032")
    set_ISSN("j-TRANSFUSION",				"0041-1132 (print), 1537-2995 (electronic)")
    set_ISSN("j-TRANSPORT-RES",				"0041-1647 (print), 1878-3821 (electronic)")
    set_ISSN("j-TRANSPORT-SCI",				"0041-1655 (print), 1526-5447 (electronic)")
    set_ISSN("j-TRAV-HUM",				"0041-1868 (print), 2104-3663 (electronic)")
    set_ISSN("j-TRAVAUX-SCI",				"0243-7473")
    set_ISSN("j-TRENDS-BIOCHEM-SCI",			"0968-0004, 0167-7640, 0376-5067")
    set_ISSN("j-TRENDS-COGN-SCI",			"1364-6613 (print), 1879-307X (electronic)")
    set_ISSN("j-TRENDS-ECOL-EVOL",			"0169-5347 (print), 1872-8383 (electronic)")
    set_ISSN("j-TRENDS-GENET",				"0168-9525")
    set_ISSN("j-TRENDS-MICROBIOL",			"0966-842X (print), 1878-4380 (electronic)")
    set_ISSN("j-TRENDS-NEUROSCI",			"0166-2236, 0378-5912")
    set_ISSN("j-TRETS",					"1936-7406 (print), 1936-7414 (electronic)")
    set_ISSN("j-TSAS",					"2374-0353 (print), 2374-0361 (electronic)")
    set_ISSN("j-TSC",					"2469-7818 (print), 2469-7826 (electronic)")
    set_ISSN("j-TSI",					"0264-7419")
    set_ISSN("j-TSLP",					"1550-4875")
    set_ISSN("j-TUGBOAT",				"0896-3207")
    set_ISSN("j-TUMORI",				"0300-8916 (print), 2038-2529 (electronic)")
    set_ISSN("j-TURBOMACH-INT",				"0149-4147")
    set_ISSN("j-TWEB",					"1559-1131 (print), 1559-114X (electronic)")
    set_ISSN("j-TWIO",					"????")
    set_ISSN("j-TWO-YEAR-COLL-MATH-J",			"0049-4925 (print), 2325-9116 (electronic)")
    set_ISSN("j-U-LC",					"0362-6245")
    set_ISSN("j-UKR-MAT-Z",				"0041-6053")
    set_ISSN("j-ULTIM-REAL-MEAN",			"0709-549X")
    set_ISSN("j-ULTRA-MIC",				"0304-3991 (print), 1879-2723 (electronic)")
    set_ISSN("j-ULTRASONIC-IMAGING",			"0161-7346 (print), 1096-0910 (electronic)")
    set_ISSN("j-UMAP",					"0197-3622 (print), 1938-338X (electronic)")
    set_ISSN("j-UNESCO-COUR",				"0041-5278")
    set_ISSN("j-UNIV-COMP",				"0265-4385")
    set_ISSN("j-UNIVERSITAS",				"0041-9079")
    set_ISSN("j-UNIX-DEVELOPER",			"1090-2279")
    set_ISSN("j-UNIX-REVIEW",				"0742-3136", 1)
    set_ISSN("j-UNIX-WORLD",				"0739-5922")
    set_ISSN("j-UNIXWORLD-OPEN-COMP",			"1072-4044")
    set_ISSN("j-US-NEWS-WORLD-REP",			"0041-5537")
    set_ISSN("j-USENIX-SCP",				"1049-5606")
    set_ISSN("j-USPEKHI-FIZ-NAUK",			"0042-1294 (print), 1996-6652 (electronic)")
    set_ISSN("j-USPEHI-MAT-NAUK",			"0042-1316")
    set_ISSN("j-USP-MEH",				"0137-3722")
    set_ISSN("j-USSR-COMP-MATH-MATH-PHYS",		"0041-5553, 0502-9902")
    set_ISSN("j-UTIL-MATH",				"0315-3681")
    set_ISSN("j-UTNE-READER",				"8750-0256")
    set_ISSN("j-VAX-PROF",				"8750-9628")
    set_ISSN("j-VEGETATIO",				"0042-3106")
    set_ISSN("j-VERH-DTSCH-PHYS-GES",			"0372-5448")
    set_ISSN("j-VERH-DTSCH-PHYS-GES-3",			"0372-5448")
    set_ISSN("j-VERH-GES-DTSCH-NATURFORSCH-AERZTE",	"0172-0651")
    set_ISSN("j-VERH-K-ACAD-GENEESKD-BELG",             "0372-610X")
    set_ISSN("j-VERH-SCHWEIZ-NATURFORSCH-GES",		"0080-7362")
    set_ISSN("j-VEROFF-UNIBIB-ESSEN",			"0931-7503")
    set_ISSN("j-VIC-LIT-CULT",				"1060-1503 (print), 1470-1553 (electronic)")
    set_ISSN("j-VIC-STUD",				"0042-5222 (print), 1527-2052 (electronic)")
    set_ISSN("j-VIE-SCI",				"0762-0969")
    set_ISSN("j-VIENNA-CIRCLE-INSTITUTE-YEARBOOK",	"0929-6328 (print), 2215-1818 (electronic)")
    set_ISSN("j-VIERTELJAHRESSCHR-NATURFORSCH-GES-ZURICH", "0042-5672")
    set_ISSN("j-VIS-COMM-IMG-PROC",			"????")
    set_ISSN("j-VIS-RES",				"0042-6989 (print), 1878-5646 (electronic)")
    set_ISSN("j-VISIBLE-LANGUAGE",			"0022-2224 (print), 2691-5529 (electronic)")
    set_ISSN("j-VISUAL-COMPUTER",			"0178-2789 (print), 1432-2315 (electronic)")
    set_ISSN("j-VLDB-J",				"1066-8888 (print), 0949-877X (electronic)")
    set_ISSN("j-VOPROSY-VYCHISL-PRIKL-MAT",		"0320-9016")
    set_ISSN("j-WALL-ST-COMPUT-REV",			"0738-4343")
    set_ISSN("j-WALL-ST-J",				"0099-9660")
    set_ISSN("j-WALL-ST-TECH",				"1060-989X")
    set_ISSN("j-WAR-HIST",				"0968-3445 (print), 1477-0385 (electronic)")
    set_ISSN("j-WASH-CRIME-NEWS-SERV-CORP-SECURITY-DIGEST","0894-3826")
    set_ISSN("j-WASHINGTON-POST",			"0190-8286")
    set_ISSN("j-WASSERWIRTSCHAFT",			"0043-0978 (print), 2192-8762 (electronic)")
    set_ISSN("j-WATER-AIR-SOIL-POLLUT",			"0049-6979 (print), 1573-2932 (electronic)")
    set_ISSN("j-WATER-RESOUR-RES",			"0043-1397 (print), 1944-7973 (electronic)")
    set_ISSN("j-WATER-SCI-TECHNOL",			"0273-1223 (print), 1996-9732 (electronic)")
    set_ISSN("j-WAVE-MOTION",				"0165-2125 (print), 1878-433X (electronic)")
    set_ISSN("j-WAVES-RANDOM-COMPLEX-MEDIA",		"1745-5030 (print), 1745-5049 (electronic)")
    set_ISSN("j-WAVES-RANDOM-MEDIA",			"0959-7174 (print), 1361-6676 (electronic)")
    set_ISSN("j-WEB-APPS",				"1090-2287")
    set_ISSN("j-WEB-REVIEW",				"????")
    set_ISSN("j-WEB-WEEK",				"????")
    set_ISSN("j-WEB-TECHNIQUES",			"1086-556X")
    set_ISSN("j-WEBSERVER",				"1087-4232")
    set_ISSN("j-WESCON-CONF-REC",			"1044-6036")
    set_ISSN("j-WHARTON-REPORT",			"0950-1800")
    set_ISSN("j-WHOLE-EARTH-REV",			"0749-5056")
    set_ISSN("j-WIEN-CHEM-ZTG",				"0372-7270")
    set_ISSN("j-WIRES",					"1939-0068 (print), 1939-5108 (electronic)")
    set_ISSN("j-WILSON-LIBR-BULL",			"0043-5651")
    set_ISSN("j-WILSON-Q",				"0363-3276")
    set_ISSN("j-WINDOWS-MAG",				"1060-1066")
    set_ISSN("j-WIRED",					"1059-1028 (print), 1078-3148 (electronic)")
    set_ISSN("j-WIRTSCHAFTSINFORMATIK",			"0937-6429 (print), 1861-8936 (electronic)")
    set_ISSN("j-WISS-Z-PAEDAGOG-HOCHSCH-K-F-W-WANDER-DRESDEN", "????")
    set_ISSN("j-WISS-Z-PAEDAGOG-HOCHSCH-KARL-LIEBKNECHT-POTSDAM","0941-9896, 0138-290X")
    set_ISSN("j-WISS-Z-TECH-HOCHSCH-KARL-MARX-STADT",	"0372-7610")
    set_ISSN("j-WISS-Z-TECH-HOCHSCH-LEUNA-MERSEBURG",	"0323-5270")
    set_ISSN("j-WISS-Z-TECH-UNIV-DRESDEN",		"0043-6925")
    set_ISSN("j-WISS-Z-TECH-UNIV-DRESDEN-GESELLSCHAFT",	"0323-8822")
    set_ISSN("j-WOMENS-STUD-INT-FORUM",			"0277-5395 (print), 1879-243X (electronic)")
    set_ISSN("j-WORD-WAYS",				"0043-7980")
    set_ISSN("j-WORK-PROC-IMPROV-TODAY",		"1073-2233")
    set_ISSN("j-WORK-PUB-SYS",				"????")
    set_ISSN("j-WORLD-MONIT",				"0897-9472")
    set_ISSN("j-WORLD-WIDE-WEB-J",			"1085-2301")
    set_ISSN("j-WORLD-PRESS-REV",			"0195-8895")
    set_ISSN("j-WSEAS-TRANS-MATH",			"1109-2769 (print), 2224-2880 (electronic)")
    set_ISSN("j-X-J",					"1056-7003")
    set_ISSN("j-X-RESOURCE",				"1058-5591")
    set_ISSN("j-YAD-FIZ",				"0044-0027")
    set_ISSN("j-YALE-LAW-POLICY-REV",			"0740-8048")
    set_ISSN("j-YEAST-CHICHESTER",			"0749-503X (print), 1097-0061 (electronic)")
    set_ISSN("j-YEAST-DAVIS",				"0513-5222")
    set_ISSN("j-YUGO-J-OPER-RES",			"0354-0243 (print), 1820-743X (electronic)")
    set_ISSN("j-Z-ALLG-WISSENSCHAFTSTHEOR",		"0044-2216 (print), 1572-8587 (electronic)")
    set_ISSN("j-Z-ANAL-ANWEND",				"0232-2064 (print), 1661-4534 (electronic)")
    set_ISSN("j-Z-ANAL-CHEM",				"1618-2642 (print), 1618-2650 (electronic)")
    set_ISSN("j-Z-ANGE-CHEM",				"0932-2132")
    set_ISSN("j-Z-ANGE-MATH-MECH",			"0044-2267 (print), 1521-4001 (electronic)")
    set_ISSN("j-Z-ANGE-MATH-PHYS",			"0044-2275 (print), 1420-9039 (electronic)", 1)
    set_ISSN("j-Z-ASTROPHYSIK",				"0372-8331")
    set_ISSN("j-Z-BIOL",				"0372-8366")
    set_ISSN("j-Z-CHEM-STUTTGART",			"0044-2402")
    set_ISSN("j-Z-EKSP-TEOR-FIZ",			"0044-4510")
    set_ISSN("j-Z-ELEKTROCHEM",				"0372-8382")
    set_ISSN("j-Z-ELEKTROCHEM-ANGEW-PHYS-CHEM",		"0372-8323")
    set_ISSN("j-Z-KRISTALLOGR",				"0044-2968")
    set_ISSN("j-Z-MATH-LOGIK-GRUNDL-MATH",		"0044-3050")
    set_ISSN("j-Z-NATURFORSCH",				"0372-9516")
    set_ISSN("j-Z-NATURFORSCH-A-ASTROPHYS-PHYS-PHYS-CHEM",	"0044-3166")
    set_ISSN("j-Z-NATURFORSCH-A-PHYS-SCI",		"0932-0784 (print), 1865-7109 (electronic)")
    set_ISSN("j-Z-NATURFORSCH-SECT-C-BIOSCI",		"0341-0382")
    set_ISSN("j-Z-OPER-RES",				"0340-9422")
    set_ISSN("j-Z-PFLANZENKR-PFLANZENSCHUTZ",		"0340-8159")
    set_ISSN("j-Z-PHILOS-FORSCH",			"0044-3301")
    set_ISSN("j-Z-PHYS-CHEM-B",				"0372-9664")
    set_ISSN("j-Z-PHYS-CHEM-LEIPZIG",			"0323-4479")
    set_ISSN("j-Z-PHYS-CHEM-STOECHIOM-VERWANDTSCHAFTSL","0372-8501")
    set_ISSN("j-Z-PHYSIK",				"0044-3328")
    set_ISSN("j-Z-PHYSIK-A",				"0930-1151")
    set_ISSN("j-Z-PHYSIK-A-HADRONS-NUCL",		"0939-7922 (print), 1431-5831 (electronic)")
    set_ISSN("j-Z-PHYSIK-B-CM",				"0722-3277 (print), 1431-584X (electronic)")
    set_ISSN("j-Z-PHYSIK-B-CMQ",			"0340-224X")
    set_ISSN("j-Z-PHYSIK-C",				"0170-9739 (print), 1431-5858 (electronic)")
    set_ISSN("j-Z-PHYSIK-D",				"0178-7683 (print), 1431-5866 (electronic)")
    set_ISSN("j-Z-TECH-PHYS",				"0373-0093")
    set_ISSN("j-Z-TEH-FIZ",				"0044-4642 (print), 1726-748X (electronic)")
    set_ISSN("j-Z-THEOL-KIRCHE",			"0044-3549 (print), 1868-7377 (electronic)")
    set_ISSN("j-Z-VERMESSUNGSWESEN",			"0340-4560")
    set_ISSN("j-Z-VYCISL-MAT-MAT-FIZ",			"0044-4669")
    set_ISSN("j-Z-WAHRSCHEINLICHKEITSTHEOR-VERW-GEB",	"0044-3719")
    set_ISSN("j-ZAP-NAUC-SEMIN-LENINGR-OTD-ORDENA",	"0373-2703")
    set_ISSN("j-ZASTOS-MAT",				"????")
    set_ISSN("j-ZH-RUSS-FIZ-KHIM-OBSHCH-CHAST-FIZ",	"0372-9834")
    set_ISSN("j-ZH-VYCHISL-MAT-MAT-FIZ",		"0044-4669")
    set_ISSN("j-ZOO-SCI",				"0289-0003")
    set_ISSN("j-ZOR-MATH-METHODS-OPER-RES",		"0340-9422")
    set_ISSN("j-ZYGON-J-RELIG-SCI",			"0591-2385 (print), 1467-9744 (electronic)")

    # special cases go here, to ease the job of merging in new
    # entries into the list above

    # Japanese name for the journal below:
    set_ISSN("j-JOHO-SHORI",				"0447-8053")
    set_ISSN("j-J-INFO-PROC-SOC-JAPAN",			"0447-8053", 1)

    set_ISSN("j-J-JAPAN-SOC-COMPUT-STAT",		"0915-2350 (print), 1881-1337 (electronic)")

    set_ISSN("j-J-JPN-INT-ECON",			"0889-1583 (print), 1095-8681 (electronic)")

    # Which ISSN is correct?
    # set_ISSN("j-J-KOREA-INFO-SCI-SOCIETY",		"8264-5521")
    set_ISSN("j-J-KOREA-INFO-SCI-SOCIETY",		"0258-9125")

    # This journal ceased in 1993, Vol. 10, no. 1, and was
    # replaced by Software---Concepts and Tools
    set_ISSN("j-STRUCT-PROGRAM",			"0935-1183")

    # SIAM Journal on Scientific and Statistical Computing (1980--1992)
    # renamed to
    # SIAM Journal on Scientific Computing (1993--)
    set_ISSN("j-SIAM-J-SCI-STAT-COMP",			"0196-5204")
#   set_ISSN("j-SIAM-J-SCI-COMP",			"1064-8275 (print), 1095-7197 (electronic)")
    set_ISSN("j-SIAM-J-SCI-COMP",			"1064-8275 (print), 1095-7197 (electronic)")
}


function initialize_ISSN_L(    k)
{
    ### These assignments are generated from the issn.org mapping
    ### file, ISSN-L_to_ISSN_20110808.txt, which contains about 1.54
    ### million lines of the form
    ###
    ###     ISSN-L ISSN-1 ISSN-2 ... ISSN-n
    ###
    ### with n >= 1.  Of these, only 55,888 records have n > 2, so to
    ### save time, that file has been preprocessed to produce the much
    ### shorter file ISSN-L_to_ISSN.map by
    ###
    ###     awk 'NF > 2' ISSN-L_to_ISSN_20110808.txt > ISSN-L_to_ISSN.map
    ###
    ### that we load each time this function is invoked.  There are
    ### just too many records to usefully include here as direct
    ### assignments, and it is better to refer directly to the raw
    ### data instead.

    ISSN_to_ISSN_L["2150-4008"] = "0000-0019"	# force map array creation

    while ((getline < ISSN_L_TO_ISSN_MAP_FILE) > 0)
    {
	for (k = 2; k <= NF; ++k)
	    ISSN_to_ISSN_L[$k] = $1
    }

    close(ISSN_L_TO_ISSN_MAP_FILE)
}


function initialize_quad()
{
    ### These initializations are a more compact way of handling
    ### journal definitions.  The preferred abbreviated form should be
    ### given after the CODEN, ISSN, and journal-abbreviation
    ### arguments, optionally followed by the long name when it is
    ### known.

    ## Data derived from Inorganic Crystal Structure Database (http://icsd.ccp14.ac.uk/icsd/journals-main.html)

    ## Suppress entries where data already exists:
    ## set_quad("ACACBN", "0108-7673", "j-ACTA-CRYSTALLOGR-SECT-A",		"Acta Crystallogr., Sect. A")
    ## set_quad("ACACEQ", "0108-7673", "j-ACTA-CRYSTALLOGR-SECT-A-FND-CRYST",	"Acta Crystallogr., Sect. A (Fnd. Cryst. )")
    ## set_quad("ASBSDK", "0108-7681", "j-ACTA-CRYSTALLOGR-SECT-B-STR-SCI-1983","Acta Crystallogr., Sect. B (Str. Sci. 1983--)")
    ## set_quad("BUFCAE", "????-????", "j-BULL-SOC-FR-MINER-CRIST",		"Bull. Soc. Fr. Miner. Crist.")
    ## set_quad("COREAF", "????-????", "j-C-R-ACAD-SCI",			"C. R. Acad. Sci.")
    ## set_quad("DANKAS", "0002-3264", "j-DOKL-AKAD-NAUK-SSSR-DOKL-CHEM",	"Dokl. Akad. Nauk SSSR (Dokl. Chem)")
    ## set_quad("JACGAR", "0021-8898", "j-J-APPL-CRYSTALLOGR",			"J. Appl. Crystallogr.")
    ## set_quad("JACSAT", "0002-7863", "j-J-AM-CHEM-SOC",			"J. Am. Chem. Soc.")
    ## set_quad("JACTAW", "0002-7820", "j-J-AMER-CERAM-SOC",			"J. Amer. Ceram. Soc.")
    ## set_quad("JAPIAU", "0021-8979", "j-J-APPL-PHYS",				"J. Appl. Phys.")
    ## set_quad("JAPLD8", "0021-4922", "j-JAP-J-APPL-PHYS-PART-2",		"Jap. J. Appl. Phys. Part 2")
    ## set_quad("JCOMEL", "0953-8984", "j-J-PHYSICS-CONDENSED-MATTER-1989",	"J. Physics: Condensed Matter (1989--)")
    ## set_quad("JCPSA6", "0021-9606", "j-J-CHEM-PHYS",				"J. Chem. Phys.")
    ## set_quad("JCSOA9", "0368-1769", "j-J-CHEM-SOC",				"J. Chem. Soc.", "Journal of the Chemical Society")
    ## set_quad("JPCHAX", "0022-3654", "j-J-PHYS-CHEM",				"Journal of Physical Chemistry")
    ## set_quad("JPCHAX", "0022-3654", "j-J-PHYS-CHEM",				"J. Phys. Chem.")

    ## set_quad("JPCSAW", "0022-3697", "j-J-PHYS-CHEM-SOLIDS",			"J. Phys. Chem. Solids")
    ## set_quad("JPSOAW", "0022-3719", "j-J-PHYS-CSOLID-STATE-PHYSICS",		"J. Phys. C:Solid State Physics")
    ## set_quad("MOCMB7", "0026-9247", "j-MONATSHEFTE-CHEMIE",			"Monatshefte fuer Chemie und verwandte Teile anderer Wissenschaften (109, 1978--)")
    ## set_quad("NATUAS", "0028-0836", "j-NATURE-LONDON",			"Nature (London)")
    ## set_quad("PHYBE3", "0921-4526", "j-PHYSICA-B-CONDENSED-MATTER",		"Physica B: Condensed Matter")
    ## set_quad("PHYCE6", "0921-4534", "j-PHYSICA-C-SUPERCONDUCTIVITY",		"Physica C: Superconductivity")
    ## set_quad("PODIE2", "0885-7156", "j-POWDER-DIFFRACTION",			"Powder Diffraction")
    ## set_quad("PSSABA", "0031-8965", "j-PHYS-STATUS-SOLIDI-A",		"Phys. Status Solidi, A.")
    ## set_quad("ZKNSFT", "1433-7266", "j-Z-KRISTALLOGR-NEW-CRYSTAL-STRUCTURES","Z. Kristallogr. -New Crystal Structures")

    ## New entries sorted by CODEN:

    set_quad("ACAPCT", "0302-4369", "j-ACTA-CHEM-SCAND-SER-A",			"Acta Chem. Scand. Ser. A")
    set_quad("ACBCAR", "0108-7681", "j-ACTA-CRYSTALLOGR-SECT-B-1968-85",	"Acta Crystallogr., Sect. B (1968--85)")
    set_quad("ACCRA9", "0567-7408", "j-ACTA-CRYSTALLOGR-1948-1967",		"Acta Crystallogr. (1948--1967)")
    set_quad("ACHSE7", "0904-213X", "j-ACTA-CHEM-SCAND",			"Acta Chem. Scand.")
    set_quad("ACSAA4", "0904-213X", "j-ACTA-CHEM-SCAND-1973-2000",		"Acta Chem. Scand. (1973--2000)")
    set_quad("ACSCEE", "0108-2701", "j-ACTA-CRYSTALLOGR-SECT-C-CR-STR-COMM-1983", "Acta Crystallogr., Sect. C (Cr. Str. Comm. 1983--)")
    set_quad("ACSEBH", "1600-5368", "j-ACTA-CRYSTALLOGR-SECT-E-STRUCT-REP",	"Acta Crystallogr., Sect. E (Struct. Rep. )")
    set_quad("AMMIAY", "0003-004X", "j-AMERICAN-MINERALOGIST",			"American Mineralogist")
    set_quad("ANCEAD", "0044-8249 (print), 1521-3757 (electronic)", "j-ANGEW-CHEM",				"Angew. Chem.")
    set_quad("ANCPAC", "0151-9107", "j-ANN-CHIM-PARIS",				"Ann. Chim. (Paris)")
    set_quad("ARKEAD", "0365-6128", "j-ARK-KEMI",				"Ark. Kemi")
    set_quad("BCSJA8", "0009-2673", "j-BULL-CHEM-SOC-JAP",			"Bull. Chem. Soc. Jap.")
    set_quad("BSCFAS", "0037-8968", "j-BULL-SOC-CHIM-FR",			"Bull. Soc. Chim. Fr.")
    set_quad("CAMIA6", "0008-4476", "j-CANADIAN-MINERALOGIST",			"Canadian Mineralogist")
    set_quad("CHDCAQ", "1387-1609", "j-C-R-ACAD-SCI-SER-C",			"C. R. Acad. Sci., Ser. C")
    set_quad("CJCHAG", "0008-4042", "j-CAN-J-CHEM",				"Can. J. Chem.")
    set_quad("CMATEX", "0897-4756", "j-CHEMISTRY-OF-MATERIALS",			"Chemistry of Materials")
    set_quad("EJMIER", "0935-1221", "j-EUROP-J-MINERALOGY-1989",		"Europ. J. Mineralogy (1989--)")
    set_quad("EJSCE5", "0992-4361", "j-EUR-J-SOLID-STATE-INORG-CHEM",		"Eur. J. Solid State Inorg. Chem.")
    set_quad("FEROA8", "0015-0193", "j-FERROELECTRICS",				"Ferroelectrics")
    set_quad("GCITA9", "0016-5603", "j-GAZZ-CHIM-ITAL",				"Gazz. Chim. Ital.")
    set_quad("ICHAA3", "0020-1693", "j-INORG-CHIM-ACTA",			"Inorg. Chim. Acta")
    set_quad("INOCAJ", "0020-1669", "j-INORG-CHEM",				"Inorg. Chem.")
    set_quad("IVNMAW", "0002-337X", "j-IZV-AKAD-NAUK-SSSR-NEORG-MATER-INORG-MAT","Izv. Akad. Nauk SSSR, Neorg. Mater. (Inorg. Mat. )")
    set_quad("JALCEU", "0925-8388", "j-J-ALLOYS-AND-COMPOUNDS",			"J. Alloys and Compounds")
    set_quad("JCCCAT", "0022-4936", "j-J-CHEM-SOC-CHEM-COMMUN-1972",		"J. Chem. Soc., Chem. Commun. (1972--)")
    set_quad("JCDTBI", "0300-9246", "j-J-CHEM-SOC-DALTON-TRANS-INORG-CHEM-1972","J. Chem. Soc. Dalton Trans. Inorg. Chem. (1972--)")
    set_quad("JCOMAH", "0022-5088", "j-J-LESS-COMMON-MET-NOW-J-ALLOYS-C",	"J. Less-Common Met. (now J. Alloys & C. )")
    set_quad("JINCAO", "0277-5387", "j-J-INORG-NUCL-CHEM",			"J. Inorg. Nucl. Chem.")
    set_quad("JMACEP", "0959-9428", "j-J-MATER-CHEM",				"J. Mater. Chem.")
    set_quad("JMMMDC", "0304-8853", "j-J-MAGN-MAGN-MATER",			"J. Magn. Magn. Mater.")
    set_quad("JSSCBI", "0022-4596", "j-J-SOLID-STATE-CHEM",			"J. Solid State Chem.")
    set_quad("JUPSAU", "0031-9015", "j-J-PHYS-SOC-JAP",				"J. Phys. Soc. Jap.")
    set_quad("KOKHDC", "0132-344X", "j-KOORD-KHIM",				"Koord. Khim.")
    set_quad("KRISAJ", "0023-4761", "j-KRISTALLOGRAFIYA-CRYSTAL-REPORTS",	"Kristallografiya (Crystal. Reports)")
    set_quad("MJTOAS", "0544-2540", "j-MINERALOGICAL-JOURNAL-JAPAN",		"Mineralogical Journal (Japan)")
    set_quad("MNLMBB", "0026-461X", "j-MIN-MAG-1969",				"Min. Mag. (1969--)")
    set_quad("MOCHAP", "0026-9247", "j-MONATSH-CHEM-CHEM-MONTHLY",		"Monatsh. Chem. (Chem. Monthly)")
    set_quad("MRBUAC", "0025-5408", "j-MATER-RES-BULL",				"Mater. Res. Bull.")
    set_quad("MSFOEP", "0255-5476", "j-MATERIALS-SCIENCE-FORUM",		"Materials Science Forum")
    set_quad("NJMIAK", "0077-7757", "j-N-JAHRB-MINERAL-ABHANDLUNGEN-1950",	"N. Jahrb. Mineral. Abhandlungen (1950--)")
    set_quad("NJMMAW", "0028-3649", "j-NEUES-JAHRB-MIN-MONATSH",		"Neues Jahrb. Min., Monatsh.")
    # set_quad("PCMIDU", "0342-1791 (print), 1432-2021 (electronic)", "j-PHYS-CHEM-MINERALS-GERMANY",		"Phys. Chem. Minerals (Germany)")
    # set_quad("PRBMDO", "1095-3795", "j-PHYS-REV-B-CONDENS-MAT",			"Phys. Rev. B, Condens. Mat.")
    set_quad("RVCMA8", "0035-1032", "j-REV-CHIM-MINER",				"Rev. Chim. Miner.")
    set_quad("SSIOD3", "0167-2738", "j-SOLID-STATE-IONICS",			"Solid State Ionics")
    set_quad("ZAACAB", "0044-2313 (print), 1521-3749 (electronic)", "j-Z-ANORG-ALLG-CHEM",			"Z. Anorg. Allg. Chem.")
    set_quad("ZEKGAX", "1433-7266", "j-Z-KRISTALLOGR-ABT-A-1922-1989",		"Z. Kristallogr., Abt. A (1922--1989)")
    # set_quad("ZEKRDZ", "0044-2968", "j-Z-KRISTALLOGR",				"Z. Kristallogr.")
    set_quad("ZEOLD3", "0144-2449", "j-ZEOLITES",				"Zeolites")
    set_quad("ZNBSEN", "0932-0776", "j-Z-NATURFORSCH-TEIL-B",			"Z. Naturforsch., Teil B")
    set_quad("ZNOKAQ", "0044-457X", "j-ZH-NEORG-KHIM-RUS-J-INORG-CHEM",		"Zh. Neorg. Khim. (Rus. J. Inorg. Chem. )")
    set_quad("ZSTKAI", "0044-4634", "j-ZH-STRUKT-KHIM",				"Zh. Strukt. Khim.")
}


function initialize_strings()
{
    #########################################################
    # WARNING: Do NOT re-sort the following define() calls! #
    #########################################################

    # Journal abbreviations and their expansions, sorted by
    # abbreviations. The FIRST expansion for a given abbreviation, is
    # the one that will be used in output @String{} definitions.
    # Matching against quoted string journal names ignores period,
    # comma, space, discretionary hyphen, emdash, and letter case.

    define("j-16TH-CENT",			"The Sixteenth Century Journal")

    define("j-3X-400-SYST-MANAG",		"3X/400 Systems Management")
    define("j-3X-400-SYST-MANAG",		"3X/400 syst. manag.")

    define("j-A-PLUS",				"A+")

    define("j-AAICA",				"Annales de l'Association Internationale pour le Calcul Analogique")
    define("j-AAICA",				"Ann. Assoc. Calcul. Analog.")

    define("j-AAPG-EXPLOR",			"American Association of Petroleum Geologists Explorer")
    define("j-AAPG-EXPLOR",			"AAPG Explorer")
    define("j-AAPG-EXPLOR",			"AAPG explor.")

    define("j-AAUP-BULL",			"{AAUP} Bulletin")
    define("j-AAUP-BULL",			"{AAUP} Bull.")

    define("j-ABACUS",				"Abacus")

    define("j-ABERDEEN-UNIV-REV",		"Aberdeen University Review")
    define("j-ABERDEEN-UNIV-REV",		"Aberdeen Univ. Rev.")

    define("j-ABH-MATH-SEMIN-UNIV-HAMBG",	"Abhandlungen aus dem Mathematischen Seminar der Universit{\\\"a}t Hamburg")
    define("j-ABH-MATH-SEMIN-UNIV-HAMBG",	"Abh. Math. Sem. Univ. Hamburg")
    define("j-ABH-MATH-SEMIN-UNIV-HAMBG",	"Abh. Math. Semin. Univ. Hambg.")

    define("j-ABSTR-APPL-ANAL",			"Abstract and Applied Analysis")
    define("j-ABSTR-APPL-ANAL",			"Abstr. Appl. Anal.")

    define("j-ABSTR-PAP-AM-CHEM-SOC",		"Abstracts of Papers of the American Chemical Society")
    define("j-ABSTR-PAP-AM-CHEM-SOC",		"Abstracts of papers / American Chemical Society")
    define("j-ABSTR-PAP-AM-CHEM-SOC",		"Abstr. pap. - Am. Chem. Soc.")

    define("j-ACAD-COMPUT",			"Academic computing (McKinney, TX)")
    define("j-ACAD-COMPUT",			"Academic computing")
    define("j-ACAD-COMPUT",			"Acad. comput.")

    define("j-ACAPA",				"American Crystallographic Association Program and Abstracts")

    define("j-ACCOUNTANCY",			"Accountancy: The journal of the {Institute of Chartered Accountants in England and Wales}")
    define("j-ACCOUNTANCY",			"Accountancy: the leading magazine for the accounting world")
    define("j-ACCOUNTANCY",			"Accountancy")

    define("j-ACCOUNT-HIST-J",			"Accounting Historians Journal")
    define("j-ACCOUNT-HIST-J",			"Account. Hist. J.")

    define("j-ACCOUNT-RES",			"Accountability in Research")
    define("j-ACCOUNT-RES",			"Account. Res.")

    define("j-ACCOUNT-REV",			"The Accounting Review")
    define("j-ACCOUNT-REV",			"Accounting Review")
    define("j-ACCOUNT-REV",			"Account. Rev.")

    define("j-ACM-COMM-COMP-ALGEBRA",		"ACM Communications in Computer Algebra")
    define("j-ACM-COMM-COMP-ALGEBRA",		"ACM Comm. Comp. Algebra")
    define("j-ACM-COMM-COMP-ALGEBRA",		"ACM Commun. Comp. Algebra")

    define("j-ACM-J-EXP-ALGORITHMICS",		"ACM Journal of Experimental Algorithmics")
    define("j-ACM-J-EXP-ALGORITHMICS",		"ACM J. Exp. Algorithmics")

    define("j-ACM-SIGCAS-COMPUT-SOC",		"ACM SIGCAS Computers and Society")
    define("j-ACM-SIGCAS-COMPUT-SOC",		"ACM SIGCAS Comput. Soc.")

    define("j-ACM-SIGMOBILE-MOBILE-COMPUT-COMMUN-REV",	"ACM SIGMOBILE Mobile Computing and Communications Review ($MC^2R$)")
    define("j-ACM-SIGMOBILE-MOBILE-COMPUT-COMMUN-REV",	"ACM SIGMOBILE Mobile Computing and Communications Review")
    define("j-ACM-SIGMOBILE-MOBILE-COMPUT-COMMUN-REV",	"Mobile Comput. Commun. Rev.")
    define("j-ACM-SIGMOBILE-MOBILE-COMPUT-COMMUN-REV",	"ACM SIGMOBILE Mobile Comput. Commun. Rev.")

    define("j-ACM-SIGSOFT",			"ACM SIGSOFT Software Engineering Notes")
    define("j-ACM-SIGSOFT",			"ACM Sigsoft")
    define("j-ACM-SIGSOFT",			"SIGSOFT Softw. Eng. Notes")
    define("j-ACM-SIGSOFT",			"SIGSOFT Software Engineering Notes")

    define("j-ACOUSTICS-AUSTRALIA",		"Acoustics Australia")
    define("j-ACT-CONG-INT-MATH",		"Actes du Congr{\\`e}s International des Math{\\'e}\\-ma\\-ticiens")

    define("j-ACTA-ANAT",			"Acta Anatomica, Basle")
    define("j-ACTA-ANAT",			"Acta Anatomica")
    define("j-ACTA-ANAT",			"Acta Anat.")

    define("j-ACTA-APPL-MATH",			"Acta Applicandae Mathematicae")
    define("j-ACTA-APPL-MATH",			"Acta Applicandae Math.")
    define("j-ACTA-APPL-MATH",			"Acta Appl. Math.")

    define("j-ACTA-ARITHMETICA",		"Acta Arithmetica")
    define("j-ACTA-ARITHMETICA",		"Acta Arith.")

    define("j-ACTA-ASTRONAUT",			"Acta Astronautica")
    define("j-ACTA-ASTRONAUT",			"Acta Astronaut.")

    define("j-ACTA-BIOTHEOR",			"Acta biotheoretica")
    define("j-ACTA-BIOTHEOR",			"Acta biotheor.")

    define("j-ACTA-CRYSTALLOGR",		"Acta Crystallographica")
    define("j-ACTA-CRYSTALLOGR",		"Acta Crystallogr.")
    define("j-ACTA-CRYSTALLOGR",		"Acta Crystal.")

    # Titled "... Crystal physics, diffraction, theoretical and general
    # crystallography" (CODEN ACACBN) from 1967--1982, and
    # "...Foundations of crystallography" from 1983-- (CODEN ACACEQ).
    define("j-ACTA-CRYSTAL-A",			"Acta crystallographica. Section A")
    define("j-ACTA-CRYSTAL-A",			"Acta crystallographica. Section A, Crystal physics, diffraction, theoretical and general crystallography")
    define("j-ACTA-CRYSTAL-A",			"Acta crystallogr., Sect. A. Cryst. phys. diffr. theor. gen. crystallogr.")
    define("j-ACTA-CRYSTAL-A",			"Acta Crystal A")

    define("j-ACTA-CRYSTAL-A-FOUND-CRYST",	"Acta crystallographica. Section A, Foundations of crystallography")
    define("j-ACTA-CRYSTAL-A-FOUND-CRYST",	"Acta Crystallogr. Sect. A")

    define("j-ACTA-CYBER",			"Acta Cybernetica")

    define("j-ACTA-GEOD-GEOPHYS-HU",		"Acta Geodaetica et Geophysica Hungarica")
    define("j-ACTA-GEOD-GEOPHYS-HU",		"Acta Geod. Geophys. Hu.")

    define("j-ACTA-HISTOCHEM-SUPPL",		"Acta histochemica. Supplementband.")
    define("j-ACTA-HISTOCHEM-SUPPL",		"Acta histochem. Suppl.")
    define("j-ACTA-HISTOCHEM-SUPPL",		"Acta Histochem Suppl (QU1)")

    define("j-ACTA-INFO",			"Acta Informatica")

    define("j-ACTA-LITT-SCI-SZEGED",		"Acta Litterarum ac Scientiarum Regiae Universitatis Hungaricae Francisco-Josephinae. Sectio philosophica. Szeged, Hungary")
    define("j-ACTA-LITT-SCI-SZEGED",		"Acta Litt. Sci. Szeged")

    define("j-ACTA-MATER",			"Acta Materialia")
    define("j-ACTA-MATER",			"Acta Mater.")

    define("j-ACTA-MATH",			"Acta Mathematica")
    define("j-ACTA-MATH",			"Acta Math")

    define("j-ACTA-MATH-HUNG",			"Acta mathematica Academiae Scientiarum Hungaricae")
    define("j-ACTA-MATH-HUNG",			"Acta math. Acad. scient. hung.")
    define("j-ACTA-MATH-HUNG",			"Acta Math. Acad. Sci. Hung.")

    define("j-ACTA-MATH-SINICA",		"Acta Mathematica Sinica (New Series)")
    define("j-ACTA-MATH-SINICA",		"Acta Mathematica Sinica. New Series")
    define("j-ACTA-MATH-SINICA",		"Acta Math. Sinica (N.S.)")

    define("j-ACTA-MECH",			"Acta mechanica")
    define("j-ACTA-MECH",			"Acta mech.")

    define("j-ACTA-MED-SCAND",			"Acta medica Scandinavica")
    define("j-ACTA-MED-SCAND",			"Acta med. Scand.")

    define("j-ACTA-METALL",			"Acta metallurgica")
    define("j-ACTA-METALL",			"Acta metall.")

    define("j-ACTA-METALL-MATER",		"Acta metallurgica et materialia")
    define("j-ACTA-METALL-MATER",		"Acta metall. mater.")

    define("j-ACTA-NUMERICA",			"Acta Numerica")
    define("j-ACTA-NUMERICA",			"Acta Numer.")
    define("j-ACTA-NUMERICA",			"Acta Num.")

    define("j-ACTA-ONCOL",			"Acta Oncologica (Stockholm)")
    define("j-ACTA-ONCOL",			"Acta Oncologica")
    define("j-ACTA-ONCOL",			"Acta Oncol.")

    define("j-ACTA-OPHTHALMOL",			"Acta Ophthalmologica")
    define("j-ACTA-OPHTHALMOL",			"Acta Ophthalmol.")

    define("j-ACTA-PADIATR-SCAND",		"Acta padiatrica Scandinavica")
    define("j-ACTA-PADIATR-SCAND",		"Acta padiatr. Scand.")
    define("j-ACTA-PADIATR-SCAND",		"Acta. Paediat. Scand.")

    define("j-ACTA-PHYS-ACAD-SCI-HUNG",		"Acta physica Academiae Scientiarum Hungaricae")
    define("j-ACTA-PHYS-ACAD-SCI-HUNG",		"Acta phys. Acad. Sci. Hungar.")
    define("j-ACTA-PHYS-ACAD-SCI-HUNG",		"Acta phys. Acad. Sci. Hung.")
    ## NB: There is a spelling error here: "Scientarium" should be
    ## "Scientiarum".  The error occurs in journal databases and
    ## library catalogs, so we fix it here by mapping the erroneous
    ## one to the correct one above.
    define("j-ACTA-PHYS-ACAD-SCI-HUNG",		"Acta physica Academiae Scientarium Hungaricae")

    define("j-ACTA-PHYS-AUSTRIACA",		"Acta Physica Austriaca")
    define("j-ACTA-PHYS-AUSTRIACA",		"Acta Phys. Austriaca")

    define("j-ACTA-PHYS-HUNG-A",		"Acta Physica Hungarica A: Heavy Ion Physics")
    define("j-ACTA-PHYS-HUNG-A",		"Acta Phys. Hung. A")

    define("j-ACTA-PHYS-HUNG-NEW-SERIES-HEAVY-ION-PHYS",	"Acta Physica Hungarica New Series: Heavy Ion Physics")
    define("j-ACTA-PHYS-HUNG-NEW-SERIES-HEAVY-ION-PHYS",	"Acta Physica Hungarica Heavy Ion Physics, New Series")
    define("j-ACTA-PHYS-HUNG-NEW-SERIES-HEAVY-ION-PHYS",	"Acta Phys. Hung. New Ser.: Heavy Ion Phys.")

    # v1 1932--v8 1939; v9 1947/1948-v36 n6 Dec. 1969, then split into parts A and B
    define("j-ACTA-PHYS-POL",			"Acta Physica Polonica")
    define("j-ACTA-PHYS-POL",			"Acta Phys. Polonica")
    define("j-ACTA-PHYS-POL",			"Acta Phys. Polon.")
    define("j-ACTA-PHYS-POL",			"Acta Phys. Pol.")

    define("j-ACTA-PHYS-POL-A",			"Acta Physica Polonica A")
    define("j-ACTA-PHYS-POL-A",			"Acta Phys. Pol., A")

    define("j-ACTA-PHYS-POL-B",			"Acta Physica Polonica B")
    define("j-ACTA-PHYS-POL-B",			"Acta Phys. Pol., B")

    define("j-ACTA-POLYTECH-HUNG",		"Acta Polytechnica Hungarica")
    define("j-ACTA-POLYTECH-HUNG",		"Acta Polytech. Hung.")

    define("j-ACTA-POLYTECH-SCAND-ELECTR-ENG-SER", "Acta Polytechnica Scandinavica, Electrical Engineering Series")
    define("j-ACTA-POLYTECH-SCAND-ELECTR-ENG-SER", "Acta polytech. Scand., Electr. eng. ser.")

    define("j-ACTA-PROTOZOO",			"Acta protozoologica")

    define("j-ACTA-SCI-MATH-SZEGED",		"Acta Scientiarum Mathematicarum (Szeged)")
    define("j-ACTA-SCI-MATH-SZEGED",		"Acta Sci. Math. (Szeged)")

    define("j-ACTA-SCI-NATUR-UNIV-SUNYATSENI",	"Acta Scientiarum Naturalium Universitatis Sunyatseni. Zhongshan Daxue Xuebao. Ziran Kexue Ban")
    define("j-ACTA-SCI-NATUR-UNIV-SUNYATSENI",	"Acta Sci. Natur. Univ. Sunyatseni")

    define("j-ACTA-SOC-BOT-POL",		"Acta Societatis Botanicorum Poloniae: organ Polskiego Towarzystwa Botanicznego")
    define("j-ACTA-SOC-BOT-POL",		"Acta Societatis Botanicorum Poloniae")
    define("j-ACTA-SOC-BOT-POL",		"Acta soc. bot. pol.")

    define("j-ACTA-SOCIOL",			"Acta Sociologica")
    define("j-ACTA-SOCIOL",			"Acta Sociol.")

    define("j-ADA-USER",			"Ada User")
    define("j-ADA-USER",			"Ada User (Netherlands), Ada User")
    define("j-ADA-USER",			"Ada User (UK), Ada User")

    define("j-ADA-USER-J",			"Ada User Journal")
    define("j-ADA-USER-J",			"Ada User J.")
    define("j-ADA-USER-J",			"Ada User J. (Netherlands), Ada User Journal")

    define("j-ADV-APPL-MATH",			"Advances in Applied Mathematics")
    define("j-ADV-APPL-MATH",			"Adv. Appl. Math.")
    define("j-ADV-APPL-MATH",			"Adv. in Appl. Math.")

    define("j-ADV-APPL-MECH",			"Advances in Applied Mechanics")
    define("j-ADV-APPL-MECH",			"Adv. Appl. Mech.")

    define("j-ADV-APPL-PROB",			"Advances in Applied Probability")
    define("j-ADV-APPL-PROB",			"Adv. Appl. Prob.")

    define("j-ADV-APPL-STAT",			"Advances and Applications in Statistics")
    define("j-ADV-APPL-STAT",			"Adv. Appl. Stat.")

    define("j-ADV-APPL-STAT-SCI",		"Advances and Applications in Statistical Sciences")
    define("j-ADV-APPL-STAT-SCI",		"Adv. Appl. Stat. Sci.")

    define("j-ADV-BIOPHYS",			"Adv Biophys (2J2)")

    define("j-ADV-CARDIOL",			"Advances in Cardiology")
    define("j-ADV-CARDIOL",			"Adv. cardiol.")

    define("j-ADV-CHEM-PHYS",			"Advances in Chemical Physics")
    define("j-ADV-CHEM-PHYS",			"Adv. Chem. Phys.")

    define("j-ADV-COMPLEX-SYST",		"Advances in Complex Systems")
    define("j-ADV-COMPLEX-SYST",		"Adv. Complex Syst.")

    define("j-ADV-COMPUT-MATH",			"Advances in Computational Mathematics")
    define("j-ADV-COMPUT-MATH",			"Adv. Comput. Math.")

    define("j-ADV-CYCLIC-NUCLEOTIDE-RES",	"Advances in Cyclic Nucleotide Research")
    define("j-ADV-CYCLIC-NUCLEOTIDE-RES",	"Adv. Cyclic Nucleotide Res.")

    define("j-ADV-DIFFERENCE-EQU",		"Advances in Difference Equations")
    define("j-ADV-DIFFERENCE-EQU",		"Adv. Difference Equ.")

    define("j-ADV-ENG-SOFTWARE",		"Advances in Engineering Software (1978)")
    define("j-ADV-ENG-SOFTWARE",		"Advances in Engineering Software")

    define("j-ADV-ENG-SOFTWARE",		"Advances in Engineering Software")
    define("j-ADV-ENG-SOFTWARE",		"Adv. Engin. Software")
    define("j-ADV-ENG-SOFTWARE",		"Adv. Eng. Softw")
    define("j-ADV-ENG-SOFTWARE",		"Adv. Engr. Software")

    define("j-ADV-ENG-SOFTWARE-WORKSTATIONS",	"Advances in Engineering Software and Workstations")

    define("j-ADV-ENZYMOL",			"Advances in Enzymology and Related Subjects")
    define("j-ADV-ENZYMOL",			"Adv. Enzymol.")

    define("j-ADV-EXP-MED-BIO",                 "Advances in experimental medicine and biology")
    define("j-ADV-EXP-MED-BIO",                 "Adv. exp. med. bio.")

    define("j-ADV-GEOPHYS",			"Advances in Geophysics")
    define("j-ADV-GEOPHYS",			"Adv. Geophys.")

    define("j-ADV-HIST-STUD",			"Advances in Historical Studies")
    define("j-ADV-HIST-STUD",			"Adv. Hist. Stud.")

    define("j-ADV-IMAGING",			"Advanced Imaging")

    define("j-ADV-MATER",			"Advanced materials")
    define("j-ADV-MATER",			"Adv. Mater.")

    define("j-ADV-MATH",			"Advances in Mathematics")
    define("j-ADV-MATH",			"Adv. Math")
    define("j-ADV-MATH",			"Adv. in Math")
    define("j-ADV-MATH",			"Advances in Math.")

    define("j-ADV-MORPHOGENESIS",		"Advances in Morphogenesis")
    define("j-ADV-MORPHOGENESIS",		"Adv. Morphogenesis")

    define("j-ADV-NEURAL-INF-PROCESS-SYST",	"Advances in neural information processing systems")
    define("j-ADV-NEURAL-INF-PROCESS-SYST",	"Adv. neural inf. process. syst.")

    define("j-ADV-NONLINEAR-ANAL",		"Advances in Nonlinear Analysis")
    define("j-ADV-NONLINEAR-ANAL",		"Adv. Nonlinear Anal.")

    define("j-ADV-PHYS",			"Advances in Physics")
    define("j-ADV-PHYS",			"Adv. Phys.")

    define("j-ADV-PURE-APPL-MATH",		"Advances in Pure Mathematics")
    define("j-ADV-PURE-APPL-MATH",		"Adv. Pure Appl. Math.")

    define("j-ADV-PROTEIN-PHOSPHATASES",	"Advances in protein phosphatases")

    define("j-ADV-QUANTUM-CHEM",		"Advances in Quantum Chemistry")
    define("j-ADV-QUANTUM-CHEM",		"Adv. Quantum Chem.")
    define("j-ADV-QUANTUM-CHEM",		"Advan. Quantum Chem.")

    # j-ADV-SCI: v1 n1 Oct. 1939-v27 n134 June 1971 (discontinued)
    define("j-ADV-SCI",				"Advancement of Science")
    define("j-ADV-SCI",				"Adv. Sci.")

    define("j-ADV-SCI-LETT",			"Advanced Science Letters")
    define("j-ADV-SCI-LETT",			"Adv. Sci. Lett.")

    define("j-ADV-SOFT-SCI-TECH",		"Advances in software science and technology")
    define("j-ADV-SPACE-RES",			"Advances in space research: the official journal of the Committee on Space Research (COSPAR)")

    define("j-ADV-THEORY-SIMUL",		"Advanced Theory and Simulations")
    define("j-ADV-THEORY-SIMUL",		"Adv. Theory Simul.")

    define("j-ADV-WATER-RESOURCES",		"Advances in Water Resources")
    define("j-ADV-WATER-RESOURCES",		"Advances in water resources")
    define("j-ADV-WATER-RESOURCES",		"Adv. Water Resources")

    define("j-AEDS-J",				"AEDS J")

    define("j-AEQUATIONES-MATHEMATICAE",	"Aequationes Mathematicae")
    define("j-AEQUATIONES-MATHEMATICAE",	"Aequationes Math.")
    define("j-AEQUATIONES-MATHEMATICAE",	"Aequ. math.")

    define("j-AEROBIOLOGIA",			"Aerobiologia")
    define("j-AEROSPACE-AMERICA",		"Aerospace America")

    define("j-AEU",				"AEU: Archiv f{\\\"u}r Elektronik und Ubertragungstech")
    define("j-AEU",				"AEU: Archiv fur Elektronik und Ubertragungstech")

    define("j-AGAINST-GRAIN",			"Against the Grain")
    define("j-AGAINST-GRAIN",			"Against Grain")

    define("j-AGRIC-EDUC-MAG",			"Agricultural education magazine")
    define("j-AGRIC-EDUC-MAG",			"Agric. educ. mag.")
    define("j-AGRIC-EDUC-MAG",			"The Agricultural education magazine")

    define("j-AI-EXPERT",			"AI Expert")
    define("j-AI-MAGAZINE",			"The AI Magazine")

    define("j-AI-SOC",				"AI and Society")
    define("j-AI-SOC",				"AI &amp; Society")
    define("j-AI-SOC",				"AI \\& soc.")
    define("j-AI-SOC",				"AI &amp; soc.")
    define("j-AI-SOC",				"AI and soc.")

    define("j-AIAA-ASME-ASCE-AHS-STRUCT-STRUCT-DYN-MAT-CONF","AIAA/ASME/ASCE/AHS Structures, Structural Dynamics \\& Materials Conference --- Collection of Technical Papers")

    define("j-AIAA-J",				"American Institute of Aeronautics and Astronautics Journal")
    define("j-AIAA-J",				"AIAA Journal")
    define("j-AIAA-J",				"AIAA J.")
    define("j-AIAA-J",				"Am. Inst. Aero. Astro. J.")

    define("j-AIAA-PAPER",			"AIAA paper")
    define("j-AIAA-PAPER",			"AIAA pap.")

    define("j-AICHE-SYMP-SER",			"American Institute of Chemical Engineers symposium series")
    define("j-AICHE-SYMP-SER",			"AIChE symposium series")
    define("j-AICHE-SYMP-SER",			"AIChE symp. ser.")

    define("j-AIP-ADV",				"AIP Advances")
    define("j-AIP-ADV",				"AIP Adv.")

    define("j-AIP-CONF-PROC",			"AIP Conference Proceedings")
    define("j-AIP-CONF-PROC",			"American Institute of Physics Conference Proceedings")
    define("j-AIP-CONF-PROC",			"AIP Conf. Proc.")

    define("j-AIR-FORCE-MAG",			"{Air Force} magazine")
    define("j-AIR-FORCE-MAG",			"Air Force magazine")
    define("j-AIR-FORCE-MAG",			"Air Force mag.")

    define("j-AIR-TRANSP-WORLD",		"Air transport world")
    define("j-AIR-TRANSP-WORLD",		"Air transp. world")

    define("j-AISB-Q",				"Artificial Intelligence and Simulation of Behavior quarterly")
    define("j-AISB-Q",				"AISB quarterly")

    define("j-AIXTRA",				"/{AIXtra}: {IBM}'s Magazine for {AIX} Professionals")
    define("j-AIXTRA",				"AIXtra")

    define("j-ALGEBRA-LOGIC",			"Algebra and Logic")
    define("j-ALGEBRA-LOGIC",			"Algebra Logic")

    define("j-ALGOL-BULLETIN",			"ALGOL Bulletin (Amsterdam: Mathematisch Centrum)")
    define("j-ALGOL-BULLETIN",			"Algol Bulletin (Amsterdam: Mathematisch Centrum)")
    define("j-ALGOL-BULLETIN",			"ALGOL Bulletin")
    define("j-ALGOL-BULLETIN",			"Algol Bull.")
    define("j-ALGOL-BULLETIN",			"ALGOL Bull.")

    define("j-ALGORITHMICA",			"Algorithmica")

    define("j-ALGORITHMS-BASEL",		"Algorithms (Basel)")
    define("j-ALGORITHMS-BASEL",		"Algorithms")

    define("j-ALLC-BULL",			"ALLC Bull")
    define("j-AFTERIMAGES",                     "Afterimages")

    define("j-ALMAGEST",			"Almagest: International Journal for the History of Scientific Ideas")
    define("j-ALMAGEST",			"Almagest")

    define("j-ALTA-FREQ",			"Alta frequenza")
    define("j-ALTA-FREQ",			"Alta freq.")

    define("j-ALTERNATIVES",                    "Alternatives")

    define("j-AM-ANTHROPOL",			"American anthropologist")
    define("j-AM-ANTHROPOL",			"Am. anthropol.")
    define("j-AM-ANTHROPOL",			"Amer. Anthropologist")

    define("j-AM-BIOL-TEACH",			"The American Biology Teacher")
    define("j-AM-BIOL-TEACH",			"American Biology Teacher")
    define("j-AM-BIOL-TEACH",			"Amer. Biol. Teach.")
    define("j-AM-BIOL-TEACH",			"Am. Biol. Teach.")

    define("j-AM-CRAFT",			"American Craft")
    define("j-AM-CRAFT",			"Am. Craft")

    define("j-AM-DOC",				"American Documentation")
    define("j-AM-DOC",				"Am. Doc.")

    define("j-AM-EDUC",				"American Educator")
    define("j-AM-EDUC",				"Am. Educ.")
    define("j-AM-EDUC",				"Amer. Educator")

    define("j-AM-HEART-J",			"American heart journal")
    define("j-AM-HEART-J",			"Am. heart j.")

    define("j-AM-HIST-REV",			"The American Historical Review")
    define("j-AM-HIST-REV",			"American Historical Review")
    define("j-AM-HIST-REV",			"Amer. Hist. Rev.")
    define("j-AM-HIST-REV",			"Am. Hist. Rev.")

    define("j-AM-J-ANAT",			"American Journal of Anatomy")
    define("j-AM-J-ANAT",			"Am. J. Anat.")
    define("j-AM-J-ANAT",			"Am. J. Anatomy")

    define("j-AM-J-APPL-SCI",			"American Journal of Applied Sciences")
    define("j-AM-J-APPL-SCI",			"Am. J. Appl. Sci.")

    define("j-AM-J-ARCHAEOL",			"American Journal of Archaeology")
    define("j-AM-J-ARCHAEOL",			"Am. J. Archaeol.")

    define("j-AM-J-CARDIOL",			"American journal of cardiology")
    define("j-AM-J-CARDIOL",			"Am. J. Cardiol.")

    define("j-AM-J-ECON-SOCIOL",		"The American Journal of Economics and Sociology")
    define("j-AM-J-ECON-SOCIOL",		"American Journal of Economics and Sociology")
    define("j-AM-J-ECON-SOCIOL",		"Am. J. Econ. Sociol.")

    define("j-AM-J-HUM-GENET",			"American journal of human genetics")
    define("j-AM-J-HUM-GENET",			"Am. j. hum. genet.")
    define("j-AM-J-HUM-GENET",			"Am. j. hum. gen.")
    define("j-AM-J-HUM-GENET",			"Amer. j. hum. gen.")

    define("j-AM-J-MATH",			"American Journal of Mathematics")
    define("j-AM-J-MATH",			"Am. J. Math.")
    define("j-AM-J-MATH",			"Amer. J. Math.")

    define("j-AM-J-MATH-MANAGE-SCI",		"American Journal of Mathematical and Management Sciences")
    define("j-AM-J-MATH-MANAGE-SCI",		"Am. J. Math. Management Sci.")
    define("j-AM-J-MATH-MANAGE-SCI",		"Amer. J. Math. Management Sci.")

    define("j-AM-J-MED",			"American Journal of Medicine")
    define("j-AM-J-MED",			"Am. j. med.")

    define("j-AM-J-MED-SCI",			"The American journal of the medical sciences")
    define("j-AM-J-MED-SCI",			"Am. j. med. sci.")

    define("j-AM-J-OPHTHALMOL",			"American Journal of Ophthalmology")
    define("j-AM-J-OPHTHALMOL",			"Am. j. ophthalmol.")
    define("j-AM-J-OPHTHALMOL",			"Amer. J. Opthalmol.")

    define("j-AM-J-PHYS-ANTHROPOL",		"American Journal of Physical Anthropology")
    define("j-AM-J-PHYS-ANTHROPOL",		"Am. J. Phys. Anthropol.")

    define("j-AM-J-PHYSIOL",			"American Journal of Physiology")
    define("j-AM-J-PHYSIOL",			"Am. J. Physiol.")

    define("j-AM-J-PSYCHIATRY",			"American Journal of Psychiatry")
    define("j-AM-J-PSYCHIATRY",			"Am. J. Psychiatr.")
    define("j-AM-J-PSYCHIATRY",			"Am. J. Psychiatry")

    define("j-AM-J-SCI",			"American Journal of Science")
    define("j-AM-J-SCI",			"Amer. J. Sci.")
    define("j-AM-J-SCI",			"Am. J. Sci.")

    define("j-AM-J-SOCIOL",			"American journal of sociology")
    define("j-AM-J-SOCIOL",			"Am. j. sociol.")
    define("j-AM-J-SOCIOL",			"Amer. J. Sociology")
    define("j-AM-J-SOCIOL",			"Am. J. Sociology")

    define("j-AM-NAT",				"American Naturalist")
    define("j-AM-NAT",				"Am. Nat.")

    define("j-AM-PHOTO",			"American photo")
    define("j-AM-PHOTO",			"Am. photo")

    define("j-AM-PROG",				"American Programmer")

    define("j-AM-PROSPECT",			"The American Prospect")
    define("j-AM-PROSPECT",			"American Prospect")
    define("j-AM-PROSPECT",			"Am. Prospect")

    define("j-AM-Q",				"American Quarterly")
    define("j-AM-Q",				"Amer. Quart.")
    define("j-AM-Q",				"Am. Q.")

    define("j-AM-SCH",				"American Scholar")
    define("j-AM-SCH",				"The American Scholar")
    define("j-AM-SCH",				"Am. Sch.")

    define("j-AM-SCI",				"American Scientist")
    define("j-AM-SCI",				"Amer. Scientist")
    define("j-AM-SCI",				"Amer. sci.")
    define("j-AM-SCI",				"Am. sci.")

    define("j-AM-STUD",				"American Studies")
    define("j-AM-STUD",				"Amer. Stud.")
    define("j-AM-STUD",				"Am. Stud.")

    define("j-AMBIX",				"Ambix: Journal of the Society for the History of Alchemy and Chemistry")
    define("j-AMBIX",				"Ambix")

    define("j-AMER-AGR-ECON",			"American Journal of Agricultural Economics")

    define("j-AMER-J-CLIN-PATH",		"American journal of clinical pathology")

    define("j-AMER-J-PHYSICS",			"American Journal of Physics")
    define("j-AMER-J-PHYSICS",			"Amer. J. Physics")
    define("j-AMER-J-PHYSICS",			"Amer. J. Phys.")
    define("j-AMER-J-PHYSICS",			"Am. J. Physics")
    define("j-AMER-J-PHYSICS",			"Am. J. Phys.")

    define("j-AMER-J-PSYCHOLOGY",		"American Journal of Psychology")
    define("j-AMER-J-PSYCHOLOGY",		"The American Journal of Psychology")
    define("j-AMER-J-PSYCHOLOGY",		"Amer. J. Psychol.")
    define("j-AMER-J-PSYCHOLOGY",		"Am. J. Psychol.")

    define("j-AMER-LIBRARIES",			"American Libraries")

    define("j-AMER-MATH-MONTHLY",		"American Mathematical Monthly")
    define("j-AMER-MATH-MONTHLY",		"Amer. Math. Monthly")
    define("j-AMER-MATH-MONTHLY",		"Am. math. mon.")

    define("j-AMER-MATH-MONTHLY-SLAUGHT",	"Mathematical Association of America. Herbert Ellsworth Slaught Memorial Papers")
    define("j-AMER-MATH-MONTHLY-SLAUGHT",	"American Mathematical Monthly Slaught Memorial Papers")

    define("j-AMER-PSYCHOLOGIST",		"American Psychologist")
    define("j-AMER-PSYCHOLOGIST",		"Am. psychol.")

    define("j-AMER-SOC-MECH-ENG-AESD",		"American Society of Mechanical Engineers. Advanced Energy Systems Division")
    define("j-AMER-SOC-MECH-ENG-AESD",		"American Society of Mechanical Engineers, Advanced Energy Systems Division (Publication) AES")

    define("j-AMER-STAT",			"The American Statistician")
    define("j-AMER-STAT",			"Amer. Statist.")
    define("j-AMER-STAT",			"Am. Statistician")
    define("j-AMER-STAT",			"Am. stat.")

    define("j-AMERICAS-NETWORK",		"America's network: technology for the information highway")
    define("j-AMERICAS-NETWORK",		"America's network: technology for the informat")

    define("j-AMERIKASTUDIEN",			"Amerikastudien / American Studies")
    define("j-AMERIKASTUDIEN",			"Amerikastudien")

    define("j-AMS-COLL-PUB",			"AMS Colloquium Publication")
    define("j-AMS-COLL-PUB",			"AMS Coll. Publ.")

    define("j-AN-R-ACAD-NAC-MED-MADR",          "Anales de la Real Academia Nacional de Medicina (Madrid)")
    define("j-AN-R-ACAD-NAC-MED-MADR",          "Anales de la Real Academia Nacional de Medicina")
    define("j-AN-R-ACAD-NAC-MED-MADR",          "An R Acad Nac Med Madr.")

    define("j-ANAESTHESIA",			"Anaesthesia")

    define("j-ANAL-CHEM",			"Analytical Chemistry (Washington, DC, USA)")
    define("j-ANAL-CHEM",			"Analytical Chemistry (Washington, DC, United States)")
    define("j-ANAL-CHEM",			"Analytical Chemistry")
    define("j-ANAL-CHEM",			"Anal. Chem.")
    define("j-ANAL-CHEM",			"Anal. Chem. (Washington, DC, U.S.)")
    define("j-ANAL-CHEM",			"Anal. Chem. (Washington, DC, USA)")

    define("j-ANAL-MATH-PHYS",			"Analysis and Mathematical Physics")
    define("j-ANAL-MATH-PHYS",			"Anal. Math. Phys.")

    define("j-ANALYST",				"The Analyst")
    define("j-ANALYST",				"Analyst")

    define("j-ANALYT-BIOCHEM",			"Analytical biochemistry")
    define("j-ANALYT-BIOCHEM",			"Anal. Biochem.")
    define("j-ANALYT-BIOCHEM",			"Anal Biochem (4NK)")

    define("j-ANAT-EMBRYOL",			"Anatomy and embryology")
    define("j-ANAT-EMBRYOL",			"Anat. embryol.")

    define("j-ANESTHESIA-ANALGESIA-CURR-RESEARCHES","Anesthesia and Analgesia: Current Researches")

    define("j-ANESTHESIOL-HAGERSTOWN",		"Anesthesiology (Hagerstown)")
    define("j-ANESTHESIOL-HAGERSTOWN",		"Anesthesiol. (Hagerstown)")

    define("j-ANG-INFO-ELEK-DATEN",		"Angewandte Informatik (Elektron. Datenverarbeitung)")
    define("j-ANG-INFO-ELEK-DATEN",		"Angewandte Informatik")
    define("j-ANG-INFO-ELEK-DATEN",		"Angew. Inf.")
    define("j-ANG-INFO-ELEK-DATEN",		"Angew. Inf. (Elektron. Datenverarbeitung)")

    define("j-ANGEW-CHEM",			"Angewandte Chemie")
    define("j-ANGEW-CHEM",			"Angew. Chem.")

    define("j-ANGEW-CHEM-INT-ED",		"Angewandte Chemie, International Edition")
    define("j-ANGEW-CHEM-INT-ED",		"Angew. Chem., Int. Ed.")

    define("j-ANGEW-CHEM-INT-ED-ENGL",		"Angewandte Chemie, International Edition in English")
    define("j-ANGEW-CHEM-INT-ED-ENGL",		"Angew. Chem., Int. Ed. Engl.")

    define("j-ANIM-BEHAV",			"Animal Behaviour")
    define("j-ANIM-BEHAV",			"Anim. Behav.")

    define("j-ANN-ACAD-REGIAE-SCI-UPS",		"Annales Academiae regiae scientiarum upsaliensis")
    define("j-ANN-ACAD-REGIAE-SCI-UPS",		"Ann. Acad. Reg. Sci. Upsal.")
    define("j-ANN-ACAD-REGIAE-SCI-UPS",		"Ann. Acad. Regiae. Sci. Upsal.")
    define("j-ANN-ACAD-REGIAE-SCI-UPS",		"Kungliga Vetenskapssamhaellets i Uppsala, Aarsbok")
    define("j-ANN-ACAD-REGIAE-SCI-UPS",		"K. Vetenskapssamh. Uppsala, Aarsb.")
    define("j-ANN-ACAD-REGIAE-SCI-UPS",		"Ann. Acad. Regiae Sci. Ups.")

    define("j-ANN-AM-ACAD-POLIT-SOC-SCI",	"Annals of the American Academy of Political and Social Science")
    define("j-ANN-AM-ACAD-POLIT-SOC-SCI",	"Ann. Am. Acad. Polit. Soc. Sci.")

    # v. 1 (1914/1915)--date
    define("j-ANN-APPL-BIOL",			"Annals of Applied Biology")
    define("j-ANN-APPL-BIOL",			"Ann. Appl. Biol.")

    define("j-ANN-APPL-PROBAB",			"Annals of Applied Probability")
    define("j-ANN-APPL-PROBAB",			"Annals of Applied Probability : an Official Journal of the Institute of Mathematical Statistics")
    define("j-ANN-APPL-PROBAB",			"Ann. appl. probab.")
    define("j-ANN-APPL-PROBAB",			"Ann. Applied Prob.")

    define("j-ANN-APPL-STAT",			"Annals of Applied Statistics")
    define("j-ANN-APPL-STAT",			"Ann. Applied Stat.")
    define("j-ANN-APPL-STAT",			"Ann. Appl. Stat.")

    define("j-ANN-BIOMED-ENG",			"Annals of biomedical engineering")
    define("j-ANN-BIOMED-ENG",			"Ann. Biomed. Eng.")
    define("j-ANN-BIOMED-ENG",			"Ann Biomed Eng (4ZX)")
    define("j-ANN-BIOMED-ENG",			"Ann Biomed Eng")

    define("j-ANN-CHIM-PHYS",			"Annales de Chimie et de Physique")
    define("j-ANN-CHIM-PHYS",			"Annales de Chimie et de Physique [1816--1913]")
    define("j-ANN-CHIM-PHYS",			"Ann. Chim. Phys.")

    define("j-ANN-EUGENICS",			"Annals of Eugenics")
    define("j-ANN-EUGENICS",			"Ann. Eugenics")

    define("j-ANN-FAC-SCI-UNIV-CLERMONT",	"Annales de la Facult{\\'e} des Sciences de l'Universit{\\'e} de Clermont")
    define("j-ANN-FAC-SCI-UNIV-CLERMONT",	"Ann. Fac. Sci. Univ. Clermont")

    define("j-ANN-FINANCE",			"Annals of Finance")
    define("j-ANN-FINANCE",			"Ann. Finance")

    define("j-ANN-FOURIER",			"Annales de l'Institut Fourier (Grenoble)")
    define("j-ANN-FOURIER",			"Ann. Inst. Fourier (Grenoble)")

    define("j-ANN-FOND-LOUIS-DE-BROGLIE",	"Annales de la Fondation Louis de Broglie")
    define("j-ANN-FOND-LOUIS-DE-BROGLIE",	"Ann. Fond. Louis de Broglie")

    define("j-ANN-FUNCT-ANAL",			"Annals of Functional Analysis")
    define("j-ANN-FUNCT-ANAL",			"Ann. Funct. Anal.")

    define("j-ANN-HIST-COMPUT",			"Annals of the History of Computing")
    define("j-ANN-HIST-COMPUT",			"Ann. Hist. Comp.")
    define("j-ANN-HIST-COMPUT",			"Ann. Hist. Comput.")
    define("j-ANN-HIST-COMPUT",			"Ann. Hist. Computing")

    ## Formerly known as Annals of Eugenics (1925--1954)
    define("j-ANN-HUM-GENET",			"Ann. Hum. Genet.")
    define("j-ANN-HUM-GENET",			"Annals of Human Genetics")

    define("j-ANN-INST-HENRI-POINCARE-ANAL-NON-LINEAIRE", "Annales de l'Institut Henri Poincar{\\'e}. Analyse non lin{\\'e}aire")
    define("j-ANN-INST-HENRI-POINCARE-ANAL-NON-LINEAIRE", "Annales de l'Institut Henri Poincare. Analyse non lineaire")
    define("j-ANN-INST-HENRI-POINCARE-ANAL-NON-LINEAIRE", "Ann. Inst. Henri Poincar{\\'e}, Anal. non lin{\\'e}aire")
    define("j-ANN-INST-HENRI-POINCARE-ANAL-NON-LINEAIRE", "Ann. Inst. Henri Poincare, Anal. non lineaire")
    define("j-ANN-INST-HENRI-POINCARE-ANAL-NON-LINEAIRE", "Ann. Inst. H. Poincar{\\'e} Anal. Non Lin{\\'e}aire")
    define("j-ANN-INST-HENRI-POINCARE-ANAL-NON-LINEAIRE", "Ann. Inst. H. Poincar\\'e Anal. Non Lin\\'eaire")
    define("j-ANN-INST-HENRI-POINCARE-ANAL-NON-LINEAIRE", "Annales De L'Institut Henri Poincare.  Annales:  Analyse Non Lineaire/Nonlinear Analysis")

    define("j-ANN-INST-HENRI-POINCARE",		"Annales de l'Institut Henri Poincar{\\'e}")
    define("j-ANN-INST-HENRI-POINCARE",		"Ann. Inst. Henri Poincar{\\'e}")
    define("j-ANN-INST-HENRI-POINCARE",		"Ann. Inst. H. Poincar{\\'e}")

    define("j-ANN-INST-HENRI-POINCARE-A",	"Annales de l'institut Henri Poincar{\\'e} (A) Physique th{\\'e}orique")
    define("j-ANN-INST-HENRI-POINCARE-A",	"Ann. Inst. Henri Poincar{\\'e}, Sect. A")

    define("j-ANN-INST-HENRI-POINCARE-B",	"Annales de l'Institut Henri Poincar{\\'e}. Section B, Probabilit{\\'e}s et statistiques")
    define("j-ANN-INST-HENRI-POINCARE-B",	"Annales de l'Institut Henri Poincare. Section B, Probabilites et statistiques")
    define("j-ANN-INST-HENRI-POINCARE-B",	"Ann. Inst. Henri Poincar{\\'e}")
    define("j-ANN-INST-HENRI-POINCARE-B",	"Ann. Inst. Henri Poincare. B. Calc. probab. stat.")
    define("j-ANN-INST-HENRI-POINCARE-B",	"Annales de l'Institut Henri Poincare. Section B. Calcul des probabilites et statistique")
    define("j-ANN-INST-HENRI-POINCARE-B",	"Annales de l'Institut Henri Poincar{\\'e}. Section B. Calcul des probabilit{\\'e}s et statistique")
    define("j-ANN-INST-HENRI-POINCARE-B",	"Ann. Inst. H. Poincar\\'e Probab. Statist.")

    define("j-ANN-INST-HENRI-POINCARE-PROBAB-STATIST",	"Annales de l'Institut Henri Poincar{\\'e}, Probabilit{\\'e}s et Statistiques")
    define("j-ANN-INST-HENRI-POINCARE-PROBAB-STATIST",	"Ann. Inst. H. Poincar{\\'e} Probab. Statist.")

    define("j-ANN-INST-STAT-MATH-TOKYO",	"Annals of the Institute of Statistical Mathematics (Tokyo)")
    define("j-ANN-INST-STAT-MATH-TOKYO",	"Annals of the Institute of Statistical Mathematics")
    define("j-ANN-INST-STAT-MATH-TOKYO",	"Ann. Inst. Statist. Math. (Tokyo)")
    define("j-ANN-INST-STAT-MATH-TOKYO",	"Ann. Inst. Stat. Math. (Tokyo)")
    define("j-ANN-INST-STAT-MATH-TOKYO",	"Ann. Inst. Statist. Math.")

    define("j-ANN-INTERN-MED",			"Annals of internal medicine")
    define("j-ANN-INTERN-MED",			"Ann. intern. med.")

    define("j-ANN-MAT-PURA-APPL-4",		"Annali di matematica pura ed applicata. Series 4")
    define("j-ANN-MAT-PURA-APPL-4",		"Ann. mat. pura appl. (4)")
    define("j-ANN-MAT-PURA-APPL-4",		"Annali di Matematica pura ed applicata (IV)")

    define("j-ANN-MATH",			"Annals of Mathematics")
    define("j-ANN-MATH",			"Ann. Math.")

    define("j-ANN-MATH-2",			"Annals of Mathematics (2)")
    define("j-ANN-MATH-2",			"Ann. of Math. (2)")

    define("j-ANN-MATH-ARTIF-INTELL",		"Annals of Mathematics and Artificial Intelligence")
    define("j-ANN-MATH-ARTIF-INTELL",		"Ann. math. artif. intell.")
    define("j-ANN-MATH-ARTIF-INTELL",		"Ann. Math. Artificial Intelligence")

    ## j-ANN-MATH-STAT (1939--1972) split into j-ANN-PROBAB and j-ANN-STAT in 1973
    define("j-ANN-MATH-STAT",			"Annals of Mathematical Statistics")
    define("j-ANN-MATH-STAT",			"The Annals of Mathematical Statistics")
    define("j-ANN-MATH-STAT",			"Annals Math. Stat.")
    define("j-ANN-MATH-STAT",			"Ann. Math. Statistics")
    define("j-ANN-MATH-STAT",			"Ann. Math. Statist.")
    define("j-ANN-MATH-STAT",			"Ann. Math. Stat.")

    define("j-ANN-MATH-STUDIES",		"Annals of Mathematics Studies")

    define("j-ANN-NUCL-ENERGY",			"Annals of Nuclear Energy")
    define("j-ANN-NUCL-ENERGY",			"Annals Nucl. Energy")
    define("j-ANN-NUCL-ENERGY",			"Ann. Nucl. Energy")

    define("j-ANN-NUM-MATH",			"Annals of Numerical Mathematics")

    define("j-ANN-NY-ACAD-SCI",			"Annals of the New York Academy of Sciences")
    define("j-ANN-NY-ACAD-SCI",			"Annals N. Y. Acad. Sci.")
    define("j-ANN-NY-ACAD-SCI",			"Ann. N. Y. Acad. Sci.")
    define("j-ANN-NY-ACAD-SCI",			"Ann N Y Acad Sci (5NM)")

    define("j-ANN-OPER-RESEARCH",		"Annals of Operations Research")
    define("j-ANN-OPER-RESEARCH",		"Ann. Oper. Res.")

    define("j-ANN-PHYS",			"Annals of Physics")
    define("j-ANN-PHYS",			"Ann. physics")
    define("j-ANN-PHYS",			"Ann. Phys. (N.Y.)")
    define("j-ANN-PHYS",			"Ann. phys.")

    ## Annalen der Physik series:
    ##     1900--1928   4. Folge, Bd. 1, no. 1    (1900)--4. Folge, Bd. 87, No. 24   (1928);
    ##     1929--1944   5. Folge, Bd. 1, Heft 1   (1929)--5. Folge, Bd. 43, Heft 8   (1944);
    ##     1947--1957   6. Folge, Bd. 1, Heft 1/3 (1947)--6. Folge, Bd. 20, Heft 7/8 (1957);
    ##     1958--1990   7. Folge, Bd. 1, Heft 1/3 (1958)--7. Folge, Bd. 47, Heft 8   (1990);
    ##     1992--20xx   8th ser., v. 1 (1992)--
    ## 3 volumes per year 1900--1999, variable issue number count
    ## 12 issues per year 2000--20xx
    ## volume numbering can be from 1900 (volume 1), or from 17xx

    define("j-ANN-PHYS-1900",			"Annalen der Physik (1900)")
    define("j-ANN-PHYS-1900",			"Annalen der Physik")
    ## Suppress this conflicting abbreviation
    ## define("j-ANN-PHYS-1900",			"Ann. phys.")
    define("j-ANN-PHYS-1900",			"Ann. d. phys.")
    define("j-ANN-PHYS-1900",			"Ann. d. physik")

    define("j-ANN-PHYS-1900-4",			"Annalen der Physik (1900) (series 4)")
    define("j-ANN-PHYS-1900-4",			"Annalen der Physik (1900) (4. Folge)")
    define("j-ANN-PHYS-1900-4",			"Ann. d. physik (4. Folge)")

    define("j-ANN-PHYS-5",			"Annalen der Physik 5 (Berlin, Germany)")
    define("j-ANN-PHYS-5",			"Annalen der Physik (5)")
    define("j-ANN-PHYS-5",			"Annalen der Physik (Berlin, Germany)")
    define("j-ANN-PHYS-5",			"Ann. Phys. 5 (Berlin, Ger.)")
    define("j-ANN-PHYS-5",			"Ann. Phys. (5)")
    define("j-ANN-PHYS-5",			"Ann. Phys. (Berlin, Ger.)")

    define("j-ANN-PHYS-6",			"Annalen der Physik 6 (Berlin, Germany)")
    define("j-ANN-PHYS-6",			"Annalen der Physik (6)")
    define("j-ANN-PHYS-6",			"Annalen der Physik (Berlin, Germany)")
    define("j-ANN-PHYS-6",			"Ann. Physik 6 (Berlin, Ger.)")
    define("j-ANN-PHYS-6",			"Ann. Phys. 6 (Berlin, Ger.)")
    define("j-ANN-PHYS-6",			"Ann. Physik (6)")
    define("j-ANN-PHYS-6",			"Ann. Phys. (6)")
    define("j-ANN-PHYS-6",			"Ann. Phys. (Berlin, Ger.)")

    ## Annalen der Physik Volume 7 number 1 1998 (8th series) == volume 510 of complete series
    ## see http://onlinelibrary.wiley.com/doi/10.1002/andp.2060070101/pdf

    define("j-ANN-PHYS-8",			"Annalen der Physik 8 (Berlin, Germany)")
    define("j-ANN-PHYS-8",			"Annalen der Physik (8)")
    define("j-ANN-PHYS-8",			"Annalen der Physik (Berlin, Germany)")
    define("j-ANN-PHYS-8",			"Ann. Phys. 8 (Berlin, Ger.)")
    define("j-ANN-PHYS-8",			"Ann. Phys. (8)")
    define("j-ANN-PHYS-8",			"Ann. Phys. (Berlin, Ger.)")

    ## The volume numbering of Annalen der Physik is a mess, with more
    ## than 8 series issued.  From the National Research Council of Canada
    ## library record:
    ##
    ##     Frequency varies, 1900--1999
    ##     4. Folge, Bd. 1 (1900)--Bd. 87 (1928);
    ##     5. Folge, Bd. 1 (1929)--Bd. 43 (1944);
    ##     6. Folge, Bd. 1 (1947)--Bd. 20 (1957);
    ##     7. Folge, Bd. 1 (1958)--Bd. 47, Heft 5 (1990);
    ##     8th ser., v. 1 (1992)-
    ##     Issues for v. 7, no. 4 (1998)- also have title: Ann. phys.
    ##     Continues: Annalen der Physik und Chemie. Leipzig.
    ##
    ## The journal publisher proposes a solution at
    ##
    ##     http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1521-3889/homepage/2257_new.html
    ##
    ## with this recommendation:
    ##
    ##     How to cite?  To make sure that references to this journal
    ##     are correctly recorded and resolved (for example in
    ##     CrossRef or ISI Web of Science), please use the following
    ##     abbreviated title in any citations: "Ann. Phys. (Berlin)"
    ##     (punctuation may vary according to the style of the citing
    ##     journal).
    ##
    ##     Valid from June 1, 2010 Annalen der Physik will use the
    ##     following citation form:
    ##
    ##     Ann. Phys. (Berlin) complete volume number (issue number),
    ##     page(s) (year).
    ##
    ##     The previously used citation form for the articles of the
    ##     8th series (starting 1992 until June 2010) is still valid
    ##     for these articles, e.g. Ann. Phys. (Berlin) 19, 5 (2010).
    ##     Please note that from June 2010 onwards these articles can
    ##     also be cited in the new form, e.g. Ann. Phys. (Berlin)
    ##     522, 5 (2010).  Please make sure to always use
    ##     Ann. Phys. (Berlin) as journal abbreviation; there are also
    ##     other journals using Ann. Phys. as abbreviation, like
    ##     Annals of Physics or Annales de Physique.

    define("j-ANN-PHYS-BERLIN",			"{Annalen der Physik (Berlin)}")
    define("j-ANN-PHYS-BERLIN",			"{Ann. Phys. (Berlin)}")

    ## Ann. Phys. Chem., 1824--1899
    define("j-ANN-PHYS-CHEM",			"{Annalen der Physik und Chemie}")
    define("j-ANN-PHYS-CHEM",			"{Ann. Phys. Chem.}")

    ## Ann. Phys. Phys. Chem., 1819--1824
    define("j-ANN-PHYS-PHYS-CHEM",		"Annalen der Physik und der Physikalischen Chemie")
    define("j-ANN-PHYS-PHYS-CHEM",		"Ann. Phys. Phys. Chem.")

    ## j-ANN-MATH-STAT (1939--1972) split into j-ANN-PROBAB and j-ANN-STAT in 1973
    define("j-ANN-PROBAB",			"Annals of Probability")
    define("j-ANN-PROBAB",			"Ann. Probability")
    define("j-ANN-PROBAB",			"Ann. Prob.")
    define("j-ANN-PROBAB",			"Ann. Probab.")

    define("j-ANN-REG-SCI",			"Annals of Regional Science")

    define("j-ANN-REV-BIOCHEM",			"Annual Review of Biochemistry")
    define("j-ANN-REV-BIOCHEM",			"Ann. Rev. Biochem.")
    define("j-ANN-REV-BIOCHEM",			"Annu. Rev. Biochem.")

    define("j-ANN-REV-BIOPHYS-BIOPHYS-CHEM",	"Annual review of biophysics and biophysical chemistry")
    define("j-ANN-REV-BIOPHYS-BIOPHYS-CHEM",	"Ann. rev. biophys. biophys. chem.")
    define("j-ANN-REV-BIOPHYS-BIOPHYS-CHEM",	"Annu. rev. biophys. biophys. chem.")

    define("j-ANN-REV-CELL-BIOL",		"Annual Review of Cell Biology")
    define("j-ANN-REV-CELL-BIOL",		"Annual reviews of cell biology")
    define("j-ANN-REV-CELL-BIOL",		"Ann. Rev. Cell Biol.")

    define("j-ANN-REV-ECOLOG-SYST",		"Annual Review of Ecology and Systematics")
    define("j-ANN-REV-ECOLOG-SYST",		"Ann. rev. ecolog. syst.")

    define("j-ANN-REV-FLUID-MECH",		"Annual Review of Fluid Mechanics")
    define("j-ANN-REV-FLUID-MECH",		"Annu. rev. fluid mech.")

    define("j-ANN-REV-GENET",			"Annual Review of Genetics")
    define("j-ANN-REV-GENET",			"Annu. rev. genet.")

    define("j-ANN-REV-MATERIAL-SCI",		"Annual Review of Materials Science")
    define("j-ANN-REV-MATERIAL-SCI",		"Ann. Rev. Mater. Sci.")

    define("j-ANN-REV-MATERIAL-SCI",		"Annual Rev. of Materials Science")

    define("j-ANN-REV-NEURO",			"Annual Review of Neuroscience")
    define("j-ANN-REV-NEURO",			"Annual Rev. Neurosci.")

    define("j-ANN-REV-PHYS-CHEM",		"Annual Review of Physical Chemistry")
    define("j-ANN-REV-PHYS-CHEM",		"Ann. Rev. Phys. Chem.")

    define("j-ANN-REV-PHYSIOL",			"Annual Review of Physiology")
    define("j-ANN-REV-PHYSIOL",			"Annual Rev. Physiol.")
    define("j-ANN-REV-PHYSIOL",			"Ann. Rev. Physiol.")

    define("j-ANN-SC-NORM-SUPER-PISA-CL-SCI",	"Annali della Scuola normale superiore di Pisa, Classe di scienze")
    define("j-ANN-SC-NORM-SUPER-PISA-CL-SCI",	"Ann. Sc. norm. super. Pisa, Cl. sci.")
    define("j-ANN-SC-NORM-SUPER-PISA-CL-SCI",	"Ann. Scuola Norm. Sup. Pisa Cl. Sci. (4)")

    define("j-ANN-SCI-MATH-QUEBEC",		"Les Annales des sciences math{\\'e}matiques du Qu{\\'e}bec")
    define("j-ANN-SCI-MATH-QUEBEC",		"Ann. Sci. Math. Qu{\\'e}bec")

    define("j-ANN-SCIENCE",			"Annals of Science")
    define("j-ANN-SCIENCE",			"Ann. Sci.")
    define("j-ANN-SCIENCE",			"Ann. Science")

    define("j-ANN-SENS",			"Annales scientifiques de l'{\\'E}cole Normale Sup{\\'e}rieure")
    define("j-ANN-SENS",			"Ann. Scient. Ec. Norm. Sup.")

    ## j-ANN-MATH-STAT (1939--1972) split into j-ANN-PROBAB and j-ANN-STAT in 1973
    define("j-ANN-STAT",			"Annals of Statistics")
    define("j-ANN-STAT",			"Ann. of Statist.")
    define("j-ANN-STAT",			"Ann. Statist.")
    define("j-ANN-STAT",			"Ann. Stat.")

    define("j-ANN-SYMP-FOCS",			"Annual Symposium on Foundations of Computer Science")
    define("j-ANN-SYMP-FOCS",			"Annual Symposium on Foundations of Computer Science [papers]")

    define("j-ANN-TELECOMMUN",			"Annales des T{\\'e}l{\\'e}communications")
    define("j-ANN-TELECOMMUN",			"Ann. T{\\'e}l{\\'e}commun.")
    define("j-ANN-TELECOMMUN",			"Ann. Telecommun.")

    define("j-ANN-THEOR-PSYCHOL",		"Annals of Theoretical Psychology")
    define("j-ANN-THEOR-PSYCHOL",		"Ann. Theor. Psychol.")

    define("j-ANNALES-ACAD-SCIENT-FENNICAE-A-I", "Annales Academiae Scientiarum Fennicae. Series A. I, Mathematica. Dissertationes")
    define("j-ANRITSU-TECHNICAL-BULL",		"Anritsu Technical Bulletin")
    define("j-ANTIMICROB-AGENTS-CHEMOTHER",	"Antimicrob Agents Chemother (6HK)")

    define("j-ANTIOCH-REV",			"The Antioch Review")
    define("j-ANTIOCH-REV",			"Antioch Review")
    define("j-ANTIOCH-REV",			"Antioch Rev.")

    define("j-ANTISENSE-RES-DEV",		"Antisense research and development")
    define("j-ANTISENSE-RES-DEV",		"Antisense Res Dev (BI7)")

    define("j-ANNU-REP-PROG-CHEM",		"Annual Reports on the Progress of Chemistry")
    define("j-ANNU-REP-PROG-CHEM",		"Ann. Rep. Progr. Chem.")
    define("j-ANNU-REP-PROG-CHEM",		"Annu. Rep. Prog. Chem.")

    define("j-ANNU-REV-ASTRON-ASTROPHYS",	"Annual Review of Astronomy and Astrophysics")
    define("j-ANNU-REV-ASTRON-ASTROPHYS",	"Annu. Rev. Astron. Astrophys.")

    define("j-ANNU-REV-AUTOM-PROGRAM",		"Annual Review in Automatic Programming")
    define("j-ANNU-REV-AUTOM-PROGRAM",		"Annu. Rev. Autom. Prog.")
    define("j-ANNU-REV-AUTOM-PROGRAM",		"Annu. Rev. Autom. Program.")

    define("j-ANNU-REV-NUCL-PART-SCI",		"Annual Review of Nuclear and Particle Science")
    define("j-ANNU-REV-NUCL-PART-SCI",		"Annu. Rev. Nucl. Part. Sci.")

    define("j-ANNU-REV-NUCL-SCI",		"Annual Review of Nuclear Science")
    define("j-ANNU-REV-NUCL-SCI",		"Annu. Rev. Nucl. Sci.")

    define("j-ANNUAL-ACM-SYMP-PAR-ALG-ARCH",	"Annual ACM Symposium on Parallel Algorithms and Architectures")

    define("j-ANZIAM-J",			"The ANZIAM Journal")
    define("j-ANZIAM-J",			"ANZIAM Journal")
    define("j-ANZIAM-J",			"ANZIAM J.")

    ## Formed by the union of Australian Journal of Statistics and New
    ## Zealand Statistician, and continues the numbering of the
    ## former. AJS : v1 n1 April 1959 to v39 n3 September 1997
    ## ANZJS: v40 n1 March 1998 to date
    define("j-ANZJS",				"Australian and New Zealand Journal of Statistics")
    define("j-ANZJS",				"Australian \\& New Zealand Journal of Statistics")
    define("j-ANZJS",				"Austral. \\& New Zealand J. Statist.")
    define("j-ANZJS",				"Austral. and New Zealand J. Statist.")

    define("j-AP",				"Automn Prog.")

    define("j-APL-MAT",				"Aplikace Matematiky")
    define("j-APL-MAT",				"Aplik. mat.")
    define("j-APL-MAT",				"Apl. mat.")

    define("j-APL-QUOTE-QUAD",			"APL Quote Quad")
    define("j-APL-QUOTE-QUAD",			"ACM SIGAPL APL Quote Quad")

    define("j-APPL-ALGEBRA-ENG-COMMUN-COMPUT",	"Applicable algebra in engineering, communication and computing")
    define("j-APPL-ALGEBRA-ENG-COMMUN-COMPUT",	"Appl. algebra eng. commun. comput.")
    define("j-APPL-ALGEBRA-ENG-COMMUN-COMPUT",	"Appl. Algebra Engrg. Comm. Comput.")

    define("j-APPL-ANAL",			"Applicable Analysis")
    define("j-APPL-ANAL",			"Appl. Anal.")
    define("j-APPL-ANAL",			"Applicable Anal.")

    define("j-APPL-COMPUT-HARMON-ANAL",		"Applied and Computational Harmonic Analysis. Time-Frequency and Time-Scale Analysis, Wavelets, Numerical Algorithms, and Applications")
    define("j-APPL-COMPUT-HARMON-ANAL",		"Applied and Computational Harmonic Analysis")
    define("j-APPL-COMPUT-HARMON-ANAL",		"Appl. Comput. Harmon. Anal.")

    define("j-APPL-ECON-LETT",			"Applied Economics Letters")
    define("j-APPL-ECON-LETT",			"Appl. Econ. Lett.")

    define("j-APPL-ENV-MICROBIOL",		"Applied and environmental microbiology")
    define("j-APPL-ENV-MICROBIOL",		"Appl. Environ. Microbiol.")
    define("j-APPL-ENV-MICROBIOL",		"Appl Environ Microbiol (6K6)")

    define("j-APPL-FINANC-ECON",		"Applied Financial Economics")
    define("j-APPL-FINANC-ECON",		"Appl. Financ. Econ.")

    define("j-APPL-INTELL",			"Applied Intelligence")

    define("j-APPL-MATH",			"Applications of Mathematics")
    define("j-APPL-MATH",			"Appl. Math.")

    define("j-APPL-MATH-COMP-SCI",		"Applied Mathematics and Computer Science")
    define("j-APPL-MATH-COMP-SCI",		"Appl. Math. Comp. Sci")

    define("j-APPL-MATH-COMP",			"Applied Mathematics and Computation")
    define("j-APPL-MATH-COMP",			"App. Math. Comp.")
    define("j-APPL-MATH-COMP",			"Appl. Math. Comp.")
    define("j-APPL-MATH-COMP",			"Appl. Math. Comput.")
    define("j-APPL-MATH-COMP",			"Applied Math. Comp.")

    define("j-APPL-MATH-LETT",			"Applied Mathematics Letters")
    define("j-APPL-MATH-LETT",			"Appl. Math. Let.")
    define("j-APPL-MATH-LETT",			"Appl. Math. Lett.")
    define("j-APPL-MATH-LETT",			"Appl. Math. Letters")

    define("j-APPL-MATH-MECH-ENGL-ED",		"Applied Mathematics and Mechanics = Ying yung shu hsueh ho li hsueh")
    define("j-APPL-MATH-MECH-ENGL-ED",		"Applied Mathematics and Mechanics (English Edition)")
    define("j-APPL-MATH-MECH-ENGL-ED",		"Appl. Math. Mech. Engl. Ed.")
    define("j-APPL-MATH-MECH-ENGL-ED",		"Appl. math. mech.")
    define("j-APPL-MATH-MECH-ENGL-ED",		"Applied Mathematics in Mechanics")

    define("j-APPL-MATH-MODEL",			"Applied Mathematical Modelling")
    define("j-APPL-MATH-MODEL",			"Appl. Math. Model.")

    define("j-APPL-MATH-NOTES",			"Applied Mathematics Notes")
    define("j-APPL-MATH-NOTES",			"Appl. Math. Notes")

    define("j-APPL-MATH-OPTIM",			"Applied Mathematics and Optimization")
    define("j-APPL-MATH-OPTIM",			"Appl. Math. and Optimization")
    define("j-APPL-MATH-OPTIM",			"Appl. Math. Optim.")

    define("j-APPL-MATH-SCI-RUSE",		"Applied Mathematical Sciences (Ruse)")
    define("j-APPL-MATH-SCI-RUSE",		"Applied Mathematical Sciences")
    define("j-APPL-MATH-SCI-RUSE",		"Appl. Math. Sci.")
    define("j-APPL-MATH-SCI-RUSE",		"Appl. Math. Sci. (Ruse)")

    define("j-APPL-MATH-SER-NBS",		"Applied mathematics series / National Bureau of Standards")
    define("j-APPL-MATH-SER-NBS",		"Nat. Bureau of Standards Applied Mathematics Series")
    define("j-APPL-MATH-SER-NBS",		"Appl. math. ser. (Wash. D.C.)")
    define("j-APPL-MATH-SER-NBS",		"Appl. math. ser. (Wash. DC)")
    define("j-APPL-MATH-SER-NBS",		"Natl. Bur. Stand. Appl. Math. Series")
    define("j-APPL-MATH-SER-NBS",		"Applied Mathematics Series ({Washington, DC})")

    define("j-APPL-MECH-REV",			"Applied Mechanics Reviews")
    define("j-APPL-MECH-REV",			"ASME Applied Mechanics Reviews")
    define("j-APPL-MECH-REV",			"Appl. Mech, Rev.")
    define("j-APPL-MECH-REV",			"Appl. Mech. Rev.")

    define("j-APPL-MICROBIOL-BIOTECHNOL",	"Applied Microbiology and Biotechnology")
    define("j-APPL-MICROBIOL-BIOTECHNOL",	"Appl. microbiol. biotechnol.")
    define("j-APPL-MICROBIOL-BIOTECHNOL",	"Appl Microbiol Biotechnol (AMC)")

    define("j-APPL-NUM-ANA",			"Applied Numerical Analysis")

    define("j-APPL-NUM-ANAL-COMPUT-MATH",	"ANACM. Applied Numerical Analysis and Computational Mathematics")
    define("j-APPL-NUM-ANAL-COMPUT-MATH",	"Applied Numerical Analysis and Computational Mathematics")
    define("j-APPL-NUM-ANAL-COMPUT-MATH",	"Appl. Numer. Anal. Comput. Math.")

    define("j-APPL-NUM-MATH",			"Applied Numerical Mathematics: Transactions of IMACS")
    define("j-APPL-NUM-MATH",			"Appl. Numer. Math.")
    define("j-APPL-NUM-MATH",			"Appl. Num. Math.")
    define("j-APPL-NUM-MATH",			"Applied Numerical Mathematics")
    define("j-APPL-NUM-MATH",			"Applied Numer. Math.")
    define("j-APPL-NUM-MATH",			"App. Numer. Math.")

    define("j-APPL-OPTICS",			"Applied Optics")
    define("j-APPL-OPTICS",			"Appl. Optics")

    define("j-APPL-PHYS",			"Applied Physics")
    define("j-APPL-PHYS",			"Appl. Phys.")

    define("j-APPL-PHYS-A",			"Applied Physics A: Materials Science \\& Processing")
    define("j-APPL-PHYS-A",			"Applied Physics A")
    define("j-APPL-PHYS-A",			"Appl. Phys. A")

    define("j-APPL-PHYS-LET",			"Applied Physics Letters")
    define("j-APPL-PHYS-LET",			"Appl. Phys. Lett.")

    define("j-APPL-PHYS-EXPRESS",		"Applied Physics Express")
    define("j-APPL-PHYS-EXPRESS",		"Appl. Phys. Express")

    define("j-APPL-PSYCH-MEASUREMENT",		"Applied psychological measurement")

    define("j-APPL-SCI-RES",			"Applied Science Research")
    define("j-APPL-SCI-RES",			"Appl. Sci. Res.")
    define("j-APPL-SCI-RES",			"Appl. Sci. Research")

    define("j-APPL-SCI-RES-SECT-B",		"Applied Scientific Research, Section B")
    define("j-APPL-SCI-RES-SECT-B",		"Applied Scientific Research, Section B: Electrophysics, Acoustics, Optics, Mathematical Methods")
    define("j-APPL-SCI-RES-SECT-B",		"Appl. Sci. Res., Sect. B")

    define("j-APPL-STAT",			"Applied Statistics")
    define("j-APPL-STAT",			"Appl. Stat.")
    define("j-APPL-STAT",			"Appl. Statist.")
    define("j-APPL-STAT",			"J. Roy. Statist. Soc. Ser. C")
    define("j-APPL-STAT",			"J. Roy. Statist. Soc. Ser. C Appl. Statist.")
    define("j-APPL-STAT",			"J. Roy. Statist. Soc. Ser. C Appl. Statist.")
    define("j-APPL-STAT",			"Journal of the Royal Statistical Society. Series C (Applied Statistics)")
    define("j-APPL-STAT",			"J. R. Stat. Soc. Ser. C. Appl. Stat.")
    define("j-APPL-STAT",			"J. Roy. Statist. Soc. Ser. C")

    define("j-APPL-SURF-SCI",			"Applied Surface Science")
    define("j-APPL-SURF-SCI",			"Appl. Surf. Sci.")

    define("j-APPL-SURF-SCI-1977-1985",		"Applications of Surface Science (1977--1985)")
    define("j-APPL-SURF-SCI-1977-1985",		"Applications of Surface Science")
    define("j-APPL-SURF-SCI-1977-1985",		"Appl. Surf. Sci. (1977--1985)")

    define("j-APPROX-THEORY-APPL",		"Approximation Theory and its Applications")

    define("j-AQUAC-FISH-FISH",			"Aquaculture, Fish and Fisheries")
    define("j-AQUAC-FISH-FISH",			"Aquac. Fish Fish.")

    define("j-AQUAT-BOT",			"Aquatic Botany")
    define("j-AQUAT-BOT",			"Aquat. Bot.")

    define("j-AQUAT-TOXICOL",			"Aquatic toxicology (Amsterdam, Netherlands)")
    define("j-AQUAT-TOXICOL",			"Aquat. toxicol.")
    define("j-AQUAT-TOXICOL",			"Aquatic toxicology")
    define("j-AQUAT-TOXICOL",			"Aquatic toxicol.")

    define("j-ARCH-APPL-MECH",			"Archive of Applied Mechanics = Ingenieur-Archiv")
    define("j-ARCH-APPL-MECH",			"Archive of Applied Mechanics")
    define("j-ARCH-APPL-MECH",			"Arch. Appl. Mech. = Ing. Arch.")
    define("j-ARCH-APPL-MECH",			"Arch. Appl. Mech.")

    define("j-ARCH-BIOCHEM-BIOPHYS",		"Archives of biochemistry and biophysics")
    define("j-ARCH-BIOCHEM-BIOPHYS",		"Arch Biochem Biophys (6SK)")
    define("j-ARCH-BIOCHEM-BIOPHYS",		"Arch. Biochem. Biophys.")

    define("j-ARCH-ENTWICKLUNGSMECH",		"Archiv f{\\\"u}r Entwicklungsmechanik der Organismen")
    define("j-ARCH-ENTWICKLUNGSMECH",		"Arch. Entwickl. Mech. Org.")
    define("j-ARCH-ENTWICKLUNGSMECH",		"Arch. Entwicklungsmech")

    define("j-ARCH-HIST-EXACT-SCI",		"Archive for History of Exact Sciences")
    define("j-ARCH-HIST-EXACT-SCI",		"Arch. History Exact Sci.")
    define("j-ARCH-HIST-EXACT-SCI",		"Arch. Hist. Exact Sci.")

    define("j-ARCH-INEQUAL-APPL",		"Archives of Inequalities and Applications.")
    define("j-ARCH-INEQUAL-APPL",		"Archives of Inequalities and Applications.  An International Journal for Theory and Applications")
    define("j-ARCH-INEQUAL-APPL",		"Arch. Inequal. Appl.")

    define("j-ARCH-MATH",			"{Archiv der Mathematik}")
    define("j-ARCH-MATH",			"{Arch. Math. (Basel)}")
    define("j-ARCH-MATH",			"{Arch. Math.}")

    define("j-ARCH-MECH",			"Archives of mechanics = Archiwum mechaniki stosowanej")
    define("j-ARCH-MECH",			"Archives of mechanics")
    define("j-ARCH-MECH",			"Arch. mech.")

    define("j-ARCH-MED-RES",			"Archives of medical research")
    define("j-ARCH-MED-RES",			"Arch Med Res (BIC)")

    define("j-ARCH-MICROBIOL",			"Archives of microbiology")
    define("j-ARCH-MICROBIOL",			"Arch. Microbiol.")

    ## v1 1866--v30 1897; s2 v1 1898--s2 v15 1910
    ## Successor Title(s)
    ##     Archives Neerlandaises des Sciences Exactes et Naturelles, Serie 3A: Sciences Exactes
    ##     Archives Neerlandaises des Sciences Exactes et Naturelles, Serie 3B: Sciences Naturelles
    define("j-ARCH-NEERL-SCI-EXACTES-NAT",	"Archives N{\\'e}erlandaises des Sciences Exactes et Naturelles")
    define("j-ARCH-NEERL-SCI-EXACTES-NAT",	"Archives Neerlandaises des Sciences Exactes et Naturelles")
    define("j-ARCH-NEERL-SCI-EXACTES-NAT",	"Arch. Neerl. Sci. Exactes Nat.")

    define("j-ARCH-NEUROL",			"Archives of Neurology")
    define("j-ARCH-NEUROL",			"Arch. Neurol.")

    define("j-ARCH-NUM-SOFT",			"Archive of Numerical Software")
    define("j-ARCH-NUM-SOFT",			"Arch. Numer. Soft.")
    define("j-ARCH-NUM-SOFT",			"Arch. Numer. Softw.")
    define("j-ARCH-NUM-SOFT",			"Arch. Num. Soft.")
    define("j-ARCH-NUM-SOFT",			"Arch. Num. Softw.")

    define("j-ARCH-PHARM-WEINHEIM",		"{Archiv der Pharmazie (Weinheim, Germany)}")
    define("j-ARCH-PHARM-WEINHEIM",		"{Archiv der Pharmazie}")
    define("j-ARCH-PHARM-WEINHEIM",		"Arch. Pharm. Weinheim")
    define("j-ARCH-PHARM-WEINHEIM",		"Arch. Pharm.")

    define("j-ARCH-SCI-PHYS-NAT",		"Archives des Sciences Physiques et Naturelles")
    define("j-ARCH-SCI-PHYS-NAT",		"Arch. Sci. Phys. Nat.")

    define("j-ARCH-PHILOS",			"Archives de Philosophie")
    define("j-ARCH-PHILOS",			"Arch. Philos.")

    define("j-ARCH-RAT-MECH-ANAL",		"Archive for Rational Mechanics and Analysis")
    define("j-ARCH-RAT-MECH-ANAL",		"Arch. Rat. Mech. and Analysis")
    define("j-ARCH-RAT-MECH-ANAL",		"Arch. Rat. Mech. Anal.")
    define("j-ARCH-RAT-MECH-ANAL",		"Arch. Ration. Mech. Anal.")
    define("j-ARCH-RAT-MECH-ANAL",		"Arch. Rational Mech. Anal.")

    define("j-ARCHIMEDE",			"Archimede. Rivista per gli Insegnanti e i Cultori di Matematiche Pure e Applicate")
    define("j-ARCHIMEDE",			"Archimede")

    define("j-ARITH-TEACHER",			"Arithmetic Teacher")

    define("j-ARKHIMEDES",			"Arkhimedes")

    define("j-ARKIV-MAT-ASTRON-FYSIK",		"Arkiv f{\\\"o}r Matematik, Astronomi och Fysik")
    define("j-ARKIV-MAT-ASTRON-FYSIK",		"Arkiv f{\\\"o}r Matematik, Astronomi och Fysik, Utgivet av K. Svenska Vetenskapsakademien")
    define("j-ARKIV-MAT-ASTRON-FYSIK",		"Arkiv Mat. Astron. Fysik")

    define("j-ARKIV-MATH",			"Arkiv f{\\\"o}r Mathematik")
    define("j-ARKIV-MATH",			"Arkiv f{\\\"o}r Math.")

    define("j-ARKIV-MATH-NATUR",		"Arkiv for Mathematik og Naturvidenskab (Oslo)")

    define("j-ARKIV-FYSIK",			"Arkiv f{\\\"o}r fysik")
    define("j-ARKIV-FYSIK",			"Arkiv f{\\\"o}r fysik / utgivet av K. Svenska Vetenskapsakademien")
    define("j-ARKIV-FYSIK",			"Ark. Fys.")

    define("j-ARM-J-PHYS",			"Armenian Journal of Physics")
    define("j-ARM-J-PHYS",			"Arm. J. Phys.")

    define("j-ARMS",				"American Review of Mathematics and Statistics")
    define("j-ARMS-CONTROL-TODAY",		"Arms Control Today")

    define("j-ARS-COMB",			"Ars Combinatoria. The Canadian Journal of Combinatorics")
    define("j-ARS-COMB",			"Ars Combinatoria. A Canadian Journal of Combinatorics")
    define("j-ARS-COMB",			"Ars Combinatoria")
    define("j-ARS-COMB",			"Ars Combin.")
    define("j-ARS-COMB",			"Ars Comb.")

    define("j-ARSP-ARCH-RECHTS-SOZIALPHILOS",	"{ARSP: Archiv f{\\\"u}r Rechts- und Sozialphilosophie} / Archives for Philosophy of Law and Social Philosophy")
    define("j-ARSP-ARCH-RECHTS-SOZIALPHILOS",	"{ARSP: Archiv f{\\\"u}r Rechts- und Sozialphilosophie}")
    define("j-ARSP-ARCH-RECHTS-SOZIALPHILOS",	"{ARSP: Arch. Rechts-Sozialphilos.}")

    define("j-ART-BULL",			"Art Bulletin")

    define("j-ART-INTELL",			"Artificial Intelligence")
    define("j-ART-INTELL",			"Artif. Intell.")

    define("j-ART-LIFE-ROBOT",			"Artificial Life and Robotics")
    define("j-ART-LIFE-ROBOT",			"Art. Life Robot.")

    define("j-ARTIF-LIFE",			"Artificial Life")
    define("j-ARTIF-LIFE",			"Artif. Life")

    define("j-ARTISTS-MAG",			"Artist's magazine")
    define("j-ARTISTS-MAG",			"Artist's mag.")

    define("j-ASEAN-PROPRINT",			"Asean proprint: the graphic arts magazine")
    define("j-ASIAWEEK",			"Asiaweek")

    define("j-ASIA-PAC-MATH-NEWSL",		"Asia Pacific Mathematics Newsletter")
    define("j-ASIA-PAC-MATH-NEWSL",		"Asia Pac. Math. Newsl.")

    define("j-ASLIB-PROC",			"ASLIB Proceedings")
    define("j-ASPECTS-APPL-BIOL",		"Aspects of Applied Biology")

    define("j-ASTA-ADV-STAT-ANAL",		"Advances in Statistical Analysis")
    define("j-ASTA-ADV-STAT-ANAL",		"Advances in Statistical Analysis: AStA")
    define("j-ASTA-ADV-STAT-ANAL",		"AStA. Advances in Statistical Analysis")
    define("j-ASTA-ADV-STAT-ANAL",		"AStA. Adv. stat. anal.")

    define("j-ASTERISK",			"Asterisk: the journal of computer documentation")
    define("j-ASTERISK",			"Asterisk")

    define("j-ASTM-SPEC-TECH-PUB",		"ASTM special technical publication")

    define("j-ASTRO-NACHR",			"Astronomische Nachrichten")
    define("j-ASTRO-NACHR",			"Astron. Nachr.")

    define("j-ASTROBIOLOGY",			"Astrobiology")

    define("j-ASTRON-ASTROPHYS",		"Astronomy and Astrophysics")
    define("j-ASTRON-ASTROPHYS",		"Astronomy \\& Astrophysics")
    define("j-ASTRON-ASTROPHYS",		"Astronomy {\\&} Astrophysics")
    define("j-ASTRON-ASTROPHYS",		"Astron. Astrophys.")

    define("j-ASTRON-ASTROPHYS-REV",		"Astronomy and Astrophysics Review")
    define("j-ASTRON-ASTROPHYS-REV",		"The Astronomy and Astrophysics Review")
    define("j-ASTRON-ASTROPHYS-REV",		"Astron. astrophys. rev.")

    define("j-ASTRON-ASTROPHYS-SUPPL-SER",	"Astronomy and Astrophysics; Supplement Series")
    define("j-ASTRON-ASTROPHYS-SUPPL-SER",	"Astron. astrophys. Suppl. ser.")

    define("j-ASTRON-ASTROPHYS-TRANS",		"Astronomical and Astrophysical Transactions")
    define("j-ASTRON-ASTROPHYS-TRANS",		"Astron. Astrophys. Trans.")

    define("j-ASTRON-GEOPHYS",			"Astronomy and Geophysics")
    define("j-ASTRON-GEOPHYS",			"Astronomy \\& Geophysics")
    define("j-ASTRON-GEOPHYS",			"Astron. Geophys.")

    define("j-ASTRON-J",			"Astronomical Journal")
    define("j-ASTRON-J",			"Astron. J.")

    define("j-ASTRON-Q",			"Astronomy Quarterly")
    define("j-ASTRON-Q",			"Astron. Q.")

    define("j-ASTROPART-PHYS",			"Astroparticle Physics")
    define("j-ASTROPART-PHYS",			"Astropart. Phys.")

    define("j-ASTROPHYS-LETT",			"Astrophysical Letters")
    define("j-ASTROPHYS-LETT",			"Astrophys. Lett.")

    define("j-ASTROPHYS-SPACE-SCI",		"Astrophysics and Space Science")
    define("j-ASTROPHYS-SPACE-SCI",		"Astrophys. Space Sci.")

    define("j-ASTROPHYSICAL-J",			"The Astrophysical Journal")
    define("j-ASTROPHYSICAL-J",			"Astrophysical Journal")
    define("j-ASTROPHYSICAL-J",			"Ap. J.")
    define("j-ASTROPHYSICAL-J",			"Astrophys. J.")

    define("j-ASTROPHYSICAL-J-SUPPL-SER",	"Astrophysical Journal. Supplement Series")
    define("j-ASTROPHYSICAL-J-SUPPL-SER",	"Astrophysical Journal Supplement Series")
    define("j-ASTROPHYSICAL-J-SUPPL-SER",	"Astrophysical Journal Supplement")
    define("j-ASTROPHYSICAL-J-SUPPL-SER",	"Astrophys. J., Suppl. Series")
    define("j-ASTROPHYSICAL-J-SUPPL-SER",	"Astrophys. J. Supp.")
    define("j-ASTROPHYSICAL-J-SUPPL-SER",	"Astrophys. J. Suppl.")
    define("j-ASTROPHYSICAL-J-SUPPL-SER",	"Astrophys. J., Suppl. Ser.")

    define("j-ASYMP-STAT",			"Asymptotic Statistics")

    define("j-ASYMPTOT-ANAL",			"Asymptotic analysis")
    define("j-ASYMPTOT-ANAL",			"Asymptot. anal.")
    define("j-ASYMPTOT-ANAL",			"Asymptotic Anal.")

    define("j-AT-DATA-NUCL-DATA-TABLES",	"Atomic Data and Nuclear Data Tables")
    define("j-AT-DATA-NUCL-DATA-TABLES",	"At. Data Nucl. Data Tables")

    define("j-ATLANTIC-MONTHLY",		"Atlantic Monthly")
    define("j-ATLANTIC-MONTHLY",		"The Atlantic Monthly")

    define("j-ATMOS-ENV",			"Atmospheric Environment")

    define("j-ATMOS-SCI-LETT",			"Atmospheric Science Letters")
    define("j-ATMOS-SCI-LETT",			"Atmos. Sci. Lett.")

    define("j-ATOMS",				"Atoms")

    define("j-ATT-BELL-LABORATORIES-RECORD",	"The AT\\&T Bell Laboratories Record")

    define("j-ATT-BELL-LAB-TECH-J",		"AT\\&T Bell Laboratories Technical Journal")
    define("j-ATT-BELL-LAB-TECH-J",		"AT\\&T Bell Lab. tech. j")

    define("j-ATT-TECH-J",			"AT\\&T Technical Journal")

    define("j-ATTEN-PERCEPT-PSYCHOPHYS",	"Attention, Perception, \\& Psychophysics")
    define("j-ATTEN-PERCEPT-PSYCHOPHYS",	"Attention, Perception, and Psychophysics")
    define("j-ATTEN-PERCEPT-PSYCHOPHYS",	"Atten. Percept. Psychophys.")

    define("j-AUDIO-VISUAL",			"Audio Visual")

    define("j-AUDITING",			"Auditing: A Journal of Practice \\& Theory")
    define("j-AUDITING",			"Auditing")

    define("j-AUST-J-AGRIC-RES",		"Australian Journal of Agricultural Research")
    define("j-AUST-J-AGRIC-RES",		"Aust. J. Agric. Res.")

    define("j-AUST-J-MATH-ANAL-APPL",		"Australian Journal of Mathematical Analysis and Applications")
    define("j-AUST-J-MATH-ANAL-APPL",		"The Australian Journal of Mathematical Analysis and Applications")
    define("j-AUST-J-MATH-ANAL-APPL",		"Aust. J. Math. Anal. Appl.")

    define("j-AUST-J-STAT",			"Australian Journal of Statistics")
    define("j-AUST-J-STAT",			"Austral. J. Statist.")
    define("j-AUST-J-STAT",			"Aust. J. Stat.")

    define("j-AUSTRALIAN-COMP-J",		"Australian Computer Journal")
    define("j-AUSTRALIAN-COMP-SCI-COMM",	"Australian Computer Science Communications")

    define("j-AUSTRALIAN-J-PHYS",		"Australian Journal of Physics")
    define("j-AUSTRALIAN-J-PHYS",		"Aust. J. Phys")

    define("j-AUSTRALIAN-J-STAT",		"Australian journal of statistics")
    define("j-AUSTRALIAN-J-STAT",		"Aust. j. stat.")
    define("j-AUSTRALIAN-J-STAT",		"Austral. J. Statist.")

    define("j-AUSTRALIAN-LIBR-REV",		"Australian Library Review")

    define("j-AUSTRALIAN-MATH-SOC-GAZ",		"Australian Mathematical Society Gazette")
    define("j-AUSTRALIAN-MATH-SOC-GAZ",		"Australian Mathematical Gazette")
    define("j-AUSTRALIAN-MATH-SOC-GAZ",		"Austral. Math. Soc. Gaz.")

    define("j-AUSTRALIAN-MATH-TEACHER",		"The {Australian} Mathematics Teacher")
    define("j-AUSTRALIAN-MATH-TEACHER",		"{Australian} Mathematics Teacher")
    define("j-AUSTRALIAN-MATH-TEACHER",		"{Australian} Math. Teach.")
    define("j-AUSTRALIAN-MATH-TEACHER",		"{Australian} Math. Teacher")

    define("j-AUSTRALIAN-PERSONAL-COMP",	"Australian Personal Computer")
    define("j-AUTO-CTL-COMP-SCI",		"Automatic Control and Computer Sciences")

    define("j-AUTOM-REMOTE-CONTROL",		"Automation and Remote Control")
    define("j-AUTOM-REMOTE-CONTROL",		"Autom. Remote Control")

    # Automatic and Remote Control published only from 1960 to 1963
    # also under names Regelung und Fernsteuerung and Automatisme et telecommande
    define("j-AUTOMATIC-REMOTE-CTL",		"Automatic and Remote Control")
    define("j-AUTOMATIC-REMOTE-CTL",		"Automat. Remote Control")

    # Automation and Remote Control (1956--date) is a translation of Avtomatika i telemekhanika (Moscow, Russia)
    define("j-AUTOMATION-REMOTE-CTL",		"Automation and Remote Control")
    define("j-AUTOMATION-REMOTE-CTL",		"Autom. Remote Control")

    define("j-AUTOMATICA",			"Automatica: the journal of IFAC, the International Federation of Automatic Control")
    define("j-AUTOMOTIVE-ENG",			"Automotive Engineering")
    define("j-AV-VIDEO",			"AV video")

    define("j-AVIAT-WEEK-SPACE-TECHNOL",	"Aviation week \\& space technology")
    define("j-AVIAT-WEEK-SPACE-TECHNOL",	"Aviation Week and Space Technology (New York)")
    define("j-AVIAT-WEEK-SPACE-TECHNOL",	"Aviat. week space technol.")

    define("j-AXIOMS-BASEL",			"Axioms (Basel)")
    define("j-AXIOMS-BASEL",			"Axioms")

    define("j-AXIS",				"Axis: the UCISA journal of academic computing and information systems")
    define("j-AXIS",				"Axis")

    define("j-BANK-SYST-TECHNOL",		"Bank Systems + Technology")
    define("j-BANK-SYST-TECHNOL",		"Bank syst. + technol.")

    define("j-BANKING-TECH",                    "Banking Technology")

    define("j-BASIC-LIFE-SCI",			"Basic Life Sciences")
    define("j-BASIC-LIFE-SCI",			"Basic Life Sci")
    define("j-BASIC-LIFE-SCI",			"Basic Life Sci (9K0)")

    define("j-BASIC-RES-CARDIOL",		"Basic Research in Cardiology")
    define("j-BASIC-RES-CARDIOL",		"Basic res. cardiol.")

    define("j-BAYESIAN-ANAL",			"Bayesian Analysis")
    define("j-BAYESIAN-ANAL",			"Bayesian Anal.")

    define("j-BEHAV-BRAIN-SCI",			"Behavioral and Brain Sciences")
    define("j-BEHAV-BRAIN-SCI",			"Behav. brain sci.")

    define("j-BEHAV-INF-TECH",			"Behaviour \\& Information Technology")
    define("j-BEHAV-INF-TECH",			"Behav. Inf. Technol")

    ## Behavior Research Methods has three different names, but Springer treats
    ## their archives together at http://www.springerlink.com/content/1554-351x/
    ## Vol. 37, no. 1 (Feb. 2005)-Ceased with: vol. 41, no. 4 (Nov. 2009)
    define("j-BEHAV-RES-METH",			"Behavior Research Methods")
    define("j-BEHAV-RES-METH",			"Behav. Res. Methods")

    ## Vol. 1, no. 1 (Sept. 1968)--v. 15, no. 6 (Dec. 1983).
    define("j-BEHAV-RES-METH-INSTR",		"Behavior Research Methods and Instrumentation")
    define("j-BEHAV-RES-METH-INSTR",		"Behav. res. meth. instr.")
    define("j-BEHAV-RES-METH-INSTR",		"Behav. res. meth. instrum")

    ## Vol. 16, no. 1 (Feb. 1984)-v. 36, no. 4 (Nov. 2004).
    define("j-BEHAV-RES-METH-INSTR-COMP",	"Behavior Research Methods, Instruments, and Computers")
    define("j-BEHAV-RES-METH-INSTR-COMP",	"Behavior Research Methods, Instruments, \\& Computers")
    define("j-BEHAV-RES-METH-INSTR-COMP",	"Behavior research methods, instruments, and computers: a journal of the Psychonomic Society, Inc")
    ## define("j-BEHAV-RES-METH-INSTR-COMP",	"Behavior Research Methods")

    define("j-BEHAV-SCI",			"Behavioral Science")
    define("j-BEHAV-SCI",			"Behav. Sci.")

    define("j-BEHAVIOUR",			"Behaviour")

    ## v1 1877--v43 1919
    define("j-BEIBL-ANN-PHYS",			"{Beibl{\\\"a}tter zu den Annalen der Physik}")
    define("j-BEIBL-ANN-PHYS",			"{Beibl{\\\"a}tter zu den Annalen der Physik und Chemie XII}")
    define("j-BEIBL-ANN-PHYS",			"Beibl. Ann. Phys.")

    define("j-BEITRAGE-NUMER-MATH",		"Beitr{\\\"a}ge zur Numerischen Mathematik")
    define("j-BEITRAGE-NUMER-MATH",		"Beitrage zur Numerischen Mathematik")
    define("j-BEITRAGE-NUMER-MATH",		"Beitr. Numer. Math.")
    define("j-BEITRAGE-NUMER-MATH",		"Beitr{\\\"a}ge Numer. Math.")

    define("j-BELL-LABS-RECORD",		"Bell Laboratories Record")
    define("j-BELL-LABS-RECORD",		"Bell Labs. Record")

    define("j-BELL-LABS-TECH-J",		"Bell Labs Technical Journal")
    define("j-BELL-LABS-TECH-J",		"Bell Labs Technical J.")
    define("j-BELL-LABS-TECH-J",		"Bell Labs Tech. J.")

    define("j-BELL-SYST-TECH-J",		"The Bell System Technical Journal")
    define("j-BELL-SYST-TECH-J",		"Bell System Technical Journal")
    define("j-BELL-SYST-TECH-J",		"Bell Systems Technical Journal")
    define("j-BELL-SYST-TECH-J",		"Bell Syst. Tech. J")
    define("j-BELL-SYST-TECH-J",		"Bell Sys. Tech. J")
    define("j-BELL-SYST-TECH-J",		"BSTJ")
    define("j-BELL-SYST-TECH-J",		"Bell System Technical J.")
    define("j-BELL-SYST-TECH-J",		"Bell System Tech. J.")

    define("j-BELLCORE-EXCHANGE",		"Bellcore Exchange")

    define("j-BER-BUNSENGES-PHYS-CHEM",		"Berichte der Bunsen-Gesellschaft fuer Physikalische Chemie, 1963--1990")
    define("j-BER-BUNSENGES-PHYS-CHEM",		"Berichte der Bunsengesellschaft f{\\\"u}r physikalische Chemie, 1963--1990")
    define("j-BER-BUNSENGES-PHYS-CHEM",		"Berichte der Bunsengesellschaft f{\\\"u}r physikalische Chemie")
    define("j-BER-BUNSENGES-PHYS-CHEM",		"Berichte der Bunsen-Gesellschaft f{\\\"u}r Physikalische Chemie")
    define("j-BER-BUNSENGES-PHYS-CHEM",		"Berichte der Bunsengesellschaft f{\\\"u}r Physikalische Chemie")
    define("j-BER-BUNSENGES-PHYS-CHEM",		"Ber. Bunsenges. Phys. Chem.")

    ## v1 1868--v51 1918
    define("j-BER-DTSCH-CHEM-GES",		"{Berichte der deutschen chemischen Gesellschaft}")
    define("j-BER-DTSCH-CHEM-GES",		"{Berichte der deutschen chemischen Gesellschaft zu Berlin}")
    define("j-BER-DTSCH-CHEM-GES",		"{Ber. Dtsch. Chem. Ges.}")

    define("j-BER-DTSCH-CHEM-GES-ABT-A",	"{Berichte der deutschen chemischen Gesellschaft (Abteilung A: Vereins-Nachrichten)}")
    define("j-BER-DTSCH-CHEM-GES-ABT-A",	"{Berichte der deutschen chemischen Gesellschaft (Abteilung A)}")
    define("j-BER-DTSCH-CHEM-GES-ABT-A",	"{Berichte der deutschen chemischen Gesellschaft (A)}")
    define("j-BER-DTSCH-CHEM-GES-ABT-A",	"{Ber. Dtsch. Chem. Ges. Abt. A}")
    define("j-BER-DTSCH-CHEM-GES-ABT-A",	"{Ber. Dtsch. Chem. Ges. A}")

    ## v80 1946--date
    define("j-BER-DTSCH-CHEM-GES-ABT-A-B",	"{Berichte der deutschen chemischen Gesellschaft (Abteilung A und B)}")
    define("j-BER-DTSCH-CHEM-GES-ABT-A-B",	"{Berichte der deutschen chemischen Gesellschaft (A and B Series)}")
    define("j-BER-DTSCH-CHEM-GES-ABT-A-B",	"{Ber. Dtsch. Chem. Ges. Abt. A B}")
    define("j-BER-DTSCH-CHEM-GES-ABT-A-B",	"{Ber. Dtsch. Chem. Ges. A B}")

    define("j-BER-WISSENSCHAFTGESCH",		"{Berichte zur Wissenschaftsgeschichte}")
    define("j-BER-WISSENSCHAFTGESCH",		"{Ber. Wissenschaftsgesch.}")

    define("j-BERICHTE-GMD-BONN",		"Berichte der Gesellschaft f{\\\"u}r Mathematik und Datenverarbeitung")
    define("j-BERICHTE-GMD-BONN",		"Berichte Der GMD Bonn")

    define("j-BERNOULLI",			"Bernoulli: official journal of the Bernoulli Society for Mathematical Statistics and Probability")
    define("j-BERNOULLI",			"Bernoulli")

    define("j-BESTS-REV-LIFE-HEALTH-INSUR-ED",	"Best's review (Life/health insurance ed.)")
    define("j-BESTS-REV-LIFE-HEALTH-INSUR-ED",	"Best's review --- life/health insurance edition")
    define("j-BESTS-REV-LIFE-HEALTH-INSUR-ED",	"Best's rev. (Life-health insur. ed.)")

    define("j-BIO-CHEM-HOPPE-SEYLER",		"Biological chemistry Hoppe-Seyler")
    define("j-BIO-CHEM-HOPPE-SEYLER",		"Biol Chem Hoppe Seyler (AHC)")

    define("j-BIOCHEM",				"Biochemistry")
    define("j-BIOCHEM",				"Biochem.")
    define("j-BIOCHEM",				"Biochemistry (Easton)")
    define("j-BIOCHEM",				"Biochemistry (American Chemical Society)")
    define("j-BIOCHEM",				"Biochemistry (Am. Chem. Soc.)")
    define("j-BIOCHEM",				"Biochemistry (A0G)")

    define("j-BIOCHEM-BIOKHIM",			"Biochemistry = Biokhimiya")

    define("j-BIOCHEM-BIOPHYS-RES-COMMUN",	"Biochemical and Biophysical Research Communications")
    define("j-BIOCHEM-BIOPHYS-RES-COMMUN",	"Biochem Biophys Res Commun (9Y8)")
    define("j-BIOCHEM-BIOPHYS-RES-COMMUN",	"Biochem. Biophys. Res. Com.")
    define("j-BIOCHEM-BIOPHYS-RES-COMMUN",	"Biochem. Biophys. Res. Commun.")
    define("j-BIOCHEM-BIOPHYS-RES-COMMUN",	"Biochem. \\& Biophy. Res. Communic.")
    define("j-BIOCHEM-BIOPHYS-RES-COMMUN",	"Biochem. biophys. res. commun.")

    define("j-BIOCHEM-CELL-BIOL",		"Biochemistry and cell biology = Biochimie et biologie cellulaire")
    define("j-BIOCHEM-CELL-BIOL",		"Biochem Cell Biol (ALR)")
    define("j-BIOCHEM-CELL-BIOL",		"Biochem. Cell Biol.")

    define("j-BIOCHEM-INT",			"Biochemistry International")
    define("j-BIOCHEM-INT",			"Biochem Int (9Y9)")

    define("j-BIOCHEM-J",			"The Biochemical journal")
    define("j-BIOCHEM-J",			"Biochem J (9YO)")
    define("j-BIOCHEM-J",			"Biochem. J.")

    define("j-BIOCHEM-MOL-BIOL-INT",		"Biochemistry and Molecular Biology International")
    define("j-BIOCHEM-MOL-BIOL-INT",		"Biochem Mol Biol Int (BOD)")

    define("j-BIOCHEM-PHARM",			"Biochemical pharmacology")
    define("j-BIOCHEM-PHARM",			"Biochem Pharmacol (9Z4)")

    define("j-BIOCHEM-SOC-SYMP",		"Biochemical Society Symposia")
    define("j-BIOCHEM-SOC-SYMP",		"Biochem Soc Symp (9ZK)")
    define("j-BIOCHEM-SOC-SYMP",		"Biochem. Soc. Symp.")

    define("j-BIOCHEM-SOC-TRANS",		"Biochem Soc Trans (E48)")
    define("j-BIOCHEM-SYS-ECO",			"Biochemical systematics and ecology")

    define("j-BIOCHEM-SER-MONOGR",		"Biochemistry, a Series of Monographs")
    define("j-BIOCHEM-SER-MONOGR",		"Biochem. Ser. Monogr")

    define("j-BIOCHEM-Z",			"Biochemische Zeitschrift")
    define("j-BIOCHEM-Z",			"Biochem. Z.")

    define("j-BIOCHIM-BIOPHYS-ACTA",		"Biochimica et Biophysica Acta")
    define("j-BIOCHIM-BIOPHYS-ACTA",		"Biochim Biophys Acta (A0W)")
    define("j-BIOCHIM-BIOPHYS-ACTA",		"Biochim. Biophys. Acta")
    define("j-BIOCHIM-BIOPHYS-ACTA",		"Biochem. Biophys. Acta")

    define("j-BIOCHIM-BIOPHYS-ACTA-GENE-STRUCT-EXPRESS","Biochimica et biophysica acta. Gene structure and expression")
    define("j-BIOCHIM-BIOPHYS-ACTA-GENE-STRUCT-EXPRESS","Biochim. Biophys. Acta, Gene Struct. Expression")

    define("j-BIOCHIM-BIOPHYS-ACTA-HUNG",	"Acta biochimica et biophysica Hungarica")
    define("j-BIOCHIM-BIOPHYS-ACTA-HUNG",	"Acta biochimica et biophysica Hungarica: a quarterly of the Hungarian Academy of sciences")
    define("j-BIOCHIM-BIOPHYS-ACTA-HUNG",	"Acta biochim. biophys. acta hung.")

    define("j-BIOCHIM-BIOPHYS-ACTA-MOL-CELL-RES","Biochimica et biophysica acta. Molecular cell research")
    define("j-BIOCHIM-BIOPHYS-ACTA-MOL-CELL-RES","Biochim. Biophys. Acta, Mol. Cell Res.")

    ## define("j-BIOCHIMICA-BIOPHYSICA-ACTA",	"Biochimica et Biophysica Acta")

    define("j-BIOCHIMIE",			"Biochimie")
    define("j-BIOCHIMIE",			"Biochimie (A14)")

    define("j-BIOELECTROCHEM-BIOENERG",		"Bioelectrochemistry and bioenergetics")
    define("j-BIOELECTROCHEM-BIOENERG",		"Bioelectrochem. Bioenerg.")

    define("j-BIOENERGETICS",			"Biochimica et biophysica acta. Bioenergetics")
    define("j-BIOENERGETICS",			"Bioenergetics")

    define("j-BIOESSAYS",			"BioEssays")
    define("j-BIOESSAYS",			"Bioessays (9YY)")
    define("j-BIOESSAYS",			"Bio Essays")
    define("j-BIOESSAYS",			"Bioessays")

    define("j-BIOFIZIKA",			"Biofizika")

    define("j-BIOGR-MEM-NAT-ACAD-SCI",		"Biographical memoirs --- National Academy of Sciences of the United States of America")
    define("j-BIOGR-MEM-NAT-ACAD-SCI",		"Biographical Memoirs of the {National Academy of Sciences}")
    define("j-BIOGR-MEM-NAT-ACAD-SCI",		"Biographical memoirs of the National Academy of Sciences of the United States of America")
    define("j-BIOGR-MEM-NAT-ACAD-SCI",		"Biographical memoirs of the National Academy of Sciences")
    define("j-BIOGR-MEM-NAT-ACAD-SCI",		"Biogr. Mem. Nat. Acad. Sci.")

    define("j-BIOGRAPH-MEMOIRS-FELLOWS-ROY-SOC","Biographical Memoirs of Fellows of the Royal Society")
    define("j-BIOGRAPH-MEMOIRS-FELLOWS-ROY-SOC","Biogr. Mem. Fell. R. Soc.")
    define("j-BIOGRAPH-MEMOIRS-FELLOWS-ROY-SOC","Biogr. Mem. Fell. R. Soc. Lond.")

    define("j-BIOGRAPHY-HONOLULU",		"Biography (Honolulu)")
    define("j-BIOGRAPHY-HONOLULU",		"Biography --- An Interdisciplinary Quarterly")

    define("j-BIOINFORMATICS",			"Bioinformatics")

    define("j-BIOL-BULL",			"Biological Bulletin")
    define("j-BIOL-BULL",			"Biol. Bull.")
    define("j-BIOL-BULL",			"Biol. Bull. (Lancaster)")

    define("j-BIOL-CYBERN",			"Biological cybernetics")
    define("j-BIOL-CYBERN",			"Biol. Cybernetics")
    define("j-BIOL-CYBERN",			"Biological cybernetics")

    define("j-BIOL-J-LINNEAN-SOC",		"Biological Journal of the Linnean Society")
    define("j-BIOL-J-LINNEAN-SOC",		"Biol. J. Linnean Soc.")

    define("j-BIOL-REPROD",                     "Biology of reproduction")
    define("j-BIOL-REPROD",                     "Biol Reprod.")

    define("j-BIOL-REV-CAMB-PHIL-SOC",		"Biological Reviews of the Cambridge Philosophical Society")
    define("j-BIOL-REV-CAMB-PHIL-SOC",		"Biol. Rev. Camb. Phil. Soc.")

    define("j-BIOMED-BIOCHIM-ACTA",		"Biomedica Biochimica Acta")
    define("j-BIOMED-BIOCHIM-ACTA",		"Biomed Biochim Acta (9YX)")
    define("j-BIOMED-BIOCHIM-ACTA",		"Biomed. Biochim. Acta")

    define("j-BIOMEMBRANES",			"Biomembranes (New York, NY)")
    define("j-BIOMEMBRANES",			"Biomembranes")

    define("j-BIOMETRIC-BULL",			"Biometric Bulletin")

    define("j-BIOMETRICAL-J",			"Biometrical Journal")
    define("j-BIOMETRICAL-J",			"Biometrical J.")

    define("j-BIOMETRICS",			"Biometrics")

    define("j-BIOMETRIKA",			"Biometrika")
    define("j-BIOMETRISCHE-Z",			"Biometrische Zeitschrift")
    define("j-BIOPHYS",				"Biophysics")

    define("j-BIOPHYS-CHEM",			"Biophysical Chemistry")
    define("j-BIOPHYS-CHEM",			"Biophys Chem (A5T)")

    define("j-BIOPHYS-J",			"Biophysical Journal")
    define("j-BIOPHYS-J",			"Biophys J (A5S)")
    define("j-BIOPHYS-J",			"Biophys. J.")
    define("j-BIOPHYS-J",			"Biophys. Jour.")

    define("j-BIOPHYS-STRUCT-MECH",		"Biophysics of structure and mechanism")
    define("j-BIOPHYS-STRUCT-MECH",		"Biophys. Struct. Mech.")

    define("j-BIOPOLYMERS-SYMPOSIA",		"Biopolymers Symposia")

    define("j-BIORHEOLOGY",			"Biorheology")
    define("j-BIORHEOLOGY",			"Biorheology (A65)")

    define("j-BIOSCI",				"BioScience")

    define("j-BIOSCI-REP",			"Bioscience Reports")
    define("j-BIOSCI-REP",			"Biosci Rep (A6D)")

    define("j-BIOSYSTEMS",			"Biosystems (A6E)")
    define("j-BIOSYSTEMS",			"Biosystems")

    define("j-BIOTECH",				"Bio/technology")
    define("j-BIOTECH",				"Biotechnology (N Y) (AL1)")

    define("j-BIT",				"BIT (Nordisk tidskrift for informationsbehandling)")
    define("j-BIT",				"BIT")
    define("j-BIT",				"Nordisk Tidskr. Informationsbehandling (BIT)")

    define("j-BLOOD",				"Blood")

    define("j-BLOOD-CELLS",			"Blood Cells")
    define("j-BLOOD-CELLS",			"Blood Cells (A8H)")

    define("j-BLOOD-REV",			"Blood Reviews")
    define("j-BLOOD-REV",			"Blood rev.")

    define("j-BLUT",				"Blut")

    define("j-BMC-BIOINFORMATICS",		"BMC Bioinformatics")
    define("j-BMC-BIOINFORMATICS",		"BioMed Central Bioinformatics")

    define("j-BOL-MAT-SAO-PAULO",		"Boletim da Sociedade de Matem{\\'a}tica de Sa{\\~o} Paulo")
    define("j-BOL-MAT-SAO-PAULO",		"Boletim. Sociedade de Matem{\\'a}tica de Sa{\\~o} Paulo")
    define("j-BOL-MAT-SAO-PAULO",		"Boletim. Sociedade de Matem{\\'a}tica de Sao Paulo")
    define("j-BOL-MAT-SAO-PAULO",		"Bol. Soc. Matem. Sa{\\~o} Paulo")

    define("j-BOL-SOC-PORT-MAT",		"Boletim da Sociedade Portuguesa de Matem{\\'a}tica")
    define("j-BOL-SOC-PORT-MAT",		"Bol. Soc. Port. Mat.")

    define("j-BOLL-STOR-SCI-MAT",		"Bollettino di Storia delle Scienze Matematiche")
    define("j-BOLL-STOR-SCI-MAT",		"Boll. Storia Sci. Mat.")
    define("j-BOLL-STOR-SCI-MAT",		"Boll. Stor. Sci. Mat.")

    define("j-BOLL-UNIONE-MAT-ITAL",		"Bollettino della Unione matematica italiana")
    define("j-BOLL-UNIONE-MAT-ITAL",		"Boll. Unione mat. ital.")
    define("j-BOLL-UNIONE-MAT-ITAL",		"Bollettino U.M.I.")

    define("j-BOLL-UNIONE-MAT-ITAL-A",		"Bollettino della Unione matematica italiana. A.")
    define("j-BOLL-UNIONE-MAT-ITAL-A",		"Bollettino della Unione Matematica Italiana. Sezione A. La Matematica nella Societ\\`a e nella Cultura. Serie VIII")
    define("j-BOLL-UNIONE-MAT-ITAL-A",		"Boll. Unione Mat. Ital. Sez. A Mat. Soc. Cult. (8)")
    define("j-BOLL-UNIONE-MAT-ITAL-A",		"Boll. Unione mat. ital. A.")
    define("j-BOLL-UNIONE-MAT-ITAL-A",		"Bollettino U.M.I. A.")

    define("j-BONE-MINERAL",			"Bone and mineral")
    define("j-BOSTON-GLOBE",			"Boston Globe")
    define("j-BOSTON-PHOENIX",			"Boston Phoenix")

    define("j-BOUND-VALUE-PROBL",		"Boundary Value Problems")
    define("j-BOUND-VALUE-PROBL",		"Bound. Value Probl.")

    define("j-BOUNDARY-LAYER-METEOROL",		"Boundary-Layer Meteorology")
    define("j-BOUNDARY-LAYER-METEOROL",		"Boundary Layer Meteorol.")
    define("j-BOUNDARY-LAYER-METEOROL",		"Boundary-Layer Meteorol.")

    ## NB: Title varies: Some issues as Report of the Meeting, Report of the Annual Meeting, etc
    ## History: v1/2 1831--1916; 1919--v108 1938 (No meetings held 1917--1918)
    define("j-BR-ASSOC-ADV-SCI-REP",		"British Association for the Advancement of Science, Report")
    define("j-BR-ASSOC-ADV-SCI-REP",		"British Assoc. Advanc. Sci.")
    define("j-BR-ASSOC-ADV-SCI-REP",		"British Assoc. for Adv. of Sci. Report")
    define("j-BR-ASSOC-ADV-SCI-REP",		"Br. Assoc. Adv. Sci., Rep.")

    define("j-BR-J-APPL-PHYS",			"British Journal of Applied Physics")
    define("j-BR-J-APPL-PHYS",			"Brit. J. Appl. Phys.")
    define("j-BR-J-APPL-PHYS",			"Br. J. Appl. Phys.")

    define("j-BR-J-HAEMATOL",			"British Journal of Haematology")
    define("j-BR-J-HAEMATOL",			"Br. j. haematol.")
    define("j-BR-J-HAEMATOL",			"Brit. J. Haematol.")

    define("j-BR-J-NEUROSURG",			"British Journal of Neurosurgery")
    define("j-BR-J-NEUROSURG",			"Br. j. neurosurg.")

    define("j-BR-J-PHOTOGR",			"British Journal of Photography")
    define("j-BR-J-PHOTOGR",			"Br. J. Photogr.")

    define("j-BR-MED-J",			"British Medical Journal")
    define("j-BR-MED-J",			"Br. med. j.")
    define("j-BR-MED-J",			"Brit. Med. J.")

    define("j-BRAIN-COGN",			"Brain and Cognition")
    define("j-BRAIN-COGN",			"Brain Cogn.")

    define("j-BRAIN-RES",                       "Brain Research")
    define("j-BRAIN-RES",                       "Brain Res.")

    define("j-BRAIN-RES-REV",                   "Brain Research Reviews")
    define("j-BRAIN-RES-REV",                   "Brain Res. Rev.")

    define("j-BRAZ-J-PHYS",			"Brazilian Journal of Physics")
    define("j-BRAZ-J-PHYS",			"Braz. J. Phys.")

    define("j-BRAZILIAN-J-MED-BIOL-RES",	"Brazilian journal of medical and biological research = Revista brasileira de pesquisas medicas e biologicas")
    define("j-BRAZILIAN-J-MED-BIOL-RES",	"Braz J Med Biol Res (BOF)")

    define("j-BRITISH-DENTAL-J",		"British dental journal")

    define("j-BRITISH-HEART-J",			"British heart journal")
    define("j-BRITISH-HEART-J",			"Br. heart j.")
    define("j-BRITISH-HEART-J",			"Brit. heart j.")

    define("j-BRITISH-J-CANCER",		"British Journal of Cancer")
    define("j-BRITISH-J-CANCER",		"British J. Cancer")
    define("j-BRITISH-J-CANCER",		"Br. J. Cancer")

    define("j-BRITISH-J-HIST-MATH",		"British Journal for the History of Mathematics")
    define("j-BRITISH-J-HIST-MATH",		"Br. J. Hist. Math.")

    define("j-BRITISH-J-HIST-SCI",		"British Journal for the History of Science")
    define("j-BRITISH-J-HIST-SCI",		"British Society for the History of Science.  British Journal for the History of Science")
    define("j-BRITISH-J-HIST-SCI",		"British J. Hist. Sci.")
    define("j-BRITISH-J-HIST-SCI",		"Br. J. Hist. Sci.")

    define("j-BRITISH-J-MATH-STATIST-PSYCHOL",	"British Journal of Mathematical and Statistical Psychology")
    define("j-BRITISH-J-MATH-STATIST-PSYCHOL",	"British J. Math. Statist. Psychol.")

    define("j-BRITISH-J-PHILOS-SCI",		"British Journal for the Philosophy of Science")
    define("j-BRITISH-J-PHILOS-SCI",		"Br J Philos Sci")
    define("j-BRITISH-J-PHILOS-SCI",		"Br. J. Philos. Sci.")
    define("j-BRITISH-J-PHILOS-SCI",		"Brit. J. Philos. Sci.")
    define("j-BRITISH-J-PHILOS-SCI",		"Br. J. Phil. Sci.")

    define("j-BRITISH-LIBRARY-RDR",		"The British Library research and development reports")

    define("j-BRITISH-PRINTER",			"The British Printer: a journal for the printing trades")
    define("j-BRITISH-PRINTER",			"British Printer")
    define("j-BRITISH-PRINTER",			"Br. print.")

    define("j-BROADCAST-CABLE",			"Broadcasting \\& cable")
    define("j-BROADCAST-CABLE",			"Broadcast. cable")

    define("j-BSHM-BULL",			"BSHM Bulletin: Journal of the British Society for the History of Mathematics")
    define("j-BSHM-BULL",			"BSHM Bulletin")
    define("j-BSHM-BULL",			"BSHM Bull.")

    define("j-BSHM-NEWSLETTER",			"BSHM Newsletter")
    define("j-BSHM-NEWSLETTER",			"British Society for the History of Mathematics Newsletter")

    define("j-BT-TECH-J",			"BT Technology Journal")
    define("j-BT-TECH-J",			"BT technology")

    # v1 1953--v5 1957 (no online archive appears to be available)
    define("j-BUL-ACAD-STIINTE-REPUB-MOD-MAT",	"Buletinul Academiei de {\\c{S}}tiin{\\c{t}}e a Republicii Moldova. Matematica. Izvestiya Akademii Nauk Respubliki Moldova. Matematika")
    define("j-BUL-ACAD-STIINTE-REPUB-MOD-MAT",	"Bul. Acad. {\\c{S}}tiin{\\c{t}}e Repub. Mold. Mat.")

    define("j-BULL-ACAD-POL-SCI-CL-3",		"Bulletin de l'Acad{\\'e}mie polonaise des sciences. Classe troisi{\\`e}me")
    define("j-BULL-ACAD-POL-SCI-CL-3",		"Bulletin de l'Acad{\\'e}mie Polonaise des Sciences, Classe 3")
    define("j-BULL-ACAD-POL-SCI-CL-3",		"Bulletin de l'Acad{\\'e}mie Polonaise des Sciences, Classe 3: Math{\\'e}matique, Astronomie, Physique, Chimie, G{\\'e}ologie et G{\\'e}ographie")
    define("j-BULL-ACAD-POL-SCI-CL-3",		"Bull. Acad. Polon. Sci. Cl. III")
    define("j-BULL-ACAD-POL-SCI-CL-3",		"Bull. Acad. Pol. Sci., Cl. 3")

    # v6 1958--v26 n12 Dec. 1978
    define("j-BULL-ACAD-POL-SCI-SER-SCI-MATH-ASTRON-PHYS",	"Bulletin de l'Acad{\\'e}mie Polonaise des Sciences, S{\\'e}rie des Sciences, Math{\\'e}matiques, Astronomiques et Physiques")
    define("j-BULL-ACAD-POL-SCI-SER-SCI-MATH-ASTRON-PHYS",	"Bull. Acad. Polon. Sci. S{\\'e}r. Sci. Math. Astronom. Phys.")
    define("j-BULL-ACAD-POL-SCI-SER-SCI-MATH-ASTRON-PHYS",	"Bull. Acad. Pol. Sci., Ser. Sci., Math., Astron. Phys.")

    define("j-BULL-AM-SOC-INF-SCI",		"Bulletin of the American Society for Information Science")
    define("j-BULL-AM-SOC-INF-SCI",		"Bull. Am. Soc. Inf. Sci.")

    define("j-BULL-AMER-PHYS-SOC",		"Bulletin of the American Physical Society")
    define("j-BULL-AMER-PHYS-SOC",		"Bull. American Phys. Soc.")
    define("j-BULL-AMER-PHYS-SOC",		"Bull. Amer. Phys. Soc.")
    define("j-BULL-AMER-PHYS-SOC",		"Bull. Am. Phys. Soc.")

    define("j-BULL-AMS",			"Bulletin of the American Mathematical Society")
    define("j-BULL-AMS",			"Bull. Amer. Math. Soc.")
    define("j-BULL-AMS",			"Bull. AMS")
    define("j-BULL-AMS",			"Bulletin Amer. Math. Soc.")
    define("j-BULL-AMS",			"Bull. Am. Math. Soc.")

    define("j-BULL-AMS-N-S",			"Bulletin of the American Mathematical Society (new series)")
    define("j-BULL-AMS-N-S",			"Bulletin Amer. Math. Soc. (N. S.)")
    define("j-BULL-AMS-N-S",			"Bulletin (new series) of the American Mathematical Society")
    define("j-BULL-AMS-N-S",			"Bull. Amer. Math. Soc. (N.S.)")
    define("j-BULL-AMS-N-S",			"Bull. (New Series) AMS")
    define("j-BULL-AMS-N-S",			"Bulletin Amer. Math. Soc. (New Series)")

    define("j-BULL-ASSOC-SUISE-ELECTRICIENS",	"Bulletin de l'Association Suisse des Electriciens")
    define("j-BULL-ASSOC-SUISE-ELECTRICIENS",	"Bulletin")

    define("j-BULL-ASTRON-SOC-INDIA",		"Bulletin of the Astronomical Society of India = Bharatiya Jyotir Vijyan Parishad")
    define("j-BULL-ASTRON-SOC-INDIA",		"Bulletin of the Astronomical Society of India")
    define("j-BULL-ASTRON-SOC-INDIA",		"Bull. Astron. Soc. India")

    define("j-BULL-AUSTRAL-MATH-SOC",		"Bulletin of the Australian Mathematical Society")
    define("j-BULL-AUSTRAL-MATH-SOC",		"Bull. Aust. Math. Soc.")
    define("j-BULL-AUSTRAL-MATH-SOC",		"Bull. Austral. Math. Soc.")

    define("j-BULL-CALCUTTA-MATH-SOC",		"Bulletin of the Calcutta Mathematical Society")
    define("j-BULL-CALCUTTA-MATH-SOC",		"Bull. Calcutta Math. Soc.")

    define("j-BULL-EATCS",			"Bulletin of the European Association for Theoretical Computer Science")

    define("j-BULL-ENV-CONTAM-TOXIC",		"Bulletin of environmental contamination and toxicology")
    define("j-BULL-ENV-CONTAM-TOXIC",		"Bull Environ Contam Toxicol (BFN)")

    define("j-BULL-GEODESIQUE",			"Bulletin G{\\'e}od{\\'e}sique (Toulouse)")
    define("j-BULL-GEODESIQUE",			"Bulletin {G\\'e}od{\\'e}sique}")

    define("j-BULL-INST-MATH-APPL",		"Bulletin of the Institute of Mathematics and its Applications")
    define("j-BULL-INST-MATH-APPL",		"Bull. Inst. Math. Applics.")
    define("j-BULL-INST-MATH-APPL",		"Bull. Inst. Math. Appl.")
    define("j-BULL-INST-MATH-APPL",		"Bull. IMA")

    ## NB: j-BULL-INST-MATH-STAT became j-IMS-BULL in 1998
    define("j-BULL-INST-MATH-STAT",		"Bulletin --- Institute of Mathematical Statistics")
    define("j-BULL-INST-MATH-STAT",		"Bulletin / Institute of Mathematical Statistics")
    define("j-BULL-INST-MATH-STAT",		"Bulletin (Institute of Mathematical Statistics)")
    define("j-BULL-INST-MATH-STAT",		"The Institute of Mathematical Statistics Bulletin")
    define("j-BULL-INST-MATH-STAT",		"Bull. Inst. Math. Stat.")
    define("j-BULL-INST-MATH-STAT",		"Inst. of Math. Stat. Bulletin")
    define("j-BULL-INST-MATH-STAT",		"Bull. IMS")

    define("j-BULL-HIST-CHEM",			"Bulletin for the History of Chemistry")
    define("j-BULL-HIST-CHEM",			"Bull. Hist. Chem.")

    define("j-BULL-INFO-CYBER",			"Bulletin of Informatics and Cybernetics")

    define("j-BULL-KNOB",			"Bulletin van de Koninklijke Nederlandse Oudheidkundige Bond")
    define("j-BULL-KNOB",			"Bulletin KNOB")

    define("j-BULL-LOND-MATH-SOC",		"Bulletin of the London Mathematical Society")
    define("j-BULL-LOND-MATH-SOC",		"Bull. London Math. Soc.")
    define("j-BULL-LOND-MATH-SOC",		"Bull. Lond. Math. Soc.")

    define("j-BULL-MATH-BIOL",			"Bulletin of Mathematical Biology")
    define("j-BULL-MATH-BIOL",			"Bull. Math. Biol.")
    define("j-BULL-MATH-BIOL",			"Bull. Math. Biology")

    define("j-BULL-MATH-BIOPHYS",		"Bulletin of Mathematical Biophysics")
    define("j-BULL-MATH-BIOPHYS",		"Bull. Math. Biophys.")

    define("j-BULL-MATH-SOC-SCI-MATH-ROUMANIE",	"Bulletin math{\\'e}matique de la Soci{\\'e}t{\\'e} des sciences math{\\'e}matiques de la R{\\'e}publique socialiste de Roumanie")
    define("j-BULL-MATH-SOC-SCI-MATH-ROUMANIE",	"Bulletin mathematique de la Societe des sciences mathematiques de la Republique socialiste de Roumanie")
    define("j-BULL-MATH-SOC-SCI-MATH-ROUMANIE",	"Bull. Math. de la Soc. Sci. Math. de la R. S. Roumanie")

    define("j-BULL-PLANKTON-SOC-JAPAN",		"Bulletin of Plankton Society of Japan =  Nihon Purankuton Gakkai ho")
    define("j-BULL-PLANKTON-SOC-JAPAN",		"Bulletin of Plankton Society of Japan")
    define("j-BULL-PLANKTON-SOC-JAPAN",		"Bull. Plankton Soc. Japan")
    define("j-BULL-PLANKTON-SOC-JAPAN",		"Bulletin of the Plankton Sociey of Japan")

    define("j-BULL-SCHWEIZ-ELEKTROTECH",	"Bulletin des Schweizerischen Elektrotechnischen Vereins and des Verbandes Schweizerischer Elektrizitaetswerke")

    define("j-BULL-AT-SCI",			"Bulletin of the Atomic Scientists")
    define("j-BULL-AT-SCI",			"Bull. Atomic Scientists")
    define("j-BULL-AT-SCI",			"Bull. Atom. Sci.")
    define("j-BULL-AT-SCI",			"Bull. At. Sci.")

    define("j-BULL-SANTA-FE-INST",		"The Bulletin of the Santa Fe Institute")
    define("j-BULL-SANTA-FE-INST",		"Bulletin of the Santa Fe Institute")
    define("j-BULL-SANTA-FE-INST",		"Santa Fe Institute Bulletin")
    define("j-BULL-SANTA-FE-INST",		"Bull. Santa Fe Inst.")

    define("j-BULL-SCI-ASSOC-INGEN-ELECTRICIENS-MONTEFIORE","Bulletin Scientifique de l'Association des Ing{\\'e}nieurs Electriciens sortis de l'Institut Electrotechnique Montefiore")

    define("j-BULL-SOC-MATH-FRANCE",		"Bulletin de la Soci\\'et\\'e Math\\'ematique de France")
    define("j-BULL-SOC-MATH-FRANCE",		"Bull. Soc. Math. France")
    define("j-BULL-SOC-MATH-FRANCE",		"Bull. Soc. Math. Fr.")

    define("j-BULL-SOC-R-SCI-LIEGE",		"Bulletin de la Soci{\\'e}t{\\'e} royale des sciences de Li{\\`e}ge")
    define("j-BULL-SOC-R-SCI-LIEGE",		"Bull. Soc. Roy. Sci. Li{\\`e}ge")
    define("j-BULL-SOC-R-SCI-LIEGE",		"Bull. Soc. R. Sci. Li{\\`e}ge")

    define("j-BULL-SYMB-LOG",			"Bulletin of Symbolic Logic")
    define("j-BULL-SYMB-LOG",			"Bull. Symbolic Logic")
    define("j-BULL-SYMB-LOG",			"Bull. Symb. Logic")
    define("j-BULL-SYMB-LOG",			"Bull. Symb. Log.")

    define("j-BUS-AM",				"Business America: the magazine of international trade")
    define("j-BUS-AM",				"Business America: the magazine of internationa")
    define("j-BUS-AM",				"Business America")
    define("j-BUS-AM",				"Bus. Am.")

    define("j-BUS-COMMUN-REV",			"Business communications review")
    define("j-BUS-COMMUN-REV",			"Bus. commun. rev.")

    define("j-BUS-INDIA",			"Business India")
    define("j-BUS-INDIA",			"Bus. India")

    define("j-BUSINESS-INFO-REV",               "Business Information Review")
    define("j-BUSINESS-MARKETING",              "Business Marketing")
    define("j-BUSINESS-PUBLISHING",		"Business publishing")

    define("j-BUSINESS-REVIEW-WEEKLY",		"Business Review Weekly")
    define("j-BUSINESS-REVIEW-WEEKLY",		"BRW: the magazine of Australian \\& New Zealand business")

    define("j-BUSINESS-WEEK",			"Business week")

    define("j-BYTE",				"BYTE Magazine")
    define("j-BYTE",				"BYTE")
    define("j-BYTE",				"Byte Magazine")

    define("j-C-JET",				"C: JET, Communication: journalism education today")

    define("j-C-R-ACAD-BULGARE-SCI",		"Comptes rendus de l'Acad{\\'e}mie bulgare des sciences")
    define("j-C-R-ACAD-BULGARE-SCI",		"C. R. Acad. Bulgare Sci.")

    define("j-C-R-ACAD-BULGARE-SCI-SCI-MATH-NAT","Comptes rendus de l'Academie bulgare des sciences: sciences math{\\'e}matiques et naturelles")
    define("j-C-R-ACAD-BULGARE-SCI-SCI-MATH-NAT","C. R. Acad. Bulgare Sci. Sci. Math. Nat.")
    define("j-C-R-ACAD-BULGARE-SCI-SCI-MATH-NAT","Doklady Bolgarskoj akademija nauk")
    define("j-C-R-ACAD-BULGARE-SCI-SCI-MATH-NAT","Dokl. Bolg. akad. nauk.")

    define("j-C-R-ACAD-SCI",			"Comptes Rendus de l'Acad{\\'e}mie des Sciences")
    define("j-C-R-ACAD-SCI",			"C. R. Acad. Sci.")

    define("j-C-R-ACAD-SCI-CANADA",		"Comptes rendus de l'Acad{\\'e}mie des sciences. Canada")
    define("j-C-R-ACAD-SCI-CANADA",		"C. R. Math. Rep. Acad. Sci. Canada")

    define("j-C-R-ACAD-SCI-I",			"Comptes rendus de l'Acad{\\'e}mie des sciences. S{\\'e}rie I, Math{\\'e}matique")
    define("j-C-R-ACAD-SCI-I",			"Comptes Rendus de l'Acad{\\'e}mie des Sciences - Series I - Mathematics")
    define("j-C-R-ACAD-SCI-I",			"Comptes Rendus de l'Acad{\\'e}mie des Sciences --- Series I --- Mathematics")
    define("j-C-R-ACAD-SCI-I",			"C. R. Acad. Sci. Paris S{\\'e}r. I Math.")

    define("j-C-R-ACAD-SCI-III",		"Comptes rendus de l'Acad{\\'e}mie des sciences. S{\\'e}rie III, Sciences de la vie")
    define("j-C-R-ACAD-SCI-III",		"Comptes rendus de l'Academie des sciences. Serie III, Sciences de la vie")
    define("j-C-R-ACAD-SCI-III",		"C R Acad Sci III (CA1)")

    define("j-C-R-ACAD-SCI-PARIS",		"Comptes rendus de l'Acad{\\'e}mie des sciences, Paris")
    define("j-C-R-ACAD-SCI-PARIS",		"C. R. Acad. Sci. Paris")
    define("j-C-R-ACAD-SCI-PARIS",		"C.R. Acad. Sc. Paris")
    define("j-C-R-ACAD-SCI-PARIS",		"Compte Rendu Academie Science Paris")

    define("j-C-R-ACAD-SCI-PARIS-SER-A",	"Comptes Rendus des S{\\'e}ances de l'Acad{\\'e}mie des Sciences, S{\\'e}rie A: Sciences Math{\\'e}matiques")
    define("j-C-R-ACAD-SCI-PARIS-SER-A",	"C. R. S{\\'e}ances Acad. Sci., Ser. A")

    define("j-C-R-ACAD-SCI-PARIS-SER-B",	"Comptes Rendus des S{\\'e}ances de l'Acad{\\'e}mie des Sciences, S{\\'e}rie B: Sciences Physiques")
    define("j-C-R-ACAD-SCI-PARIS-SER-B",	"C. R. S{\\'e}ances Acad. Sci., Ser. B")

    define("j-C-R-ACAD-SCI-PARIS-SER-AB",	"Comptes Rendus Hebdomadaires des S{\\'e}ances de l'Acad{\\'e}mie des Sciences. S{\\'e}ries A et B")
    define("j-C-R-ACAD-SCI-PARIS-SER-AB",	"C. R. Acad. Sci. Paris S{\\e}r. A--B")
    define("j-C-R-ACAD-SCI-PARIS-SER-AB",	"C. R. Acad. Sci. Paris S{\\'e}r. A--B")

    define("j-C-R-ACAD-SCI-SER-GEN-VIE-SCI",	"Comptes Rendus de l'Acad{\\'e}mie des Sciences, S{\\'e}rie G{\\'e}n{\\'e}rale: la Vie des Sciences")
    define("j-C-R-ACAD-SCI-SER-GEN-VIE-SCI",	"C. R. Acad. Sci., S{\\'e}r. G{\\'e}n. Vie Sci.")

    define("j-C-R-ACAD-SCI-PARIS-SER-I-MATH",	"Comptes Rendus des S{\\'e}ances de l'Acad{\\'e}mie des Sciences. S{\\'e}rie I. Math{\\'e}matique")
    define("j-C-R-ACAD-SCI-PARIS-SER-I-MATH",	"Comptes Rendus des SÃ©ances de l'AcadÃ©mie des Sciences. SÃ©rie I. MathÃ©matique")
    define("j-C-R-ACAD-SCI-PARIS-SER-I-MATH",	"C. R. Acad. Sci. Paris S{\\'e}r. I Math.")
    define("j-C-R-ACAD-SCI-PARIS-SER-I-MATH",	"C. R. Acad. Sci. Paris SÃ©r. I Math.")
    define("j-C-R-ACAD-SCI-PARIS-SER-I-MATH",	"C. R. Acad. Sci. Paris S&eacute;r. I Math.")

    define("j-C-R-ACAD-SCI-URSS",		"Comptes rendus de l'Academie des sciences de l'URSS = Doklady Akademii nauk SSSR")
    define("j-C-R-ACAD-SCI-URSS",		"C. R. (Doklady) Acad. Sci. U.S.S.R.")

    define("j-C-R-BIOL",			"Comptes Rendus Biologies")
    define("j-C-R-BIOL",			"C. R. Biol.")

    define("j-C-R-DAS-URSS",			"Comptes Rendus (Doklady) de l'Acad{\\'e}mie des Sciences de l'URSS")

    ## define("j-C-R-MATH-I",			"Comptes rendus de l'Acad{\\'e}mie des sciences. Serie I, Math{\\'e}matique")
    ## define("j-C-R-MATH-I",			"Comptes rendus de l'Academie des sciences. Serie I, Mathematique")
    ## define("j-C-R-MATH-I",			"C. R. Acad. Sci. Paris S{\\'e}r. I Math.")

    define("j-C-R-MATH-ACAD-SCI-PARIS",		"Comptes Rendus Math{\\'e}matique. Acad{\\'e}mie des Sciences. Paris")
    define("j-C-R-MATH-ACAD-SCI-PARIS",		"C. R. Math. Acad. Sci. Paris")

    define("j-C-R-MEC",				"Comptes Rendus M{\\'e}canique")
    define("j-C-R-MEC",				"C. R. Mec.")

    define("j-C-R-PHYS",			"Comptes Rendus Physique")
    define("j-C-R-PHYS",			"C. R. Phys.")

    define("j-CABLE-TRANS",			"Cables et Transmissions")

    define("j-CACM",				"Communications of the ACM")
    define("j-CACM",				"Commun. ACM")
    define("j-CACM",				"Comm. ACM")
    define("j-CACM",				"Comm. Assoc. Comput. Mach.")
    define("j-CACM",				"CACM")
    define("j-CACM",				"Commun. of the ACM")
    define("j-CACM",				"Communications of the Association for Computing Machinery")
    define("j-CACM",				"Communs Ass. comput. Mach.")
    define("j-CACM",				"Assn Computing Machy-Communications")

    ## define("j-CAD",				"Computer Aided Design")
    ## define("j-CAD",				"Comput. Aided Des.")

    define("j-CADALYST",			"CADalyst: the newsletter of the AutoCAD Users' Group")

    define("j-CAGD",				"Computer-Aided Geometric Design")
    define("j-CAGD",				"Comput. Aided Geom. Design")

    define("j-CAH-PHYS",			"Cahiers de Physique")
    define("j-CAH-PHYS",			"Cah. Phys.")

    define("j-CAHIERS-CENTRE-ETUDES-RECH-OPER",	"Cahiers du Centre d'{\\'e}tudes de recherche op{\\'e}rationnelle")
    define("j-CAHIERS-CENTRE-ETUDES-RECH-OPER",	"Cahiers du Centre d'etudes de recherche operationnelle")
    define("j-CAHIERS-CENTRE-ETUDES-RECH-OPER",	"Cahiers Centre d'Etudes Rech. Oper")

    define("j-CALCOLO",				"Calcolo: a quarterly on numerical analysis and theory of computation")
    define("j-CALCOLO",				"Calcolo")

    define("j-CALC-VAR-PARTIAL-DIFFER-EQU",	"Calculus of variations and partial differential equations")
    define("j-CALC-VAR-PARTIAL-DIFFER-EQU",	"Calc. var. partial differ. equ.")
    define("j-CALC-VAR-PARTIAL-DIFFER-EQU",	"Calc. Var. Partial Differential Equations")

    define("j-CALIF-MANAGE-REV",		"California management review")
    define("j-CALIF-MANAGE-REV",		"Calif. manage. rev.")

    define("j-CALPHAD",				"CALPHAD: computer coupling of phase diagrams and thermochemistry")
    define("j-CAMBRIDGE-STUDIES-ADV-MATH",	"Cambridge Studies in Advanced Mathematics")

    define("j-CAMPUS-WIDE-INF-SYST",		"Campus-wide information systems: CWIS")
    define("j-CAMPUS-WIDE-INF-SYST",		"Campus-wide information systems")
    define("j-CAMPUS-WIDE-INF-SYST",		"Campus-wide inf. syst.")

    define("j-CAN-APPL-MATH-Q",			"Canadian Applied Mathematics Quarterly")
    define("j-CAN-APPL-MATH-Q",			"Can. Appl. Math. Quar.")
    define("j-CAN-APPL-MATH-Q",			"Can. Appl. Math. Q.")

    define("j-CAN-ELECTR-ENG-J",		"Canadian electrical engineering journal = Revue canadienne de g{\\'e}nie {\\'e}lectrique")
    define("j-CAN-ELECTR-ENG-J",		"Can. electr. eng. j.")
    define("j-CAN-ELECTR-ENG-J",		"Canadian Electr. Engineering Journal")

    define("j-CAN-J-ARCHAEO",			"Canadian Journal of Archaeology / Journal Canadien d'Arch{\\'e}ologie")
    define("j-CAN-J-ARCHAEO",			"Canadian Journal of Archaeology")
    define("j-CAN-J-ARCHAEO",			"Canadian Journal of Archaeology / Journal Canadien d'Arch{\\'e}ologie")
    define("j-CAN-J-ARCHAEO",			"Journal Canadien d'Arch{\\'e}ologie")
    define("j-CAN-J-ARCHAEO",			"Can. J. Archaeol.")

    define("j-CAN-J-BIOCHEM-CELL-BIOL",		"Can J Biochem Cell Biol (CHO)")

    define("j-CAN-J-CARDIOL",			"Canadian journal of cardiology")
    define("j-CAN-J-CARDIOL",			"Can. j. cardiol.")

    define("j-CAN-J-CHEM",			"Canadian Journal of Chemistry == Journal canadien de chimie")
    define("j-CAN-J-CHEM",			"Canadian Journal of Chemistry")
    define("j-CAN-J-CHEM",			"Can. J. Chem.")

    define("j-CAN-J-EARTH-SCI",			"Canadian Journal of Earth Sciences = Journal canadien des sciences de la terre")
    define("j-CAN-J-EARTH-SCI",			"Canadian Journal of Earth Sciences")
    define("j-CAN-J-EARTH-SCI",			"Can. J. Earth Sci.")

    define("j-CAN-J-ELECT-COMP-ENG",		"Canadian journal of electrical and computer engineering = Revue canadienne de genie electrique et informatique")

    define("j-CAN-J-FOR-RES",			"Canadian Journal of Forest Research = Journal canadien de la recherche foresti{\\`e}re")
    define("j-CAN-J-FOR-RES",			"Canadian Journal of Forest Research")
    define("j-CAN-J-FOR-RES",			"Can. J. For. Res.")

    define("j-CAN-J-INFO-SCIENCE",		"Canadian Journal of Information Science")

    define("j-CAN-J-FISH-AQUAT-SCI",		"Canadian Journal of Fisheries and Aquatic Sciences = Journal canadien des sciences halieutiques et aquatiques")
    define("j-CAN-J-FISH-AQUAT-SCI",		"Canadian Journal of Fisheries and Aquatic Sciences")
    define("j-CAN-J-FISH-AQUAT-SCI",		"Can. J. Fish. Aquat. Sci.")

    define("j-CAN-J-HIGHER-ED",			"Canadian Journal of Higher Education = La Revue canadienne d'enseignement sup{\\'e}rieur")
    define("j-CAN-J-HIGHER-ED",			"Canadian Journal of Higher Education")
    define("j-CAN-J-HIGHER-ED",			"Can. J. Higher Ed.")

    define("j-CAN-J-MATH",			"Canadian Journal of Mathematics = Journal canadien de math{\\'e}matiques")
    define("j-CAN-J-MATH",			"Canadian Journal of Mathematics")
    define("j-CAN-J-MATH",			"Canadian J. Math.")
    define("j-CAN-J-MATH",			"Canad. J. Math.")

    define("j-CAN-J-MICROBIOL",			"Canadian Journal of Microbiology")
    define("j-CAN-J-MICROBIOL",			"Can J Microbiol (CJ3)")

    define("j-CAN-J-PHYS",			"Canadian Journal of Physics = Journal canadien de physique")
    define("j-CAN-J-PHYS",			"Canadian Journal of Physics")
    define("j-CAN-J-PHYS",			"Canadian J. Phys.")
    define("j-CAN-J-PHYS",			"Can. J. Phys.")

    define("j-CAN-J-PHYSIOL-PHARMACOL",		"Canadian Journal of Physiology and Pharmacology")
    define("j-CAN-J-PHYSIOL-PHARMACOL",		"Can. J. Physiol. Pharmacol.")

    define("j-CAN-J-RES-SECT-A",		"Canadian Journal of Research, Section A: Physical Sciences")
    define("j-CAN-J-RES-SECT-A",		"Canadian Journal of Research Section A --- Physical Sciences")
    define("j-CAN-J-RES-SECT-A",		"Can. J. Res., Sect. A")

    define("j-CAN-J-STAT",			"Canadian Journal of Statistics = Revue canadienne de statistique")
    define("j-CAN-J-STAT",			"Canadian Journal of Statistics")
    define("j-CAN-J-STAT",			"Canad. J. Statist.")
    define("j-CAN-J-STAT",			"Can. J. Statist.")
    define("j-CAN-J-STAT",			"Can. J. Stat.")

    define("j-CAN-MATH-BULL",			"Canadian mathematical bulletin = Bulletin canadien de math{\\'e}matiques")
    define("j-CAN-MATH-BULL",			"Canadian mathematical bulletin = Bulletin canadien de mathematiques")
    define("j-CAN-MATH-BULL",			"Canadian Math. Bulletin")
    define("j-CAN-MATH-BULL",			"Canad. Math. Bull.")
    define("j-CAN-MATH-BULL",			"Can. Math. Bull.")

    define("j-CANCER-METASTASIS-REV",		"Cancer Metastasis Rev (C9H)")
    define("j-CAPACITY-MANAGEMENT-REVIEW",	"Capacity management review: CMR: a monthly report on managing computer performance")

    define("j-CARBOHYDR-RES",			"Carbohydrate Research")
    define("j-CARBOHYDR-RES",			"Carbohydr Res (CNY)")

    define("j-CARTOGRAPHICA",			"Cartographica")
    define("j-CARBON",				"Carbon")
    define("j-CARDIOSCIENCE",			"Cardioscience")

    define("j-CARDIOVASC-RES",			"Cardiovascular research")
    define("j-CARDIOVASC-RES",			"Cardiovasc. res.")

    define("j-CART-GIS",			"Cartography and Geographic Information Systems")

    define("j-CAS-PEST-MAT",			"{\\v{C}}asopis Pro Pestovani Matematiky")
    define("j-CAS-PEST-MAT",			"{\\v{C}}as. Pest. Mat.")

    define("j-CAT-CLASSIF-Q",			"Cataloging \\& classification quarterly")
    define("j-CAT-CLASSIF-Q",			"Cat. classif. q.")

    define("j-CCCUJ",				"C/C++ Users Journal")
    define("j-CCCUJ",				"C C Plus Plus Users Journal")

    define("j-CCPE",				"Concurrency and Computation: Prac\\-tice and Experience")
    define("j-CCPE",				"Concurrency and Computation")

    define("j-CD-ROM-PROF",			"CD-ROM Professional")
    define("j-CD-ROM-WORLD",			"CD-ROM World")
    define("j-CEE",				"CEE. Chemical engineering education")

    define("j-CELEST-MECH",			"Celestial mechanics")
    define("j-CELEST-MECH",			"Celest. mech.")
    define("j-CELEST-MECH",			"Celestial Mech.")

    define("j-CELEST-MECH-DYN-ASTR",		"Celestial Mechanics and Dynamical Astronomy")
    define("j-CELEST-MECH-DYN-ASTR",		"Celestial Mech. Dynam. Astronom.")
    define("j-CELEST-MECH-DYN-ASTR",		"Celest. Mech. Dyn. Astr.")

    define("j-CELL",				"Cell")
    define("j-CELL",				"Cell (CQ4)")

    define("j-CELL-BIOL-INT",			"Cell Biol Int (BPN)")

    define("j-CELL-BIOL-INT-REP",		"Cell biology international reports")
    define("j-CELL-BIOL-INT-REP",		"Cell Biology International Reports")
    define("j-CELL-BIOL-INT-REP",		"Cell Biol. Int. Rep.")
    define("j-CELL-BIOL-INT-REP",		"Cell Biol. Int. Rpts.")
    define("j-CELL-BIOL-INT-REP",		"Cell Biol. internat. Rpts.")
    define("j-CELL-BIOL-INT-REP",		"Cell Biol. Intn. Rpts.")
    define("j-CELL-BIOL-INT-REP",		"Cell Biol Int Rep (CRC)")
    define("j-CELL-BIOL-INT-REP",		"Cell Biol. Intern. Rep.")

    define("j-CELL-BIOPHYS",			"Cell Biophys")
    define("j-CELL-BIOPHYS",			"Cell Biophys (CQC)")

    define("j-CELL-CALCIUM",			"Cell calcium")
    define("j-CELL-CALCIUM",			"Cell Calcium (CQE)")

    define("j-CELL-DIFFER",			"Cell Differ (CQ6)")
    define("j-CELL-DIFFER",			"Cell Differentiation")
    define("j-CELL-DIFFER",			"Cell Differ.")

    define("j-CELL-DIFFER-DEV",			"Cell Differ Dev (CDD)")
    define("j-CELL-MOTIL",			"Cell Motil (CQF)")

    define("j-CELL-MOTIL-CYTOSKEL",		"Cell Motility and the Cytoskeleton")
    define("j-CELL-MOTIL-CYTOSKEL",		"Cell Motil Cytoskeleton (CRD)")
    define("j-CELL-MOTIL-CYTOSKEL",		"Cell Motil and the Cytoskel.")
    define("j-CELL-MOTIL-CYTOSKEL",		"Cell Motil. Cytoskel")
    define("j-CELL-MOTIL-CYTOSKEL",		"J. Cell Motil. Cytoskel")

    define("j-CELL-REGUL",			"Cell Regul (A1U)")
    define("j-CELL-SIGNAL",			"Cellular Signalling")
    define("j-CELL-SIGNAL",			"Cell. Signal.")
    define("j-CELL-SIGNAL",			"Cell Signal (AVB)")

    define("j-CELL-STRUCT-FUNCT",		"Cell structure and function")
    define("j-CELL-STRUCT-FUNCT",		"Cell Struct Funct (CSF)")

    define("j-CELL-SYST",			"Cell Systems")
    define("j-CELL-SYST",			"Cell Syst.")

    define("j-CELL-TISSUE-RES",                 "Cell and Tissue Research")
    define("j-CELL-TISSUE-RES",                 "Cell Tissue Res.")

    define("j-CELL-TISSUE-KINET",		"Cell and tissue kinetics")
    define("j-CELL-TISSUE-KINET",		"Cell tissue kinet.")

    define("j-CENTAURUS",			"Centaurus: An International Journal of the History of Science and its Cultural Aspects")
    define("j-CENTAURUS",			"Centaurus")

    define("j-CERN-COURIER",			"CERN Courier: International Journal of High-Energy Physics")
    define("j-CERN-COURIER",			"CERN Courier")
    define("j-CERN-COURIER",			"CERN Cour.")

    # (1954--1965)
    define("j-CESK-CAS-FYZ",			"{\\v{C}}eskoslovensky {\\c{c}}asopis pro fyziku")
    define("j-CESK-CAS-FYZ",			"{\\v{C}}esk. {\\c{c}}as fyz.")

    # Section A (1966--1989)
    define("j-CESK-CAS-FYZ-SEK-A",		"{\\v{C}}eskoslovensky {\\v{C}}asopis pro Fyziku Sekce {A}")
    define("j-CESK-CAS-FYZ-SEK-A",		"{\\v{C}}eskoslovensky {\\v{C}}asopis pro Fysiku Sekce {A}")
    define("j-CESK-CAS-FYZ-SEK-A",		"{\\v{C}}esk. {\\v{C}}as. Fyz. Sek. A")
    define("j-CESK-CAS-FYZ-SEK-A",		"{\\v{C}}esk. {\\v{C}}as. Fyz. Sek. A")

    define("j-CG-WORLD",			"Computer Graphics World")

    define("j-CGF",				"Com{\\-}pu{\\-}ter Graphics Forum")
    define("j-CGF",				"Computer Graphics Forum")
    define("j-CGF",				"Computer Graphics Forum: Journal of the European Association for Computer Graphics")
    define("j-CGF",				"Comput. Graph. Forum")

    # CGIP: V.1-20, April 1972-December 1982: see CVGIP* for later years
    define("j-CGIP",				"Computer Graphics and Image Processing")
    define("j-CGIP",				"Computer Graphics \\& Image Processing")
    define("j-CGIP",				"Comput. Gr. Image Process.")
    define("j-CGIP",				"Comp. Graphics and Image Processing")
    define("j-CGIP",				"Computer Graphics and Image Processing (CGIP)")
    define("j-CGIP",				"Computer Graphics and Image Processing (USA)")
    define("j-CGIP",				"CGIP")

    define("j-CHANCE",				"Chance: a magazine for people interested in the analysis of data")
    define("j-CHANCE",				"Chance")

    define("j-CHAOS",				"Chaos (Woodbury, NY)")
    define("j-CHAOS",				"Chaos: An Interdisciplinary Journal of Nonlinear Science")
    define("j-CHAOS",				"Chaos")

    define("j-CHAOS-SOLITONS-FRACTALS",		"Chaos, Solitons \\& Fractals")
    define("j-CHAOS-SOLITONS-FRACTALS",		"Chaos, Solitons and Fractals")
    define("j-CHAOS-SOLITONS-FRACTALS",		"Chaos Solitons Fractals")

    define("j-CHEM-BRITAIN",			"Chemistry in Britain")

    # Which journal is j-CHEM-ENG??  CMERA9/0302-0797 (London), or
    # 0095-8875 (New York).  The latter published from 1904 to 1920,
    # and the former from 1970 to date.
    define("j-CHEM-ENG",			"Chemical Engineer")

    define("j-CHEM-ENG-COMMUN",			"Chemical Engineering Communications")
    define("j-CHEM-ENG-COMMUN",			"Chem. Eng. Commun.")

    define("j-CHEM-ENG-NEWS",			"Chemical \\& Engineering News")
    define("j-CHEM-ENG-NEWS",			"Chemical and Engineering News")
    define("j-CHEM-ENG-NEWS",			"Chemical and Engineering News: `news edition' of the American Chemical Society")
    define("j-CHEM-ENG-NEWS",			"Chem. Eng. News")

    define("j-CHEM-ENG-NEWS-ARCHIVE",		"Chemical \\& Engineering News Archive")
    define("j-CHEM-ENG-NEWS-ARCHIVE",		"Chemical and Engineering News Archive")
    define("j-CHEM-ENG-NEWS-ARCHIVE",		"Chem. Eng. News Archive")

    define("j-CHEM-ENG-PROG",			"Chemical Engineering Progress")
    define("j-CHEM-ENG-PROG",			"Chem. Eng. Prog.")

    define("j-CHEM-ENG-SCI",			"Chemical Engineering Science")
    define("j-CHEM-ENG-SCI",			"Chem. Eng. Sci.")

    define("j-CHEM-IND-CHICHESTER-UK",		"Chemistry \\& Industry (Chichester, UK)")
    define("j-CHEM-IND-CHICHESTER-UK",		"Chem. Ind. (Chichester, UK)")

    ## Discontinued Serial: an. 1995-v6 n4 2000
    define("j-CHEM-INTELL",			"The Chemical Intelligencer")
    define("j-CHEM-INTELL",			"Chemical Intelligencer")
    define("j-CHEM-INTELL",			"Chem. Intell.")

    define("j-CHEM-MATER",			"Chemistry of Materials")
    define("j-CHEM-MATER",			"Chem. Mater.")

    ## Continuation (1921--1932) of j-CHEM-NEWS-J-PHYS-SCI
    define("j-CHEM-NEWS-J-IND-SCI",		"Chemical News and Journal of Industrial Science")
    define("j-CHEM-NEWS-J-IND-SCI",		"Chem. News J. Ind. Sci.")

    define("j-CHEM-NEWS-J-PHYS-SCI",		"Chemical News and Journal of Physical Science")
    define("j-CHEM-NEWS-J-PHYS-SCI",		"Chem. News J. Phys. Sci.")

    define("j-CHEM-PHARM-BULL",			"Chem Pharm Bull (Tokyo) (CZP)")

    define("j-CHEM-PHYS",			"Chemical Physics")
    define("j-CHEM-PHYS",			"Chem. Phys.")

    define("j-CHEM-PHYS-LETT",			"Chemical Physics Letters")
    define("j-CHEM-PHYS-LETT",			"Chem. Phys. Lett.")
    define("j-CHEM-PHYS-LETT",			"Chem. Phys. Letters")
    define("j-CHEM-PHYS-LETT",			"Chemical Phys. Lett.")

    define("j-CHEM-REV",			"Chemical Reviews")
    define("j-CHEM-REV",			"Chem. Rev.")

    define("j-CHEM-UNSERER-ZEIT",		"{Chemie in unserer Zeit}")
    define("j-CHEM-UNSERER-ZEIT",		"{Chem. unserer Zeit}")

    define("j-CHEMINFORM",			"ChemInform")

    define("j-CHEMO-INTELL-LAB",		"Chemometrics and Intelligent Laboratory Systems")
    define("j-CHEMO-INTELL-LAB",		"Chemometrics and Intelligent Laboratory System")
    define("j-CHEMO-INTELL-LAB",		"Chemometrics and intelligent laboratory systems: an international journal sponsored by the Chemometrics Society")

    define("j-CHEMOSPHERE",			"Chemosphere")

    define("j-CHEMPHYSCHEM",			"ChemPhysChem")
    define("j-CHEMTECH",			"CHEMTECH")

    define("j-CHIC-J-THEOR-COMPUT-SCI",		"Chicago Journal of Theoretical Computer Science")
    define("j-CHIC-J-THEOR-COMPUT-SCI",		"Chic. J. Theor. Comput. Sci.")

    define("j-CHIC-REV",			"Chicago Review")
    define("j-CHIC-REV",			"Chic. Rev.")

    define("j-CHIFFRES",			"Chiffres: Revue de l'Association fran{\\c{c}}aise de Calcul")
    define("j-CHIFFRES",			"Chiffres")

    define("j-CHILTONS-AUTOMOT-IND",		"Chilton's automotive industries")
    define("j-CHILTONS-AUTOMOT-IND",		"Chilton's automot. ind.")

    define("j-CHIN-J-COMPUTERS",		"Chinese Journal of Computers = Chi suan chi hsueh pao")
    define("j-CHIN-J-COMPUTERS",		"Chinese J. Comput.")
    define("j-CHIN-J-COMPUTERS",		"Chi suan chi hsueh pao = Chinese journal of computers")
    define("j-CHIN-J-COMPUTERS",		"Chinese Journal of Computers")

    define("j-CHIN-J-LASERS",			"Chinese Journal of Lasers = Zhongguo Jiguang")
    define("j-CHIN-J-LASERS",			"Zhongguo Jiguang/Chinese Journal of Lasers")

    define("j-CHIN-PHYS-LETT",			"Chinese Physics Letters")
    define("j-CHIN-PHYS-LETT",			"Chin. Phys. Lett.")

    define("j-CHIRALITY",			"Chirality (AVD)")

    define("j-CHR-SCI-MON",			"The Christian Science Monitor")
    define("j-CHR-SCI-MON",			"Christian Science Monitor")
    define("j-CHR-SCI-MON",			"Chr. Sci. Mon.")

    define("j-CHRON-HIGHER-ED",			"The Chronicle of Higher Education")

    define("j-CHYMIA",				"Chymia: Annual Studies in the History of Chemistry")
    define("j-CHYMIA",				"Chymia")

    define("j-CIBA-FOUND-SYMP",                 "Ciba Foundation symposium")
    define("j-CIBA-FOUND-SYMP",                 "Ciba Found. Symp.")

    define("j-CIEL-TERRE",			"Ciel et Terre")
    define("j-CIEL-TERRE",			"Ciel Terre")

    define("j-CIENC-INVEST",			"Ciencia e Investigaci{\\'o}n")
    define("j-CIENC-INVEST",			"Cienc. Invest.")

    define("j-CIRC-ARRHYTHM-ELECTROPHYSIOL",	"Circulation: Arrhythmia and Electrophysiology")
    define("j-CIRC-ARRHYTHM-ELECTROPHYSIOL",	"Circ.: Arrhythmia Electrophysiol.")

    define("j-CIRC-RES",			"Circulation research")
    define("j-CIRC-RES",			"Circulation research: a journal of the American Heart Association")
    define("j-CIRC-RES",			"Circ. Res.")

    define("j-CIRCULATION",			"Circulation")

    define("j-CISCO-WORLD",			"Cisco World: The Independent Journal for Internetworking Professionals")
    define("j-CISCO-WORLD",			"Cisco World")

    define("j-CIVILIZ",				"Civilization (The Magazine of the {Library of Congress})")
    define("j-CIVILIZ",				"Civilization")
    define("j-CIVILIZ",				"Civiliz.")

    define("j-CLASS-COMP-LEARN",		"Classroom Computer Learning")

    define("j-CLASS-QUANTUM-GRAV",		"Classical and quantum gravity")
    define("j-CLASS-QUANTUM-GRAV",		"Class. Quant. Grav.")
    define("j-CLASS-QUANTUM-GRAV",		"Class. Quantum Grav.")

    define("j-CLIENT-SERVER-ECONOMICS-LETT",    "Client\\slash Server Economics Letter")
    define("j-CLIENT-SERVER-ECONOMICS-LETT",    "Client/Server Economics Letter")

    define("j-CLIN-EXP-IMMUNOL",		"Clinical and Experimental Immunology: an official journal of the British Society for Immunology")
    define("j-CLIN-EXP-IMMUNOL",		"Clinical and Experimental Immunology")
    define("j-CLIN-EXP-IMMUNOL",		"Clin Exp Immunol (DD7)")

    define("j-CLIN-HAEMATOL",			"Clinics in haematology")
    define("j-CLIN-HAEMATOL",			"Clin. haematol.")
    define("j-CLIN-HAEMATOL",			"Clin. in Haematol.")

    define("j-CLIN-LAB-HAEMOTOLOGY",		"Clinical and laboratory haematology")

    define("j-CLIN-PHARMACOL-THER",		"Clinical pharmacology and therapeutics")
    define("j-CLIN-PHARMACOL-THER",		"Clin. pharmacol. ther.")

    define("j-CLIN-PLAST-SURG",			"Clinics in plastic surgery")
    define("j-CLIN-PLAST-SURG",			"Clin. plast. surg.")

    define("j-CLIN-SCI",			"Clin Sci (Colch) (DIZ)")
    define("j-CLNET",				"c$\\|$net central")
    define("j-CMCM",				"Computer-Mediated Communication Magazine")
    define("j-CMG-PROC",			"CMG Proceedings")

    define("j-CMS-NOTES",			"Canadian Mathematical Society Notes")
    define("j-CMS-NOTES",			"Notes of the Canadian Mathematical Society")
    define("j-CMS-NOTES",			"CMS Notes == Notes de la SMC")
    define("j-CMS-NOTES",			"CMS Notes")

    define("j-COAL-NEWSLETTER",			"COAL Newsletter")
    define("j-COASTAL-ZONE",			"Coastal Zone: Proceedings of the Symposium on Coastal and Ocean Management")
    define("j-COED",				"CoED")

    define("j-COGN-SCI",			"Cognitive Science")
    define("j-COGN-SCI",			"Cogn. Sci.")

    define("j-COGNITION",			"Cognition")

    define("j-COLD-SPRING-HARBOR-SYMP-QUANT-BIOL","Cold Spring Harbor Symposia on Quantitative Biology")
    define("j-COLD-SPRING-HARBOR-SYMP-QUANT-BIOL","Cold Spring Harbor Symp. Quantit. Biol.")
    define("j-COLD-SPRING-HARBOR-SYMP-QUANT-BIOL","Cold Spring Harb Symp Quant Biol (DMT)")

    define("j-COLL-ALGOR-ACM",			"Collected Algorithms from ACM")

    define("j-COLL-ENGL",			"College English")
    define("j-COLL-ENGL",			"Coll. Engl.")

    define("j-COLL-MICRO",			"Collegiate Microcomputer")
    define("j-COLL-RESEARCH-LIB",		"College and Research Libraries")

    define("j-COLL-RESEARCH-LIB-NEWS",		"College and Research Libraries News")
    define("j-COLL-RESEARCH-LIB-NEWS",		"Coll. Res. Libr. News")

    define("j-COLL-OCEAN-WORKS",		"Collected oceanic works = Hai yang wen chi")
    define("j-COLL-OCEAN-WORKS",		"Hai yang wen chi = Collected oceanic works")

    define("j-COLLECT-CZECH-CHEM-COMMUN",	"Collection of Czechoslovak Chemical Communications")
    define("j-COLLECT-CZECH-CHEM-COMMUN",	"Collection Czech. Chem. Commun.")
    define("j-COLLECT-CZECH-CHEM-COMMUN",	"Collect. Czech. chem. commun.")

    ## j-TWO-YEAR-COLL-MATH-J v1n1 1970 to v14n5 1983, then renamed to j-COLLEGE-MATH-J
    ## v15n1 1984 to date
    define("j-COLLEGE-MATH-J",			"College Mathematics Journal")
    define("j-COLLEGE-MATH-J",			"College Mathematics Journal: an official publication of the Mathematical Association of America")
    define("j-COLLEGE-MATH-J",			"Coll. Math. J.")
    define("j-COLLEGE-MATH-J",			"College Math. J.")

    define("j-COLLNET-J-SCIENTOMETRICS-INF-MANAGE",	"Collnet Journal of Scientometrics and Information Management")
    define("j-COLLNET-J-SCIENTOMETRICS-INF-MANAGE",	"Collnet J. Scientometrics Info. Manage.")

    define("j-COLLOQ-GER",			"Colloquia Germanica")
    define("j-COLLOQ-GER",			"Colloq. Ger.")

    define("j-COLLOQ-MATH",			"Colloquium Mathematicum")
    define("j-COLLOQ-MATH",			"Colloq. Math.")

    define("j-COLLOQ-MATH-BOLYAI",		"Colloquia Mathematica Societatis J{\\'a}nos Bolyai") # this is also a book series
    define("j-COLLOQ-MATH-BOLYAI",		"Colloq. Math. Soc. J{\\'a}nos Bolyai")

    define("j-COLO-LAWYER",			"Colorado Lawyer")
    define("j-COLO-LAWYER",			"Colo. lawyer")

    define("j-COLO-LIBR",			"Colorado libraries")
    define("j-COLO-LIBR",			"Colo. libr.")

    define("j-COLUMBIA-LAW-REV",		"Columbia Law Review")
    define("j-COLUMBIA-LAW-REV",		"Columbia Law Rev.")

    define("j-COMBINATORICA",			"Combinatorica")
    define("j-COMBINATORICA",			"Combinatorica: an international journal of the Janos Bolyai Mathematical Society")

    define("j-COMM-APPL-ANAL",			"Communications in Applied Analysis")
    define("j-COMM-APPL-ANAL",			"Comm. Appl. Anal.")
    define("j-COMM-APPL-ANAL",			"Commun. Appl. Anal.")

    define("j-COMM-APPL-NUM-METH",		"Communications in Applied Numerical Methods")

    define("j-COMM-PARTIAL-DIFF-EQNS",		"Communications in partial differential equations")
    define("j-COMM-PARTIAL-DIFF-EQNS",		"Comm. in Partial Differential Equations")
    define("j-COMM-PARTIAL-DIFF-EQNS",		"Comm. Partial Differential Equations")

    define("j-COMM-NONLIN-SCI-NUM-SIM",		"Communications in Nonlinear Science and Numerical Simulation")
    define("j-COMM-NONLIN-SCI-NUM-SIM",		"Comm. Nonlin. Sci. Numer Sim.")
    define("j-COMM-NONLIN-SCI-NUM-SIM",		"Comm. Nonlin. Sci. Numer Simul.")
    define("j-COMM-NONLIN-SCI-NUM-SIM",		"Comm. Nonlin. Sci. Num. Simul.")
    define("j-COMM-NONLIN-SCI-NUM-SIM",		"Commun. Nonlin. Sci. Num. Sim.")
    define("j-COMM-NONLIN-SCI-NUM-SIM",		"Comm. Nonlin. Sci. Num. Sim.")

    define("j-COMM-NUMER-METHODS-ENGRG",	"Communications in Numerical Methods in Engineering")
    define("j-COMM-NUMER-METHODS-ENGRG",	"Comm. Numer. Methods Engrg.")

    define("j-COMM-PURE-APPL-MATH",		"Communications on Pure and Applied Mathematics (New York)")
    define("j-COMM-PURE-APPL-MATH",		"Communications on Pure and Applied Mathematics")
    define("j-COMM-PURE-APPL-MATH",		"Comm. Pure Appl. Math.")
    define("j-COMM-PURE-APPL-MATH",		"Commun. Pure \\& Appl. Math.")

    define("j-COMM-THEOR-PHYS",			"Communications in theoretical physics")

    define("j-COMMENT-MATH-HELV",		"Commentarii Mathematici Helvetici (Zurich)")
    define("j-COMMENT-MATH-HELV",		"Commentarii Mathematici Helvetici")
    define("j-COMMENT-MATH-HELV",		"Comment. Math. Helvetici")
    define("j-COMMENT-MATH-HELV",		"Comment. Math. Helv.")

    define("j-COMMENT-MATH-UNIV-CAROLINEA",	"Commentationes Mathematicae Universitatis Carolinea")

    define("j-COMMENT-PONTIF-ACAD-SCI",		"Commentarii --- Pontificia Academia Scientiarum")
    define("j-COMMENT-PONTIF-ACAD-SCI",		"Comment. - Pontif. Acad. Sci.")
    define("j-COMMENT-PONTIF-ACAD-SCI",		"Pontificia Academia Scientia, Commentarii")
    define("j-COMMENT-PONTIF-ACAD-SCI",		"Pontif. Acad. Sci., Comment.")

    define("j-COMMENTS-AT-MOL-PHYS",		"Comments on Atomic and Molecular Physics")
    define("j-COMMENTS-AT-MOL-PHYS",		"Comments At. Mol. Phys.")

    # v1 n1 Jan. 1967-v22 n4 Feb. 1998? (Gordon & Breach Science Publishers)
    define("j-COMMENTS-NUCL-PART-PHYS",		"Comments on Nuclear and Particle Physics")
    define("j-COMMENTS-NUCL-PART-PHYS",		"Comm. Nucl. Part. Phys")
    define("j-COMMENTS-NUCL-PART-PHYS",		"Comments Nucl. Part. Phys.")

    define("j-COMMENTS-THEOR-BIOL",		"Comments on modern biology. Part C, Comments on theoretical biology")
    define("j-COMMENTS-THEOR-BIOL",		"Comments theor. biol.")
    define("j-COMMENTS-THEOR-BIOL",		"Comments on theoretical biology")
    define("j-COMMENTS-THEOR-BIOL",		"Comm. on Theor. Biol.")

    define("j-COMMON-CAUSE",			"Common Cause")
    define("j-COMMON-CAUSE-MAGAZINE",		"Common Cause Magazine")

    define("j-COMMUN-ALGEBRA",			"Communications in Algebra")
    define("j-COMMUN-ALGEBRA",			"Commun. Algebra")
    define("j-COMMUN-ALGEBRA",			"Comm. Algebra")

    define("j-COMMUN-APPL-MATH-COMPUT-SCI",	"Communications in Applied Mathematics and Computational Science")
    define("j-COMMUN-APPL-MATH-COMPUT-SCI",	"Commun. Appl. Math. Comput. Sci.")

    define("j-COMMUN-BOOKNOTES-Q",		"Communication Booknotes Quarterly")
    define("j-COMMUN-BOOKNOTES-Q",		"Communication Booknotes Quarterly: CBQ")
    define("j-COMMUN-BOOKNOTES-Q",		"CBQ")
    define("j-COMMUN-BOOKNOTES-Q",		"Commun. Booknotes Q.")

    define("j-COMMUN-COMPUT-PHYS",		"Communications in Computational Physics")
    define("j-COMMUN-COMPUT-PHYS",		"Commun. Comput. Phys.")

    define("j-COMMUN-CONTEMP-MATH",		"Communications in Contemporary Mathematics")
    define("j-COMMUN-CONTEMP-MATH",		"Commun. Contemp. Math.")

    define("j-COMMUN-DESIGN-Q-REVIEW",		"Communication Design Quarterly Review")
    define("j-COMMUN-DESIGN-Q-REVIEW",		"Communication Design Quarterly")
    define("j-COMMUN-DESIGN-Q-REVIEW",		"Comm. Design. Q. Rev.")
    define("j-COMMUN-DESIGN-Q-REVIEW",		"Commun. Design. Q. Rev.")
    define("j-COMMUN-DESIGN-Q-REVIEW",		"Commun. Design Q. Review")

    define("j-COMMUN-INF-SYST",			"Communications in Information and Systems")
    define("j-COMMUN-INF-SYST",			"Commun. Inf. Syst.")

    define("j-COMMUN-KOREAN-MATH-SOC",		"Communications of the Korean Mathematical Society")
    define("j-COMMUN-KOREAN-MATH-SOC",		"Korean Mathematical Society. Communications")
    define("j-COMMUN-KOREAN-MATH-SOC",		"Commun. Korean Math. Soc.")

    define("j-COMMUN-MATH-PHYS",		"Communications in Mathematical Physics")
    define("j-COMMUN-MATH-PHYS",		"Comm. Math Phys.")
    define("j-COMMUN-MATH-PHYS",		"Commun. Math. Phys.")

    define("j-COMMUN-MATH-SCI",			"Communications in Mathematical Sciences")
    define("j-COMMUN-MATH-SCI",			"Comm. Math. Sci.")
    define("j-COMMUN-MATH-SCI",			"Commun. Math. Sci.")

    define("j-COMMUN-MATH-STAT",		"Communications in Mathematics and Statistics")
    define("j-COMMUN-MATH-STAT",		"Comm. Math. Stat.")
    define("j-COMMUN-MATH-STAT",		"Comm. Math. Stat.")
    define("j-COMMUN-MATH-STAT",		"Comm. Math. Statist.")
    define("j-COMMUN-MATH-STAT",		"Commun. Math. Stat.")
    define("j-COMMUN-MATH-STAT",		"Commun. Math. Statist.")
    define("j-COMMUN-MATH-STAT",		"Commun. Math. Stat.")

    define("j-COMMUN-NEWS",			"Communications news (Geneva, IL)")
    define("j-COMMUN-NEWS",			"Communications news")
    define("j-COMMUN-NEWS",			"Commun. news")

    define("j-COMMUN-Q",			"Communication Quarterly")
    define("j-COMMUN-Q",			"Comm. Q.")
    define("j-COMMUN-Q",			"Commun. Q.")

    define("j-COMMUN-STAT",			"Communications in Statistics")
    define("j-COMMUN-STAT",			"Commun. Statist.")
    define("j-COMMUN-STAT",			"Commun. Stat.")

    define("j-COMMUN-STAT-SIMUL-COMPUT",	"Communications in Statistics: Simulation and Computation")
    define("j-COMMUN-STAT-SIMUL-COMPUT",	"Communications in Statistics - Simulation and Computation")
    define("j-COMMUN-STAT-SIMUL-COMPUT",	"Communications in Statistics, Part B -- Simulation and Computation")
    define("j-COMMUN-STAT-SIMUL-COMPUT",	"Communications in Statistics. Simulation and Computation")
    define("j-COMMUN-STAT-SIMUL-COMPUT",	"Commun. stat., Simul. comput.")
    define("j-COMMUN-STAT-SIMUL-COMPUT",	"Commun. Statist.-Simula. Computa.")
    define("j-COMMUN-STAT-SIMUL-COMPUT",	"Comm. stat., Simul. comput.")
    define("j-COMMUN-STAT-SIMUL-COMPUT",	"Commun. stat., Simul. comput.")

    define("j-COMMUN-STAT-THEORY-METH",		"Communications in Statistics. Theory and Methods")
    define("j-COMMUN-STAT-THEORY-METH",		"Communications in Statistics: Theory and Methods")
    define("j-COMMUN-STAT-THEORY-METH",		"Comm. Statist. Theory Methods")
    define("j-COMMUN-STAT-THEORY-METH",		"Comm. Statist. Theory Methods")
    define("j-COMMUN-STAT-THEORY-METH",		"Commun. Statis., Theory Methods")
    define("j-COMMUN-STAT-THEORY-METH",		"Commun. Stat., Theory Methods")
    define("j-COMMUN-STAT-THEORY-METH",		"Commun. Stat. Theory Meth.")

    define("j-COMMUNICATION-ARTS",		"Communication arts")

    define("j-COMP-APPLIC-BIOSCI",		"Computer Applications in the Biosciences: CABIOS")
    define("j-COMP-APPLIC-BIOSCI",		"Computer Applications in the Biosciences: CABI")
    define("j-COMP-ARCH-NEWS",			"ACM SIGARCH Computer Architecture News")

    define("j-COMP-ART-INTELL",			"Computers and Artificial Intelligence = Vychislitel'nye mashiny i iskusstvennyi intellekt")
    define("j-COMP-ART-INTELL",			"Computers and Artificial Intelligence")
    define("j-COMP-ART-INTELL",			"Comput. Artif. Intell")

    define("j-COMP-AUTO",			"Computers and Automation")

    define("j-COMP-AUTO-PEOPLE",		"Computers and Automation and People")
    define("j-COMP-AUTO-PEOPLE",		"Comput. autom. people")

    define("j-COMP-BIOCHEM-PHYSIOL",		"Comparative biochemistry and physiology")
    define("j-COMP-BIOCHEM-PHYSIOL",		"Comp. Biochem. Physiol.")

    define("j-COMP-BIOCHEM-PHYSIOL-B",		"Comparative biochemistry and physiology. B, Comparative biochemistry")
    define("j-COMP-BIOCHEM-PHYSIOL-B",		"Comp. biochem. physiol., B. Comp. biochem.")
    define("j-COMP-BIOCHEM-PHYSIOL-B",		"Comp Biochem Physiol [B] (DNV)")

    define("j-COMP-CHEM-ENG",			"Computers \\& Chemical Engineering")
    define("j-COMP-CHEM-ENG",			"Comput. Chem. Engng.")

    define("j-COMP-CIVIL-ENG",			"Journal of Computing in Civil Engineering")
    define("j-COMP-COMM",			"Computer Communications")

    define("j-COMP-COMM-REV",			"Computer Communication Review")
    define("j-COMP-COMM-REV",			"Comput. commun. rev.")
    define("j-COMP-COMM-REV",			"ACM SIGCOMM newsletter")

    define("j-COMP-CONTROL-ENG-J",		"Computing and Control Engineering Journal")
    define("j-COMP-DESIGN",			"Computer Design")
    define("j-COMP-ECONOMICS",			"Computational Economics")

    define("j-COMP-ECONOMICS-REP",              "Computer Economics Report (International Edition)")

    define("j-COMP-EDU",			"Computers and Education")
    define("j-COMP-EDU",			"Comput. Educ.")

    define("j-COMP-EDU-J",			"Computers in education journal")
    define("j-COMP-EDU-J",			"Comput. Educ. J.")

    define("j-COMP-FLUIDS",			"Computers and Fluids")
    define("j-COMP-FLUIDS",			"Computers \\& Fluids")
    define("j-COMP-FLUIDS",			"Computers \\& Fluids. An International Journal")
    define("j-COMP-FLUIDS",			"Comput. \\& Fluids")

    define("j-COMP-FRAUD-SECURITY-BULL",	"Computer fraud and security bulletin")
    define("j-COMP-GEOLOGY",			"Computers and Geology")

    define("j-COMP-GEOM",			"Computational Geometry. Theory and Applications")
    define("j-COMP-GEOM",			"Computational Geometry")
    define("j-COMP-GEOM",			"Comput. Geom.")

    define("j-COMP-GEOSCI",			"Computers and Geosciences")
    define("j-COMP-GEOSCI",			"Computers and Geoscience")
    define("j-COMP-GEOSCI",			"Comput. and Geosci.")
    define("j-COMP-GEOSCI",			"Comput. Geosci.")
    define("j-COMP-GEOSCI",			"Comput. and Geosc.")

    define("j-COMP-GRAPHICS",			"Computer Graphics")
    define("j-COMP-GRAPHICS",			"Computer Graphics (ACM)")
    define("j-COMP-GRAPHICS",			"Comput Graph (ACM)")
    define("j-COMP-GRAPHICS",			"ACM Computer Graphics")
    define("j-COMP-GRAPHICS",			"ACM Computer Graphics Special Issue")
    define("j-COMP-GRAPHICS",			"ACM SIG{\\-}GRAPH\\emdash Com{\\-}puter Graphics")

    define("j-COMP-GRAPHICS-PROC",		"Computer Graphics Proceedings Annual Conference Series")
    define("j-COMP-GRAPHICS-PROC",		"Comput. graph. proc. annu. conf. ser.")

    define("j-COMP-HUM",			"Computers and the Humanities")
    define("j-COMP-HUM",			"Comput. Hum.")
    define("j-COMP-INDUSTRY",			"Computers in industry")

    define("j-COMP-J",				"The Computer Journal")
    define("j-COMP-J",				"Computer Journal")
    define("j-COMP-J",				"Comput. J.")
    define("j-COMP-J",				"Computer J.")
    define("j-COMP-J",				"The (British) Computer Journal")
    define("j-COMP-J",				"Comp. Journ.")

    define("j-COMP-LANG-MAG",			"Computer Language Magazine")
    define("j-COMP-LANG-MAG",			"Computer Language")

    define("j-COMP-LANGS",			"Computer Languages")

    define("j-COMP-LANGS-SYS-STRUCT",		"Computer Languages, Systems and Structures")
    define("j-COMP-LANGS-SYS-STRUCT",		"Comp. Lang. Sys. Struct.")

    define("j-COMP-LAW-J",			"Computer/Law Journal")
    define("j-COMP-LAW-SECURITY-REP",		"The Computer Law and Security Report")
    define("j-COMP-LAWYER",			"The Computer Lawyer")
    define("j-COMP-LIB",			"Computers in Libraries")
    define("j-COMP-LING",			"Computational Linguistics")

    define("j-COMP-MATH",			"Computational Mathematics")
    define("j-COMP-MATH",			"Computational Math.")

    define("j-COMP-MATH-APP",			"Computers in Mathematical Applications")


#    define("j-COMP-MATH-APPL",			"Computers and Mathematics with Applications")
#    define("j-COMP-MATH-APPL",			"Computers and Mathematics and Applications")
#    define("j-COMP-MATH-APPL",			"Computers and Mathematics with Applications (Oxford, England)")
#    define("j-COMP-MATH-APPL",			"Computers and Mathematics and Applications (Oxford, England)")
#    define("j-COMP-MATH-APPL",			"Comp. and Maths. with Appls (Oxford, England)")
#    define("j-COMP-MATH-APPL",			"Comp. and Maths. with Appls.")
#    define("j-COMP-MATH-APPL",			"Comput. Math. Appl.")
#    define("j-COMP-MATH-APPL",			"Comput. Math. Applic.")
#    define("j-COMP-MATH-APPL",			"Computers Math. Applic.")
#
#    define("j-COMP-MATH-APPL-A",		"Computers and Mathematics with Applications. Part A")
#    define("j-COMP-MATH-APPL-A",		"Computers and Mathematics and Applications. Part A")
#    define("j-COMP-MATH-APPL-A",		"Comp. and Maths. with Appls. Part A")
#
#    define("j-COMP-MATH-APPL-B",		"Computers and Mathematics with Applications. Part B")
#    define("j-COMP-MATH-APPL-B",		"Computers and Mathematics and Applications. Part B")
#    define("j-COMP-MATH-APPL-B",		"Comp. and Maths. with Appls. Part B")
#    define("j-COMP-MATH-APPL-B",		"Comput. Math. Appl., Part B")

    define("j-COMP-MATH-SCI-TEACHING",		"Journal of Computers in Mathematics and Science Teaching")

    define("j-COMP-MUSIC-J",			"Computer Music Journal")

    define("j-COMP-NET",			"Computer Networks")
    define("j-COMP-NET",			"Computer Networks: The International Journal of Distributed Informatique")
    define("j-COMP-NET",			"Comput. netw.")

    define("j-COMP-NET-ISDN",			"Computer Networks and ISDN Systems")
    define("j-COMP-NET-ISDN",			"Comput. netw. ISDN syst.")
    define("j-COMP-NET-ISDN",			"Computer Networks and ISDN Systems: the intern")
    define("j-COMP-NET-ISDN",			"Comput. Netw. ISDN Syst. (Netherlands), Computer Networks and ISDN Systems")

    define("j-COMP-NET-AMSTERDAM",		"Computer Networks (Amsterdam, Netherlands: 1999)")

    define("j-COMP-OP-RES",			"Computers and Operations Research")
    define("j-COMP-OP-RES",			"Comput. Oper. Res.")
    define("j-COMP-OP-RES",			"Comput. \\& Ops. Res.")
    define("j-COMP-OP-RES",			"Comput. \\& OR")
    define("j-COMP-OP-RES",			"Computers \\& OR")
    define("j-COMP-OP-RES",			"Computers Opns. Res.")

    define("j-COMP-OPTIM-APPL",			"Computational optimization and applications")
    define("j-COMP-OPTIM-APPL",			"Comput. Optim. Appl.")

    define("j-COMP-PERSONNEL",			"Computer personnel")

    define("j-COMP-PHYS-COMM",			"Computer Physics Communications")
    define("j-COMP-PHYS-COMM",			"Comput. Phys. Commun.")
    define("j-COMP-PHYS-COMM",			"Comput. Phys. Comm")
    define("j-COMP-PHYS-COMM",			"Comp. Phys. Commun.")
    define("j-COMP-PHYS-COMM",			"Comp. Phys. Comm.")

    # define("j-COMP-PHYSICS",			"Computers in Physics")
    # define("j-COMP-PHYSICS",			"Comput. Physics")

    define("j-COMP-PHYSIOL-C",			"Comparative biochemistry and physiology. Part C, Pharmacology, toxicology \\& endocrinology")
    define("j-COMP-PICTURES",			"Computer Pictures")
    define("j-COMP-RESELLER-NEWS",		"Computer Reseller News")
    define("j-COMP-RETAIL-WEEK",		"Computer Retail Week")

    define("j-COMP-REV",			"Computing Reviews")
    define("j-COMP-REV",			"Comput. Rev.")
    define("j-COMP-REV",			"Comp. Rev.")

    define("j-COMP-SCI-INFO",			"Computer Science and Informatics")

    define("j-COMP-SCI-REV",			"Computer Science Review")
    define("j-COMP-SCI-REV",			"Comp. Sci. Rev.")

    define("j-COMP-SCI-SCI-COMP",		"Computer Science and Scientific Computing")
    define("j-COMP-SCI-SCI-COMP",		"Computer Science and Scientific Comp.")

    define("j-COMP-SPEECH-LANG",		"Computer Speech and Language")
    define("j-COMP-SPEECH-PROC",		"Computer Speech Processing")

    define("j-COMP-STANDARDS-INTERFACES",	"Computer Standards and Interfaces")
    define("j-COMP-STANDARDS-INTERFACES",	"Computer Standards & Interfaces")
    define("j-COMP-STANDARDS-INTERFACES",	"Comp. Stand. Interfaces")

    define("j-COMP-STAT",			"Computational Statistics")
    define("j-COMP-STAT",			"Comput. Statist.")
    define("j-COMP-STAT",			"Comput. Stat.")
    define("j-COMP-STAT",			"Comp. Stat.")

    ## DUPLICATE: define("j-COMP-STAT-DATA-ANA",		"Computational Statistics and Data Analysis")
    ## DUPLICATE: define("j-COMP-STAT-DATA-ANAL",		"Computational statistics \\& data analysis")
    ## DUPLICATE: define("j-COMP-STAT-DATA-ANAL",		"Computational statistics and data analysis")
    ## DUPLICATE: define("j-COMP-STAT-DATA-ANAL",		"Comput. stat. data anal.")

    define("j-COMP-STRUCTURES",			"Computers and Structures")
    define("j-COMP-STRUCTURES",			"Comput. Struct.")
    define("j-COMP-STRUCTURES",			"Comput. \\& Structures")

    define("j-COMP-SURV",			"ACM Computing Surveys")
    define("j-COMP-SURV",			"ACM Comput. Surveys")
    define("j-COMP-SURV",			"Computing Surveys")

    define("j-COMP-SYS",			"Computing Systems")
    define("j-COMP-SYS",			"Computing systems: the journal of the USENIX Association")
    define("j-COMP-SYS",			"Computing systems: the journal of the USENIX A")

    define("j-COMP-SYS-NEWS",			"Computer Systems News")

    # [03-Feb-1999]: j-COMP-SYS-SCI-ENG replaced by j-COMPUT-SYST-SCI-ENG
    # define("j-COMP-SYS-SCI-ENG",		"Computer Systems Science and Engineering")

    define("j-COMP-TECH-REV",			"Computer Technology Review")

    # see j-CVGIP
    # define("j-COMP-VIS-GRAPHICS-IMG-PROC",	"Computer Vision, Graphics, and Image Processing")

    define("j-COMP-VIS-IMAGE-UNDERSTANDING",	"Computer Vision and Image Understanding: CVIU")
    define("j-COMP-VIS-IMAGE-UNDERSTANDING",	"CVIU: Computer Vision and Image Understanding")

    define("j-COMPCON-SPRING89",		"Digest of Papers of COMPCON Spring `89")
    define("j-COMPLEX-SYSTEMS",			"Complex Systems")

    define("j-COMPLEX-VAR-ELLIPTIC-EQU",	"Complex Variables and Elliptic Equations")
    define("j-COMPLEX-VAR-ELLIPTIC-EQU",	"Complex Var. Elliptic Equ.")

    define("j-COMPLEX-VARIABLES-THEORY-APPL",	"Complex Variables, Theory and Application")
    define("j-COMPLEX-VARIABLES-THEORY-APPL",	"Complex Variables Theory Appl.")

    define("j-COMPLEXITY",			"Complexity")
    define("j-COMPOS-ENG",			"Composites engineering")

    define("j-COMPOS-MATH",			"Compositio Mathematica")
    define("j-COMPOS-MATH",			"Compositio Math.")
    define("j-COMPOS-MATH",			"Compositio Mathmatica")
    define("j-COMPOS-MATH",			"Compos. Math.")

    define("j-COMPOS-SCI-TECH",			"Composites Science and Technology")
    define("j-COMPOS-SCI-TECH",			"Compos. Sci. Tech.")

    define("j-COMPOS-STRUCT",			"Composite Structures")

    define("j-COMPUT-ACOUSTICS",		"Journal of Computational Acoustics")
    define("j-COMPUT-ACOUSTICS",		"Journal of Computational Acoustics. An IMACS Journal")
    define("j-COMPUT-ACOUSTICS",		"J. Comput. Acoust.")

    define("j-COMPUT-AIDED-CIVIL-INFRASTRUCT-ENG",	"Computer-Aided Civil and Infrastructure Engineering")
    define("j-COMPUT-AIDED-CIVIL-INFRASTRUCT-ENG",	"Comput.-Aided Civil Infrastruct. Eng.")

    define("j-COMPUT-AIDED-DES",		"Computer-Aided Design")
    define("j-COMPUT-AIDED-DES",		"Comput. Aided Des.")

    define("j-COMPUT-AIDED-ENG",		"Computer-aided engineering: CAE")
    define("j-COMPUT-AIDED-ENG",		"Comput. aided eng.")

    ## NB: j-COMPUT-AND-BIOMED-RES and j-COMPUT-BIOMED-RES are
    ## DIFFERENT, but both published by Academic Press:
    ##     Computers and biomedical research 1967--2000
    ##     Computers in biomedical research  Vol. 1(1965)-Vol. 4 (1974)
    ## The former is succeeded by Journal of Biomedical Informatics.
    define("j-COMPUT-AND-BIOMED-RES",		"Computers and Biomedical Research")
    define("j-COMPUT-AND-BIOMED-RES",		"Computer and Biomedical Research")
    define("j-COMPUT-AND-BIOMED-RES",		"Comput. and Biomed. Res. (USA)")

    define("j-COMPUT-ANIM-VIRTUAL-WORLDS",	"Computer Animation and Virtual Worlds")
    define("j-COMPUT-ANIM-VIRTUAL-WORLDS",	"Comput. Anim. Virtual Worlds")

    define("j-COMPUT-APPL-ENG-EDUC",		"Computer Applications in Engineering Education")
    define("j-COMPUT-APPL-ENG-EDUC",		"Comput. appl. eng. educ.")

    define("j-COMPUT-BIOL-MED",			"Computers in Biology and Medicine")
    define("j-COMPUT-BIOL-MED",			"Comput. Biol. Med.")
    define("j-COMPUT-BIOL-MED",			"Comput Biol Med (DOC)")

    ## NB: j-COMPUT-AND-BIOMED-RES and j-COMPUT-BIOMED-RES are
    ## DIFFERENT, but both published by Academic Press:
    ##     Computers and biomedical research 1967--2000
    ##     Computers in biomedical research  Vol. 1(1965)-Vol. 4 (1974)
    ## The former is succeeded by Journal of Biomedical Informatics.
    define("j-COMPUT-BIOMED-RES",		"Computers in Biomedical Research")
    define("j-COMPUT-BIOMED-RES",		"Comput. biomed. res.")
    define("j-COMPUT-BIOMED-RES",		"Comput Biomed Res (DOF)")

    define("j-COMPUT-BULL",			"The Computer Bulletin")
    define("j-COMPUT-BULL",			"Computer Bulletin")
    define("j-COMPUT-BULL",			"Comput. Bull.")

    define("j-COMPUT-CARDIOL",			"Computers in cardiology")
    define("j-COMPUT-CARDIOL",			"Comput. cardiol.")

    define("j-COMPUT-CHEM",			"Computers and Chemistry")

    define("j-COMPUT-CHEM-INSTRUM",		"Computers in Chemistry and Instrumentation")
    define("j-COMPUT-CHEM-INSTRUM",		"Comput. Chem. Instrum.")

    define("j-COMPUT-COMPLEX",			"Computational complexity")
    define("j-COMPUT-COMPLEX",			"Comput. complex.")

    define("j-COMPUT-DECIS",			"Computer decisions (Teaneck, NJ: 1988)")
    define("j-COMPUT-DECIS",			"Computer decisions")
    define("j-COMPUT-DECIS",			"Comput. decis. (1988)")

    define("j-COMPUT-EDGE",			"Computing Edge")
    define("j-COMPUT-EDGE",			"Comput. Edge")

    define("j-COMPUT-ELECTRON-AGRIC",		"Computers and Electronics in Agriculture")
    define("j-COMPUT-ELECTRON-AGRIC",		"Comput. Electron. Agric.")

    define("j-COMPUT-ELECTR-ENG",		"Computers and Electrical Engineering")
    define("j-COMPUT-ELECTR-ENG",		"Comput. Electr. Eng.")

    define("j-COMPUT-GEOSCI",			"Computational Geosciences")
    define("j-COMPUT-GEOSCI",			"Comput. Geosci.")

    define("j-COMPUT-HUM-BEHAV",		"Computers in Human Behavior")
    define("j-COMPUT-HUM-BEHAV",		"Comput. hum. behav.")

    define("j-COMPUT-IND-ENG",			"Computers \\& industrial engineering")
    define("j-COMPUT-IND-ENG",			"Comput. Ind. Eng.")

    define("j-COMPUT-INTELL",			"Computational Intelligence")
    define("j-COMPUT-INTELL",			"Computational Intelligence = Intelligence informatique")
    define("j-COMPUT-INTELL",			"Comput. Intell.")

    define("j-COMPUT-MATER-SCI",		"Computational Materials Science")
    define("j-COMPUT-MATER-SCI",		"Comput. Mater. Sci.")

    define("j-COMPUT-MATH-APPL",		"Computers and Mathematics with Applications")
    define("j-COMPUT-MATH-APPL",		"Computers and Mathematics and Applications")
    define("j-COMPUT-MATH-APPL",		"Computers and Mathematics with Applications (Oxford, England)")
    define("j-COMPUT-MATH-APPL",		"Computers and Mathematics and Applications (Oxford, England)")
    define("j-COMPUT-MATH-APPL",		"Comp. and Maths. with Appls (Oxford, England)")
    define("j-COMPUT-MATH-APPL",		"Comp. and Maths. with Appls.")
    define("j-COMPUT-MATH-APPL",		"Comput. Math. Appl.")
    define("j-COMPUT-MATH-APPL",		"Comput. Math. Applic.")
    define("j-COMPUT-MATH-APPL",		"Computers Math. Applic.")

    define("j-COMPUT-MATH-APPL-A",		"Computers and Mathematics with Applications. Part A")
    define("j-COMPUT-MATH-APPL-A",		"Computers and Mathematics and Applications. Part A")
    define("j-COMPUT-MATH-APPL-A",		"Comp. and Maths. with Appls. Part A")

    define("j-COMPUT-MATH-APPL-B",		"Computers and Mathematics with Applications. Part B")
    define("j-COMPUT-MATH-APPL-B",		"Computers and Mathematics and Applications. Part B")
    define("j-COMPUT-MATH-APPL-B",		"Comp. and Maths. with Appls. Part B")
    define("j-COMPUT-MATH-APPL-B",		"Comput. Math. Appl., Part B")

    define("j-COMPUT-MATH-MATH-PHYS",		"Computational Mathematics and Mathematical Physics")
    define("j-COMPUT-MATH-MATH-PHYS",		"Comp. Math. Math. Phys.")
    define("j-COMPUT-MATH-MATH-PHYS",		"Comput. Math. Math. Phys.")

    define("j-COMPUT-MECH",			"Computational mechanics")
    define("j-COMPUT-MECH",			"Comput. mech.")
    define("j-COMPUT-MECH",			"Comp. Mechanics")

    define("j-COMPUT-METH-APPL-MATH",		"Computational Methods in Applied Mathematics")
    define("j-COMPUT-METH-APPL-MATH",		"Comput. Methods Appl. Math.")

    define("j-COMPUT-METH-APPL-MECH-ENG",	"Computer Methods in Applied Mechanics and Engineering")
    define("j-COMPUT-METH-APPL-MECH-ENG",	"Comp. Meth. Appl. Mech. Engr.")
    define("j-COMPUT-METH-APPL-MECH-ENG",	"Comp. Methods in Appl. Mech. and Engrg.")
    define("j-COMPUT-METH-APPL-MECH-ENG",	"Comput. Meth. Appl. Mech. Engin.")
    define("j-COMPUT-METH-APPL-MECH-ENG",	"Comput. Methods in Appl. Mech. Eng.")
    define("j-COMPUT-METH-APPL-MECH-ENG",	"Comput. Methods in Appl. Mech. Engrg.")
    define("j-COMPUT-METH-APPL-MECH-ENG",	"Comput. methods appl. mech. eng.")
    define("j-COMPUT-METH-APPL-MECH-ENG",	"Comput. Methods Appl. Mech. Engrg.")
    define("j-COMPUT-METH-APPL-MECH-ENG",	"Comp. Meth. Appl. Mech. Engng")
    define("j-COMPUT-METH-APPL-MECH-ENG",	"Comp. Meth. Appl. Mech. Engnrg.")
    define("j-COMPUT-METH-APPL-MECH-ENG",	"Comp. Meth. Appl. Mechs. Engrg")
    define("j-COMPUT-METH-APPL-MECH-ENG",	"Comp. Meths. Appl. Mech. Engrg.")

    define("j-COMPUT-METH-FUNCT-THEORY",	"Computational Methods and Function Theory")
    define("j-COMPUT-METH-FUNCT-THEORY",	"Comput. Methods Funct. Theory")

    define("j-COMPUT-METH-PROG-BIOMED",		"Computer Methods and Programs in Biomedicine")
    define("j-COMPUT-METH-PROG-BIOMED",		"Comp. Methods Programs Biomed.")
    define("j-COMPUT-METH-PROG-BIOMED",		"Comput Methods Programs Biomed (DOH)")

    ## Published v1 n1 Nov./Dec. 1987-v12 n6 Nov./Dec. 1998: replaced by j-COMPUT-SCI-ENG
    define("j-COMPUT-PHYS",			"Computers in Physics")
    define("j-COMPUT-PHYS",			"Comput. Physics")
    define("j-COMPUT-PHYS",			"Comput. Phys.")

    define("j-COMPUT-PHYS-REP",			"Computer Physics Reports")
    define("j-COMPUT-PHYS-REP",			"Comput. phys. rep.")
    define("j-COMPUT-PHYS-REP",			"Computer Physics Rep")
    define("j-COMPUT-PHYS-REP",			"Comp. Phys. Rep.")

    define("j-COMPUT-PROGRAMS-BIOMED",		"Computer Programs in Biomedicine")
    define("j-COMPUT-PROGRAMS-BIOMED",		"Comput. programs biomed.")
    define("j-COMPUT-PROGRAMS-BIOMED",		"Comput Programs Biomed (DOI)")

    define("j-COMPUT-RES-NEWS",			"Computing Research News: the News Journal of the Computing Research Association")
    define("j-COMPUT-RES-NEWS",			"Computing Research News")
    define("j-COMPUT-RES-NEWS",			"Comput. Res. News")

    define("j-COMPUT-SCH",			"Computers in the schools")
    define("j-COMPUT-SCH",			"Comput. sch.")

    define("j-COMPUT-SCI-ECON-MANAG",		"Computer Science in Economics and Management")
    define("j-COMPUT-SCI-ECON-MANAG",		"Comput. sci. econ. manag.")

    define("j-COMPUT-SCI-ENG",			"Computing in Science and Engineering")
    define("j-COMPUT-SCI-ENG",			"Computing in Science & Engineering")
    define("j-COMPUT-SCI-ENG",			"Comput. Sci. Eng.")
    define("j-COMPUT-SCI-ENG",			"Computing in Science {\\&} Engineering [see also IEEE Computational Science and Engineering]")

    define("j-COMPUT-SECUR",			"Computers and Security")
    define("j-COMPUT-SECUR",			"Computers \\& Security")
    define("j-COMPUT-SECUR",			"Computers & Security")
    define("j-COMPUT-SECUR",			"Comput. secur.")

    define("j-COMPUT-SECUR-J",			"Computer Security Journal")
    define("j-COMPUT-SECUR-J",			"Comput. secur. j")

    define("j-COMPUT-SOFTW-BIG-SCI",		"Computing and Software for Big Science")
    define("j-COMPUT-SOFTW-BIG-SCI",		"Comput. Softw. Big Sci.")

    define("j-COMPUT-STAND",			"Computers and Standards")
    define("j-COMPUT-STAND",			"Comp. Stand.")
    define("j-COMPUT-STAND",			"Comput. Stand.")

    define("j-COMPUT-STAT-Q",			"Computational Statistics Quarterly")
    define("j-COMPUT-STAT-Q",			"CSQ---Comput. Statist. Quart.")
    define("j-COMPUT-STAT-Q",			"Comput. stat. q.")
    define("j-COMPUT-STAT-Q",			"CSQ, Comput. stat. q.")

    define("j-COMPUT-STAT-DATA-ANAL",		"Computational Statistics \\& Data Analysis")
    define("j-COMPUT-STAT-DATA-ANAL",		"Computational Statistics and Data Analysis")
    define("j-COMPUT-STAT-DATA-ANAL",		"Computational statistics and data analysis")
    define("j-COMPUT-STAT-DATA-ANAL",		"Comput. statist. data anal.")
    define("j-COMPUT-STAT-DATA-ANAL",		"Comput. stat. data anal.")

    define("j-COMPUT-SUPPORTED-COOP-WORK",	"Computer Supported Cooperative Work [CSCW]")

    define("j-COMPUT-SYST-ENG",			"Computing systems in engineering: an international journal")
    define("j-COMPUT-SYST-ENG",			"Computing Systems in Engineering")
    define("j-COMPUT-SYST-ENG",			"Comput. syst. eng.")
    define("j-COMPUT-SYST-ENG",			"Comp. Syst. Engr.")

    define("j-COMPUT-SYST-SCI-ENG",		"Computer Systems Science and Engineering")
    define("j-COMPUT-SYST-SCI-ENG",		"Computer systems science \\& engineering")
    define("j-COMPUT-SYST-SCI-ENG",		"Comput. syst. sci. eng.")

    define("j-COMPUT-TEACH",			"Computing Teacher")
    define("j-COMPUT-TEACH",			"Comput. Teach.")

    # Former Title(s):	Journal of Molecular Structure: THEOCHEM
    define("j-COMPUT-THEOR-CHEM",		"Computational \\& Theoretical Chemistry")
    define("j-COMPUT-THEOR-CHEM",		"Comput. Theor. Chem.")

    define("j-COMPUT-VIS-SCI",			"Computing and Visualization in Science")
    define("j-COMPUT-VIS-SCI",			"Comput. Vis. Sci.")

    define("j-COMPUTABILITY",			"Computability")

    define("j-COMPUTE",				"Compute")

    define("j-COMPUTER",			"Computer")
    define("j-COMPUTER",			"IEEE Computer")

    define("j-COMPUTER-PROC-CHINESE-ORIENTAL-LANG",	"Computer Processing of Chinese and Oriental Languages")
    define("j-COMPUTER-PROC-CHINESE-ORIENTAL-LANG",	"Computer Processing of Chinese and Oriental Languages: an international journal of the Chinese Language Computer Society")

    define("j-COMPUTER-SHOPPER",		"Computer Shopper")

    define("j-COMPUTERS-AND-GRAPHICS",		"Computers and Graphics")
    define("j-COMPUTERS-AND-GRAPHICS",		"Computers \\& Graphics (Pergamon)")

    define("j-COMPUTERWOCHE",			"Computerwoche")

    define("j-COMPUTERWORLD",			"ComputerWorld")
    define("j-COMPUTERWORLD",			"Computerworld")

    define("j-COMPUTING",			"Computing: Archiv f{\\\"u}r informatik und numerik")
    define("j-COMPUTING",			"Computing: Archiv fur informatik und numerik")
    define("j-COMPUTING",			"Computing")

    define("j-COMPUTING-SUPPLEMENTUM",		"Computing. Supplementum")
    define("j-COMPUTING-SUPPLEMENTUM",		"Computing (Suppl.)")
    define("j-COMPUTING-SUPPLEMENTUM",		"Computing, Suppl.")

    define("j-COMUN-ESTAD",			"Comunicaciones en Estad{\\'\\i}stica")
    define("j-COMUN-ESTAD",			"Comun. Estad.")

    define("j-CONCEPTS-NEUROSCI",		"Concepts in Neuroscience")
    define("j-CONCEPTS-NEUROSCI",		"Concepts Neurosci.")

    define("j-CONF-LOCAL-COMPUT-NETW",		"Conference on Local Computer Networks")
    define("j-CONF-LOCAL-COMPUT-NETW",		"Conf. Local Comput. Netw.")

    define("j-CONFIGURATIONS",			"Configurations: a Journal of Literature, Science, and Technology")
    define("j-CONFIGURATIONS",			"Configurations")

    define("j-CONG-NUM",			"Congressus Numerantium")
    define("j-CONG-NUM",			"Congr. numer.")

    define("j-CONGR-Q-WKLY-REP",		"Congressional quarterly weekly report")
    define("j-CONGR-Q-WKLY-REP",		"Congr. q. wkly. rep.")
    define("j-CONGR-Q-WKLY-REP",		"CQ weekly report")

    define("j-CONN-LAW-REVIEW",			"Connecticut Law Review")
    define("j-CONN-LAW-REVIEW",			"Conn. law rev.")

    define("j-CONSERV-BIOL",			"Conservation Biology: the Journal of the Society for Conservation Biology")
    define("j-CONSERV-BIOL",			"Conservation Biology")
    define("j-CONSERV-BIOL",			"Conserv. Biol")

    define("j-CONSPECTUS",                      "Conspectus")

    define("j-CONST-APPROX",			"Constructive Approximation")
    define("j-CONST-APPROX",			"Constr. Approx.")

    define("j-CONTACT-CONTEXT",			"Contact in context")

    define("j-CONTEMP-BR-HIST",			"Contemporary British History")
    define("j-CONTEMP-BR-HIST",			"Contemp. Br. Hist.")

    define("j-CONTEMP-MATH",			"Contemporary mathematics (American Mathematical Society)")
    define("j-CONTEMP-MATH",			"AMS Contemp. Math.")
    define("j-CONTEMP-MATH",			"Contemporary mathematics")
    define("j-CONTEMP-MATH",			"Contemp. math.")

    define("j-CONTEMP-PHYS",			"Contemporary Physics")
    define("j-CONTEMP-PHYS",			"Contemp. Phys.")

    define("j-CONTEMP-SOCIOL",			"Contemporary Sociology --- a Journal of Reviews")
    define("j-CONTEMP-SOCIOL",			"Contemporary Sociology")
    define("j-CONTEMP-SOCIOL",			"Contemp. Sociol.")

    define("j-CONTIN-MECH-THERMODYN",		"Continuum mechanics and thermodynamics")
    define("j-CONTIN-MECH-THERMODYN",		"Contin. mech. thermodyn.")
    define("j-CONTIN-MECH-THERMODYN",		"Continuum Mech. and Thermodyn.")
    define("j-CONTIN-MECH-THERMODYN",		"Continuum Mech. Thermodyn.")
    define("j-CONTIN-MECH-THERMODYN",		"Continuum Mech. and Thermodyn.")

    define("j-CONTRACT-DES",			"Contract design")
    define("j-CONTRACT-DES",			"Contract des.")

    define("j-CONTROL-CYBERN",			"Control and cybernetics")
    define("j-CONTROL-CYBERN",			"Control cybern.")
    define("j-CONTROL-CYBERN",			"Control Cybernet.")

    define("j-CONTROL-ENG",			"Control Engineering")

    define("j-CONTROL-ENG-PRACT",		"Control Engineering Practice")
    define("j-CONTROL-ENG-PRACT",		"Control Eng. Pract.")

    define("j-CONTROLLED-CLIN-TRIALS",		"Controlled Clinical Trials")
    define("j-CONTROLLED-CLIN-TRIALS",		"Controlled Clin. Trials")

    define("j-CORMOSEA-BULL",			"CORMOSEA bulletin")
    define("j-CORMOSEA-BULL",			"CORMOSEA bull.")

    define("j-CORNELL-ENG",			"Cornell Engineer")
    define("j-CORNELL-ENG",			"Cornell Eng.")

    define("j-CORNELL-REV",			"Cornell Review")
    define("j-CORNELL-REV",			"Cornell Rev.")

    define("j-CPE",				"Concurrency, practice and experience")
    define("j-CPE",				"Conc. pract. exp.")

    define("j-C-PLUS-PLUS-REPORT",		"C++ Report")

    define("j-CPSR",				"CPSR (Computer Professionals for Social Responsibility) Newsletter")
    define("j-CPSR",				"CPSR Newsletter")

    define("j-CQ-RES",				"Congressional quarterly researcher")
    define("j-CQ-RES",				"CQ res.")

    # Is this Comptes Rendus de l'Acad{\'e}mie des Sciences??
    define("j-CRAS",				"C.R.A.S.")

    define("j-CRAY-CHANNELS",			"CRAY Channels")

    define("j-CREAT-COMPUT",			"Creative Computing")
    define("j-CREAT-COMPUT",			"Creat. Comput.")
    define("j-CREAT-COMPUT",			"Creative Comput")

    define("j-CRC-CRIT-REV-BIOCHEM",		"CRC critical reviews in biochemistry")
    define("j-CRC-CRIT-REV-BIOCHEM",		"CRC crit. rev. biochem.")

    define("j-CRC-CRIT-REV-BIOMED-ENG",		"CRC critical reviews in biomedical engineering")
    define("j-CRC-CRIT-REV-BIOMED-ENG",		"CRC Crit. rev. biomed. eng.")
    define("j-CRC-CRIT-REV-BIOMED-ENG",		"Crit. rev. biomed. eng.")

    define("j-CRIT-CARE-MED",			"Critical Care Medicine")
    define("j-CRIT-CARE-MED",			"Crit. Care Med.")

    define("j-CRIT-REV-MICROBIOL",		"Critical Reviews in Microbiology")
    define("j-CRIT-REV-MICROBIOL",		"Crit. rev. microbiol.")

    define("j-CRITICA-MEXICO",			"Cr{\\'\\i}tica: Revista Hispanoamericana de Filosof{\\'\\i}a")
    define("j-CRITICA-MEXICO",			"Cr{\\'\\i}tica (M{\\'e}xico")

    define("j-CROAT-CHEM-ACTA",			"Croatica Chemica Acta")
    define("j-CROAT-CHEM-ACTA",			"Croat. Chem. Acta")

    define("j-CROSSROADS",			"ACM Crossroads")
    define("j-CROSSROADS",			"Crossroads")
    define("j-CROSSROADS",			"Crossroads (Assoc. Comput. Mach., Print)")
    define("j-CROSSROADS",			"ACM Crossroads Magazine")

    define("j-CRYPTOBYTES",			"CryptoBytes")

    define("j-CRYPTOGR-COMMUN",			"Cryptography and Communications")
    define("j-CRYPTOGR-COMMUN",			"Cryptography and Communications: Discrete Structures, Boolean Functions and Sequences")
    define("j-CRYPTOGR-COMMUN",			"Cryptogr. Commun.")

    define("j-CRYPTOLOGIA",			"Cryptologia")

    define("j-CRYST-LATTICE-DEFECTS",		"Crystal Lattice Defects")
    define("j-CRYST-LATTICE-DEFECTS",		"Cryst. Lattice Defects")

    define("j-CRYST-RES-TECHNOL",		"Crystal Research and Technology")
    define("j-CRYST-RES-TECHNOL",		"Cryst Res. Tech.")
    define("j-CRYST-RES-TECHNOL",		"Cryst Res. Technol.")

    define("j-CRYSTAL-GROWTH",			"Crystal Growth")
    define("j-CSGD",				"Curves and Surfaces in Geometric Design")

    define("j-CSSP",				"Circuits, systems, and signal processing: {CSSP}")
    define("j-CSSP",				"Circuits, systems, and signal processing")

    define("j-CT",				"C T: Magazin f{\\\"u}r Computer Technik (Hannover)")
    define("j-CT",				"c't")

    define("j-CUJ",				"C Users Journal")

    define("j-CURR-BIOL",			"Current biology")
    define("j-CURR-BIOL",			"Curr. biol.")
    define("j-CURR-BIOL",			"Curr Biol (B44)")

    define("j-CURR-CONTENTS-PHYS-CHEM-EARTH-SCI", "Current Contents: Physical, Chemical \\& Earth Sciences")
    define("j-CURR-CONTENTS-PHYS-CHEM-EARTH-SCI", "Curr. contents, Phys. chem. earth sci.")

    define("j-CURR-CONTENTS-ENG-TECH-APPL-SCI",	"Current contents. Engineering, technology \\& applied sciences")
    define("j-CURR-CONTENTS-ENG-TECH-APPL-SCI",	"Curr. contents, Eng. tech. appl. sci.")

    define("j-CURR-GEN",			"Current genetics")
    define("j-CURR-GEN",			"Curr Genet (CUG)")

    define("j-CURR-MICROBIOL",			"Current microbiology")
    define("j-CURR-MICROBIOL",			"Curr Microbiol (BMW)")

    define("j-CURR-OPIN-BIOTECH",		"Current opinion in biotechnology")
    define("j-CURR-OPIN-BIOTECH",		"Curr Opin Biotechnol (A92)")

    define("j-CURR-OPIN-CELL-BIOL",		"Curr Opin Cell Biol (AOE)")
    define("j-CURR-OPIN-CELL-BIOL",		"Curr. Opin. Cell Biol.")
    define("j-CURR-OPIN-GENET-DEV",		"Curr Opin Genet Dev (BJC)")

    define("j-CURR-OPIN-HEMATOL",		"Current opinion in hematology")
    define("j-CURR-OPIN-HEMATOL",		"Curr. opin. hematol.")

    define("j-CURR-OPIN-IMMUNOL",		"Curr Opin Immunol (AH1)")

    define("j-CURR-SCI",			"Current Science")
    define("j-CURR-SCI",			"Current Sci.")

    define("j-CURR-TOP-CELL-REGUL",		"Current topics in cellular regulation")
    define("j-CURR-TOP-CELL-REGUL",		"Curr. top. cell. regul.")
    define("j-CURR-TOP-CELL-REGUL",		"Curr Top Cell Regul (DWM)")
    define("j-CURR-TOP-CELL-REGUL",		"Curr. Topics Cell. Reg.")

    define("j-CURR-TOP-DEV-BIOL",		"Current topics in developmental biology")
    define("j-CURR-TOP-DEV-BIOL",		"Curr. Top. Dev. Biol.")
    define("j-CURR-TOP-DEV-BIOL",		"Curr Top Dev Biol (DWN)")

    define("j-CURR-TOPICS-MEMBRANES-TRANSPORT",	"Current Topics in Membranes and Transport")
    define("j-CURR-TOPICS-MEMBRANES-TRANSPORT",	"Curr. Topics Membranes Transport")
    define("j-CURR-TOPICS-MEMBRANES-TRANSPORT",	"Curr. Topics Membranes and Transport")

    # CVGIP: 1983--1990, CVGIP-GMIP: 1991--1994, CVGIP-IU: 1991--1994 (defunct from 1995??)

    define("j-CVGIP",				"Computer Vision, Graphics, and Image Processing")
    define("j-CVGIP",				"Computer Vision, Graphics and Image Processing (CVGIP)")
    define("j-CVGIP",				"CVGIP")

    define("j-CVGIP-GMIP",			"Computer Vision, Graphics, and Image Processing. Graphical models and Image Processing")
    define("j-CVGIP-GMIP",			"CVGIP. Graphical models and image processing")

    define("j-CVGIP-IU",			"Computer Vision, Graphics, and Image Processing. Image Understanding")
    define("j-CVGIP-IU",			"CVGIP. Image Understanding")

    define("j-CWI-QUARTERLY",			"CWI Quarterly")
    define("j-CYBER",				"Cybernetics")

    define("j-CYBERNETICS-SYSTEMS",		"Cybernetics and Systems")
    define("j-CYBERNETICS-SYSTEMS",		"Cybernetics and Systems: An International Journal")

    define("j-CYTOBIOLOGIE",			"Cytobiologie")

    define("j-CYTOLOGIA",			"Cytologia: international journal of cytology")
    define("j-CYTOLOGIA",			"Cytologia")

    define("j-CYTOMETRY",			"Cytometry")
    define("j-CYTOMETRY",			"Cytometry (D92)")

    define("j-CZECH-J-PHYS",			"Czechoslovak Journal of Physics")
    define("j-CZECH-J-PHYS",			"Czechoslov. J. Phys.")
    define("j-CZECH-J-PHYS",			"Czech. J. Phys.")

    define("j-CZECH-MATH-J",			"Czechoslovak mathematical journal = Chekhoslovatskii matematicheskii zhurnal")
    define("j-CZECH-MATH-J",			"Czechoslovak Math. J.")
    define("j-CZECH-MATH-J",			"Czech. Math. J.")

    define("j-D-LIB-MAGAZINE",			"D-Lib magazine: the magazine of the Digital Library Forum")
    define("j-D-LIB-MAGAZINE",			"D-Lib magazine")

    define("j-DAEDALUS",			"D{\\ae}dalus")
    define("j-DAEDALUS",			"Daedalus")
    define("j-DAEDALUS",			"Daedalus: proceedings of the American Academy of Arts and Sciences")
    define("j-DAEDALUS",			"Daedalus (Boston)")
    define("j-DAEDALUS",			"Daedalus (Cambridge)")

    define("j-DANCE-TEACHER-NOW",               "Dance teacher now")
    define("j-DATA-COMMUNICATIONS",		"Data communications")
    define("j-DATA-HANDLING-SCI-TECH",		"Data handling in science and technology")

    define("j-DATA-KNOWLEDGE-ENG",		"Data and Knowledge Engineering")
    define("j-DATA-KNOWLEDGE-ENG",		"Data \\& Knowledge Engineering")

    define("j-DATA-PROCESS",			"Data Processing")
    define("j-DATA-PROCESS",			"Data Proc.")
    define("j-DATA-PROCESS",			"Data Process.")

    define("j-DATABASE",			"Database")

    define("j-DATABASE-DIRECTORY",		"Database Directory: the buyer's guide to database products and services")
    define("j-DATABASE-DIRECTORY",		"Database Directory")

    define("j-DATABASES-J",                     "Databases Journal")
    define("j-DATAMATION",			"Datamation")

    define("j-DBMS",				"DBMS")
    define("j-DBMS",				"DBMS: client/server computing")
    define("j-DBMS",				"DBMS: client\\slash server computing")

    define("j-DDDU",				"Dr. Dobb's Developer Update")

    define("j-DDJ",				"Dr. Dobb's Journal of Software Tools")
    define("j-DDJ",				"Dr. Dobb's journal of software tools for the pro")
    define("j-DDJ",				"Dr. Dobb's Journal")
    define("j-DDJ",				"Dr. Dobbs Journal")
    define("j-DDJ",				"Dr. Dobb's journal: software tools for the professional programmer")
    define("j-DDJ",				"Dr. Dobb's journal: software tools for the pro")
    define("j-DDJ",				"Dr. Dobb's Journal of Software Tools for Professional Programmer")
    define("j-DDJ",				"Doctor Dobbs Journal")

    define("j-DDJ-SOURCEBOOK",			"Dr. Dobb's Sourcebook")
    define("j-DDJ-SOURCEBOOK",			"Doctor Dobb's sourcebook")
    define("j-DDJ-SOURCEBOOK",			"Doctor Dobb's windows sourcebook")
    define("j-DDJ-SOURCEBOOK",			"Dr. Dobb's windows sourcebook")

    define("j-DEC-PROFESSIONAL",		"The DEC Professional")
    define("j-DEC-SUPP-SYS",			"Decision Support Systems")

    define("j-DEC-TECH-J",			"Digital Technical Journal")
    define("j-DEC-TECH-J",			"Digital Technical Journal of Digital Equipment Corporation")

    define("j-DEEP-SEA-RES-PART-2-TOP-STUD-OCEANOGR",	"Deep Sea Research Part II: Topical Studies in Oceanography")
    define("j-DEEP-SEA-RES-PART-2-TOP-STUD-OCEANOGR",	"Deep Sea Research II: Topical Studies in Oceanography")
    define("j-DEEP-SEA-RES-PART-2-TOP-STUD-OCEANOGR",	"Deep-sea Res., Part 2, Top. Stud. Oceanogr.")

    define("j-DELFT-PROG-REP",			"Delft progress report")
    define("j-DELFT-PROG-REP",			"Delft prog. rep.")
    define("j-DELFT-PROG-REP",			"Delft Progr. Rep.")

    define("j-DELTA-KAPPA-GAMMA-BULL",		"Delta Kappa Gamma bulletin")
    define("j-DELTA-KAPPA-GAMMA-BULL",		"Delta Kappa Gamma bull.")

    define("j-DEMOGRAPHY",			"Demography")

    define("j-DEMONSTRATIO-MATHEMATICA",	"Demonstratio Mathematica")

    define("j-DESIGN-NEWS",			"Design news")

    define("j-DESIGNS-CODES-CRYPTOGR",		"Designs, codes, and cryptography")
    define("j-DESIGNS-CODES-CRYPTOGR",		"Designs codes cryptogr.")
    define("j-DESIGNS-CODES-CRYPTOGR",		"Des. Codes Cryptogr.")

    define("j-DESKTOP-PUB-COMM",		"Desktop Publishing Commentary")
    define("j-DEUTSCH-MATH-V",			"Jber. Deutsch. Math.--Verein")

    define("j-DEV-CELL",			"Developmental Cell")
    define("j-DEV-CELL",			"Dev. Cell")

    define("j-DEV-DYNAMICS",                    "Developmental Dynamics")
    define("j-DEV-DYNAMICS",                    "Developmental Dynamics: An Official Publication of the American Association of Anatomists")
    define("j-DEV-DYNAMICS",			"Dev. Dynamics")

    define("j-DEVEL",				"Development")
    define("j-DEVEL",				"Development (ECW)")

    define("j-DEVEL-BIOL",			"Developmental Biology")
    define("j-DEVEL-BIOL",			"Dev Biol (E7T)")
    define("j-DEVEL-BIOL",			"Devel. Biol.")
    define("j-DEVEL-BIOL",			"Dev. Biol.")

    define("j-DEVEL-BIOL-N-Y",			"Dev Biol (N Y 1985) (AH9)")

    define("j-DEVEL-GENETICS",			"Developmental Genetics")
    define("j-DEVEL-GENETICS",			"Dev Genet (DEG)")
    define("j-DEVEL-GENETICS",			"Devel. Genetics")
    define("j-DEVEL-GENETICS",			"Dev. Gen.")

    define("j-DEVEL-GROWTH-DIFF",		"Development, growth and differentiation")

    define("j-DEVEL-SUPPL",			"Development. Supplement")
    define("j-DEVEL-SUPPL",			"Dev Suppl (A8Z)")

    define("j-DGOV",				"Digital Government: Research and Practice (DGOV)")
    define("j-DGOV",				"Digital Government: Research and Practice")
    define("j-DGOV",				"DGOV")

    define("j-DIABETOLOGIA",			"Diabetologia")

    define("j-DIALECTICA",			"Dialectica: International Review of Philosophy of Knowledge")
    define("j-DIALECTICA",			"Dialectica")

    define("j-DIALOGUE",			"Dialogue: Canadian Philosophical Review / Revue canadienne de philosophie")
    define("j-DIALOGUE",			"Dialogue: Can. Philos. Rev. / Rev. can. philo.")
    define("j-DIALOGUE",			"Dialogue")

    define("j-DIFF-EQ",				"Differential Equations")

    define("j-DIFFER-URAVN-MINSK-1965",		"Differencial'nye uravnenija (Minsk, 1965)")
    define("j-DIFFER-URAVN-MINSK-1965",		"Differ. uravn. (Minsk, 1965)")

    define("j-DIFFERENTIATION",			"Differentiation")
    define("j-DIFFERENTIATION",			"Differen.")
    define("j-DIFFERENTIATION",			"Differentiation (E99)")

    define("j-DIGEST-PAPERS-IEEE-SYMP-MASS-STOR-SYS","Digest of Papers --- IEEE Symposium on Mass Storage Systems")

    define("j-DIGITAL-AGE",			"Digital Age")
    define("j-DIGITAL-AGE",			"Digit. Age")

    define("j-DIGITAL-MEDIA",			"Digital Media")
    define("j-DIGITAL-NEWS-REVIEW",		"Digital News and Review")
    define("j-DIGITAL-REVIEW",			"Digital Review")
    define("j-DIGITAL-SYS-J",			"Digital systems journal")
    define("j-DIGITAL-SYS-REP",                 "Digital Systems Report")

    define("j-DIN-SPLOS-SREDY",			"Dinamika sploshnoi sredy")
    define("j-DIN-SPLOS-SREDY",			"Din. splos. sredy.")
    define("j-DIN-SPLOS-SREDY",			"Dinamika Sploshn. Sredy")

    define("j-DIPL-HIST",			"Diplomatic History")
    define("j-DIPL-HIST",			"Dipl. Hist.")

    define("j-DISCRETE-APPL-MATH",		"Discrete Applied Mathematics")
    define("j-DISCRETE-APPL-MATH",		"Discrete appl. math.")

    define("j-DISCRETE-COMPUT-GEOM",		"Discrete and Computational Geometry")
    define("j-DISCRETE-COMPUT-GEOM",		"Discr. Comput. Geom.")
    define("j-DISCRETE-COMPUT-GEOM",		"Disc. Comput. Geom.")
    define("j-DISCRETE-COMPUT-GEOM",		"Disc. Comp. Geom.")
    define("j-DISCRETE-COMPUT-GEOM",		"Discrete Comput. Geom.")

    define("j-DISCRETE-CONTIN-DYN-SYST",	"Discrete and Continuous Dynamical Systems. Series A")
    define("j-DISCRETE-CONTIN-DYN-SYST",	"Discr. Contin. Dyn. Syst.")
    define("j-DISCRETE-CONTIN-DYN-SYST",	"Discrete Contin. Dyn. Syst.")

    define("j-DISCRETE-DYN-NAT-SOC",		"Discrete Dynamics in Nature and Society")
    define("j-DISCRETE-DYN-NAT-SOC",		"Discrete Dyn. Nat. Soc.")

    define("j-DISCRETE-MATH",			"Discrete Mathematics")
    define("j-DISCRETE-MATH",			"Discrete Math.")
    define("j-DISCRETE-MATH",			"Discrete Math")

    define("j-DISCRETE-MATH-APPL",		"Discrete Mathematics and Applications")
    define("j-DISCRETE-MATH-APPL",		"Discrete Math. Appl.")

    define("j-DISCRETE-MATH-THEOR-COMPUT-SCI",	"Discrete Mathematics \\& Theoretical Computer Science")
    define("j-DISCRETE-MATH-THEOR-COMPUT-SCI",	"Discrete Math. Theor. Comput. Sci.")
    define("j-DISCRETE-MATH-THEOR-COMPUT-SCI",	"DMTCS")

    define("j-DISTRIB-COMPUT",			"Distributed Computing")
    define("j-DISTRIB-COMPUT",			"Distrib. comput.")

    define("j-DISTRIBUTION",			"Distribution")

    define("j-DLT",				"Distributed Ledger Technologies: Research and Practice (DLT)")
    define("j-DLT",				"Distributed Ledger Technologies: Research and Practice")
    define("j-DLT",				"Distributed Ledger Technologies (DLT)")
    define("j-DLT",				"Distributed Ledger Technologies")
    define("j-DLT",				"Distrib. Ledger Technol.")

    define("j-DNA",				"DNA (EAW)")
    define("j-DNA-CELL-BIOL",			"DNA Cell Biol (AF9)")
    define("j-DNA-SEQ",				"DNA Seq (A9H)")

    define("j-DOC-MATH",			"Documenta mathematica")
    define("j-DOC-MATH",			"Documenta mathematica : Journal der Deutschen Mathematiker-Vereinigung")
    define("j-DOC-MATH",			"Doc. math.")

    define("j-DOCUMENTALISTE-SCI-INFO",		"Documentaliste -- Sciences de l'Information")

    # Which section of this journal...there are many
    define("j-DOKL-AKAD-NAUK",			"Doklady Akademii nauk SSSR")
    define("j-DOKL-AKAD-NAUK",			"Dokladi Akad. Nauk SSSR")
    define("j-DOKL-AKAD-NAUK",			"Dokl. Akad. Nauk SSSR")
    define("j-DOKL-AKAD-NAUK",			"Dokl. Akad. Nauk")
    define("j-DOKL-AKAD-NAUK",			"Doklady RAN")
    define("j-DOKL-AKAD-NAUK",			"Doklady Akad. Nauk. SSSR")

    define("j-DOKL-MATH",			"Doklady Mathematics")
    define("j-DOKL-MATH",			"Dokl. Math.")

    define("j-DOOPS",				"Doopsgezinde Bijdragen (Amsterdam)")
    define("j-DOOPS",				"Doopsgezinde Bijdragen")

    define("j-DRUG-DISCOVERY-TODAY",		"Drug Discovery Today")

    define("j-DTRAP",				"Digital Threats: Research and Practice (DTRAP)")
    define("j-DTRAP",				"Digital Threats: Research and Practice")
    define("j-DTRAP",				"DTRAP")

    define("j-DUKE-MATH-J",			"Duke Mathematical Journal")
    define("j-DUKE-MATH-J",			"Duke Math. J.")

    define("j-DYN-CONTIN-DISCR-IMPULS-B",	"Dynamics of Continuous, Discrete \\& Impulsive Systems. Series B. Applications \\& Algorithms")
    define("j-DYN-CONTIN-DISCR-IMPULS-B",	"Dyn. Contin. Discrete Impuls. Syst. Ser. B Appl. Algorithms")

    define("j-DYNAMICS-CONTROL",		"Dynamics Control")

    define("j-EARTH-SURF-PROCESSES",		"Earth Surface Processes")
    define("j-EARTH-SURF-PROCESSES",		"Earth Surf. Processes")

    define("j-EARTH-SURF-PROCESSES-LANDFORMS",	"Earth Surface Processes and Landforms")
    define("j-EARTH-SURF-PROCESSES-LANDFORMS",	"Earth Surf. Processes Landforms")

    define("j-EARTHQUAKE-ENG-STRUCT-DYN",	"Earthquake engineering \\& structural dynamics")
    define("j-EARTHQUAKE-ENG-STRUCT-DYN",	"Earthquake engineering and structural dynamics")
    define("j-EARTHQUAKE-ENG-STRUCT-DYN",	"Earthquake engng. struct. dyn.")
    define("j-EARTHQUAKE-ENG-STRUCT-DYN",	"Earthquake eng. struct. dyn.")

    define("j-ECOL-MODELL",			"Ecological Modelling")
    define("j-ECOL-MODELL",			"Ecological Modelling: International Journal on Ecological Modelling and Systems Ecology")
    define("j-ECOL-MODELL",			"Ecol. modell.")

    define("j-ECOL-MONOGR",			"Ecological monographs")
    define("j-ECOL-MONOGR",			"Ecol. monogr.")

    define("j-ECOLOGY",				"Ecology")

    define("j-ECON-GEOL",			"Economic Geology and the Bulletin of the Society of Economic Geologists")
    define("j-ECON-GEOL",			"Economic Geology")
    define("j-ECON-GEOL",			"Econ. geol.")

    # Renamed to Stochastics and Quality Control (ISSN 2367-2404): when??
    define("j-ECON-QUAL-CONTROL",		"Economic Quality Control")
    define("j-ECON-QUAL-CONTROL",		"Econ. Qual. Control")

    define("j-ECONOM-J",			"The Econometrics Journal")
    define("j-ECONOM-J",			"Econometrics Journal")
    define("j-ECONOM-J",			"Econom. J.")

    define("j-ECONOM-LETT",			"Economics Letters")
    define("j-ECONOM-LETT",			"Econom. Lett.")
    define("j-ECONOM-LETT",			"Econ. Lett.")

    define("j-ECONOM-STAT",			"Econometrics and Statistics")
    define("j-ECONOM-STAT",			"Econom. Stat.")

    define("j-ECONOMIST",			"The Economist")
    define("j-ECONOMIST",			"Economist (London, England: 1843)")
    define("j-ECONOMIST",			"Economist (Lond.)")

    define("j-ECONOMETRICA",			"Econometrica")

    define("j-ED-PUBL",				"Editor \\& publisher")
    define("j-ED-PUBL",				"Ed. publ.")

    define("j-EDN",				"EDN")
    define("j-EDPACS",                          "EDPACS")

    define("j-EDU-CHEM",			"Education in Chemistry")
    define("j-EDU-CHEM",			"Edu. Chem.")

    define("j-EDU-PSYCH-MEASUREMENT",		"Educational and Psychological Measurement")

    define("j-EDU-TRAINING-TECH",		"Educational and Training Technology International")
    define("j-EDU-TRAINING-TECH",		"Educational \\& Training Technology International: ETTI")

    define("j-ELECT-COMM-ENG-J",		"Electronics and Communication Engineering Journal")
    define("j-ELECT-COMM-ENG-J",		"Electronics \\& Communication Engineering Journal")

    define("j-EDUC-STUD-MATH",			"Educational Studies in Mathematics")
    define("j-EDUC-STUD-MATH",			"Educ. Stud. Math.")

    define("j-EDUCOM-REV",			"Educom Review")
    define("j-EDUCOM-REV",			"Educom Rev.")

    define("j-ELECT-COMM-JAPAN-3-FUND-ELECT-SCI",	"Electronics and communications in Japan. Part 3, Fundamental electronic science")
    define("j-ELECT-COMM-JAPAN-3-FUND-ELECT-SCI",	"Electronics and communications in Japan. Part 3")
    define("j-ELECT-COMM-JAPAN-3-FUND-ELECT-SCI",	"Electron. Comm. Japan Part III Fund. Electron. Sci.")
    define("j-ELECT-COMM-JAPAN-3-FUND-ELECT-SCI",	"Electron. commun. Jpn., Part 3 Fundam. electron. sci.")
    define("j-ELECT-COMM-JAPAN-3-FUND-ELECT-SCI",	"Electron. commun. Jpn., Part 3")

    define("j-ELECT-COMPOSITION-IMAGING",	"Electronic Composition and Imaging")

    define("j-ELECT-J-COMB",			"Electronic Journal of Combinatorics")
    define("j-ELECT-J-COMB",			"Electron. J. Combin.")
    define("j-ELECT-J-COMB",			"Electr. J. Comb.")

    define("j-ELECT-LETTERS",			"Electronics Letters")
    define("j-ELECT-LETTERS",			"Electron. Lett.")
    define("j-ELECT-LETTERS",			"Electron. Lett.")

    define("j-ELECT-NOTES-THEOR-COMP-SCI",	"Electronic Notes in Theoretical Computer Science")
    define("j-ELECT-NOTES-THEOR-COMP-SCI",	"Elect. Notes. Theor. Comp. Sci.")

    define("j-ELECT-STUDIES",			"Electoral Studies")
    define("j-ELECT-STUDIES",			"Elect. Studies")

    define("j-ELECTR-COMMUN",			"Electrical Communication")
    define("j-ELECTR-COMMUN",			"Electr. commun.")

    define("j-ELECTR-ENG",			"Electrical Engineering (American Institute of Electrical Engineers)")
    define("j-ELECTR-ENG",			"Electrical Engineering (Am. Inst. Electr. Eng.)")
    define("j-ELECTR-ENG",			"Electrical Engineering")
    define("j-ELECTR-ENG",			"Electr. Eng. (Am. Inst. Electr. Eng.)")
    define("j-ELECTR-ENG",			"Electr. Eng.")

    define("j-ELECTR-REV",			"The Electrical Review (London)")
    define("j-ELECTR-REV",			"The Electrical Review")
    define("j-ELECTR-REV",			"Electr. Rev.")

    define("j-ELECTRICIAN",			"The Electrician: the Oldest Weekly Illustrated Journal of Electrical Engineering, Industry, Science and Finance")
    define("j-ELECTRICIAN",			"The Electrician")
    define("j-ELECTRICIAN",			"Electrician")

    define("j-ELECTRO",				"Electro conference record")
    define("j-ELECTRO",				"Electro")

    define("j-ELECTROMAGNETICS",		"Electromagnetics")

    define("j-ELECTRON-COMMUN-JPN",		"Electronics and communications in Japan")
    define("j-ELECTRON-COMMUN-JPN",		"lectronics \\& communications in Japan")
    define("j-ELECTRON-COMMUN-JPN",		"Electron. commun. Jpn.")
    define("j-ELECTRON-COMMUN-JPN",		"Electron. Comm. Japan")

    define("j-ELECTRON-COMMUN-JPN-PART-1-COMMUN",	"Electronics and Communications in Japan (Part I: Communications)")
    define("j-ELECTRON-COMMUN-JPN-PART-1-COMMUN",	"Electron. Commun. Jpn., Part 1, Commun.")

    define("j-ELECTRON-COMMUN-PROBAB",		"Electronic Communications in Probability")
    define("j-ELECTRON-COMMUN-PROBAB",		"Electron. Comm. Probab.")
    define("j-ELECTRON-COMMUN-PROBAB",		"Electron. Commun. Probab.")

    define("j-ELECTRON-ENG",			"Electronic Engineering")
    define("j-ELECTRON-ENG",			"Electron. Eng.")

    define("j-ELECTRON-J-BOUND-ELEM",		"Electronic Journal of Boundary Elements")
    define("j-ELECTRON-J-BOUND-ELEM",		"Electron. J. Bound. Elem.")

    define("j-ELECTRON-J-LINEAR-ALGEBRA",	"Electronic Journal of Linear Algebra")
    define("j-ELECTRON-J-LINEAR-ALGEBRA",	"Electron. J. Lin. Alg.")
    define("j-ELECTRON-J-LINEAR-ALGEBRA",	"Electron. J. Linear Algebra")

    define("j-ELECTRON-J-PROBAB",		"Electronic Journal of Probability")
    define("j-ELECTRON-J-PROBAB",		"Electron. J. Prob.")
    define("j-ELECTRON-J-PROBAB",		"Electron. J. Probab.")

    define("j-ELECTRON-J-THEOR-PHYS",		"Electronic Journal of Theoretical Physics")
    define("j-ELECTRON-J-THEOR-PHYS",		"Elect. J. Theor. Phys.")
    define("j-ELECTRON-J-THEOR-PHYS",		"Electron. J. Theor. Phys.")

    define("j-ELECTRON-MICROSC-REV",		"Electron Microsc Rev (A55)")

    define("j-ELECTRON-POWER",			"Electronics and power")
    define("j-ELECTRON-POWER",			"Electron. + power")
    define("j-ELECTRON-POWER",			"Electronics and power: the journal of the Institution of Electrical Engineers")

    define("j-ELECTRON-TRANS-NUMER-ANAL",	"Electronic Transactions on Numerical Analysis")
    define("j-ELECTRON-TRANS-NUMER-ANAL",	"Electron. Trans. Numer. Anal.")

    define("j-ELECTRONIC-DESIGN",		"Electronic Design")
    define("j-ELECTRONIC-ENG-TIMES",		"Electronic engineering times")
    define("j-ELECTRONIC-LEARNING",		"Electronic Learning")

    define("j-ELECTRONIC-LIBRARY",		"Electronic Library")
    define("j-ELECTRONIC-LIBRARY",		"The Electronic library: the international journal for minicomputer, microcomputer, and software applications in libraries")
    define("j-ELECTRONIC-LIBRARY",		"The Electronic library: the international jour")

    define("j-ELECTRONIC-MUSICIAN",		"Electronic Musician")
    define("j-ELECTRONIC-PRODUCTS",		"Electronic Products")
    define("j-ELECTRONICS",			"Electronics")

    define("j-ELECTRONICS-WORLD-WIRELESS-WORLD","Electronics world + wireless world")
    define("j-ELECTRONICS-WORLD-WIRELESS-WORLD","Electronics world \\& wireless world")

    define("j-ELECTRONIK",			"Elektronik")
    define("j-ELECTRONIK",			"Elektronik (Germany)")

    define("j-ELECTROPHORESIS",			"Electrophoresis")
    define("j-ELECTROPHORESIS",			"Electrophoresis (ELE)")

    define("j-ELEK-INFO-KYBER",			"Elektronische Informationsverarbeitung und Kybernetik (EIK)")
    define("j-ELEK-INFO-KYBER",			"Elektronische Informationsverarbeitung und Kybernetik")
    define("j-ELEK-INFO-KYBER",			"Elektron. Inform. verarb. Kybernet. EIK")

    define("j-ELEK-RECHENANLAGEN",		"Elektronische Rechenanlagen")
    define("j-ELEK-RECHENANLAGEN",		"El. Rechenanlagen")
    define("j-ELEK-RECHENANLAGEN",		"Elektron. Rechenanl.")
    define("j-ELEK-RECHENANLAGEN",		"Elektron. Rechenanlagen")

    define("j-ELEKTRONIKER",			"Elektroniker (Switzerland)")
    define("j-ELEKTRONIKER",			"Elektroniker (Schweiz)")
    define("j-ELEKTRONIKER",			"Elektroniker")

    define("j-ELEM-MATH",			"Elemente der Mathematik")
    define("j-ELEM-MATH",			"Elem. Math.")

    define("j-ELEMENTA-TMFK",			"Elementa: tidskrift for matematik, fysik och kemi")

    define("j-ELET-IRODALOM",			"{\\'E}let {\\'e}s Irodalom [Life and Literature]")
    define("j-ELET-IRODALOM",			"{\\'E}let {\\'e}s Irodalom")
    define("j-ELET-IRODALOM",			"{\\'E}let Irodalom")

    define("j-ELET-TUDOMANY",			"{\\'E}let {\\'e}s Tudom{\\'a}ny [{Life} and Science]")
    define("j-ELET-TUDOMANY",			"{\\'E}let {\\'e}s Tudom{\\'a}ny")
    define("j-ELET-TUDOMANY",			"{\\'E}let Tudom{\\'a}ny")

    define("j-ELETTRONICA-OGGI",                "Elettronica Oggi")
    define("j-ELETTROTECNICA",			"Elettrotecnica")
    define("j-EMBED-SYS-PROG",			"Embedded Systems Programming")
    define("j-EMBEDDED-LINUX-J",		"Embedded Linux Journal")
    define("j-EMBO-J",				"The EMBO journal")
    define("j-EMBO-J",				"EMBO J.")
    define("j-EMBO-J",				"EMBO\\ J.")
    define("j-EMBO-J",				"EMBO Jour.")
    define("j-EMBO-J",				"EMBO J (EMB)")

    define("j-EMORY-LAW",			"Emory Law Journal")

    define("j-EMPIR-SOFTWARE-ENG",		"Empirical Software Engineering")
    define("j-EMPIR-SOFTWARE-ENG",		"Empir. Soft. Eng.")
    define("j-EMPIR-SOFTWARE-ENG",		"Empir. Software Eng.")

    define("j-EMPIRICA",			"Empirica")

    define("j-ENCYCL-LIB-INFO-SCI",		"Encyclopedia of Library and Information Science")
    define("j-ENDEAVOUR",			"Endeavour")

    define("j-ENDOCRINE",			"Endocrine")

    define("j-ENDOCRINOL",			"Endocrinology")
    define("j-ENDOCRINOL",			"Endocrinol.")

    define("j-ENERGY-RES",			"Energy Research")
    define("j-ENERGY-RES",			"Energy Res.")

    define("j-ENERGY-TECHNOL-REV",		"Energy and technology review")
    define("j-ENERGY-TECHNOL-REV",		"Energy technol. rev.")

    define("j-ENEWS",				"Electronic News")
    define("j-ENEWS",				"Electron. News")

    define("j-ENG-ANAL-BOUND-ELEM",		"Engineering Analysis with Boundary Elements")
    define("j-ENG-ANAL-BOUND-ELEM",		"Eng. Anal. Bound. Elem.")

    define("j-ENG-AUTOMATION",			"Engineering and Automation")
    define("j-ENG-COMP",			"Engineering Computations")
    define("j-ENG-COMP",			"Engineering Computations (Swansea, Wales)")

    define("j-ENG-COMPUT",			"Engineering with Computers")
    define("j-ENG-COMPUT",			"Engineering with Computers (New York)")
    define("j-ENG-COMPUT",			"Eng. Comput.")

    define("j-ENG-CORNELL-Q",			"Engineering: Cornell Quarterly")

    define("j-ENG-DESIGN-GRAPHICS-J",		"Engineering Design Graphics Journal")
    define("j-ENG-FRACTURE-MECH",		"Engineering fracture mechanics")

    # Is this Engineering Materials (Tokyo) = Kogyo zairyo, 0452-2834, KZAIA5??
    define("j-ENG-MAT",				"Eng. Mat.")

    define("j-ENG-SCI",				"Engineering \\& Science, California Institute of Technology")
    define("j-ENG-SCI",				"Engineering \\& Science: E \\& S")
    define("j-ENG-SCI",				"California Institute of Technology Engineering \\& Science")
    define("j-ENG-SCI",				"Eng. Sci. (CalTech)")
    define("j-ENG-SCI",				"Eng. Sci.")

    define("j-ENG-SCI-REP-KYUSHU",		"Engineering Sciences Reports, Kyushu University")
    define("j-ENG-SCI-REP-KYUSHU",		"Engineering Sciences Reports, Kyushu University = Kyushu Daigaku Daigakuin Sogo Rikogaku Kenkyuka hokoku")
    define("j-ENG-SCI-REP-KYUSHU",		"Kyushu Daigaku Daigakuin Sogo Rikogaku Kenkyuka hokoku")

    define("j-ENG-TRANS",			"Engineering transactions")
    define("j-ENG-TRANS",			"Eng. trans.")
    define("j-ENG-TRANS",			"Rozpr. inz.")
    define("j-ENG-TRANS",			"Rozprawy inzynierskie / Zaklad Mechaniki Osrodkow Ciaglych Polskiej Akademii Nauk")
    define("j-ENG-TRANS",			"Rozprawy inzynierskie")

    define("j-ENGINEER",			"The Engineer")
    define("j-ENGINEER",			"Engineer (Lond.)")
    define("j-ENGINEER",			"Engineer (London)")

    define("j-ENGLISH-LANGUAGE-TEACHING",	"English Language Teaching")
    define("j-ENGLISH-LANGUAGE-TEACHING",	"English Langauge Teaching")

    define("j-ENSEIGN-MATH",			"L'Enseignement math{\\'e}matique")
    define("j-ENSEIGN-MATH",			"L'Enseignement mathematique")
    define("j-ENSEIGN-MATH",			"Enseign. math.")
    define("j-ENSEIGN-MATH",			"L'Enseignement Math. (2)")

    define("j-ENSEIGN-MATH-2",			"L'Enseignement Math{\\'e}matique. Revue Internationale. 2e S{\\'e}rie")
    define("j-ENSEIGN-MATH-2",			"Enseign. Math. (2)")

    define("j-ENTROPY",				"Entropy")

    define("j-ENV-POLLUTION",			"Environmental pollution")
    define("j-ENV-POLLUTION",			"Environ. pollut.")

    define("j-ENV-POLLUTION-A",			"Environmental pollution. Series A, Ecological and biological")
    define("j-ENV-POLLUTION-A",			"Environ. pollut., Ser. A, Ecol. biol.")

    define("j-ENV-SCI-TECH",			"Environmental science and technology")
    define("j-ENV-SCI-TECH",			"ES\\&T")
    define("j-ENV-SCI-TECH",			"Envir. Sci. Technol.")

    define("j-ENVIRON-HIST",			"Environmental History")
    define("j-ENVIRON-HIST",			"Env. Hist.")

    define("j-ENVIRON-MONIT-ASSESS",		"Environmental Monitoring and Assessment")
    define("j-ENVIRON-MONIT-ASSESS",		"Environ. Monit. Assess.")

    define("j-EPILEPSIA",			"Epilepsia")

    define("j-EPJ-APPL-PHYS",			"European Physical Journal. Applied Physics")
    define("j-EPJ-APPL-PHYS",			"EPJ, Applied Physics")
    define("j-EPJ-APPL-PHYS",			"EPJ. Appl. Phys.")

    define("j-EPODD",				"Electronic Pub\\-lish\\-ing\\emdash{}Orig\\-i\\-na\\-tion, Dissemination, and Design")
    define("j-EPODD",				"Electronic publishing")

    define("j-ERGEB-EXAKTEN-NATURWISS",		"Ergebnisse der exakten Naturwissenschaften")
    define("j-ERGEB-EXAKTEN-NATURWISS",		"Ergeb. exakten Naturwiss.")
    define("j-ERGEB-EXAKTEN-NATURWISS",		"Ergeb. exakt. Naturwiss.")
    define("j-ERGEB-EXAKTEN-NATURWISS",		"Ergebn. exakt. Naturwiss.")

    define("j-ERGEB-MATH-GRENZGEBIETE",		"Ergebnisse der Mathematik und ihrer Grenzgebiete")
    define("j-ERGEB-MATH-GRENZGEBIETE",		"Ergeb. Math. ihrer Grenzgebiete")
    define("j-ERGEB-MATH-GRENZGEBIETE",		"Ergebnisse der Mathematik")

    define("j-ERGOD-THEORY-DYN-SYST",		"Ergodic theory and dynamical systems")
    define("j-ERGOD-THEORY-DYN-SYST",		"Ergod. theory dyn. syst.")

    define("j-ERGONOMICS",			"Ergonomics")
    define("j-ERGONOMICS",			"Ergonomics: the official publication of the Ergonomics Research Society")

    define("j-ERKENNTNIS",			"Erkenntnis") # Erkenntnis = Knowledge

    define("j-ERKENNTNIS-1975",			"Erkenntnis (1975--)")

    define("j-ESAIM-PROBAB-STATIST",		"ESAIM: Probability and Statistics")
    define("j-ESAIM-PROBAB-STATIST",		"ESAIM: Probability and Statistics (ESAIM: P\\&S)")
    define("j-ESAIM-PROBAB-STATIST",		"ESAIM Probab. Stat.")

    define("j-ESSAYS-BIOCHEM",			"Essays in biochemistry")
    define("j-ESSAYS-BIOCHEM",			"Essays Biochem.")
    define("j-ESSAYS-BIOCHEM",			"Essays in Biochem.")

    define("j-ETT",				"European Transactions on Telecommunications: ETT")
    define("j-ETT",				"European Transactions on Telecommunications")
    define("j-ETT",				"Eur. trans. telecommun.")

    define("j-EUGEN-REV",			"Eugenics Review")
    define("j-EUGEN-REV",			"Eugen. Rev.")

    define("j-EULERIANA",			"Euleriana")		

    define("j-EUR-J-APPL-MATH",			"European journal of applied mathematics")
    define("j-EUR-J-APPL-MATH",			"Applied mathematics")
    define("j-EUR-J-APPL-MATH",			"Eur. J. Appl. Math.")
    define("j-EUR-J-APPL-MATH",			"European J. Appl. Math.")
    define("j-EUR-J-APPL-MATH",			"Euro. J. Appl. Math")

    define("j-EUR-J-BIOCHEM",			"European journal of biochemistry / FEBS")
    define("j-EUR-J-BIOCHEM",			"European journal of biochemistry")
    define("j-EUR-J-BIOCHEM",			"Eur J Biochem (EMZ)")
    define("j-EUR-J-BIOCHEM",			"Eur. J. Biochem.")
    define("j-EUR-J-BIOCHEM",			"Eur. J. Biochem. FEBs")

    define("j-EUR-J-CELL-BIOL",			"Eur J Cell Biol (EM7)")
    define("j-EUR-J-CLIN-CHEM-CLIN-BIOCHEM",	"European journal of clinical chemistry and clinical biochemistry: journal of the Forum of European Clinical Chemistry Societies")

    define("j-EUR-J-COMB",			"European Journal of Combinatorics")
    define("j-EUR-J-COMB",			"European journal of combinatorics = Journal europ{\\'e}en de combinatoire = Europ{\\\"a}ische Zeitschrift f{\\\"u}r Kombinatorik")
    define("j-EUR-J-COMB",			"European J. Combin.")
    define("j-EUR-J-COMB",			"Eur. J. Combin.")
    define("j-EUR-J-COMB",			"Eur. J. Comb.")

    ## j-EUR-J-INORG-CHEM [Jan. 1998 (n1)+] formed by merger of (a)
    ## Chemische Berichte/Recueil, (b) Bulletin des Societes Chimiques
    ## Belges, (c) Bulletin de la Societe Chimique de France, and (d)
    ## Gazzetta Chimica Italiana
    define("j-EUR-J-INORG-CHEM",		"European Journal of Inorganic Chemistry")
    define("j-EUR-J-INORG-CHEM",		"Eur. J. Inorg. Chem.")

    define("j-EUR-J-MECH-A-SOLIDS",		"European journal of mechanics, A, Solids.")
    define("j-EUR-J-MECH-A-SOLIDS",		"Eur. j. mech. A. Solids.")
    define("j-EUR-J-MECH-A-SOLIDS",		"Eur. J. Mech. A Solids")
    define("j-EUR-J-MECH-A-SOLIDS",		"Eur. J. Mech. A/Solids")
    define("j-EUR-J-MECH-A-SOLIDS",		"European J. Mech. A Solids")
    define("j-EUR-J-MECH-A-SOLIDS",		"European Journal of Mechanics (A/Solids)")

    define("j-EUR-J-OPER-RES",			"European Journal of Operational Research")
    define("j-EUR-J-OPER-RES",			"Eur. j. oper. res.")
    define("j-EUR-J-OPER-RES",			"Eur. J. Operational Res.")
    define("j-EUR-J-OPER-RES",			"European J. Oper. Res.")

    define("j-EUR-J-PHYS",			"European Journal of Physics")
    define("j-EUR-J-PHYS",			"European J. Phys")
    define("j-EUR-J-PHYS",			"Eur. J. Physics")
    define("j-EUR-J-PHYS",			"Eur. J. Phys.")

    define("j-EUR-J-PROTIST",			"European journal of protistology")

    define("j-EUR-MATH-SOC-NEWSL",		"European Mathematical Society. Newsletter")
    define("j-EUR-MATH-SOC-NEWSL",		"Eur. Math. Soc. Newsl.")

    define("j-EUR-PHYS-J-A",			"European Physical Journal A: Hadrons and Nuclei")
    define("j-EUR-PHYS-J-A",			"European Physical Journal A")
    define("j-EUR-PHYS-J-A",			"Eur. Phys. J. A")

    define("j-EUR-PHYS-J-B",			"European Physical Journal B: Condensed Matter and Complex Systems")
    define("j-EUR-PHYS-J-B",			"European Physical Journal B")
    define("j-EUR-PHYS-J-B",			"Eur. Phys. J. B")

    define("j-EUR-PHYS-J-C",			"European Physical Journal C: Particles and Fields")
    define("j-EUR-PHYS-J-C",			"European Physical Journal C")
    define("j-EUR-PHYS-J-C",			"Eur. Phys. J. C")

    define("j-EUR-PHYS-J-D",			"The European Physical Journal D --- Atomic, Molecular, Optical and Plasma Physics")
    define("j-EUR-PHYS-J-D",			"The European Physical Journal D - Atomic, Molecular, Optical and Plasma Physics")
    define("j-EUR-PHYS-J-D",			"European Physical Journal D: Atomic, Molecular, Optical and Plasma Physics")
    define("j-EUR-PHYS-J-D",			"The European Physical Journal D")
    define("j-EUR-PHYS-J-D",			"Eur. Phys. J. D")

    define("j-EUR-PHYS-J-E",			"European Physical Journal E: Soft Matter and Biological Physics")
    define("j-EUR-PHYS-J-E",			"European Physical Journal E")
    define("j-EUR-PHYS-J-E",			"Eur. Phys. J. E: Soft Matter Biol. Phys.")
    define("j-EUR-PHYS-J-E",			"Eur. Phys. J. E")

    # From https://www.springer.com/physics/journal/13129:
    #	Commonly used title abbreviations: Eur. Phys. J. H, Eur.Phys.J.H, EPJH, EPJ H
    define("j-EUR-PHYS-J-H",			"European Physical Journal H")
    define("j-EUR-PHYS-J-H",			"EPJH")
    define("j-EUR-PHYS-J-H",			"Eur. Phys. J. H")

    # NB: j-EUR-PHYS-J-PLUS (v126 n1 January 2011--date) was formerly Nuovo Cimento B
    define("j-EUR-PHYS-J-PLUS",			"The European Physical Journal Plus")
    define("j-EUR-PHYS-J-PLUS",			"European Physical Journal Plus")
    define("j-EUR-PHYS-J-PLUS",			"Eur. Phys. J. Plus")

    define("j-EUR-PHYS-J-SPEC-TOP",		"European Physical Journal --- Special Topics")
    define("j-EUR-PHYS-J-SPEC-TOP",		"European Physical Journal: Special Topics")
    define("j-EUR-PHYS-J-SPEC-TOP",		"The European Physical Journal --- Special Topics")
    define("j-EUR-PHYS-J-SPEC-TOP",		"The European Physical Journal: Special Topics")
    define("j-EUR-PHYS-J-SPEC-TOP",		"Eur. Phys. J. Special Topics")
    define("j-EUR-PHYS-J-SPEC-TOP",		"Eur. Phys. J., Spec. Top.")

    define("j-EUR-PSYCH",			"European Psychiatry: the journal of the {Association of European Psychiatrists}")
    define("j-EUR-PSYCH",			"European Psychiatry")
    define("j-EUR-PSYCH",			"Eur. Psych.")

    define("j-EUR-REV-HIST",			"European Review of History = Revue europ{\\'e}enne d'histoire")
    define("j-EUR-REV-HIST",			"European Review of History")
    define("j-EUR-REV-HIST",			"Eur. Rev. Hist.")

    define("j-EUR-SCI-EDIT",			"The {EASE} Journal: European Science Editing")
    define("j-EUR-SCI-EDIT",			"European Science Editing")
    define("j-EUR-SCI-EDIT",			"Eur. Sci. Edit.")

    define("j-EUR-TRANS-TELECOMMUN-RELAT-TECHNOL",	"European transactions on telecommunications and related technologies")
    define("j-EUR-TRANS-TELECOMMUN-RELAT-TECHNOL",	"Eur. Trans. Telecommun. Relat. Technol.")
    define("j-EUR-TRANS-TELECOMMUN-RELAT-TECHNOL",	"European transactions on telecommunications and")

    define("j-EURASIP-J-ADV-SIGNAL-PROCESS",	"EURASIP Journal on Advances in Signal Processing")
    define("j-EURASIP-J-ADV-SIGNAL-PROCESS",	"EURASIP J. Adv. Signal Process.")

    define("j-EURASIP-J-EMBED-SYS",		"EURASIP Journal on Embedded Systems")
    define("j-EURASIP-J-EMBED-SYS",		"EURASIP J. Embed. Syst.")
    define("j-EURASIP-J-EMBED-SYS",		"EURASIP J. Embed. Sys.")

    define("j-EUROMATH-BULL",			"Euromath Bulletin")
    define("j-EUROMATH-BULL",			"Euromath Bull.")

    define("j-EUROPEN-NEWSLETTER",		"EurOpen Newsletter")

    define("j-EUROPHYS-LETT",			"Europhysics Letters")
    define("j-EUROPHYS-LETT",			"Europhysics Letters (EPL)")
    define("j-EUROPHYS-LETT",			"EPL (Europhysics Letters)")
    define("j-EUROPHYS-LETT",			"Europhys. Lett.")

    define("j-EUROPHYS-NEWS",			"Europhysics News")
    define("j-EUROPHYS-NEWS",			"Europhys. News")

    define("j-EUUG-NEWSLETTER",			"European UNIX Systems User Group, EUUG Newsletter")
    define("j-EUUG-NEWSLETTER",			"European UNIX Systems User Group Newsletter")
    define("j-EUUG-NEWSLETTER",			"EUUG Newsletter")

    define("j-EVOL-COMPUT",			"Evolutionary computation")
    define("j-EVOL-COMPUT",			"Evol. comput.")

    define("j-EVOL-ECOL",			"Evolutionary ecology")
    define("j-EVOL-ECOL",			"Evol. ecol.")

    define("j-EVOLUTION",			"Evolution")

    define("j-EVOL-INTEL",			"Evolutionary Intelligence")
    define("j-EVOL-INTEL",			"Evol. Intell.")
    define("j-EVOL-INTEL",			"Evol. Intel.")

    define("j-EW-J-NUM-MATH",			"East-West Journal of Numerical Mathematics")
    define("j-EW-J-NUM-MATH",			"East-West J. Numer. Math.")

    define("j-EXE",				".EXE: the software developers' magazine")
    define("j-EXE",				"EXE")

    define("j-EXEC-EDUC",			"The Executive Educator")
    define("j-EXEC-EDUC",			"Exec. Educ.")

    define("j-EXP-CELL-RES",			"Experimental Cell Research")
    define("j-EXP-CELL-RES",			"Exp Cell Res (EPB)")
    define("j-EXP-CELL-RES",			"Exp. Cell Res.")
    define("j-EXP-CELL-RES",			"Exptl. Cell Res.")

    define("j-EXP-HEMATOL",			"Experimental Hematology")
    define("j-EXP-HEMATOL",			"Exp. Hematol.")

    define("j-EXP-HEMATOL-TODAY",		"Experimental Hematology Today")
    define("j-EXP-HEMATOL-TODAY",		"Exp. Hematol. Today")

    define("j-EXP-MATH",			"Experimental Mathematics")
    define("j-EXP-MATH",			"Exp. Math.")
    define("j-EXP-MATH",			"Experiment. Math.")

    define("j-EXP-MYCO",			"Experimental Mycology")

    define("j-EXP-NEUROL",			"Experimental Neurology")
    define("j-EXP-NEUROL",			"Exp. Neurol.")

    define("j-EXP-PARASITOL",			"Experimental Parasitology")
    define("j-EXP-PARASITOL",			"Exp. Parasitol.")

    define("j-EXPEDITION",			"Expedition")

    define("j-EXPERIENTIA",			"Experientia")
    define("j-EXPERIENTIA",			"Experientia (Basel)")
    define("j-EXPERIENTIA",			"Experientia (EQZ)")

    define("j-EXPERIENTIA-SUPPL",		"Experientia. Supplementum.")

    define("j-EXPERT-SYST-APPL",		"Expert Systems with Applications")
    define("j-EXPERT-SYST-APPL",		"Expert Syst. Appl.")

    define("j-EXPO-MATH",			"Expositiones Mathematicae")
    define("j-EXPO-MATH",			"Expo. Math.")

    define("j-EXS",				"EXS")
    define("j-EXS",				"EXS (BFZ)")

    define("j-EYE",				"Eye")

    ## Vol. 1, no. 1 (1999)- Ceased with no. 2 (2008). [no online archive known]
    define("j-FACTA-PHILOS",			"Facta Philosophica")
    define("j-FACTA-PHILOS",			"{Facta Philosophica: internazionale Zeitschrift f{\\\"u}r Gegenwartsphilosophie: international journal for contemporary philosophy}")
    define("j-FACTA-PHILOS",			"{Facta Philosophica: internazionale Zeitschrift f{\\\"u}r Gegenwartsphilosophie")
    define("j-FACTA-PHILOS",			"Facta Philos.")

    define("j-FAR-EAST-J-APPL-MATH",		"Far East Journal of Applied Mathematics")
    define("j-FAR-EAST-J-APPL-MATH",		"Far East J. Appl. Math.")

    define("j-FAR-EAST-J-THEOR-STAT",		"Far East Journal of Theoretical Statistics")
    define("j-FAR-EAST-J-THEOR-STAT",		"Far East J. Theor. Stat.")

    define("j-FASEB-J",				"The FASEB journal: official publication of the Federation of American Societies for Experimental Biology")
    define("j-FASEB-J",				"The FASEB journal: official publication of the")
    define("j-FASEB-J",				"FASEB Journal")
    define("j-FASEB-J",				"FASEB J (FAS)")
    define("j-FASEB-J",				"FASEB J.")

    define("j-FEBS",				"FEBS")
    define("j-FEBS",				"Federation of European Biochemical Societies (Series)")

    define("j-FEBS-LETT",			"FEBS Letters")
    define("j-FEBS-LETT",			"FEBS Lett (EUH)")
    define("j-FEBS-LETT",			"FEBS Lett.")
    define("j-FEBS-LETT",			"FEBS Letts.")

    define("j-FED",				"American Society of Mechanical Engineers, Fluids Engineering Division (Publication) FED")
    define("j-FED",				"FED")

    define("j-FED-COMPUTER-WEEK",		"Federal computer week")

    define("j-FED-PROC",			"Federation proceedings")
    define("j-FED-PROC",			"Fed. Proc.")
    define("j-FED-PROC",			"Fedn. Proc.")

    define("j-FED-REGIST",			"Federal Register")
    define("j-FED-REGIST",			"Fed. regist.")
    define("j-FED-REGIST",			"Fed. regist. (Vienna, VA)")

    define("j-FEMS-MICROBIOL-LETT",		"FEMS microbiology letters")
    define("j-FEMS-MICROBIOL-LETT",		"FEMS micro. biol. letters")
    define("j-FEMS-MICROBIOL-LETT",		"FEMS Microbiol Lett (FML)")
    define("j-FEMS-MICROBIOL-LETT",		"FEMS Letters")
    define("j-FEMS-MICROBIOL-LETT",		"FEMS Lett.")
    define("j-FEMS-MICROBIOL-LETT",		"FEMS Microbiol. Lett.")

    define("j-FEMS-MICROBIOL-REV",		"FEMS Microbiology Reviews")
    define("j-FEMS-MICROBIOL-REV",		"FEMS Microbiol. Rev.")

    define("j-FERROELECTRICS",			"Ferroelectrics")

    define("j-FIB-QUART",			"Fibonacci Quarterly")
    define("j-FIB-QUART",			"Fibonacci Quart.") # MathSciNet abbreviation
    define("j-FIB-QUART",			"Fib. Quart.")

    define("j-FINANC-ANAL-J",			"Financial analysts journal")
    define("j-FINANC-ANAL-J",			"Financ. anal. j.")

    define("j-FINANC-TECH-INT-BULL",		"Financial Technology International Bulletin")
    define("j-FINANC-TECH-INT-BULL",		"Financ. Tech. Int. Bull.")

    define("j-FINITE-ELEMENTS-ANAL-DESIGN",	"Finite Elements in Analysis and Design")
    define("j-FINITE-ELEMENTS-ANAL-DESIGN",	"Finite Elements in Analysis and Design: the International Journal of Applied Finite Elements and Computer Aided Engineering")
    define("j-FINITE-ELEMENTS-ANAL-DESIGN",	"Finite Elem. Anal. Des.")

    define("j-FINITE-FIELDS-APPL",		"Finite Fields and their Applications")
    define("j-FINITE-FIELDS-APPL",		"Finite Fields Appl.")

    define("j-FIRST-MONDAY",                    "First Monday")

    define("j-FISH-AQUACULT-J",			"Fisheries and Aquaculture Journal")
    define("j-FISH-AQUACULT-J",			"Fish. Aquacult. J.")

    define("j-FISH-BULL",			"Fishery Bulletin")
    define("j-FISH-BULL",			"Fish. Bull.")

    define("j-FISH-FISH",			"Fish Fish.")
    define("j-FISH-FISH",			"Fish and Fisheries")

    define("j-FISH-OCEANOGR",			"Fisheries Oceanography")
    define("j-FISH-OCEANOGR",			"Fish. Oceanogr.")

    define("j-FISH-PHYSIOL-BIOCHEM",		"Fish Physiology and Biochemistry")
    define("j-FISH-PHYSIOL-BIOCHEM",		"Fish Physiol. Biochem.")

    define("j-FISH-RES",			"Fisheries Research")
    define("j-FISH-RES",			"Fish. Res.")

    define("j-FISHERIES",			"Fisheries")

    define("j-FISHES",				"Fishes")

    define("j-FIZ-SZ",				"Fizikai Szemle (Budapest)")
    define("j-FIZ-SZ",				"Fizikai Szemle")
    define("j-FIZ-SZ",				"Fiz. Szemle")
    define("j-FIZ-SZ",				"Fiz. Sz.")

    define("j-FIZMAT-SPIS-BULGAR-AKAD-NAUK",	"Fiz.-Mat. Spis. Bulgar. Akad. Nauk.")
    define("j-FIZMAT-SPIS-BULGAR-AKAD-NAUK",	"B{\\cdprime}lgarska Akademiya na Naukite. Fizicheski Institut. Matematicheski Institut. Fiziko-Matematichesko Spisanie")

    define("j-FJCC",				"Fall Joint Computer Conference")
    define("j-FJCC",				"Fall Joint Comput. Conf.")

    define("j-FLEX-TECH-J",			"Flexographic Technical Journal")

    define("j-FLUCT-NOISE-LETT",		"Fluctuation and Noise Letters")
    define("j-FLUCT-NOISE-LETT",		"Fluct. Noise Lett.")

    define("j-FOLIA-HAEMATOL",			"Folia haematologica")
    define("j-FOLIA-HAEMATOL",			"Folia Haematol.")
    define("j-FOLIA-HAEMATOL",			"Folia Haemat.")

    define("j-FOLIO",				"Folio: the Magazine for Magazine Management")
    define("j-FOLIO",				"Folio mag. mag. manage.")
    define("j-FOLIO",				"Folio")

    define("j-FORBES",				"Forbes")
    define("j-FOREFRONTS",			"Forefronts")

    define("j-FOREIGN-AFFAIRS",			"Foreign Affairs")
    define("j-FOREIGN-AFFAIRS",			"Foreign Aff.")

    define("j-FORMA",				"Forma (Tokyo)")
    define("j-FORMA",				"Forma")

    define("j-FORM-ASP-COMPUT",			"Formal Aspects of Computing")
    define("j-FORM-ASP-COMPUT",			"Formal Asp. Comput.")
    define("j-FORM-ASP-COMPUT",			"Form. Asp. Comput.")

    define("j-FORM-METHODS-SYST-DES",		"Formal Methods in System Design")
    define("j-FORM-METHODS-SYST-DES",		"Form. methods syst. des.")

    define("j-FORSCH-FORTSCHR",			"{Forschungen und Fortschritte}")
    define("j-FORSCH-FORTSCHR",			"{Forschungen und Fortschritte: Nachrichtenblatt der Deutschen Wissenschaft und Technik}")
    define("j-FORSCH-FORTSCHR",			"{Forsch. Fortschr.}")

    define("j-FORSKNINGSNYTT",			"Forskningsnytt (Norges Almenvitenskapelige Forskningsr{\\aa}d)")
    define("j-FORTEC-FORUM",			"ForTec Forum")
    define("j-FORTH-DIMENSIONS",		"Forth Dimensions")

    define("j-FORTRAN-FORUM",			"ACM Fortran Forum")
    define("j-FORTRAN-FORUM",			"Fortran Forum")

    define("j-FORTRAN-J",			"Fortran Journal")

    define("j-FORTSCHR-PHYS",			"{Fortschritte der Physik = Progress of Physics}")
    define("j-FORTSCHR-PHYS",			"{Fortschritte der Physik}\\slash {Progress of Physics}")
    define("j-FORTSCHR-PHYS",			"{Fortschritte der Physik}")
    define("j-FORTSCHR-PHYS",			"{Fortschr. Phys.}")

    define("j-FORTUNE",				"Fortune")
    define("j-FORTUNE",				"Fortune Magazine")
    define("j-FORTUNE",				"Fortune")

    define("j-FORUM-MATH",			"Forum Mathematicum")
    define("j-FORUM-MATH",			"Forum Math.")

    define("j-FOUND-CHEM",			"Foundations of Chemistry")
    define("j-FOUND-CHEM",			"Found. Chem.")

    define("j-FOUND-COMPUT-MATH",		"Foundations of Computational Mathematics. The Journal of the Society for the Foundations of Computational Mathematics")
    define("j-FOUND-COMPUT-MATH",		"Foundations of Computational Mathematics")
    define("j-FOUND-COMPUT-MATH",		"Found. Comput. Math.")

    define("j-FOUND-PHYS",			"Foundations of Physics")
    define("j-FOUND-PHYS",			"Found. Phys.")

    define("j-FOUND-PHYS-LETT",			"Foundations of Physics Letters")
    define("j-FOUND-PHYS-LETT",			"Found. Phys. Lett.")

    define("j-FOUND-SCI",			"Foundations of Science")
    define("j-FOUND-SCI",			"Found. Sci.")

    define("j-FOURIER-ANAL-APPL",		"Journal of {Fourier} Analysis and Applications")
    define("j-FOURIER-ANAL-APPL",		"The Journal of {Fourier} Analysis and Applications")
    define("j-FOURIER-ANAL-APPL",		"J. {Fourier} Anal. Appl.")

    define("j-FRACTALS",			"Fractals")

    define("j-FREE-INQUIRY",			"Free Inquiry")

    define("j-FRONTIERS-EDU-CONF",		"Frontiers in Education Conference")
    define("j-FRONTIERS-EDU-CONF",		"Proceedings - Frontiers in Education Conference")

    define("j-FRONTIERS-MAR-SCI",		"Frontiers in Marine Science")
    define("j-FRONTIERS-MAR-SCI",		"Front. Mar. Sci.")

    define("j-FRONTIERS-MASS-PAR-COMP-CONF-PROC","Frontiers of Massively Parallel Computation --- Conference Proceedings")

    define("j-FSTTCS",				"Foundations of Software Technology and Theoretical Computer Science")
    define("j-FUJITSU",				"Fujitsu")

    define("j-FUJITSU-SCI-TECH-J",		"Fujitsu scientific and technical journal")
    define("j-FUJITSU-SCI-TECH-J",		"Fujitsu sci. tech. j.")

    define("j-FUNCT-ANAL-APPL",			"Functional Analysis and Its Applications")
    define("j-FUNCT-ANAL-APPL",			"Funct. Anal. Appl.")

    define("j-FUNCT-ECOL",			"Functional ecology")
    define("j-FUNCT-ECOL",			"Funct. ecol.")

    define("j-FUNCT-SPACES",			"Journal of Function Spaces")
    define("j-FUNCT-SPACES",			"J. Funct. Spaces")

    define("j-FUND-INFO",			"Fundamenta Informaticae")
    define("j-FUND-INFO",			"Fund. Inform.")		# Library of Congress abbreviation
    define("j-FUND-INFO",			"Fund. Info.")

    define("j-FUND-SCI",			"Fundamenta Scientiae")
    define("j-FUND-SCI",			"Fundamenta Scientiae: the International Journal for Critical Analysis of Science and the Responsibility of Scientists = Revue internationale pour l'analyse critique de la science et la responsabilit{\\'e} des scientifiques")
    define("j-FUND-SCI",			"Fund. Sci.")

    define("j-FUNDAM-MATH",			"Fundamenta mathematicae")
    define("j-FUNDAM-MATH",			"Fundam. math.")
    define("j-FUNDAM-MATH",			"Fund. Math.")

    define("j-FUNKCIAL-EKVAC",			"Funkcialaj Ekvacioj. Serio Internacia")
    define("j-FUNKCIAL-EKVAC",			"Funkcialaj Ekvacioj")
    define("j-FUNKCIAL-EKVAC",			"Funkc. Ekvacioj, Ser. Int.")
    define("j-FUNKCIAL-EKVAC",			"Funkc. Ekvacioj")

    define("j-FUNKT-BIOL-MED",			"Funktionelle Biologie und Medizin")
    define("j-FUNKT-BIOL-MED",			"Funktionelle Biologie \\& Medizin")
    define("j-FUNKT-BIOL-MED",			"Funkt. Biol. Med.")
    define("j-FUNKT-BIOL-MED",			"Funk. Biol. Med.")

    ## NB: Occasional special volumes issued as: Transactions of Fusion Science and Technology
    define("j-FUSION-SCI-TECHNOL",		"Fusion Science and Technology")
    define("j-FUSION-SCI-TECHNOL",		"Fusion Sci. Technol.")

    define("j-FUSION-TECHNOL",			"Fusion Technology")
    define("j-FUSION-TECHNOL",			"Fusion Technol.")

    define("j-FUT-GEN-COMP-SYS",		"Future Generation Computer Systems")
    define("j-FUT-GEN-COMP-SYS",		"Future Gen. Comput. Sys.")
    define("j-FUT-GEN-COMP-SYS",		"Future generations computer systems: FGCS")

    define("j-FUTURE-INTERNET",			"Future Internet")

    define("j-FUTURES",				"Futures")
    define("j-FUTURES",				"Futures (London)")
    define("j-FUTURES",				"Futures (Lond)")

    define("j-FUZZY-SETS-SYSTEMS",		"Fuzzy Sets and Systems")
    define("j-FUZZY-SETS-SYSTEMS",		"Fuzzy Sets and Systems. An International Journal in Information Science and Engineering")
    define("j-FUZZY-SETS-SYSTEMS",		"Fuzzy Sets Syst.")

    define("j-G-FIS",				"Giornale di Fisica")
    define("j-G-FIS",				"Giornale di Fisica della Societa Italiana di Fisica")
    define("j-G-FIS",				"G. Fis.")

    define("j-GAKUJUTSU-GEPPO",			"Gakujutsu geppo. Japanese scientific monthly")
    define("j-GAKUJUTSU-GEPPO",			"Japanese scientific monthly")

    define("j-GAMES",				"Games")

    define("j-GAMM-MIT",			"Mitteilungen der Gesellschaft f{\\\"u}r Angewandte Mathematik und Mechanik")
    define("j-GAMM-MIT",			"Mitteilungen der Gesellschaft fur Angewandte Mathematik und Mechanik")
    define("j-GAMM-MIT",			"GAMM-Mitteilungen")
    define("j-GAMM-MIT",			"GAMM Mitt. Ges. Angew. Math. Mech.")

    define("j-GAZ-MATH",			"Gazette des Math{\\'e}maticiens")
    define("j-GAZ-MATH",			"Gaz. Math.")

    define("j-GEN",				"Genetics")
    define("j-GEN",				"Genetics (FNH)")

    define("j-GEN-RELATIVITY-GRAV",		"General Relativity and Gravitation")
    define("j-GEN-RELATIVITY-GRAV",		"Gen. Rel. Grav.")
    define("j-GEN-RELATIVITY-GRAV",		"Gen. relativ. gravit.")
    define("j-GEN-RELATIVITY-GRAV",		"Gen. Relativity Gravitation")

    define("j-GENE",				"Gene")
    define("j-GENE",				"Gene (FOP)")

    define("j-GENERAL-SUBJ",			"General subjects")

    define("j-GENES-DEVEL",			"Genes and development")
    define("j-GENES-DEVEL",			"Genes Dev (FN3)")
    define("j-GENES-DEVEL",			"Genes \\& Dev.")

    define("j-GENIE-LOGICIEL-SYS-EXPERTS",	"G{\\'e}nie Logiciel and Syst{\\`e}mes Experts")
    define("j-GENIE-LOGICIEL-SYS-EXPERTS",	"Genie Logiciel and Systemes Experts")

    define("j-GENOME-BIOL",			"Genome Biology")
    define("j-GENOME-BIOL",			"Genome Biol.")

    define("j-GENOME-RES",			"Genome Research")
    define("j-GENOME-RES",			"Genome Res.")

    define("j-GENOMICS",			"Genomics")
    define("j-GENOMICS",			"Genomics (GEN)")

    define("j-GENUS",				"Genus")

    define("j-GEOBYTE",				"Geobyte")

    define("j-GEODERMA",			"Geoderma")

    define("j-GEOGR-J",				"The Geographical Journal")
    define("j-GEOGR-J",				"Geographical Journal")
    define("j-GEOGR-J",				"Geogr. J.")

    define("j-GEOPHYS-J-INT",			"Geophysical journal international")
    define("j-GEOPHYS-J-INT",			"Geophys. j. int.")

    define("j-GEOPHYS-J-R-ASTRON-SOC",		"Geophysical Journal of the {Royal Astronomical Society}")
    define("j-GEOPHYS-J-R-ASTRON-SOC",		"Geophys. J. Roy. Astron. Soc.")
    define("j-GEOPHYS-J-R-ASTRON-SOC",		"Geophys. J. R. Astron. Soc.")

    define("j-GEOPHYS-RES-LETT",		"Geophysical Research Letters")
    define("j-GEOPHYS-RES-LETT",		"Geophys. Res. Lett.")

    define("j-GEOPHYS-MONOGR",			"Geophysical Monograph")
    define("j-GEOPHYS-MONOGR",			"Geophysical Monograph Series")
    define("j-GEOPHYS-MONOGR",			"Geophys. Monogr.")
    define("j-GEOPHYS-MONOGR",			"Geophys. Monogr. Ser.")

    define("j-GEOPHYSICS",			"Geophysics")

    define("j-GEOSCI-MODEL-DEV",		"Geoscientific Model Development")
    define("j-GEOSCI-MODEL-DEV",		"Geosci. Model Devel.")
    define("j-GEOSCI-MODEL-DEV",		"Geosci. Model Dev.")

    define("j-GER-ECON-REV",			"German Economic Review")
    define("j-GER-ECON-REV",			"Ger. Econ. Rev.")

    define("j-GER-STUD-REV",			"{German} Studies Review")
    define("j-GER-STUD-REV",			"Ger. Stud. Rev.")

    define("j-GERMAN-RES-REP-DFG",		"German research: reports of the DFG")

    define("j-GLASG-MATH-J",			"Glasgow Mathematical Journal")
    define("j-GLASG-MATH-J",			"Glasg. Math. J.")

    define("j-GLIA",                            "Glia")

    define("j-GLOB-ECOL-BIOGEOGRAPHY",		"Global Ecology and Biogeography")
    define("j-GLOB-ECOL-BIOGEOGRAPHY",		"Glob. Ecol. Biogeography")

    define("j-GLOB-FINANCE-J",			"Global Finance Journal")
    define("j-GLOB-FINANCE-J",			"Glob. Finance J.")

    define("j-GLYCOBIOLOGY",			"Glycobiology (BEL)")
    define("j-GOV-COMP-NEWS",			"Government computer news")

    define("j-GRAPH-MODELS-IMAGE-PROC",		"Graphical models and image processing: GMIP")
    define("j-GRAPH-MODELS-IMAGE-PROC",		"Graph. models image proc.")
    define("j-GRAPH-MODELS-IMAGE-PROC",		"Graphical models and image processing")

    define("j-GRAPHIC-ARTS-MONTHLY",		"Graphic arts monthly: the magazine of the printing industry")
    define("j-GRAPHIC-ARTS-MONTHLY",		"Graphic arts monthly: the magazine of the prin")

    define("j-GROUND-WATER",			"Ground water")

    define("j-GROUPS-COMPLEX-CRYPTOL",		"Groups. Complexity. Cryptology")
    define("j-GROUPS-COMPLEX-CRYPTOL",		"Groups Complex. Cryptol.")

    define("j-GSA-TODAY",			"GSA Today")
    define("j-GUARDIAN",			"The Guardian")
    define("j-GUTENBERG",			"Cahiers GUTenberg")

    define("j-HADRONIC-J",			"Hadronic Journal")
    define("j-HADRONIC-J",			"Hadronic J.")

    define("j-HAEMATOLOGICA",			"Haematologica")

    define("j-HARPERS-MAG",			"Harper's Magazine")
    define("j-HARPERS-MAG",			"Harper's")
    define("j-HARPERS-MAG",			"Harper's Mag.")

    define("j-HARVARD-BUS-REV",			"Harvard Business Review")
    define("j-HARVARD-BUS-REV",			"Harvard bus. rev.")

    define("j-HARVARD-EDUC-REV",		"Harvard Educational Review")
    define("j-HARVARD-EDUC-REV",		"Harv. educ. rev.")

    define("j-HARVARD-INT-REV",			"Harvard International Review")
    define("j-HARVARD-INT-REV",			"Harvard Int. Review")
    define("j-HARVARD-INT-REV",			"Harvard Int. Rev.")

    define("j-HARVARD-LAW-REV",			"Harvard Law Review")

    define("j-HARVARD-REV",			"Harvard Review")
    define("j-HARVARD-REV",			"Harv. Rev.")
    define("j-HARVARD-REV",			"Harvard Rev.")

    define("j-HARVEY-LECTURES",			"Harvey Lectures")
    define("j-HEALTH-PHYSICS",			"Health physics: official journal of the Health Physics Society")

    define("j-HEBREW-LINGUISTICS",		"Hebrew Linguistics: A Journal for Hebrew Descriptive, Computational, and Applied Linguistics")
    define("j-HEBREW-LINGUISTICS",		"Hebrew Linguistics = Balshanut 'Ivrit")

    define("j-HELV-CHIM-ACTA",			"Helvetica Chimica Acta")
    define("j-HELV-CHIM-ACTA",			"Helv. Chim. Acta")

    define("j-HELV-PHYS-ACTA",			"Helvetica Physica Acta")
    define("j-HELV-PHYS-ACTA",			"Helvetica Physica Acta. Physica Theoretica. Societatis Physicae Helveticae Commentaria Publica")
    define("j-HELV-PHYS-ACTA",			"Helv. Phys. Acta")
    define("j-HELV-PHYS-ACTA",			"Helvetica Phys. Acta")

    define("j-HEREDITY",			"Heredity")

    define("j-HERMIS",				"HERMIS-$\\mu\\pi$")
    define("j-HERMIS",				"HERMIS-$\\mu\\pi$: Hellenic European Research on Mathematics and Informatics Science. The International Journal of Computer Mathematics and its Applications")

    define("j-HEWLETT-PACKARD-J",		"Hewlett-Packard Journal: technical information from the laboratories of Hewlett-Packard Company")
    define("j-HEWLETT-PACKARD-J",		"Hewlett-Packard Journal")
    define("j-HEWLETT-PACKARD-J",		"Hewlett-Packard J.")
    define("j-HEWLETT-PACKARD-J",		"Hewlett-Packard journal: technical information")
    define("j-HEWLETT-PACKARD-J",		"HP Journal")

    ## published quarterly since 1910: some content available at
    ## https://discover.libraryhub.jisc.ac.uk/id/231165940
    ## https://discover.libraryhub.jisc.ac.uk/id/231165940
    ## Not listed in CAS, MathSciNet, or zbMATH
    define("j-HEXAGON",				"The Hexagon of Alpha Chi Sigma")
    define("j-HEXAGON",				"The Hexagon")
    define("j-HEXAGON",				"Hexagon")

    define("j-HEYTHROP-J",			"The Heythrop Journal")
    define("j-HEYTHROP-J",			"Heythrop Journal")
    define("j-HEYTHROP-J",			"Heythrop J.")

    define("j-HIGH-PERFORM-SYST",		"High performance systems")
    define("j-HIGH-PERFORM-SYST",		"High perform. syst.")

    define("j-HIGH-PRESSURE-RES",		"High Pressure Research")
    define("j-HIGH-PRESSURE-RES",		"High Pressure Res.")

    define("j-HIGH-TECH-LETT",			"High Technology Letters")

    define("j-HIGHER-ORDER-SYMB-COMPUT",	"Higher-Order and Symbolic Computation")
    define("j-HIGHER-ORDER-SYMB-COMPUT",	"Higher-Order Symb. Comput.")

    define("j-HIST-GEO-SPACE-SCI",		"History of Geo- and Space Sciences")
    define("j-HIST-GEO-SPACE-SCI",		"Hist. Geo- Space Sci.")

    define("j-HIST-MATH",			"Historia Mathematica")
    define("j-HIST-MATH",			"Historia Math.")
    define("j-HIST-MATH",			"Hist. Math.")

    define("j-HIST-PHILOS-LOGIC",		"History and Philosophy of Logic")
    define("j-HIST-PHILOS-LOGIC",		"Hist. Phil. Logic")
    define("j-HIST-PHILOS-LOGIC",		"Hist. Philos. Logic")

    define("j-HIST-REC-AUSTRAL-SCI",		"Historical Records of Australian Science")
    define("j-HIST-REC-AUSTRAL-SCI",		"Hist. Rec. Austral. Sci.")

    define("j-HIST-SCI",			"Historia Scientiarum = International journal of the {History of Science Society of Japan}")
    define("j-HIST-SCI",			"Historia Scientiarum")
    define("j-HIST-SCI",			"Hist. Sci.")

    define("j-HIST-SCI-2",			"Historia Scientiarum. Second Series. International Journal of the History of Science Society of Japan")
    define("j-HIST-SCI-2",			"Historia Sci. (2)")

    define("j-HIST-SCI-UK",			"History of Science (UK)")
    define("j-HIST-SCI-UK",			"History of Science")
    ## Suppress ambiguous Library-of-Congress abbreviation to avoid conflict with Historia Scientiarum
    ## define("j-HIST-SCI-UK",			"Hist. Sci.")

    define("j-HIST-STUD-NAT-SCI",		"Historical Studies in the Natural Sciences")
    define("j-HIST-STUD-NAT-SCI",		"Hist. Stud. Nat. Sci.")

    define("j-HIST-STUD-PHYS-BIOL-SCI",		"Historical Studies in the Physical and Biological Sciences")
    define("j-HIST-STUD-PHYS-BIOL-SCI",		"Hist. Stud. Phys. Biol. Sci.")

    define("j-HIST-STUD-PHYS-SCI",		"Historical Studies in the Physical Sciences")
    define("j-HIST-STUD-PHYS-SCI",		"Hist. Stud. Phys. Sci.")

    define("j-HIST-TEACH",			"The History Teacher")
    define("j-HIST-TEACH",			"Hist. Teach.")

    define("j-HIST-TECHNOL",			"History and Technology")
    define("j-HIST-TECHNOL",			"Hist. Technol.")

    define("j-HISTOCHEMISTRY",			"Histochemistry (G9K)")

    define("j-HISTORIAN",			"Historian")

    define("j-HOCHFREQUENZTECH-ELEKTROAKUST",	"{Hochfrequenztechnik und Elektroakustik}")
    define("j-HOCHFREQUENZTECH-ELEKTROAKUST",	"{Hochfrequenztech. Elektroakust.}")

    define("j-HOKKAIDO-MATH-J",			"Hokkaido Mathematical Journal")
    define("j-HOKKAIDO-MATH-J",			"Hokkaido Math. J.")

    define("j-HOME-OFF-COMPUT",			"Home office computing: building better business")
    define("j-HOME-OFF-COMPUT",			"Home office computing: building better busines")
    define("j-HOME-OFF-COMPUT",			"Home office computing")
    define("j-HOME-OFF-COMPUT",			"Home off. comput.")

    define("j-HONEYWELL-COMP-J",		"Honeywell Computer Journal")
    define("j-HONEYWELL-COMP-J",		"Honeywell Comp. J.")

    define("j-HOOVER-DIG",			"Hoover Digest")
    define("j-HOOVER-DIG",			"Hoover Dig.")

    define("j-HORM-METAB-RES-SUPPL",		"Hormone and metabolic research. Supplement series")
    define("j-HORM-METAB-RES-SUPPL",		"Horm. Metab. Res. Suppl.")

    define("j-HOUSTON-J-MATH",			"Houston Journal of Mathematics")
    define("j-HOUSTON-J-MATH",			"Houston J. Math.")

    define("j-HP-CHRONICLE",			"HP Chronicle")
    define("j-HP-PROF",				"HP professional")
    define("j-HUM-BIOL",			"Human biology")
    define("j-HUM-BIOL",			"Hum. biol.")

    define("j-HUM-FACTORS",			"Human Factors")
    define("j-HUM-FACTORS",			"Hum. Factors")

    define("j-HUM-NEUROBIOL",			"Human Neurobiology")
    define("j-HUM-NEUROBIOL",			"Hum. Neurobiol.")
    define("j-HUM-NEUROBIOL",			"Human Neurobiol.")

    define("j-HUMAN-HEREDITY",			"Human Heredity")

    define("j-HUNG-J-INDUSTRIAL-CHEM",		"Hungarian journal of industrial chemistry")
    define("j-HYDROBIOLOGIA",			"Hydrobiologia")
    define("j-HYDROCARBON-PROC-INT",		"Hydrocarbon processing (International edition)")
    define("j-HYDROCARBON-PROC-US",		"Hydrocarbon processing (US edition)")
    define("j-HYDROMETALLURGY",			"Hydrometallurgy")
    define("j-HYPERMEDIA",			"Hypermedia")

    define("j-I-CHUAN-HSUEH-PAO",		"I ch'uan hsueh pao = Acta genetica Sinica")
    define("j-I-CHUAN-HSUEH-PAO",		"I Chuan Hsueh Pao (AO5)")

    define("j-I-S-ANALYZER",			"I/S Analyzer")
    define("j-I-S-ANALYZER",			"I/S anal.")

    define("j-IAEA-BULL",			"{International Atomic Energy Agency} Bulletin")
    define("j-IAEA-BULL",			"Int. At. Energy Agency Bull.")
    define("j-IAEA-BULL",			"IAEA Bulletin")
    define("j-IAEA-BULL",			"IAEA Bull.")

    define("j-IBM-JRD",				"IBM Journal of Research and Development")
    define("j-IBM-JRD",				"IBM J. Res. Develop.")
    define("j-IBM-JRD",				"IBM J. Res. Dev.")

    define("j-IBM-SYS-J",			"IBM Systems Journal")
    define("j-IBM-SYS-J",			"IBM Systems J.")

    define("j-IBM-TDB",				"IBM Technical Disclosure Bulletin")

    ## Not to be confused with "Icarus (Trinity College, Dublin)" [unknown CODEN and ISSN]
    define("j-ICARUS-IJSSS",			"Icarus: International Journal of Solar System Studies")
    define("j-ICARUS-IJSSS",			"Icarus")

    define("j-ICC-BULL",			"ICC (International Computation Center) Bulletin (Rome)")
    define("j-ICC-BULL",			"ICC Bulletin")
    define("j-ICC-BULL",			"ICC Bull.")

    define("j-ICES-J-MAR-SCI",			"ICES Journal of Marine Science")
    define("j-ICES-J-MAR-SCI",			"ICES J. Mar. Sc")

    define("j-IECON-PROC-IND-ELEC-CONF",	"IECON Proceedings (Industrial Electronics Conference)")

    define("j-IEE-CONF-PUBL",			"IEE conference publication")
    define("j-IEE-CONF-PUBL",			"IEE conf. publ.")

    define("j-IEE-PROC",			"IEE Proceedings")
    define("j-IEE-PROC",			"IEE Proc.")

    define("j-IEE-PROC-A",			"IEE Proceedings, A: Physical science, measurement and instrumentation, management and education")
    define("j-IEE-PROC-B",			"IEE Proceedings, B: Electric power applications")
    define("j-IEE-PROC-C",			"IEE Proceedings, C: Generation, transmission, and distribution")
    define("j-IEE-PROC-D",			"IEE Proceedings, D: Control theory and applications")

    define("j-IEE-PROC-E",			"IEE proceedings, E: Computers and digital techniques")
    define("j-IEE-PROC-E",			"IEE proceedings. Part E. Computers and Digital")
    define("j-IEE-PROC-E",			"IEE Proc. E Comput. Digit. Tech. UK")
    define("j-IEE-PROC-E",			"IEE Proceedings-E")

    define("j-IEE-PROC-COMPUT-DIGIT-TECH",	"IEE Proceedings. Computers and Digital Techniques")
    define("j-IEE-PROC-COMPUT-DIGIT-TECH",	"IEE proc.-comput. digit. tech.")

    define("j-IEE-PROC-VIS-IMAGE-SIGNAL-PROCESS", "IEE proceedings. Vision, image, and signal processing")
    define("j-IEE-PROC-VIS-IMAGE-SIGNAL-PROCESS", "IEE proc.-vis. image signal process.")

    define("j-IEE-REV",				"IEE Review")
    define("j-IEE-REV",				"IEE rev.")
    define("j-IEE-REV",				"Institution of Electrical Engineers review")

    define("j-IEEE-ACCESS",			"IEEE Access")
    define("j-IEEE-ACCESS",			"IEEE Access: Practical Innovations, Open Solutions")
    define("j-IEEE-ACCESS",			"IEEE Access")

    define("j-IEEE-ACM-TASLP",			"IEEE\\slash ACM Transactions on Audio, Speech, and Language Processing")
    define("j-IEEE-ACM-TASLP",			"IEEE/ACM Transactions on Audio, Speech, and Language Processing")
    define("j-IEEE-ACM-TASLP",			"IEEE\\slash ACM Trans. Audio, Speech, Lang. Proc.")

    define("j-IEEE-ANN-HIST-COMPUT",		"IEEE Annals of the History of Computing")
    define("j-IEEE-ANN-HIST-COMPUT",		"IEEE Ann. Hist. Comput.")

    define("j-IEEE-ANTENNAS-WIREL-PROPAG-LETT",	"IEEE Antennas and Wireless Propagation Letters")
    define("j-IEEE-ANTENNAS-WIREL-PROPAG-LETT",	"IEEE Antennas Wirel. Propag. Lett.")

    define("j-IEEE-APM",			"IEEE Antennas and Propagation Magazine")
    define("j-IEEE-ASIA-PACIFIC-CONF-CIRCUITS-SYS-PROC","IEEE Asia-Pacific Conference on Circuits and Systems --- Proceedings")

    define("j-IEEE-ASSP-MAG",			"IEEE ASSP magazine: a publication of the IEEE Acoustics, Speech, and Signal Processing Society")
    define("j-IEEE-ASSP-MAG",			"IEEE ASSP magazine")
    define("j-IEEE-ASSP-MAG",			"IEEE ASSP mag.")
    define("j-IEEE-ASSP-MAG",			"IEEE ASSP Magazine (Acoustics, Speech, and Signal Processing)")

    define("j-IEEE-CAP",			"IEEE computer applications in power: CAP")
    define("j-IEEE-CGA",			"IEEE Computer Graphics and Applications")
    define("j-IEEE-COMM-MAG",			"IEEE Communications Magazine")

    define("j-IEEE-COMMUN-LET",			"IEEE Communications Letters")
    define("j-IEEE-COMMUN-LET",			"IEEE Comm. Let.")
    define("j-IEEE-COMMUN-LET",			"IEEE Commun. Let.")

    define("j-IEEE-COMPUT-ARCHIT-LETT",		"IEEE Computer Architecture Letters")
    define("j-IEEE-COMPUT-ARCHIT-LETT",		"IEEE Comp. Arch. Lett.")
    define("j-IEEE-COMPUT-ARCHIT-LETT",		"IEEE Comp. Archit. Lett.")
    define("j-IEEE-COMPUT-ARCHIT-LETT",		"IEEE Comput. Arch. Lett.")
    define("j-IEEE-COMPUT-ARCHIT-LETT",		"IEEE Comput. Archit. Lett.")

    define("j-IEEE-COMPUT-SCI-ENG",		"IEEE Computational Science \\& Engineering")
    define("j-IEEE-COMPUT-SCI-ENG",		"IEEE Computational Science & Engineering")
    define("j-IEEE-COMPUT-SCI-ENG",		"IEEE Computational Science and Engineering")
    define("j-IEEE-COMPUT-SCI-ENG",		"IEEE comput. sci. eng.")

    define("j-IEEE-CONCURR",			"IEEE Concurrency")
    define("j-IEEE-CONCURR",			"IEEE Concurr.")

    define("j-IEEE-CONTROL-SYST-MAG",		"IEEE Control Systems Magazine")
    define("j-IEEE-CONTROL-SYST-MAG",		"IEEE Control Systems")
    define("j-IEEE-CONTROL-SYST-MAG",		"IEEE control syst. mag.")
    define("j-IEEE-CONTROL-SYST-MAG",		"Control systems magazine (New York, N.Y. : 1981)")
    define("j-IEEE-CONTROL-SYST-MAG",		"Control systems magazine")

    define("j-IEEE-CONF-CONTROL-APPL",		"IEEE Conference on Control Applications --- Proceedings")
    define("j-IEEE-CONF-CONTROL-APPL",		"IEEE Conference on Control Applications")
    define("j-IEEE-CONF-CONTROL-APPL",		"IEEE Conf. Control Appl. Proc.")

    define("j-IEEE-DES-TEST-COMPUT",		"IEEE Design \\& Test of Computers")
    define("j-IEEE-DES-TEST-COMPUT",		"IEEE Design and Test of Computers")
    define("j-IEEE-DES-TEST-COMPUT",		"IEEE Des. Test Comput.")

    define("j-IEEE-DISTRIB-SYST-ONLINE",	"IEEE Distributed Systems Online")
    define("j-IEEE-DISTRIB-SYST-ONLINE",	"IEEE Distrib. Syst. Online")

    define("j-IEEE-ENG-MED-BIOL-MAG",		"IEEE engineering in medicine and biology magazine")
    define("j-IEEE-ENG-MED-BIOL-MAG",		"IEEE engineering in medicine and biology magazin")
    define("j-IEEE-ENG-MED-BIOL-MAG",		"IEEE engineering in medicine and biology magazine: the quarterly magazine of the Engineering in Medicine \\& Biology Society")
    define("j-IEEE-ENG-MED-BIOL-MAG",		"IEEE eng. med. biol. mag.")

    define("j-IEEE-EXPERT",			"IEEE expert: intelligent systems and their applications")
    define("j-IEEE-EXPERT",			"IEEE expert")

    define("j-IEEE-INT-CONF-ALG-ARCH-PAR-PROC",	"IEEE International Conference on Algorithms and Architectures for Parallel Processing")
    define("j-IEEE-INT-PROFL-COMM-CONF",	"IEEE International Professional Communications Conference")
    define("j-IEEE-INT-SYMP-HIGH-PERF-DIST-COMP-PROC","IEEE International Symposium on High Performance Distributed Computing, Proceedings")

    define("j-IEEE-INT-SYMP-INF-THEORY",	"IEEE International Symposium on Information Theory")
    define("j-IEEE-INT-SYMP-INF-THEORY",	"IEEE International Symposium on Information Theory --- Proceedings")
    define("j-IEEE-INT-SYMP-INF-THEORY",	"IEEE Int. Symp. Inf. Theory")

    define("j-IEEE-INTELL-SYST",		"IEEE Intelligent Systems")
    define("j-IEEE-INTELL-SYST",		"IEEE Intell. Syst.")

    define("j-IEEE-INTERNET-COMPUT",		"IEEE Internet Computing")
    define("j-IEEE-INTERNET-COMPUT",		"IEEE Internet Comput.")

    define("j-IEEE-J-QUANT-ELECT",		"IEEE Journal of Quantum Electronics")
    define("j-IEEE-J-QUANT-ELECT",		"IEEE J. Quantum Electronics")
    define("j-IEEE-J-QUANT-ELECT",		"IEEE J. Quantum Elect.")

    define("j-IEEE-J-ROBOTICS-AUTOMATION",	"IEEE Journal of Robotics and Automation")

    define("j-IEEE-J-SEL-AREAS-COMMUN",		"IEEE Journal on Selected Areas in Communications")
    define("j-IEEE-J-SEL-AREAS-COMMUN",		"IEEE j. sel. areas commun.")


    define("j-IEEE-J-SOLID-STATE-CIRCUITS",	"IEEE Journal of Solid-State Circuits")
    define("j-IEEE-J-SOLID-STATE-CIRCUITS",	"IEEE J. Solid-State Circuits")

    define("j-IEEE-LTS",			"IEEE Lightwave Telecommunication Systems")
    define("j-IEEE-LTS",			"IEEE LTS")

    define("j-IEEE-MICRO",			"IEEE Micro")

    define("j-IEEE-MICROW-GUIDED-WAVE-LETT",	"IEEE Microwave and Guided Wave Letters")
    define("j-IEEE-MICROW-GUIDED-WAVE-LETT",	"IEEE microw. guided wave lett.")
    define("j-IEEE-MICROW-GUIDED-WAVE-LETT",	"IEEE microwave and guided wave letters: a publication of the IEEE Microwave Theory and Techniques Society")

    define("j-IEEE-MICROW-WIREL-COMPON-LETT",	"IEEE Microwave and Wireless Components Letters")
    define("j-IEEE-MICROW-WIREL-COMPON-LETT",	"IEEE Microw. Wirel. Comp. Lett.")
    define("j-IEEE-MICROW-WIREL-COMPON-LETT",	"IEEE Microw. Wirel. Compon. Lett.")

    define("j-IEEE-MULTIMEDIA",			"IEEE MultiMedia")
    define("j-IEEE-MULTIMEDIA",			"IEEE Multimedia")
    define("j-IEEE-MULTIMEDIA",			"IEEE Multimed.")

    define("j-IEEE-NETWORK",			"IEEE network")
    define("j-IEEE-NETWORK",			"IEEE network: the magazine of computer communications")
    define("j-IEEE-NETWORK",			"IEEE network: the magazine of computer communi")
    define("j-IEEE-NETWORK",			"IEEE netw.")

    define("j-IEEE-PACIFIC-RIM-CONF-COMM-COMPUT-SIGNAL-PROC-PROC","IEEE Pacific RIM Conference on Communications, Computers, and Signal Processing --- Proceedings")

    define("j-IEEE-PAR-DIST-TECH",		"IEEE Parallel and Distributed Technology: Systems and Applications")
    define("j-IEEE-PAR-DIST-TECH",		"IEEE Parallel and Distributed Technology: System")
    define("j-IEEE-PAR-DIST-TECH",		"IEEE Parallel and Distributed Technology")

    define("j-IEEE-POT",			"IEEE Potentials")

    define("j-IEEE-PHOTONICS-TECHNOL-LETT",	"IEEE Photonics Technology Letters")
    define("j-IEEE-PHOTONICS-TECHNOL-LETT",	"IEEE Photonics Tech. Lett.")
    define("j-IEEE-PHOTONICS-TECHNOL-LETT",	"IEEE Photonics Technol. Lett.")

    define("j-IEEE-ROBOTICS-AUTOMATION-MAG",	"IEEE Robotics \\& Automation Magazine")

    define("j-IEEE-SEC-PRIV",			"IEEE Security \\& Privacy")
    define("j-IEEE-SEC-PRIV",			"IEEE Security & Privacy")

    define("j-IEEE-SIGNAL-PROCESS-LETT",	"IEEE Signal Processing Letters")
    define("j-IEEE-SIGNAL-PROCESS-LETT",	"IEEE Signal Process. Lett.")

    define("j-IEEE-SIGNAL-PROCESS-MAG",		"IEEE Signal Processing Magazine")
    define("j-IEEE-SIGNAL-PROCESS-MAG",		"IEEE Signal Process. Mag.")
    define("j-IEEE-SIGNAL-PROCESS-MAG",		"IEEE SP magazine")
    define("j-IEEE-SIGNAL-PROCESS-MAG",		"Signal Processing Magazine")

    define("j-IEEE-SOFTWARE",			"IEEE Software")
    define("j-IEEE-SOFTWARE",			"IEEE software")

    define("j-IEEE-SPECTRUM",			"IEEE Spectrum")
    define("j-IEEE-SPEECH-SIGNAL-PROC",		"IEEE Speech and Signal Processing")

    define("j-IEEE-SYMP-PAR-DIST-PROC-PROC",	"IEEE Symposium on Parallel and Distributed Processing --- Proceedings")

    define("j-IEEE-TECHNOL-SOC-MAG",		"IEEE technology \\& society magazine")
    define("j-IEEE-TECHNOL-SOC-MAG",		"IEEE technol. soc. mag.")

    define("j-IEEE-TRANS-ACOUST-SPEECH",	"IEEE Transactions on Acoustics, Speech, and Signal Processing")
    define("j-IEEE-TRANS-ACOUST-SPEECH",	"Acoustics, Speech, and Signal Processing [see also IEEE Transactions on Signal Processing], IEEE Transactions on")
    define("j-IEEE-TRANS-ACOUST-SPEECH",	"IEEE Trans. Acoustics, Speech, and Signal Processing")
    define("j-IEEE-TRANS-ACOUST-SPEECH",	"IEEE Trans. Acoustics, Speech, and Signal Proc.")
    define("j-IEEE-TRANS-ACOUST-SPEECH",	"IEEE Trans. Acoust., Speech, and Signal Process.")
    define("j-IEEE-TRANS-ACOUST-SPEECH",	"IEEE Trans. Acoust. Speech Signal Process (ASSP)")
    define("j-IEEE-TRANS-ACOUST-SPEECH",	"IEEE Trans. Acoust., Speech, Signal Processing")

    define("j-IEEE-TRANS-AEROSP-ELECTRON-SYST",	"IEEE Transactions on Aerospace and Electronic Systems")
    define("j-IEEE-TRANS-AEROSP-ELECTRON-SYST",	"IEEE trans. aerosp. electron. syst.")
    define("j-IEEE-TRANS-AEROSP-ELECTRON-SYST",	"IEEE Trans. Aerospace Electronic Systems")

    define("j-IEEE-TRANS-ANTENNAS-PROPAG",	"IEEE Transactions on Antennas and Propagation")
    define("j-IEEE-TRANS-ANTENNAS-PROPAG",	"IEEE trans. antennas propag.")
    define("j-IEEE-TRANS-ANTENNAS-PROPAG",	"IEEE Trans. Antennas Propagation")
    define("j-IEEE-TRANS-ANTENNAS-PROPAG",	"IEEE Trans. Antennas and Propagation")
    define("j-IEEE-TRANS-ANTENNAS-PROPAG",	"IEEE Trans. Antennas Propagat.")

    define("j-IEEE-TRANS-APPL-SUPERCOND",	"IEEE Transactions on Applied Superconductivity")
    define("j-IEEE-TRANS-APPL-SUPERCOND",	"IEEE Trans. Appl. Supercond.")

    define("j-IEEE-TRANS-AUDIO-ELECTROACOUST",	"IEEE Transactions on Audio and Electroacoustics")
    define("j-IEEE-TRANS-AUDIO-ELECTROACOUST",	"IEEE Trans. Audio Electroacoust.")
    define("j-IEEE-TRANS-AUDIO-ELECTROACOUST",	"IEEE Trans. Audio Electroacoustics")

    define("j-IEEE-TRANS-AUTOMAT-CONTR",	"IEEE Transactions on Automatic Control")
    define("j-IEEE-TRANS-AUTOMAT-CONTR",	"IEEE Trans. Aut. Cont.")
    define("j-IEEE-TRANS-AUTOMAT-CONTR",	"IEEE Trans. Automat. Control")
    define("j-IEEE-TRANS-AUTOMAT-CONTR",	"IEEE Trans. Automatic Control")

    define("j-IEEE-TRANS-BIG-DATA",		"IEEE Transactions on Big Data")

    define("j-IEEE-TRANS-BIOMED-ENG",		"IEEE Transactions on Biomedical Engineering")
    define("j-IEEE-TRANS-BIOMED-ENG",		"IEEE trans. biomed. eng.")
    define("j-IEEE-TRANS-BIOMED-ENG",		"IEEE Trans. Biomedical Engrg.")
    define("j-IEEE-TRANS-BIOMED-ENG",		"IEEE Trans. Biomedical Eng.")

    define("j-IEEE-TRANS-BROADCAST",		"IEEE Transactions on Broadcasting")
    define("j-IEEE-TRANS-BROADCAST",		"IEEE Trans. Broadcast.")

    define("j-IEEE-TRANS-CAD-ICS",		"IEEE Transactions on Computer-Aided Design of Integrated Circuits and Systems")
    define("j-IEEE-TRANS-CAD-ICS",		"IEEE Trans. on Computer-Aided Design")
    define("j-IEEE-TRANS-CAD-ICS",		"IEEE Transactions on Computer-Aided Design")

    define("j-IEEE-TRANS-CIRCUIT-THEORY",	"IEEE Transactions on Circuit Theory")
    define("j-IEEE-TRANS-CIRCUIT-THEORY",	"IEEE Trans. Circuit Theory")

    define("j-IEEE-TRANS-CIRCUITS-SYST",	"IEEE Transactions on Circuits and Systems")
    define("j-IEEE-TRANS-CIRCUITS-SYST",	"IEEE trans. circuits syst.")
    define("j-IEEE-TRANS-CIRCUITS-SYST",	"IEEE Trans. Circuits and Systems")
    define("j-IEEE-TRANS-CIRCUITS-SYST",	"IEEE Trans. CAS")
    define("j-IEEE-TRANS-CIRCUITS-SYST",	"IEEE Trans. on Circuits and Systems")
    define("j-IEEE-TRANS-CIRCUITS-SYST",	"Circuits and Systems, IEEE Transactions on [legacy, pre - 1988]")

    define("j-IEEE-TRANS-CIRCUITS-SYST-1",	"IEEE Transactions on Circuits and Systems I: Regular Papers")
    define("j-IEEE-TRANS-CIRCUITS-SYST-1",	"IEEE Transactions on Circuits and Systems. I")
    define("j-IEEE-TRANS-CIRCUITS-SYST-1",	"IEEE Trans. Circuits. Syst., I Regul. Pap.")

    define("j-IEEE-TRANS-CIRCUITS-SYST-2",	"IEEE Transactions on Circuits and Systems. 2, Analog and Digital Signal Processing")
    define("j-IEEE-TRANS-CIRCUITS-SYST-2",	"IEEE Transactions on Circuits and Systems. 2, Analog and Digital Signal Processing: a publication of the {IEEE Circuits and Systems Society}")
    define("j-IEEE-TRANS-CIRCUITS-SYST-2",	"IEEE Trans. Circuits Syst., 2 Analog Digit. Signal Process.")
    define("j-IEEE-TRANS-CIRCUITS-SYST-2",	"IEEE Transactions on Circuits and Systems II: Analog and Digital Signal Processing")
    define("j-IEEE-TRANS-CIRCUITS-SYST-2",	"Circuits and Systems II: Analog and Digital Signal Processing, IEEE Transactions on [see also Circuits and Systems II: Express Briefs, IEEE Transactions on]")

    define("j-IEEE-TRANS-CIRCUITS-SYST-I-FUNDAM-THEORY-APPL", "IEEE Transactions on Circuits and Systems I: Fundamental Theory and Application")
    define("j-IEEE-TRANS-CIRCUITS-SYST-I-FUNDAM-THEORY-APPL", "IEEE Trans. Circuits Syst. I, Fundam. Theory Appl.")

    define("j-IEEE-TRANS-CIRCUITS-SYST-II-EXPRESS-BRIEFS", "IEEE Transactions on Circuits and Systems II: Express Briefs")
    define("j-IEEE-TRANS-CIRCUITS-SYST-II-EXPRESS-BRIEFS", "IEEE Trans. Circuits Syst., II Express Briefs")


    define("j-IEEE-TRANS-CIRCUITS-SYST-VIDEO-TECH", "IEEE Transactions on Circuits and Systems for Video Technology")

    define("j-IEEE-TRANS-COMM",			"IEEE Transactions on Communications")
    define("j-IEEE-TRANS-COMM",			"IEEE Trans. Comm.")
    define("j-IEEE-TRANS-COMM",			"IEEE Trans. Communications")

    define("j-IEEE-TRANS-COMMUN-TECHNOL",	"IEEE Transactions on Communications Technology")
    define("j-IEEE-TRANS-COMMUN-TECHNOL",	"IEEE Trans. Comm. Tech.")
    define("j-IEEE-TRANS-COMMUN-TECHNOL",	"IEEE Trans. Comm. Technol.")
    define("j-IEEE-TRANS-COMMUN-TECHNOL",	"IEEE Trans. Commun. Tech.")
    define("j-IEEE-TRANS-COMMUN-TECHNOL",	"IEEE Trans. Commun. Technol.")

    define("j-IEEE-TRANS-COMPUT",		"IEEE Transactions on Computers")
    define("j-IEEE-TRANS-COMPUT",		"IEEE Trans. Computers")
    define("j-IEEE-TRANS-COMPUT",		"IEEE trans. on comp.")
    define("j-IEEE-TRANS-COMPUT",		"IEEE Trans. Comput.")

    define("j-IEEE-TRANS-COMPONENTS-HYBRIDS-MANUF-TECHNOL",	"IEEE Transactions on Components, Hybrids, and Manufacturing Technology")
    define("j-IEEE-TRANS-COMPONENTS-HYBRIDS-MANUF-TECHNOL",	"IEEE Trans. Components Hybrids Manuf. Technol.")
    define("j-IEEE-TRANS-COMPONENTS-HYBRIDS-MANUF-TECHNOL",	"IEEE Transactions on Components, Hybrids, and Man")

    define("j-IEEE-TRANS-COMPONENTS-PACK-MANUF-TECHNOL-A",	"IEEE Transactions on Components, Packaging, and Manufacturing Technology. {Part A}: a publication of the {IEEE Components, Packaging, and Manufacturing Technology Society}")
    define("j-IEEE-TRANS-COMPONENTS-PACK-MANUF-TECHNOL-A",	"IEEE Trans. Components. Pack. Manuf. Technol. {Part A}")

    define("j-IEEE-TRANS-CONSUMER-ELECTRONICS", "IEEE Transactions on Consumer Electronics")

    define("j-IEEE-TRANS-CONTROL-SYST-TECHNOL",	"IEEE Transactions on Control Systems Technology")
    define("j-IEEE-TRANS-CONTROL-SYST-TECHNOL",	"IEEE Trans. Control Syst. Technol.")

    define("j-IEEE-TRANS-EDUC",			"IEEE Transactions on Education")
    define("j-IEEE-TRANS-EDUC",			"IEEE Trans. Education")

    define("j-IEEE-TRANS-ELEC-COMP",		"IEEE Transactions on Electronic Computers")

    define("j-IEEE-TRANS-ELEC-INSUL",		"IEEE Transactions on Electrical Insulation")

    define("j-IEEE-TRANS-ELECTROMAGN-COMPAT",	"IEEE Transactions on Electromagnetic Compatibility")
    define("j-IEEE-TRANS-ELECTROMAGN-COMPAT",	"IEEE Trans. Electromagn. Compat.")

    define("j-IEEE-TRANS-ELECTRON-DEVICES",	"IEEE Transactions on Electron Devices")
    define("j-IEEE-TRANS-ELECTRON-DEVICES",	"IEEE Trans. Electron Devices")
    define("j-IEEE-TRANS-ELECTRON-DEVICES",	"IEEE Trans. on Electron Devices")

    define("j-IEEE-TRANS-EMERG-TOP-COMPUT",	"IEEE Transactions on Emerging Topics in Computing")
    define("j-IEEE-TRANS-EMERG-TOP-COMPUT",	"IEEE Trans. Emerg. Top. Comput.")

    define("j-IEEE-TRANS-ENG-WRIT-SPEECH",	"IEEE Transactions on Engineering Writing and Speech")
    define("j-IEEE-TRANS-ENG-WRIT-SPEECH",	"IEEE trans. eng. writ. speech")
    define("j-IEEE-TRANS-ENG-WRIT-SPEECH",	"IEEE Trans. Engineering Writing and Speech")

    define("j-IEEE-TRANS-FUZZY-SYSTEMS",	"IEEE Transactions on Fuzzy Systems")
    define("j-IEEE-TRANS-FUZZY-SYSTEMS",	"IEEE Trans. Fuzzy Syst.")
    define("j-IEEE-TRANS-FUZZY-SYSTEMS",	"Fuzzy Systems")

    define("j-IEEE-TRANS-GEOSCI-REMOTE-SENSING","IEEE Transactions on Geoscience and Remote Sensing")
    define("j-IEEE-TRANS-GEOSCI-REMOTE-SENSING","IEEE Trans. Geo. Remote Sensing")
    define("j-IEEE-TRANS-GEOSCI-REMOTE-SENSING","IEEE Transactions on Geoscience and Remote Sensing: a publication of the {IEEE Geoscience and Remote Sensing Society}")

    define("j-IEEE-TRANS-IMAGE-PROCESS",	"IEEE Transactions on Image Processing")
    define("j-IEEE-TRANS-IMAGE-PROCESS",	"IEEE Trans. Image Process.")

    define("j-IEEE-TRANS-IND-ELECTRON",		"IEEE Transactions on Industrial Electronics")
    define("j-IEEE-TRANS-IND-ELECTRON",		"IEEE Transactions on Industrial Electronics: a publication of the {IEEE Industrial Electronics Society}")
    define("j-IEEE-TRANS-IND-ELECTRON",		"IEEE Trans. Ind. Electron.")

    define("j-IEEE-TRANS-INF-FOREN-SEC",	"IEEE Transactions on Information Forensics and Security")
    define("j-IEEE-TRANS-INF-FOREN-SEC",	"IEEE Trans. Inf. Foren. Sec.")

    define("j-IEEE-TRANS-INF-THEORY",		"IEEE Transactions on Information Theory")
    define("j-IEEE-TRANS-INF-THEORY",		"IEEE Trans. on Information Theory")
    define("j-IEEE-TRANS-INF-THEORY",		"IEEE Trans. Inf. Theory")
    define("j-IEEE-TRANS-INF-THEORY",		"IEEE Trans. Inform. Theory")

    define("j-IEEE-TRANS-INSTRUM-MEAS",		"IEEE Transactions on Instrumentation and Measurement")
    define("j-IEEE-TRANS-INSTRUM-MEAS",		"IEEE Trans. Instrum. Meas.")

    define("j-IEEE-TRANS-KNOWL-DATA-ENG",	"IEEE Transactions on Knowledge and Data Engineering")
    define("j-IEEE-TRANS-KNOWL-DATA-ENG",	"IEEE Transactions on Knowledge and Data Engineer")
    define("j-IEEE-TRANS-KNOWL-DATA-ENG",	"IEEE Trans. on Knowledge and Data Eng.")

    define("j-IEEE-TRANS-MAGNETICS",		"IEEE Transactions on Magnetics")
    define("j-IEEE-TRANS-MAGNETICS",		"IEEE Trans. on Magnetics")
    define("j-IEEE-TRANS-MAGNETICS",		"IEEE Trans. on Magn.")

    define("j-IEEE-TRANS-MED-IMAG",		"IEEE Transactions on Medical Imaging")
    define("j-IEEE-TRANS-MED-IMAG",		"IEEE Trans. Med. Imag.")
    define("j-IEEE-TRANS-MED-IMAG",		"IEEE Medical Imaging")

    define("j-IEEE-TRANS-MICROWAVE-THEORY-TECH","IEEE transactions on microwave theory and techniques")
    define("j-IEEE-TRANS-MICROWAVE-THEORY-TECH","IEEE trans. microwave theor. tech.")
    define("j-IEEE-TRANS-MICROWAVE-THEORY-TECH","IEEE Trans. Microwave Theory and Techniques")

    define("j-IEEE-TRANS-NETWORKING",		"IEEE\\slash ACM Transactions on Networking")
    define("j-IEEE-TRANS-NETWORKING",		"IEEE/ACM Transactions on Networking")
    define("j-IEEE-TRANS-NETWORKING",		"IEEE\\slash ACM transactions on Networking: a joint publication of the {IEEE Communications Society}, the {IEEE Computer Society}, and the {ACM} with its {Special Interest Group on Data Communication}")

    define("j-IEEE-TRANS-NEURAL-NETW",		"IEEE Transactions on Neural Networks")
    define("j-IEEE-TRANS-NEURAL-NETW",		"IEEE Trans. Neural Netw.")
    define("j-IEEE-TRANS-NEURAL-NETW",		"IEEE Trans. Neural Networks")

    define("j-IEEE-TRANS-NUCL-SCI",		"IEEE Transactions on Nuclear Science")
    define("j-IEEE-TRANS-NUCL-SCI",		"IEEE Trans. Nucl. Sci.")

    define("j-IEEE-TRANS-PAR-DIST-SYS",		"IEEE Transactions on Parallel and Distributed Systems")
    define("j-IEEE-TRANS-PAR-DIST-SYS",		"IEEE Transactions on Parallel and Distributed Sy")
    define("j-IEEE-TRANS-PAR-DIST-SYS",		"IEEE Trans. Par. Dist. Sys.")

    define("j-IEEE-TRANS-PATT-ANAL-MACH-INTEL",	"IEEE Transactions on Pattern Analysis and Machine Intelligence")
    define("j-IEEE-TRANS-PATT-ANAL-MACH-INTEL",	"IEEE Trans. on Pattern Anal. and Machine Intel.")
    define("j-IEEE-TRANS-PATT-ANAL-MACH-INTEL",	"IEEE Trans. Pattern Analysis and Machine Intelligence")
    define("j-IEEE-TRANS-PATT-ANAL-MACH-INTEL",	"IEEE Trans. Pattern Anal. Mach. Intell.")

    define("j-IEEE-TRANS-POWER-DELIV",		"IEEE Transactions on Power Delivery")
    define("j-IEEE-TRANS-POWER-DELIV",		"IEEE Trans. Power Deliv.")
    define("j-IEEE-TRANS-POWER-DELIV",		"IEEE Transactions on Power Delivery: a publica")

    define("j-IEEE-TRANS-POWER-SYSTEMS",	"IEEE Transactions on Power Systems")
    define("j-IEEE-TRANS-POWER-SYSTEMS",	"IEEE Trans. Power Systems")

    define("j-IEEE-TRANS-PLASMA-SCI",		"IEEE Transactions on Plasma Science")
    define("j-IEEE-TRANS-PLASMA-SCI",		"IEEE Trans. Plasma Sci.")

    define("j-IEEE-TRANS-PROF-COMMUN",		"IEEE Transactions on Professional Communication")
    define("j-IEEE-TRANS-PROF-COMMUN",		"IEEE Trans. Prof. Comm.")
    define("j-IEEE-TRANS-PROF-COMMUN",		"IEEE Trans. Prof. Commun.")

    define("j-IEEE-TRANS-REHABIL-ENG",		"IEEE Transactions on Rehabilitation Engineering")
    define("j-IEEE-TRANS-REHABIL-ENG",		"IEEE Trans. Rehabil. Eng.")

    define("j-IEEE-TRANS-RELIAB",		"IEEE Transactions on Reliability")
    define("j-IEEE-TRANS-RELIAB",		"IEEE Trans. Reliab.")
    define("j-IEEE-TRANS-RELIAB",		"IEEE Trans. Reliability")

    define("j-IEEE-TRANS-ROBOT",		"IEEE Transactions on Robotics")
    define("j-IEEE-TRANS-ROBOT",		"IEEE Trans. Robot.")

    define("j-IEEE-TRANS-ROBOT-AUTOM",		"IEEE Transactions on Robotics and Automation")
    define("j-IEEE-TRANS-ROBOT-AUTOM",		"IEEE trans. robot. autom.")

    define("j-IEEE-TRANS-SIG-PROC",		"IEEE Transactions on Signal Processing")
    define("j-IEEE-TRANS-SIG-PROC",		"IEEE Trans. Signal Processing")
    define("j-IEEE-TRANS-SIG-PROC",		"IEEE Trans. Signal Process.")
    define("j-IEEE-TRANS-SIG-PROC",		"Signal Processing, IEEE Transactions on [see also Acoustics, Speech, and Signal Processing, IEEE Transactions on]")

    define("j-IEEE-TRANS-SOFTW-ENG",		"IEEE Transactions on Software Engineering")
    define("j-IEEE-TRANS-SOFTW-ENG",		"IEEE Trans. Softw. Eng.")
    define("j-IEEE-TRANS-SOFTW-ENG",		"IEEE Trans. on Software Engineering")
    define("j-IEEE-TRANS-SOFTW-ENG",		"IEEE Transactions on Software Engineering (SE)")
    define("j-IEEE-TRANS-SOFTW-ENG",		"IEEE Trans. Software Engrg.")

    define("j-IEEE-TRANS-SYST-MAN-CYBERN",	"IEEE Transactions on Systems, Man, and Cybernetics")
    define("j-IEEE-TRANS-SYST-MAN-CYBERN",	"IEEE Trans. Syst. Man Cybern.")
    define("j-IEEE-TRANS-SYST-MAN-CYBERN",	"IEEE Transactions on Systems, Man, and Cyberneti")
    define("j-IEEE-TRANS-SYST-MAN-CYBERN",	"IEEE Trans. Systems, Man, and Cybernetics")

    define("j-IEEE-TRANS-VEH-TECHNOL",		"IEEE Transactions on Vehicular Technology")
    define("j-IEEE-TRANS-VEH-TECHNOL",		"IEEE Trans. Veh. Technol.")

    define("j-IEEE-TRANS-VIS-COMPUT-GRAPH",	"IEEE Transactions on Visualization and Computer Graphics")
    define("j-IEEE-TRANS-VIS-COMPUT-GRAPH",	"IEEE Trans. Vis. Comput. Graph.")

    define("j-IEEE-TRANS-VLSI-SYST",            "IEEE Transactions on Very Large Scale Integration (VLSI) Systems")
    define("j-IEEE-TRANS-VLSI-SYST",            "IEEE Trans. VLSI Syst.")

    define("j-IEEE-TRANS-WIREL-COMMUN",		"IEEE Transactions on Wireless Communications")
    define("j-IEEE-TRANS-WIREL-COMMUN",		"IEEE Trans. Wirel. Commun.")

    define("j-IEICE-TCEIS",			"IEICE Transactions on Communications, Electronics, Information, and Systems")
    define("j-IEICE-TCEIS",			"IEICE Transactions on Communications\\slash Electronics\\slash Information and Systems")

    define("j-IEICE-TRANS-COMMUN",		"IEICE Transactions on Communications")
    define("j-IEICE-TRANS-COMMUN",		"IEICE Trans. Commun.")

    define("j-IEICE-TRANS-ELECT",		"IEICE Transactions on Electronics")

    define("j-IEICE-TRANS-FUND-ELECT",		"IEICE Transactions on Fundamentals of Electronics Communications and Computer Sciences")
    define("j-IEICE-TRANS-FUND-ELECT",		"IEICE Transactions on Fundamentals of Electronic")

    define("j-IETE-TECH-REV",			"IETE Technical Review")
    define("j-IETE-TECH-REV",			"IETE Tech. Rev.")

    define("j-IFIP-TRANS-A",			"IFIP Transactions. A. Computer Science and Technology")
    define("j-IFIP-TRANS-A",			"IFIP Transactions A [Computer Science and Technology]")
    define("j-IFIP-TRANS-A",			"IFIP Transactions A (Computer Science and Technology)")
    define("j-IFIP-TRANS-B",			"IFIP Transactions B [Applications in Technology]")

    define("j-IFLA-J",				"IFLA journal / International Federation of Library Associations")
    define("j-IFLA-J",				"IFLA journal")
    define("j-IFLA-J",				"IFLA j.")

    define("j-IIE-TRANS",			"IIE Transactions")
    define("j-IIE-TRANS",			"IIE Trans.")

    define("j-IJCSS",				"International Journal of Computer Science and Security (IJCSS)")
    define("j-IJCSS",				"International Journal of Computer Science and Security")
    define("j-IJCSS",				"Int. J. Comp. Sci. Sec.")

    define("j-IJQC",				"International Journal of Quantum Chemistry")
    define("j-IJQC",				"Int. J. Quant. Chem.")

    define("j-IJQC-BIO-SYMP",			"International Journal of Quantum Chemistry. Quantum Biology Symposium: Proceedings of the International Symposium on Quantum Biology and Quantum Pharmacology")

    define("j-IJQC-SYMP",			"International Journal of Quantum Chemistry. Quantum Chemistry Symposium")
    define("j-IJQC-SYMP",			"International Journal of Quantum Chemistry. Symposium")

    # Journal name from 1987--1993
    define("j-IJSA",				"International Journal of Supercomputer Applications")
    define("j-IJSA",				"International Journal of Supercomputer Appli")
    define("j-IJSA",				"Int Journal of Supercomputer Applications")
    define("j-IJSA",				"Int. J. Supercomputer Appl.")
    define("j-IJSA",				"Int. J. Supercomputer Applications")
    define("j-IJSA",				"Int. J. Supercomputer Applics")
    define("j-IJSA",				"Int. J. of Supercomputer Applics.")
    define("j-IJSA",				"The International Journal of Supercomputer Applications")

    # Journal renamed in 1994:
    define("j-IJSAHPC",				"International Journal of Supercomputer Applications and High Performance Computing")

    define("j-ILL-J-MATH",			"Illinois Journal of Mathematics")
    define("j-ILL-J-MATH",			"Illinois J. Math.")

    define("j-IM-INFORMATION-MANAGEMENT",	"IM Information Management")
    define("j-IMA-BULL",			"IMA Bulletin")	# International MIDI Association Bulletin???

    define("j-IMA-J-APPL-MATH",			"IMA journal of applied mathematics")
    define("j-IMA-J-APPL-MATH",			"IMA j. appl. math.")

    define("j-IMA-J-MATH-CONTROL-INF",		"IMA Journal of Mathematical Control and Information")
    define("j-IMA-J-MATH-CONTROL-INF",		"IMA J. Math. Control Inf.")
    define("j-IMA-J-MATH-CONTROL-INF",		"IMA J. of Math. Control and Information")

    define("j-IMA-J-MATH-APPL-MED-BIOL",	"IMA journal of mathematics applied in medicine and biology")
    define("j-IMA-J-MATH-APPL-MED-BIOL",	"IMA J. Math. Appl. Med. Biol.")
    define("j-IMA-J-MATH-APPL-MED-BIOL",	"IMA J. Math. Applied in Med. and Biol.")
    define("j-IMA-J-MATH-APPL-MED-BIOL",	"IMA J. Math. Applied in Medicine and Biol.")
    define("j-IMA-J-MATH-APPL-MED-BIOL",	"IMA J. Math. Appl. in Medic.\\& Biol.")
    define("j-IMA-J-MATH-APPL-MED-BIOL",	"I.M.A. Journal Math. Appl.in Med. and Biol.")
    define("j-IMA-J-MATH-APPL-MED-BIOL",	"IMA J. Maths. Appl. Med. Biol.")

    define("j-IMA-J-NUMER-ANAL",		"IMA Journal of Numerical Analysis")
    define("j-IMA-J-NUMER-ANAL",		"IMA J. Numer. Anal.")
    define("j-IMA-J-NUMER-ANAL",		"IMA J. of Num. Anal.")

    define("j-IMA-NUM-ANA-NEWSLETTER",		"IMA Numerical Analysis Newsletter")

    define("j-IMAGE-VIDEO-PROCESS",		"Image and Video Processing")
    define("j-IMAGE-VIDEO-PROCESS",		"Image Video Process.")

    define("j-IMAGE-VIS-COMPUT",		"Image and Vision Computing")
    define("j-IMAGE-VIS-COMPUT",		"Image vis. comput.")

    define("j-IMAGING-MAGAZINE",                "Imaging Magazine")

    define("j-IMMUNOL-HEMATOL-RES-MONOGR",	"Immunology and Hematology Research Monographs")
    define("j-IMMUNOL-HEMATOL-RES-MONOGR",	"Immunol. Hematol. Res. Monogr.")

    define("j-IMP-COMP-SCI-ENG",		"Impact of Computing in Science and Engineering")
    define("j-IMP-COMP-SCI-ENG",		"Impact Comput. Sci. Eng.")
    define("j-IMP-COMP-SCI-ENG",		"Impact Comput. Sci. Engrg.")

    ## NB: j-BULL-INST-MATH-STAT became j-IMS-BULL in 1998
    define("j-IMS-BULL",			"IMS Bulletin (Institute of Mathematical Statistics)")
    define("j-IMS-BULL",			"IMS Bulletin")
    define("j-IMS-BULL",			"IMS Bull.")

    define("j-IMWUT",				"Proceedings of the ACM on Interactive, Mobile, Wearable and Ubiquitous Technologies (IMWUT)")
    define("j-IMWUT",				"Proceedings of the ACM on Interactive, Mobile, Wearable and Ubiquitous Technologies")
    define("j-IMWUT",				"Proc. ACM Interactive, Mobile, Wearable, Ubiquitous Technol.")

    define("j-IN-PLANT-REPROD",			"In-plant Reproductions")
    define("j-IN-PLANT-REPROD",			"In-plant reprod.")

    define("j-IN-VITRO-CEL-DEV-BIO-ANIM",	"In Vitro Cellular \\& Developmental Biology. Animal")
    define("j-IN-VITRO-CEL-DEV-BIO-ANIM",	"In Vitro Cellular and Developmental Biology. Animal")
    define("j-IN-VITRO-CEL-DEV-BIO-ANIM",	"In Vitro Cell. Dev. Biol., Anim.")

    define("j-INC",                             "Inc")

    define("j-INCIDER",				"InCider")
    define("j-INCIDER-A",			"InCider A+")

    define("j-IND-ENG-CHEM-RES",		"Industrial and engineering chemistry research")
    define("j-IND-ENG-CHEM-RES",		"Ind. eng. chem. res.")

    define("j-IND-MATH",			"Industrial Mathematics")
    define("j-IND-MATH",			"Ind. Math.")
    define("j-IND-MATH",			"Indust. Math.")

    define("j-IND-WEEK",			"Industry Week")
    define("j-IND-WEEK",			"Ind. Week")

    define("j-INDAG-MATH",			"Indagationes Mathematic{\\ae}")
    define("j-INDAG-MATH",			"Indag. math.")

    define("j-INDAG-MATH-PROC",			"Indagationes Mathematicae (Proceedings)")
    define("j-INDAG-MATH-PROC",			"Indag. Math. (Proc.)")

    define("j-INDEXER",				"The Indexer")

    define("j-INDIAN-J-BIOCHEM-BIOPHYS",	"Indian journal of biochemistry and biophysics")
    define("j-INDIAN-J-BIOCHEM-BIOPHYS",	"Indian J Biochem Biophys (GHW)")

    define("j-INDIAN-J-EXP-BIO",		"Indian journal of experimental biology")
    define("j-INDIAN-J-EXP-BIO",		"Indian J Exp Biol (GIZ)")

    define("j-INDIAN-J-HIST-SCI",		"Indian Journal of the History of Science")
    define("j-INDIAN-J-HIST-SCI",		"Indian J. Hist. Sci.")

    define("j-INDIAN-J-MATH",			"Indian Journal of Mathematics")
    define("j-INDIAN-J-MATH",			"Indian J. Math.")

    define("j-INDIANA-U-MATH",			"Indiana University mathematics journal")
    define("j-INDIANA-U-MATH",			"Indiana Univ. Math. J.")

    define("j-INF-COMM-TECH-LAW",		"Information \\& Communications Technology Law")
    define("j-INF-COMM-TECH-LAW",		"Inf. Comm. Tech. Law")

    define("j-INF-COMPUT",			"Information and Computation")
    define("j-INF-COMPUT",			"Information and Computation (Print)")
    define("j-INF-COMPUT",			"Information and Computation (formerly Information and Control)")
    define("j-INF-COMPUT",			"Inform. Comput.")
    define("j-INF-COMPUT",			"Inf. comput.")
    define("j-INF-COMPUT",			"Inf. comput. (Print)")

    define("j-INF-CONTROL",			"Information and Control")
    define("j-INF-CONTROL",			"Inf. Control")
    define("j-INF-CONTROL",			"Inform. Contr.")

    define("j-INF-INTELL-ONLINE-LIB-MICROCOMPUT", "Information intelligence, online libraries, and microcomputers")
    define("j-INF-INTELL-ONLINE-LIB-MICROCOMPUT", "Information intelligence, online libraries, and")
    define("j-INF-INTELL-ONLINE-LIB-MICROCOMPUT", "Inf. intell., online libr. microcomputers")

    define("j-INF-INTELL-ONLINE-NEWSL",		"Information intelligence online newsletter")
    define("j-INF-INTELL-ONLINE-NEWSL",		"Inf. intell. online newsl.")

    define("j-INF-PROC",			"Information processing")
    define("j-INF-PROC",			"Inf. Proc.")

    define("j-INF-PROCESS-MACH",		"Information processing machines")
    define("j-INF-PROCESS-MACH",		"Inf. process. mach.")

    define("j-INF-RETR",			"Information Retrieval")
    define("j-INF-RETR",			"Inf. Retr.")

    define("j-INF-SOC",				"The Information Society")
    define("j-INF-SOC",				"Information Society")
    define("j-INF-SOC",				"Inf. Soc.")

    define("j-INF-STAND-Q",			"Information Standards Quarterly")
    define("j-INF-STAND-Q",			"Inf. Stand. Q.")

    define("j-INF-STORAGE-RETR",		"Information Storage and Retrieval")
    define("j-INF-STORAGE-RETR",		"Inf. storage retr.")

    define("j-INF-TECH-RES-DEV-APPL",		"Information Technology: Research Development Applications")
    define("j-INF-TECH-RES-DEV-APPL",		"Information Technology, Research and Development")
    define("j-INF-TECH-RES-DEV-APPL",		"Inf. Tech. Res. Dev. Appl.")

    define("j-INFECT-IMMUN",			"Infection and immunity")
    define("j-INFECT-IMMUN",			"Infect. immun. (Print)")
    define("j-INFECT-IMMUN",			"Infect. immun.")

    define("j-INFO-CANADA",			"Info Canada")

    # Replaced by j-INF-COMPUT
    # define("j-INFO-COMP",			"Information and Computation (formerly Information and Control)")
    # define("j-INFO-COMP",			"Inform. Comput.")

    define("j-INFO-DB",				"Info DB")
    define("j-INFO-DECISION-TECHNOLOGIES",	"Information and Decision Technologies")
    define("j-INFO-FERNSPRECH-VERMITT",		"Informationen Fernsprech-Vermittlungstechnik")
    define("j-INFO-MANAGEMENT-COMP-SECURITY",	"Information Management and Computer Security")
    define("j-INFO-MANAGEMENT-TECH",		"Information Management \\& Technology")

    define("j-INFO-PROC-LETT",			"Information Processing Letters")
    define("j-INFO-PROC-LETT",			"Inform. Process. Lett.")
    define("j-INFO-PROC-LETT",			"Information Processing Lett.")
    define("j-INFO-PROC-LETT",			"Inf. Process. Lett.")

    define("j-INFO-PROC-MAN",			"Information Processing and Management")
    define("j-INFO-PROC-MAN",			"Inf. Process. Manage.")

    define("j-INFO-RETRIEVAL-LIB-AUTO",		"Information Retrieval and Library Automation")

    define("j-INFO-SCI",			"Information Sciences")
    define("j-INFO-SCI",			"Information Sciences: An international journal")
    define("j-INFO-SCI",			"Information sciences")
    define("j-INFO-SCI",			"Inform. Sci.")
    define("j-INFO-SCI",			"Info. Sci.")

    define("j-INFO-SEC-TECH-REP",		"Information Security Technical Report")
    define("j-INFO-SEC-TECH-REP",		"Info. Sec. Tech. Rep.")

    define("j-INFO-SERVICES-USE",		"Information Services and Use")
    define("j-INFO-SOFTWARE-TECH",		"Information and Software Technology")

    define("j-INFO-SYS",			"Information systems")
    define("j-INFO-SYS",			"Information system")
    define("j-INFO-SYS",			"Inf. Sys.")

    define("j-INFO-SYST-J",			"Information Systems Journal")
    define("j-INFO-SYST-J",			"Info. Syst. J.")

    define("j-INFO-TECH-HUMAN",			"Information Technology in the Humanities: Tools, Techniques and Applications")
    define("j-INFO-TECH-LIB",			"Information Technology and Libraries")

    define("j-INFO-TECH-NURSING",		"Information technology in nursing")
    define("j-INFO-TECH-NURSING",		"Information technology in nursing: journal of the Nursing Specialist Group of the British Computer Society")

    define("j-INFOR",				"INFOR")

    define("j-INFORM-DIR",			"Informatica e diritto")
    define("j-INFORM-DIR",			"Inform. dir.")

    define("j-INFORM-THEOR-APPL",		"RAIRO. Informatique th{\\'e}orique et applications := Theoretical informatics and applications")
    define("j-INFORM-THEOR-APPL",		"Informatique th{\\'e}orique et applications := Theoretical informatics and applications")
    define("j-INFORM-THEOR-APPL",		"Inform. Th{\\'e}or. Appl.")
    define("j-INFORM-THEOR-APPL",		"Theoretical Informatics and Applications. Informatique Th{\\'e}orique et Applications")
    define("j-INFORM-THEOR-APPL",		"Theor. Inform. Appl.")

    define("j-INFORMACNE-SYSTEMY",		"Informacne Systemy")

    define("j-INFORMATICA",			"Informatica (Ljubljana, Slovenia)")
    define("j-INFORMATICA",			"Informatica (Ljubl.)")
    define("j-INFORMATICA",			"Informatica")

    define("j-INFORMATIE",			"Informatie")
    define("j-INFORMATIK-FACHBERICHTE",		"Informatik Fachberichte")
    define("j-INFORMATIK-INFORMATIONEN-REPORTE","Informatik, Informationen Reporte")
    define("j-INFORMATIK-SPEKTRUM",		"Informatik Spektrum")
    define("j-INFORMATION-WEEK",		"Information Week")

    define("j-INFORMATIONS-TECHNIK",		"Informationstechnik --- IT")
    define("j-INFORMATIONS-TECHNIK",		"IT: Informationstechnik")
    define("j-INFORMATIONS-TECHNIK",		"Informations-technik")
    define("j-INFORMATIONS-TECHNIK",		"Informationstechnik \\emdash IT")
    define("j-INFORMATIONS-TECHNIK",		"Informationstechnik - IT")

    define("j-INFORMS-J-COMPUT",                "INFORMS Journal on Computing")
    define("j-INFORMS-J-COMPUT",                "INFORMS J. Comput.")

    define("j-INFOWORLD",			"InfoWorld")

    define("j-INSECT-BIOCHEM-MOL-BIOL",		"Insect Biochemistry and Molecular Biology")
    define("j-INSECT-BIOCHEM-MOL-BIOL",		"Insect Biochem Mol Biol (BRE)")

    define("j-INST-PHYS-CONF-SER",		"Institute of Physics Conference Series")
    define("j-INST-PHYS-CONF-SER",		"Inst. Phys. Conf. Ser.")

    define("j-INSTANT-SMALL-COMMERCIAL-PRINTER","Instant and small commercial printer")
    define("j-INSTRUCTOR",			"The Instructor")

    ## NB: j-INSTRUM-CONTROL-SYST is different from
    ## Instruments and Control Systems (INCSA7, 0020-4404)
    define("j-INSTRUM-CONTROL-SYST",		"Instrumentation \\& control systems: I\\&CS")
    define("j-INSTRUM-CONTROL-SYST",		"Instrumentation & control systems")
    define("j-INSTRUM-CONTROL-SYST",		"Instrumentation and control systems: I and CS")
    define("j-INSTRUM-CONTROL-SYST",		"Instrum. control syst.")

    define("j-INSUR-MATH-ECON",			"Insurance, Mathematics and Economics")
    define("j-INSUR-MATH-ECON",			"Insurance: Mathematics and Economics")
    define("j-INSUR-MATH-ECON",			"Insur. Math. Econ.")

    define("j-INT-AFF",				"International Affairs (Royal Institute of International Affairs 1944--)")
    define("j-INT-AFF",				"International Affairs")
    define("j-INT-AFF",				"Int. Aff.")

    define("j-INT-AQUAT-RES",			"International Aquatic Research")
    define("j-INT-AQUAT-RES",			"Int. Aquat Res.")

    define("j-INT-COMMUN-HEAT-MASS-TRANSF",	"International communications in heat and mass transfer")
    define("j-INT-COMMUN-HEAT-MASS-TRANSF",	"Int. commun. heat mass transf.")
    define("j-INT-COMMUN-HEAT-MASS-TRANSF",	"Int. Commun. Heat Mass Transfer")

    define("j-INT-ECON-REV",			"International Economic Review")
    define("j-INT-ECON-REV",			"Int. Econom. Rev.")
    define("j-INT-ECON-REV",			"Int. Econ. Rev.")

    define("j-INT-EQN-OP-TH",			"Integral Equations and Operator Theory")
    define("j-INT-EQN-OP-TH",			"Integral Equations Oper. Theory")
    define("j-INT-EQN-OP-TH",			"Int. Eqn. Op. Th.")

    define("j-INT-GEOSCIENCE-REMOTE-SENSING-SYMPOSIUM","International Geoscience and Remote Sensing Symposium (IGARSS)")
    define("j-INT-INFO-COMM-EDU",		"International Information, Communication and Education")

    define("j-INT-J-ACCOUNT-INFO-SYS",		"International Journal of Accounting Information Systems")
    define("j-INT-J-ACCOUNT-INFO-SYS",		"Int. J. Account. Info. Syst.")
    define("j-INT-J-ACCOUNT-INFO-SYS",		"Int. J. Account. Info. Sys.")

    define("j-INT-J-AMBIENT-ENERGY",		"International journal of ambient energy")
    define("j-INT-J-ANDROL",			"Int J Androl (GQK)")

    define("j-INT-J-APPL-CRYPTOGR",		"International Journal of Applied Cryptography. IJACT")
    define("j-INT-J-APPL-CRYPTOGR",		"International Journal of Applied Cryptography")
    define("j-INT-J-APPL-CRYPTOGR",		"IJACT")
    define("j-INT-J-APPL-CRYPTOGR",		"Int. J. Appl. Cryptogr. IJACT")
    define("j-INT-J-APPL-CRYPTOGR",		"Int. J. Appl. Cryptogr.")

    define("j-INT-J-APPL-ELECTROMAGN-MATER",	"International journal of applied electromagnetics in materials")
    define("j-INT-J-APPL-ELECTROMAGN-MATER",	"Int. j. appl. electromagn. mater.")
    define("j-INT-J-APPL-ELECTROMAGN-MATER",	"Int. J. Appl. Electromagn. Mater.")

    define("j-INT-J-APPL-MATH",			"International Journal of Applied Mathematics")
    define("j-INT-J-APPL-MATH",			"Int. J. Appl. Math.")

    define("j-INT-J-APPL-MATH-STAT",		"International Journal of Applied Mathematics \\& Statistics")
    define("j-INT-J-APPL-MATH-STAT",		"International Journal of Applied Mathematics & Statistics")
    define("j-INT-J-APPL-MATH-STAT",		"International Journal of Applied Mathematics and Statistics")
    define("j-INT-J-APPL-MATH-STAT",		"Int. J. Appl. Math. Stat.")

    define("j-INT-J-APPROX-REASONING",		"International Journal of Approximate Reasoning")
    define("j-INT-J-APPROX-REASONING",		"Int. Journal of Approximate Reasoning")

    define("j-INT-J-ASTROBIOL",			"International Journal of Astrobiology")
    define("j-INT-J-ASTROBIOL",			"Int. J. Astrobiol.")

    define("j-INT-J-BIFURC-CHAOS-APPL-SCI-ENG",	"International journal of bifurcation and chaos in applied sciences and engineering")
    define("j-INT-J-BIFURC-CHAOS-APPL-SCI-ENG",	"Int. j. bifurc. chaos appl. sci. eng.")
    define("j-INT-J-BIFURC-CHAOS-APPL-SCI-ENG",	"Int. J. Bifurcations and Chaos")
    define("j-INT-J-BIFURC-CHAOS-APPL-SCI-ENG",	"Internat. J. Bifur. Chaos Appl. Sci. Engrg.")

    define("j-INT-J-BIOCHEM",			"International Journal of Biochemistry")
    define("j-INT-J-BIOCHEM",			"Int J Biochem (E4S)")
    define("j-INT-J-BIOCHEM",			"Intn. J. Biochem.")

    define("j-INT-J-BIOCHEM-CELL-BIOL",		"International Journal of Biochemistry and Cell Biology")
    define("j-INT-J-BIOCHEM-CELL-BIOL",		"Int. J. Biochem. Cell Biol.")

    define("j-INT-J-BIOMED-COMPUT",		"International Journal of Bio-Medical Computing")
    define("j-INT-J-BIOMED-COMPUT",		"Int. J. Bio-med. Comput.")
    define("j-INT-J-BIOMED-COMPUT",		"Int J Biomed Comput (GQQ)")

    define("j-INT-J-CIRCUIT-THEORY-APPL",	"International Journal of Circuit Theory and Applications")
    define("j-INT-J-CIRCUIT-THEORY-APPL",	"International journal of circuit theory and applications")
    define("j-INT-J-CIRCUIT-THEORY-APPL",	"Int. j. circuit theory appl.")

    define("j-INT-J-COMP-APPL-TECH",		"International Journal of Computer Applications in Technology")

    define("j-INT-J-COMP-INTEG-MANUFACTURING",	"International Journal of Computer Integrated Manufacturing")

    define("j-INT-J-COMP-PROC-LANG",		"International Journal of Computer Processing Of Languages (IJCPOL)")
    define("j-INT-J-COMP-PROC-LANG",		"Int. J.  Comp. Proc. Lang.")

    define("j-INT-J-COMP-PROC-ORIENTAL-LANG",	"International Journal of Computer Processing of Oriental Languages (IJCPOL)")
    define("j-INT-J-COMP-PROC-ORIENTAL-LANG",	"Int. J.  Comp. Proc. Oriental Lang.")

    define("j-INT-J-COMP-RESEARCH",		"International Journal of Computer Research")
    define("j-INT-J-COMP-RESEARCH",		"Int. J. Comp. Research")

    define("j-INT-J-COMP-MATH-APPL",		"International J. Computer and Mathematics with Applications")
    define("j-INT-J-COMP-MATH-APPL",		"Int. J. Computers and Mathematics with Applications")

    # [03-Feb-1999] Renamed from old j-INT-J-COMP-SYS-SCI-ENG to
    # j-INT-J-COMPUT-SYST-SCI-ENG to match journal name abbreviation.
    define("j-INT-J-COMPUT-SYST-SCI-ENG",	"International Journal of Computer Systems Science and Engineering")
    define("j-INT-J-COMPUT-SYST-SCI-ENG",	"Int. J. Comput. Syst. Sci. Eng.")

    define("j-INT-J-COMP-VISION",		"International journal of computer vision")

    define("j-INT-J-COMPUT-APPL",		"International Journal of Computers and Applications")
    define("j-INT-J-COMPUT-APPL",		"Int. J. Comput. Appl.")

    define("j-INT-J-COMPUT-ENG-SCI",		"International Journal of Computational Engineering Science (IJCES)")
    define("j-INT-J-COMPUT-ENG-SCI",		"Int. J. Comp. Engr. Sci.")
    define("j-INT-J-COMPUT-ENG-SCI",		"International J. Comp. Engr. Sci.")
    define("j-INT-J-COMPUT-ENG-SCI",		"International J. Computational Engineering Science")

    define("j-INT-J-COMPUT-FLUID-DYN",		"International Journal of Computational Fluid Dynamics")
    define("j-INT-J-COMPUT-FLUID-DYN",		"Int. J. Comput. Fluid Dyn.")

    define("j-INT-J-COMPUT-INF-SCI",		"International Journal of Computer and Information Sciences")
    define("j-INT-J-COMPUT-INF-SCI",		"Int. J. Comput. Inf. Sci.")
    define("j-INT-J-COMPUT-INF-SCI",		"Int. J. Comp. Info. Sci.")

    define("j-INT-J-COMPUT-GEOM-APPL",		"International journal of computational geometry and applications")
    define("j-INT-J-COMPUT-GEOM-APPL",		"International journal of computational geometry \\& applications")
    define("j-INT-J-COMPUT-GEOM-APPL",		"Int. j. comput. geom. appl.")

    define("j-INT-J-COMPUT-MATH",		"International Journal of Computer Mathematics")
    define("j-INT-J-COMPUT-MATH",		"Int. J. Comput. Math.")
    define("j-INT-J-COMPUT-MATH",		"International J. Computer Mathematics")
    define("j-INT-J-COMPUT-MATH",		"International J. of Computer Mathematics")
    define("j-INT-J-COMPUT-MATH",		"Int. J. Computer Maths.")
    define("j-INT-J-COMPUT-MATH",		"Internat. J. Comput. Math.")
    define("j-INT-J-COMPUT-MATH",		"Intern. J. Computer Math.")
    define("j-INT-J-COMPUT-MATH",		"Int. J. Comp. Math.")

    define("j-INT-J-COMPUT-METHODS-ENG-SCI-MECH",	"International Journal for Computational Methods in Engineering Science and Mechanics")
    define("j-INT-J-COMPUT-METHODS-ENG-SCI-MECH",	"Int. J. Comput. Methods Eng. Sci. Mech.")

    define("j-INT-J-CONTROL",			"International Journal of Control")
    define("j-INT-J-CONTROL",			"Internat. J. Control")
    define("j-INT-J-CONTROL",			"Int. J. Control")

    define("j-INT-J-DAMAGE-MECH",		"International Journal of Damage Mechanics")
    define("j-INT-J-DAMAGE-MECH",		"Int. J. Damage Mech.")
    define("j-INT-J-DAMAGE-MECH",		"Int. J. of Damage Mechanics")

    define("j-INT-J-DEV-BIOL",			"International journal of developmental biology")
    define("j-INT-J-DEV-BIOL",			"Int J Dev Biol (AV3)")

    define("j-INT-J-EEE",			"International Journal of Electrical Engineering Education")

    define("j-INT-J-ELECTRON",			"International Journal of Electronics Theoretical \\& Experimental")
    define("j-INT-J-ELECTRON",			"International Journal of Electronics")
    define("j-INT-J-ELECTRON",			"Int. J. Electron.")
    define("j-INT-J-ELECTRON",			"Int. J. Electron. Theor. Exp.")

    define("j-INT-J-ENERGY-RES",		"International Journal of Energy Research")
    define("j-INT-J-ENERGY-RES",		"Int. J. Energy Res.")

    define("j-INT-J-ENG-EDUC",			"International Journal of Engineering Education")

    define("j-INT-J-ENG-SCI",			"International journal of engineering science")
    define("j-INT-J-ENG-SCI",			"Int. j. eng. sci.")
    define("j-INT-J-ENG-SCI",			"Int. J. Engng. Sci")
    define("j-INT-J-ENG-SCI",			"Internat. J. Engrg. Sci.")

    define("j-INT-J-EPIDEMIOL",			"International Journal of Epidemiology")
    define("j-INT-J-EPIDEMIOL",			"Int. J. Epidemiol.")
    define("j-INT-J-EPIDEMIOL",			"Int J Epidemiol (GR6)")

    define("j-INT-J-FOUND-COMP-SCI",		"International Journal of Foundations of Computer Science")
    define("j-INT-J-FOUND-COMP-SCI",		"Internat. Journal of Foundations of Computer Science")
    define("j-INT-J-FOUND-COMP-SCI",		"Int. j. found. comput. sci.")
    define("j-INT-J-FOUND-COMP-SCI",		"Internat. J. Found. Comput. Sci.")

    define("j-INT-J-FRACTURE",			"International Journal of Fracture")
    define("j-INT-J-FRACTURE",			"Internat. J. Fracture")
    define("j-INT-J-FRACTURE",			"Int. J. Fracture")

    define("j-INT-J-GEN-SYST",			"International Journal of General Systems")
    define("j-INT-J-GEN-SYST",			"Internat. J. Gen. Systems")
    define("j-INT-J-GEN-SYST",			"Int. J. Gen. Syst.")

    define("j-INT-J-HEALTH-SERV",		"International Journal of Health Services")
    define("j-INT-J-HEALTH-SERV",		"Int. J. Health Serv.")

    define("j-INT-J-HEAT-MASS-TRANSFER",	"International journal of heat and mass transfer")
    define("j-INT-J-HEAT-MASS-TRANSFER",	"Int. J. Heat Mass Transfer")

    define("j-INT-J-HIGH-SPEED-COMPUTING",	"International Journal of High Speed Computing")
    define("j-INT-J-HIGH-SPEED-COMPUTING",	"Int Journal of High Speed Computing")

    define("j-INT-J-HOSP-MANAGEMENT",		"International Journal of Hospitality Management")

    define("j-INT-J-HYPERTHERMIA",		"International journal of hyperthermia: the official journal of European Society for Hyperthermic Oncology, North American Hyperthermia Group")
    define("j-INT-J-HYPERTHERMIA",		"Int J Hyperthermia (IJY)")

    define("j-INT-J-IMAGE-GRAPHICS",		"International Journal of Image and Graphics")
    define("j-INT-J-IMAGE-GRAPHICS",		"International Journal of Image and Graphics (IJIG)")
    define("j-INT-J-IMAGE-GRAPHICS",		"Int. J. Image Graphics")

    define("j-INT-J-INFO-SEC",			"International Journal of Information Security")
    # No journal abbreviation found in Library of Congress
    define("j-INT-J-INFO-SEC",			"Int. J. Info. Sec.")

    define("j-INT-J-INFO-TECH",                 "International Journal of Information Technology")
    define("j-INT-J-INTELL-SYSTEMS",		"International Journal of Intelligent Systems")

    define("j-INT-J-MAN-MACHINE-STUDIES",	"International Journal of Man-Machine Studies")
    define("j-INT-J-MAN-MACHINE-STUDIES",	"Int. J. Man-Mach. Stud.")

    define("j-INT-J-MANAGEMENT-SYS",		"International Journal of Management and Systems")
    define("j-INT-J-MANAGEMENT-SYS",		"Int. J. of Management and Systems")

    define("j-INT-J-MASS-SPECT-ION-PROC",	"International journal of mass spectrometry and ion processes")

    define("j-INT-J-MATH",			"International Journal of Mathematics")
    define("j-INT-J-MATH",			"Internat. J. Math.")

    define("j-INT-J-MATH-COMP-MODELLING",	"International J. Mathematical and Computer Modelling")

    define("j-INT-J-MATH-EDU-SCI-TECH",		"International Journal of Mathematical Education in Science and Technology")
    define("j-INT-J-MATH-EDU-SCI-TECH",		"International journal of mathematical education in science and technology")
    define("j-INT-J-MATH-EDU-SCI-TECH",		"Int. j. math. educ. sci. technol.")
    define("j-INT-J-MATH-EDU-SCI-TECH",		"Internat. J. Math. Ed. Sci. Tech.")

    define("j-INT-J-MATH-MATH-SCI",		"International Journal of Mathematics and Mathematical Sciences")
    define("j-INT-J-MATH-MATH-SCI",		"Int. j. math. math. sci.")
    define("j-INT-J-MATH-MATH-SCI",		"Internat. J. Math. Math. Sci.")

    define("j-INT-J-MECH-ENG-EDU",		"The International journal of mechanical engineering education")

    define("j-INT-J-MECH-SCI",			"International Journal of Mechanical Sciences")
    define("j-INT-J-MECH-SCI",			"Int. J. Mech. Sci.")

    define("j-INT-J-MINI-MICROCOMPUTERS",	"International Journal of Mini and Microcomputers")

    define("j-INT-J-MOD-PHYS-A",		"International Journal of Modern Physics. A, Particles and Fields, Gravitation, Cosmology")
    define("j-INT-J-MOD-PHYS-A",		"International Journal of Modern Physics A")
    define("j-INT-J-MOD-PHYS-A",		"Int. J. Mod. Phys. A")

    define("j-INT-J-MOD-PHYS-B",		"International journal of modern physics. B, Condensed matter physics, statistical physics, applied physics")
    define("j-INT-J-MOD-PHYS-B",		"International Journal of Modern Physics. B")
    define("j-INT-J-MOD-PHYS-B",		"International Journal of Modern Physics B")
    define("j-INT-J-MOD-PHYS-B",		"Int. J. Mod. Phys. B")

    define("j-INT-J-MOD-PHYS-C",		"International Journal of Modern Physics C [Physics and Computers]")
    define("j-INT-J-MOD-PHYS-C",		"International Journal of Modern Physics C")
    define("j-INT-J-MOD-PHYS-C",		"International Journal of Modern Physics C (IJMPC)")
    define("j-INT-J-MOD-PHYS-C",		"Int. J. Mod. Phys. C")
    define("j-INT-J-MOD-PHYS-C",		"Internat. J. Modern Phys. C")
    define("j-INT-J-MOD-PHYS-C",		"Int. J. Modern Phys. C")

    define("j-INT-J-MOD-PHYS-D",		"International Journal of Modern Physics. D, Gravitation, Astrophysics, Cosmology")
    define("j-INT-J-MOD-PHYS-D",		"International Journal of Modern Physics. D")
    define("j-INT-J-MOD-PHYS-D",		"Int. J. Mod. Phys. D")

    define("j-INT-J-MOD-PHYS-E",		"International journal of modern physics. E, Nuclear physics")
    define("j-INT-J-MOD-PHYS-E",		"Int. J. Mod. Phys. E")

    define("j-INT-J-MODELLING-SIMUL",		"International Journal of Modelling and Simulation")
    define("j-INT-J-MODELLING-SIMUL",		"International Journal of Modeling and Simulation") # alternate incorrect name
    define("j-INT-J-MODELLING-SIMUL",		"International journal of modelling and simulation: a journal of the International Association of Science and Technology for Development, IASTED")

    define("j-INT-J-NEURAL-SYST",		"International Journal of Neural Systems")
    define("j-INT-J-NEURAL-SYST",		"Int. J. Neural Syst.")

    define("j-INT-J-NUMBER-THEORY",		"International Journal of Number Theory (IJNT)")
    define("j-INT-J-NUMBER-THEORY",		"International Journal of Number Theory")
    define("j-INT-J-NUMBER-THEORY",		"Int. J. Number Theory")

    define("j-INT-J-NUMER-ANAL-METHODS-GEOMECH", "International Journal for Numerical and Analytical Methods in Geomechanics")
    define("j-INT-J-NUMER-ANAL-METHODS-GEOMECH", "Int. J. Numer. Anal. Methods Geomech.")

    define("j-INT-J-NUMER-MODEL",		"International journal of numerical modelling")
    define("j-INT-J-NUMER-MODEL",		"Int. j. numer. model.")

    define("j-INT-J-NUMER-METHODS-BIOMED-ENG",	"International Journal for Numerical Methods in Biomedical Engineering")
    define("j-INT-J-NUMER-METHODS-BIOMED-ENG",	"Int. J. Numer. Methods Biomed. Eng.")

    define("j-INT-J-NUMER-METHODS-ENG",		"International Journal for Numerical Methods in Engineering")
    define("j-INT-J-NUMER-METHODS-ENG",		"Int. J. Numer. Methods Eng.")
    define("j-INT-J-NUMER-METHODS-ENG",		"International J. Numer. Methods Engineering")
    define("j-INT-J-NUMER-METHODS-ENG",		"Int Journal of Numerical Methods in Engineering")
    define("j-INT-J-NUMER-METHODS-ENG",		"Int. J. Num. Meth. Eng.")
    define("j-INT-J-NUMER-METHODS-ENG",		"International J. Numer. Methods Engrg.")
    define("j-INT-J-NUMER-METHODS-ENG",		"International Journal of Numerical Methods in Engineering")
    define("j-INT-J-NUMER-METHODS-ENG",		"Int. J. Numer. Meth. Eng.")
    define("j-INT-J-NUMER-METHODS-ENG",		"Intern. J. Num. Meth. Eng.")
    define("j-INT-J-NUMER-METHODS-ENG",		"Int. J. Num. Meth. in Engng.")
    define("j-INT-J-NUMER-METHODS-ENG",		"Int. J. Numer. Meth. Engrg")
    define("j-INT-J-NUMER-METHODS-ENG",		"Internat. J. Numer. Methods Engrg.")
    define("j-INT-J-NUMER-METHODS-ENG",		"Intl. J. Numer. Meth. Engin.")
    define("j-INT-J-NUMER-METHODS-ENG",		"Intl. J. Num. Meth. Engr.")

    define("j-INT-J-NUMER-METHODS-FLUIDS",	"International Journal for Numerical Methods in Fluids")
    define("j-INT-J-NUMER-METHODS-FLUIDS",	"Int. J. Numer. Methods Fluids")
    define("j-INT-J-NUMER-METHODS-FLUIDS",	"Int. J. Numer. Meth. Fluids")
    define("j-INT-J-NUMER-METHODS-FLUIDS",	"Int. J. Num. Meth. Fluids")
    define("j-INT-J-NUMER-METHODS-FLUIDS",	"Intern. J. for Numer. Methods in Fluids")
    define("j-INT-J-NUMER-METHODS-FLUIDS",	"Internat. J. Numer. Methods Fluids")

    define("j-INT-J-OPTOELECTRON",		"International journal of optoelectronics")
    define("j-INT-J-OPTOELECTRON",		"Int. j. optoelectron.")

    define("j-INT-J-PARALLEL-PROG",		"International Journal of Parallel Programming")
    define("j-INT-J-PARALLEL-PROG",		"Int. J. Parallel Programm.")
    define("j-INT-J-PARALLEL-PROG",		"Int. J. Parallel Programming")

    define("j-INT-J-PATTERN-RECOGNITION-ARTIFICIAL-INTELLIGENCE","International Journal of Pattern Recognition and Artificial Intelligence")

    define("j-INT-J-PLAST",			"International Journal of Plasticity")
    define("j-INT-J-PLAST",			"Int. J. Plast.")

    define("j-INT-J-PROD-ECON",			"International Journal of Production Economics")
    define("j-INT-J-PROD-ECON",			"Int. j. prod. econ.")

    define("j-INT-J-PSYCHOPHYSIOL",             "International journal of psychophysiology")
    define("j-INT-J-PSYCHOPHYSIOL",             "Int J Psychophysiol.")

    define("j-INT-J-PURE-APPL-MATH",		"International Journal of Pure and Applied Mathematics")
    define("j-INT-J-PURE-APPL-MATH",		"Int. J. Pure Appl. Math.")

    define("j-INT-J-RADIAT-BIOL",		"Int J Radiat Biol (IRB)")

    define("j-INT-J-RADIAT-ONCOL-BIOL-PHYS",	"International Journal of Radiation Oncology*Biology*Physics")
    define("j-INT-J-RADIAT-ONCOL-BIOL-PHYS",	"International Journal of Radiation Oncology, Biology, Physics")
    define("j-INT-J-RADIAT-ONCOL-BIOL-PHYS",	"Int. J. Radiat. Oncol. Biol. Phys.")
    define("j-INT-J-RADIAT-ONCOL-BIOL-PHYS",	"Int J Radiat Oncol Biol Phys (G97)")

    define("j-INT-J-RES-MARK",			"International Journal of Research in Marketing")
    define("j-INT-J-RES-MARK",			"Int. J. Res. Mark.")

    define("j-INT-J-ROBOTICS-AUTOMATION",	"International Journal of Robotics and Automation")

    define("j-INT-J-ROBOTICS-RES",		"International Journal of Robotics Research")
    define("j-INT-J-ROBOTICS-RES",		"Internat. J. Robotics Research")

    define("j-INT-J-ROCK-MECH-MINING-SCI-GEOMECH-ABS",	"International Journal of Rock Mechanics and Mining Sciences and Geomechanics Abstracts")

    define("j-INT-J-SATELL-COMMUN",		"International Journal of Satellite Communications")
    define("j-INT-J-SATELL-COMMUN",		"Int. J. Satell. Commun.")

    define("j-INT-J-SCI-COMP-MOD",		"International Journal of Scientific Computing \\& Modeling")

    define("j-INT-J-SCI-ENG-RESEARCH",		"International Journal of Scientific and Engineering Research")

    define("j-INT-J-SCI-MATH-EDUC",		"International Journal of Science and Mathematics Education")
    define("j-INT-J-SCI-MATH-EDUC",		"Int. J. Sci. Maths. Educ.")
    define("j-INT-J-SCI-MATH-EDUC",		"Int. J. Sci. Math. Educ.")

    define("j-INT-J-SOFTW-TOOLS-TECHNOL-TRANSFER", "International Journal on Software Tools for Technology Transfer: STTT")
    define("j-INT-J-SOFTW-TOOLS-TECHNOL-TRANSFER", "Int J Softw Tools Technol Transfer")

    define("j-INT-J-SOLIDS-STRUCT",		"International Journal of Solids and Structures")
    define("j-INT-J-SOLIDS-STRUCT",		"Int. J. Solids Struct.")
    define("j-INT-J-SOLIDS-STRUCT",		"Int. J. Solids Structures")
    define("j-INT-J-SOLIDS-STRUCT",		"Int. J. Solids and Structures")
    define("j-INT-J-SOLIDS-STRUCT",		"Internat. J. Solids Structures")
    define("j-INT-J-SOLIDS-STRUCT",		"Internat. J. Solids and Structures")

    define("j-INT-J-STAT-PROBAB",		"International Journal of Statistics and Probability")
    define("j-INT-J-STAT-PROBAB",		"International Journal of Statistics and Probability: IJSP")
    define("j-INT-J-STAT-PROBAB",		"Int. J. Stat. Prob.")
    define("j-INT-J-STAT-PROBAB",		"Int. J. Stat. Probab.")

    define("j-INT-J-SYST-SCI",			"International Journal of Systems Science")
    define("j-INT-J-SYST-SCI",			"Int. j. Syst. Sci.")
    define("j-INT-J-SYST-SCI",			"Int. J. Systems Sci.")
    define("j-INT-J-SYST-SCI",			"Internat. J. Systems Sci.")

    define("j-INT-J-THEOR-PHYS",		"International Journal of Theoretical Physics")
    define("j-INT-J-THEOR-PHYS",		"Internat. J. Theoret. Phys.")
    define("j-INT-J-THEOR-PHYS",		"Int. J. Theor. Phys.")

    define("j-INT-J-THERMOPHYS",		"International Journal of Thermophysics")
    define("j-INT-J-THERMOPHYS",		"Int. J. Thermophys.")

    define("j-INT-J-TOMOGR-STAT",		"International Journal of Tomography \\& Statistics")
    define("j-INT-J-TOMOGR-STAT",		"International Journal of Tomography and Statistics")
    define("j-INT-J-TOMOGR-STAT",		"Int. J. Tomogr. Stat.")

    define("j-INT-J-UNITY-SCI",			"International Journal on the Unity of the Sciences")
    define("j-INT-J-UNITY-SCI",			"Int. J. Unity Sci.")

    define("j-INT-J-WAVELETS-MULTIRESOLUT-INF-PROCESS", "International Journal of Wavelets, Multiresolution and Information Processing")
    define("j-INT-J-WAVELETS-MULTIRESOLUT-INF-PROCESS", "Int. J. Wavelets Multiresolut. Inf. Process.")

    define("j-INT-PHILOS-Q",			"International Philosophical Quarterly")
    define("j-INT-PHILOS-Q",			"Int. Philos. Q.")

    define("j-INT-PHOENIX-CONF-COMPUT-COMM",	"Conference Proceedings --- International Phoenix Conference on Computers and Communications")

    define("j-INT-REV-CYTOLOGY",		"International review of cytology")
    define("j-INT-REV-CYTOLOGY",		"Int. Rev. Cyt.")
    define("j-INT-REV-CYTOLOGY",		"Int. Rev. Cytology")
    define("j-INT-REV-CYTOLOGY",		"Intn. Rev. Cytol.")
    define("j-INT-REV-CYTOLOGY",		"Intn. Rev. Cytology")

    define("j-INT-REV-PHYS",			"International Review of Physics")
    define("j-INT-REV-PHYS",			"Int. Rev. Phys.")

    define("j-INT-REV-VICTIM",			"International Review of Victimology")
    define("j-INT-REV-VICTIM",			"Int. Rev. Victim.")

    define("j-INT-SCI-TECHNOL",			"International Science and Technology")
    define("j-INT-SCI-TECHNOL",			"Int. sci. technol.")

    define("j-INT-SECUR",			"International Security")
    define("j-INT-SECUR",			"Int. Secur.")

    define("j-INT-SER-NUMER-MATH",		"International series of numerical mathematics = Internationale Schriftenreihe zur numerischen Mathematik = S{\\'e}rie internationale d'analyse num{\\'e}rique")
    define("j-INT-SER-NUMER-MATH",		"International series of numerical mathematics")
    define("j-INT-SER-NUMER-MATH",		"Int. Ser. Numer. Math.")

    define("j-INT-STAT-REV",			"International Statistical Review = Revue Internationale de Statistique")
    define("j-INT-STAT-REV",			"International Statistical Review / Revue Internationale de Statistique")
    define("j-INT-STAT-REV",			"International Statistical Review")
    define("j-INT-STAT-REV",			"Internat. Statist. Rev.")
    define("j-INT-STAT-REV",			"Int. Stat. Rev.")

    define("j-INT-STUD-PHILOS-SCI",		"International Studies in the Philosophy of Science")
    define("j-INT-STUD-PHILOS-SCI",		"Internat. Stud. Philos. Sci.")
    define("j-INT-STUD-PHILOS-SCI",		"Int. Stud. Philos. Sci.")

    define("j-INT-SYMP-SYMB-COMPUT-ISSAS-PROC",	"International Symposium on Symbolic and Computation --- ISSAS, Proceedings")

    define("j-INT-TELEMETERING-CONFERENCE",	"International Telemetering Conference (Proceedings)")

    define("j-INT-TRANS-OPL-RES",		"International Transactions in Operational Research")
    define("j-INT-TRANS-OPL-RES",		"Int. Trans. Oper. Res.")
    define("j-INT-TRANS-OPL-RES",		"Int. Trans. Opl. Res.")

    define("j-INT-YEARBOOK-LAW-COMP-TECH",	"International Yearbook of Law, Computers, and Technology")
    define("j-INT-YEARBOOK-LAW-COMP-TECH",	"International yearbook of law computers and tech")

    define("j-INTEGERS",			"Integers")

    define("j-INTEGRAL-TRANSFORMS-SPEC-FUNCT",	"Integral Transforms and Special Functions")
    define("j-INTEGRAL-TRANSFORMS-SPEC-FUNCT",	"Integral Transforms and Special Functions: An International Journal")
    define("j-INTEGRAL-TRANSFORMS-SPEC-FUNCT",	"Integral Transforms Spec. Funct.")

    define("j-INTEGRATION-VLSI-J",		"Integration, the VLSI journal")

    define("j-INTEGR-ENVIRON-ASSES-MANAG",	"Integrated Environmental Assessment and Management")
    define("j-INTEGR-ENVIRON-ASSES-MANAG",	"Integr. Environ. Assess. Manag.")

    define("j-INTELL-INSTR-COMP",		"Intelligent instruments and computers")

    define("j-INTELL-NATL-SECUR",		"Intelligence and National Security")
    define("j-INTELL-NATL-SECUR",		"Intell. natl. secur.")

    define("j-INTELL-TUTORING-MEDIA",		"Intelligent Tutoring Media")

    define("j-INTERACTIONS",			"Interactions (New York, N.Y.)")
    define("j-INTERACTIONS",			"Interactions (N. Y., N.Y.)")
    define("j-INTERACTIONS",			"Interactions")

    define("j-INTERACTIVE-AGE",			"Interactive Age")
    define("j-INTERACTIVE-SYS-EXP-APPL-MATH",	"Interactive Systems for Experimental Applied Mathematics")

    define("j-INTERDISCIP-INFORM-SCI",		"Interdisciplinary Information Sciences")
    define("j-INTERDISCIP-INFORM-SCI",		"Interdiscip. Inform. Sci.")

    define("j-INTERFACE",			"Interface")
    define("j-INTERFACE-CHICAGO",		"Interface (Chicago)")
    define("j-INTERFACE-GHENT",			"Interface (Ghent)")
    define("j-INTERFACE-SANTA-CRUZ",		"Interface (Santa Cruz)")

    define("j-INTERFACE-SCI",			"Interface Science")
    define("j-INTERFACE-SCI",			"Interface Sci.")

    define("j-INTERFACES",			"Interfaces")

    define("j-INTERLEND-DOC-SUPPLY",		"Interlending and Document Supply")
    define("j-INTERLEND-DOC-SUPPLY",		"Interlend. doc. supply")

    define("j-INTERNET-HIST",			"Internet Histories")
    define("j-INTERNET-HIST",			"Internet Hist.")

    define("j-INTERNET-J-CHEM",			"Internet Journal of Chemistry")
    define("j-INTERNET-J-CHEM",			"Internet J. Chem.")

    define("j-INTERNET-MATH",			"Internet Mathematics")
    define("j-INTERNET-MATH",			"Internet Math.")

    define("j-INTERNET-RES",			"Internet research")
    define("j-INTERNET-RES",			"Internet res.")

    define("j-INTERNET-WORLD",			"Internet World")
    define("j-INTERNETWORK",			"Internetwork")

    define("j-INTERNETWORKING",			"Internetworking: research and experience")
    define("j-INTERNETWORKING",			"Internetworking")

    define("j-INTERVAL-COMP",			"Interval Computations = Interval'nye vychisleniia")
    define("j-INTERVAL-COMP",			"Interval Computations")
    define("j-INTERVAL-COMP",			"Interval Comput./Interval. Vychisl.")

    define("j-INTRANET-NETWORKING-STRATEGIES-REP", "Intranet and Networking Strategies Report")

    define("j-INV-OP",				"Investiga{\\c c}{\\~a}o Operacional")

    define("j-INVENT-MATH",			"Inventiones Mathematicae")
    define("j-INVENT-MATH",			"Invent. Math.")

    define("j-INVERSE-PROBLEMS",		"Inverse Problems")

    define("j-INVERSE-PROBL-IMAGING",		"Inverse Problems and Imaging")
    define("j-INVERSE-PROBL-IMAGING",		"Inverse Probl. Imaging")

    define("j-INVERSE-PROBL-SCI-ENG",		"Inverse Problems in Science and Engineering")
    define("j-INVERSE-PROBL-SCI-ENG",		"Inverse Probl. Sci. Eng.")

    define("j-IR-J-PSYCHOL-MED",		"Irish Journal of Psychological Medicine")
    define("j-IR-J-PSYCHOL-MED",		"Ir. J. Psychol. Med.")

    define("j-IRE-PROC",			"IRE Proceedings")
    define("j-IRE-PROC",			"IRE Proc.")

    define("j-IRE-TRANS-ELEC-COMPUT",		"IRE Transactions on Electronic Computers")
    define("j-IRE-TRANS-ELEC-COMPUT",		"IRE Trans. Elec. Comput.")
    define("j-IRE-TRANS-ELEC-COMPUT",		"IRE Trans. Electron. Comput.")

    define("j-IRE-TRANS-ENG-WRIT-SPEECH",	"IRE Transactions on Engineering Writing and Speech")
    define("j-IRE-TRANS-ENG-WRIT-SPEECH",	"IRE Trans. Eng. Writ. Speech")
    define("j-IRE-TRANS-ENG-WRIT-SPEECH",	"IRE Trans. Engineering Writing and Speech")

    define("j-IRE-TRANS-INF-THEORY",		"IRE Transactions on Information Theory")
    define("j-IRE-TRANS-INF-THEORY",		"IRE Trans. Inf. Theory")
    define("j-IRE-TRANS-INF-THEORY",		"Trans. IRE Inform. Theory")

    define("j-IRISH-ASTRON-J",			"Irish Astronomical Journal")
    define("j-IRISH-ASTRON-J",			"Irish Astron. J.")
    define("j-IRISH-ASTRON-J",			"Ir. Astron. J.")

    define("j-IRISH-COMP",                      "Irish Computer")

    define("j-IRISH-MATH-SOC-BULL",		"Irish Mathematical Society Bulletin")
    define("j-IRISH-MATH-SOC-BULL",		"Irish Math. Soc. Bull.")

    define("j-IRIS-UNIVERSE",			"IRIS Universe")

    define("j-ISIS",				"Isis")
    define("j-ISIS",				"Isis: an international review devoted to the history of science and its cultural influences")

    define("j-ISRAEL-J-CHEM",			"Israel Journal of Chemistry")
    define("j-ISRAEL-J-CHEM",			"Israel J. Chem.")
    define("j-ISRAEL-J-CHEM",			"Isr. J. Chem.")

    define("j-ISRAEL-J-MATH",			"Israel Journal of Mathematics")
    define("j-ISRAEL-J-MATH",			"Israel J. Math")
    define("j-ISRAEL-J-MATH",			"Isra{\\\"e}l J. Math.")

    define("j-ISRAEL-STUD",			"Israel Studies")
    define("j-ISRAEL-STUD",			"Israel Stud.")

    define("j-ISSUES-SCI-TECHNOL",		"Issues in Science and Technology")
    define("j-ISSUES-SCI-TECHNOL",		"Issues Sci. Technol.")

    define("j-IT-IT",				"Informationstechnik und technische Informatik: IT + TI")
    define("j-IT-IT",				"IT+TI Informationstechnik und Technische Informatik")
    define("j-IT-IT",				"IT + IT")
    define("j-IT-IT",				"IT und IT")

    define("j-IT-MAGAZINE",			"I.T. magazine")

    define("j-IT-PRO",				"{IT} Professional")
    define("j-IT-PRO",				"{IT} Prof.")
    define("j-IT-PRO",				"{IT} Pro.")

    define("j-ITAL-J-PURE-APPL-MATH",		"Ital. J. Pure Appl. Math.")
    define("j-ITAL-J-PURE-APPL-MATH",		"Italian Journal of Pure and Applied Mathematics")

    define("j-ITE-J",				"Institute of Transportation Engineers journal")
    define("j-ITE-J",				"ITE journal")
    define("j-ITE-J",				"ITE j.")

    define("j-ITNOW",				"ITNOW")

    define("j-IZV-AKAD-ARM-SSR-MEH",		"Izvestiia Akademii nauk Armianskoi SSR. Mekhanika = Haykakan SSR Gitut'yunneri Akademiayi teghekagir. Mekhanika")
    define("j-IZV-AKAD-ARM-SSR-MEH",		"Izv. Akad. Arm. SSR, Meh.")
    define("j-IZV-AKAD-ARM-SSR-MEH",		"Izv. Akad. Nauk Arm. SSR, Mekhanika")

    define("j-IZV-AKAD-NAUK-SSSR-MAT",		"Izvestiia Akademii Nauk. USSR Seriia Matematicheskaia (Moscow)")
    define("j-IZV-AKAD-NAUK-SSSR-MAT",		"Izv. Akad. Nauk. USSR Ser. Mat.")
    define("j-IZV-AKAD-NAUK-SSSR-MAT",		"Izv. Akad. Nauk SSSR Ser. Mat.")

    define("j-IZV-AKAD-NAUK-SSSR-MEH-TVERD-TELA", "Izvestiia Akademii nauk SSSR. Mekhanika tverdogo tela")
    define("j-IZV-AKAD-NAUK-SSSR-MEH-TVERD-TELA", "Izvestiia. Mekhanika tverdogo tela")
    define("j-IZV-AKAD-NAUK-SSSR-MEH-TVERD-TELA", "MTT")
    define("j-IZV-AKAD-NAUK-SSSR-MEH-TVERD-TELA", "Izv. Akad. Nauk SSSR Mekh. Tverd. Tela")
    define("j-IZV-AKAD-NAUK-SSSR-MEH-TVERD-TELA", "Izvestiya Akademii Nauk SSSR, Mechanica Tverdogo Tela")

    define("j-IZV-ROSS-AKAD-NAUK-SER-MAT",	"Izvestiia Rossiiskoi akademii nauk. Seriia matematicheskaia")
    define("j-IZV-ROSS-AKAD-NAUK-SER-MAT",	"Izv. Ross. Akad. Nauk Ser. Mat.")
    define("j-IZV-ROSS-AKAD-NAUK-SER-MAT",	"Izv. Ross. Akad. Nauk Ser. Mat.")

    define("j-IZV-SEKTS-ASTRON-BULG-AKAD-NAUK",	"Izvestiya na Sektsiyata po Astronomiya, Bulgarska Akademiya na Naukite")
    define("j-IZV-SEKTS-ASTRON-BULG-AKAD-NAUK",	"Izv. Sekts. Astron. Blg. AN")
    define("j-IZV-SEKTS-ASTRON-BULG-AKAD-NAUK",	"Izv. Sekts. Astron., Bulg. Akad. Nauk.")

    define("j-IZV-VYSS-UCEBN-ZAVED-MAT",	"Izvestiia vysshikh uchebnykh zavedenii. Matematika")
    define("j-IZV-VYSS-UCEBN-ZAVED-MAT",	"Izv. vyss. ucebn. zaved., Mat.")
    define("j-IZV-VYSS-UCEBN-ZAVED-MAT",	"Izv. Vyssh. Uchebn. Zaved. Mat.")

    define("j-J-ACCOUNT-EDUC",			"Journal of Accounting Education")
    define("j-J-ACCOUNT-EDUC",			"J. Account. Educ.")

    define("j-J-ACCOUNTANCY",			"Journal of Accountancy")
    define("j-J-ACCOUNTANCY",			"J. Accountancy")

    define("j-J-ACM",				"Journal of the ACM")
    define("j-J-ACM",				"J. Assoc. Comput. Mach.")
    define("j-J-ACM",				"J. ACM")
    define("j-J-ACM",				"Journal of the Association for Computing Machinery")

    define("j-J-ACOUST-SOC-AM",			"Journal of the Acoustical Society of America")
    define("j-J-ACOUST-SOC-AM",			"J. Acoust. Soc. Am.")
    define("j-J-ACOUST-SOC-AM",			"J. Acoustic Soc. Amer.")
    define("j-J-ACOUST-SOC-AM",			"J. Acoust. Soc. Amer.")

    define("j-J-AERO-SPACE-SCI",		"Journal of the Aero\\slash Space Sciences")
    define("j-J-AERO-SPACE-SCI",		"Journal of the Aero/Space Sciences")
    define("j-J-AERO-SPACE-SCI",		"J. Aero/Space Sci.")
    define("j-J-AERO-SPACE-SCI",		"J. Aero\\slash Space Sci.")

    define("j-J-AEROSOL-SCI",			"Journal of Aerosol Science")
    define("j-J-AEROSOL-SCI",			"J. aerosol sci.")

    define("j-J-AGRIC-SCI",			"Journal of Agricultural Science")
    define("j-J-AGRIC-SCI",			"J. Agric. Sci.")

    define("j-J-ALG",				"Journal of Algorithms")

    define("j-J-ALGEBRA",			"Journal of Algebra")

    define("j-J-ALGEBR-COMB",			"Journal of algebraic combinatorics")
    define("j-J-ALGEBR-COMB",			"J. Algebr. Comb.")

    define("j-J-ALGORITHMS-COMPUT-TECHNOL",	"Journal of Algorithms \\& Computational Technology")
    define("j-J-ALGORITHMS-COMPUT-TECHNOL",	"Journal of Algorithms and Computational Technology")
    define("j-J-ALGORITHMS-COMPUT-TECHNOL",	"J. Algorithms Comput. Technol.")

    define("j-J-AM-CERAM-SOC",			"Journal of the American Ceramic Society")
    define("j-J-AM-CERAM-SOC",			"J. Am. Ceram. Soc.")
    define("j-J-AM-CERAM-SOC",			"J. Amer. Ceramic Soc.")

    define("j-J-AM-COLL-CARDIOL",		"Journal of the American College of Cardiology")
    define("j-J-AM-COLL-CARDIOL",		"J. Am. Coll. Cardiol.")

    define("j-J-AM-HIST",			"The Journal of American History")
    define("j-J-AM-HIST",			"Journal of American History")
    define("j-J-AM-HIST",			"J. Amer. Hist.")
    define("j-J-AM-HIST",			"J. Am. Hist.")

    define("j-J-AM-MATH-SOC",			"Journal of the American Mathematical Society")
    define("j-J-AM-MATH-SOC",			"J. Am. Math. Soc.")
    define("j-J-AM-MATH-SOC",			"J. Amer. Math. Soc.")

    define("j-J-AM-MED-ASSOC",			"Journal of the American Medical Association")
    define("j-J-AM-MED-ASSOC",			"JAMA j. Am. Med. Assoc.")
    define("j-J-AM-MED-ASSOC",			"J. Amer. Medical Assoc.")

    define("j-J-AM-SOC-INF-SCI",		"Journal of the American Society for Information Science")
    define("j-J-AM-SOC-INF-SCI",		"Journal of the ASIS")
    define("j-J-AM-SOC-INF-SCI",		"J. Am. Soc. Inf. Sci")

    define("j-J-AM-SOC-INF-SCI-TECHNOL",	"Journal of the American Society for Information Science and Technology: JASIST")
    define("j-J-AM-SOC-INF-SCI-TECHNOL",	"Journal of the American Society for Information Science and Technology")
    define("j-J-AM-SOC-INF-SCI-TECHNOL",	"JASIST")
    define("j-J-AM-SOC-INF-SCI-TECHNOL",	"J. Am. Soc. Inf. Sci. Technol.")

    define("j-J-AM-STAT-ASSOC",			"Journal of the American Statistical Association")
    define("j-J-AM-STAT-ASSOC",			"J. Amer. Statist. Assoc.")
    define("j-J-AM-STAT-ASSOC",			"J. Amer. Stat. Assoc.")
    define("j-J-AM-STAT-ASSOC",			"J. Am. Stat. Assoc.")
    define("j-J-AM-STAT-ASSOC",			"J. Am. Statist. Assoc.")

    define("j-J-ANAL-MATH",			"Journal d'analyse math{\\'e}matique")
    define("j-J-ANAL-MATH",			"Journal d'analyse mathematique")
    define("j-J-ANAL-MATH",			"J. Anal. Math.")
    define("j-J-ANAL-MATH",			"J. d'Analyse Math.")

    define("j-J-ANIM-ECOL",			"Journal of Animal Ecology")
    define("j-J-ANIM-ECOL",			"J. Anim. Ecol.")

    define("j-J-APPL-CRYSTAL",			"Journal of Applied Crystallography")
    define("j-J-APPL-CRYSTAL",			"J. Appl. Crystal.")

    define("j-J-APPL-ECOL",			"Journal of Applied Ecology")
    define("j-J-APPL-ECOL",			"J. appl. ecol.")

    define("j-J-APPL-ECONOMETRICS",		"Journal of Applied Econometrics")
    define("j-J-APPL-ECONOMETRICS",		"J. Appl. Econom.")
    define("j-J-APPL-ECONOMETRICS",		"J. Appl. Econometrics")

    define("j-J-APPL-MATH",			"Journal of Applied Mathematics")
    define("j-J-APPL-MATH",			"J. Appl. Math.")

    define("j-J-APPL-MATH-MECH",		"Journal of applied mathematics and mechanics")
    define("j-J-APPL-MATH-MECH",		"Applied mathematics and mechanics")
    define("j-J-APPL-MATH-MECH",		"Applied mathematics and mechanics. Prikladnaia matematika i mekhanika")
    define("j-J-APPL-MATH-MECH",		"J. appl. math. mech.")
    define("j-J-APPL-MATH-MECH",		"J. Appl. Math. and Mech. (Transl. of PMM)")

    define("j-J-APPL-MATH-PHYS",		"Journal of applied mathematics and physics = Zeitschrift f{\\\"u}r angewandte Mathematik und Physik")
    define("j-J-APPL-MATH-PHYS",		"Journal of applied mathematics and physics = Zeitschrift fuer angewandte Mathematik und Physik")
    define("j-J-APPL-MATH-PHYS",		"J. Appl. Math. Phys. (ZAMP)")

    define("j-J-APPL-MECH",			"Journal of Applied Mechanics")
    define("j-J-APPL-MECH",			"J. Appl. Mech.")
    define("j-J-APPL-MECH",			"Trans. ASME J. Appl. Mech.")
    define("j-J-APPL-MECH",			"ASME J. Appl. Mech.")
    define("j-J-APPL-MECH",			"Transactions of the ASME. Journal of applied mechanics")
    define("j-J-APPL-MECH",			"Trans. ASME Ser. E. J. Appl. Mech.")

    define("j-J-APPL-MECH-TECH-PHYS",		"Journal of Applied Mechanics and Technical Physics")
    define("j-J-APPL-MECH-TECH-PHYS",		"J. Appl. Mech. Tech. Phys.")

    define("j-J-APPL-PHYS",			"Journal of Applied Physics")
    define("j-J-APPL-PHYS",			"J. Appl. Physics")
    define("j-J-APPL-PHYS",			"J. Appl. Phys.")

    define("j-J-APPL-PROBAB",			"Journal of Applied Probability")
    define("j-J-APPL-PROBAB",			"J. Appl. Probability")
    define("j-J-APPL-PROBAB",			"J. appl. probab.")
    define("j-J-APPL-PROBAB",			"J. appl. prob.")

    define("j-J-APPL-PSYCHOL",			"Journal of Applied Psychology")
    define("j-J-APPL-PSYCHOL",			"J. Appl. Psychol.")
    define("j-J-APPL-PSYCHOL",			"J. of Applied Psychology")

    define("j-J-APPL-STAT",			"Journal of Applied Statistics")
    define("j-J-APPL-STAT",			"J. of Applied Statistics")
    define("j-J-APPL-STAT",			"J. Appl. Statist.")

    define("j-J-APPL-TOXIC",			"Journal of Applied Toxicology: JAT")
    define("j-J-APPL-TOXIC",			"J Appl Toxicol (H93)")

    define("j-J-APPROX-THEORY",			"Journal of Approximation Theory")
    define("j-J-APPROX-THEORY",			"J. Approx. Theory")
    define("j-J-APPROX-THEORY",			"J. Approximation Theory")
    define("j-J-APPROX-THEORY",			"J. Appr. Theory")

    define("j-J-AQUACULT-RES-DEV",		"Journal of Aquaculture Research \\& Development")
    define("j-J-AQUACULT-RES-DEV",		"J. Aquacul. Res. Dev.")

    define("j-J-ASSET-MANAGE",			"Journal of Asset Management")
    define("j-J-ASSET-MANAGE",			"J. Asset Manage.")

    define("j-J-ASSOC-INF-SCI-TECHNOL",		"Journal of the Association for Information Science and Technology")
    define("j-J-ASSOC-INF-SCI-TECHNOL",		"J. Assoc. Inf. Sci. Technol.")

    define("j-J-ASTRONAUTICAL-SCIENCES",	"Journal of the Astronautical Sciences")
    define("j-J-ASTRONAUTICAL-SCIENCES",	"J. Astronautical Sciences")

    define("j-J-ASTROPHYS-ASTRON",		"Journal of Astrophysics and Astronomy")
    define("j-J-ASTROPHYS-ASTRON",		"J. Astrophys. Astron.")
    # define("j-J-ASTROPHYS-ASTRON",		"")

    define("j-J-ATMOS-SCI",			"Journal of the Atmospheric Sciences")
    define("j-J-ATMOS-SCI",			"J. Atmospheric Sciences")
    define("j-J-ATMOS-SCI",			"J. of the Atmospheric Sciences")
    define("j-J-ATMOS-SCI",			"J. of Atmospheric Sciences")
    define("j-J-ATMOS-SCI",			"J. Atmos. Sci.")

    define("j-J-ATMOS-SOL-TERR-PHYS",		"Journal of Atmospheric and Solar-Terrestrial Physics")
    define("j-J-ATMOS-SOL-TERR-PHYS",		"J. Atmos. Sol.-Terr. Phys.")

    define("j-J-AUDIO-ENG-SOC",			"Journal of the Audio Engineering Society")
    define("j-J-AUDIO-ENG-SOC",			"J. Audio Eng. Soc.")

    define("j-J-AUSTRALIAN-MATH-SOC",		"Journal of the Australian Mathematical Society")
    define("j-J-AUSTRALIAN-MATH-SOC",		"J. Australian Math. Soc.")
    define("j-J-AUSTRALIAN-MATH-SOC",		"J. Aust. Math. Soc.")
    define("j-J-AUSTRALIAN-MATH-SOC",		"J. Austral. Math. Soc.")

    define("j-J-AUSTRAL-MATH-SOC-SER-A",	"Journal of the Australian Mathematical Society. Series A")
    define("j-J-AUSTRAL-MATH-SOC-SER-A",	"Journal of the Australian Mathematical Society. Series A: Pure mathematics")
    define("j-J-AUSTRAL-MATH-SOC-SER-A",	"Journal of the Australian Mathematical Society. Series A: Pure mathematics and statistics")
    define("j-J-AUSTRAL-MATH-SOC-SER-A",	"J. Australian Math. Soc. Series A. Pure mathematics and statistics")
    define("j-J-AUSTRAL-MATH-SOC-SER-A",	"J. Austral Math. Soc. Ser. A")

    define("j-J-AUSTRAL-MATH-SOC-SER-B",	"Journal of the Australian Mathematical Society. Series B: Applied Mathematics")
    define("j-J-AUSTRAL-MATH-SOC-SER-B",	"Journal of the Australian Mathematical Society. Series B")
    define("j-J-AUSTRAL-MATH-SOC-SER-B",	"J. Australian Math. Soc. Series B. Applied mathematics")
    define("j-J-AUSTRAL-MATH-SOC-SER-B",	"J. Australian Math. Soc. Series B")
    define("j-J-AUSTRAL-MATH-SOC-SER-B",	"J. Austral Math. Soc. Ser. B")

    define("j-J-AUTOM-REASON",			"Journal of Automated Reasoning")
    define("j-J-AUTOM-REASON",			"J. Automat. Reasoning")
    define("j-J-AUTOM-REASON",			"J. Automat. Reason.")
    define("j-J-AUTOM-REASON",			"J. Autom. Reasoning")

    define("j-J-BACTERIOL",			"Journal of bacteriology")
    define("j-J-BACTERIOL",			"J Bacteriol (HH3)")
    define("j-J-BACTERIOL",			"J. Bact.")
    define("j-J-BACTERIOL",			"J. Bacteriol.")

    define("j-J-BIOCHEM",			"The Journal of biochemistry")
    define("j-J-BIOCHEM",			"J Biochem (Tokyo) (HIF)")
    define("j-J-BIOCHEM",			"J. Biochem.")

    define("j-J-BIOCHEM-BIOPHYS-METH",		"J Biochem Biophys Methods (H94)")

    define("j-J-BIOINF-COMPUT-BIOL",		"Journal of Bioinformatics and Computational Biology")
    define("j-J-BIOINF-COMPUT-BIOL",		"J. Bioinf. Comput. Biol.")

    define("j-J-BIOL-CHEM",			"The Journal of biological chemistry")
    define("j-J-BIOL-CHEM",			"J Biol Chem (HIV)")
    define("j-J-BIOL-CHEM",			"J. Biol. Chem.")

    define("j-J-BIOL-RHYTHMS",			"Journal of biological rhythms")
    define("j-J-BIOL-RHYTHMS",			"J. biol. rhythms")

    define("j-J-BIOL-SYSTEMS",			"Journal of biological systems")
    define("j-J-BIOL-SYSTEMS",			"J. Biol. Systems")

    define("j-J-BIOMECH",			"Journal of Biomechanics")
    define("j-J-BIOMECH",			"J. Biomech.")

    define("j-J-BIOMED-ENG",			"Journal of biomedical engineering")
    define("j-J-BIOMED-ENG",			"J. biomed. eng.")

    define("j-J-BIOMED-INF",			"Journal of Biomedical Informatics")
    define("j-J-BIOMED-INF",			"J. Biomed. Inf.")

    define("j-J-BIOMED-MATER-RES",		"Journal of Biomedical Materials Research")
    define("j-J-BIOMED-MATER-RES",		"J. Biomed. Mater. Res.")

    define("j-J-BIOMOL-STRUCT-DYNAMICS",	"Journal of biomolecular structure and dynamics")
    define("j-J-BIOMOL-STRUCT-DYNAMICS",	"J Biomol Struct Dyn (AH2)")

    define("j-J-BIOSCI",			"Journal of biosciences")

    define("j-J-BIOTECH",			"Journal of biotechnology")
    define("j-J-BIOTECH",			"J Biotechnol (AL6)")

    define("j-J-BONE-MINERAL-RES",		"Journal of bone and mineral research: the official journal of the American Society for Bone and Mineral Research")
    define("j-J-BONE-MINERAL-RES",		"J Bone Miner Res (130)")

    define("j-J-BR-ASTRON-ASSOC",		"Journal of the British Astronomical Association")
    define("j-J-BR-ASTRON-ASSOC",		"J. Br. Astron. Assoc.")

    define("j-J-BR-INTERPLANET-SOC",		"Journal of the British Interplanetary Society")
    define("j-J-BR-INTERPLANET-SOC",		"J. Br. Interplanet. Soc.")

    define("j-J-BRAZIL-COMPUT-SOC",		"Journal of the Brazilian Computer Society")
    define("j-J-BRAZIL-COMPUT-SOC",		"J. Brazil. Comput. Soc.")

    define("j-J-BUS-ECON-STAT",			"Journal of Business \\& Economic Statistics")
    define("j-J-BUS-ECON-STAT",			"JBES")
    define("j-J-BUS-ECON-STAT",			"J. Bus. Econ. Stat.")

    define("j-J-BUS-UNIV-CHIC",			"The Journal of Business at the {University of Chicago}")
    define("j-J-BUS-UNIV-CHIC",			"The Journal of Business")
    define("j-J-BUS-UNIV-CHIC",			"J. Bus.")
    define("j-J-BUS-UNIV-CHIC",			"J. Bus. Univ. Chic.")

    define("j-J-CARDIOVASC-PHARMACOL",		"Journal of cardiovascular pharmacology")
    define("j-J-CARDIOVASC-PHARMACOL",		"J Cardiovasc Pharmacol.")

    define("j-J-CARDIOVASC-ELECTROPHYSIOL",	"Journal of cardiovascular electrophysiology")
    define("j-J-CARDIOVASC-ELECTROPHYSIOL",	"J. cardiovasc. electrophysiol.")

    define("j-J-CELL-BIOCHEM",			"Journal of cellular biochemistry")
    define("j-J-CELL-BIOCHEM",			"J. Cell. Biochem.")
    define("j-J-CELL-BIOCHEM",			"J Cell Biochem (HNF)")

    define("j-J-CELL-BIOL",			"Journal of Cell Biology")
    define("j-J-CELL-BIOL",			"J Cell Biol (HMV)")
    define("j-J-CELL-BIOL",			"J. Cell Biol.")
    define("j-J-CELL-BIOL",			"J. Cell. Biol.")
    define("j-J-CELL-BIOL",			"J. Cell Biology")

    # NB: "Journal of cellular and comparative physiology"
    # is an alternate name for "Journal of cellular physiology"
    define("j-J-CELL-COMP-PHYSIOL",		"Journal of Cellular and Comparative Physiology")
    define("j-J-CELL-COMP-PHYSIOL",		"J. Cell. and Comp. Physiol.")

    define("j-J-CELL-PHYSIOL",			"Journal of Cellular Physiology")
    define("j-J-CELL-PHYSIOL",			"J Cell Physiol (HNB)")
    define("j-J-CELL-PHYSIOL",			"J. Cell Physiol.")
    define("j-J-CELL-PHYSIOL",			"J. Cell. Physiol.")

    define("j-J-CELL-SCI",			"Journal of Cell Science")
    define("j-J-CELL-SCI",			"J Cell Sci (HNK)")
    define("j-J-CELL-SCI",			"J. Cell Sci")
    define("j-J-CELL-SCI",			"J. Cell Sci.")
    define("j-J-CELL-SCI",			"J. Cell. Sci.")
    define("j-J-CELL-SCI",			"J. of Cell Sci.")

    define("j-J-CELL-SCI-SUPPL",		"Journal of Cell Science. Supplement")
    define("j-J-CELL-SCI-SUPPL",		"J Cell Sci Suppl (HNG)")
    define("j-J-CELL-SCI-SUPPL",		"J. Cell Sci. Suppl.")

    define("j-J-CEREB-BLOOD-FLOW-METAB",	"Journal of Cerebral Blood Flow and Metabolism")
    define("j-J-CEREB-BLOOD-FLOW-METAB",	"Journal of Cerebral Blood Flow \\& Metabolism")
    define("j-J-CEREB-BLOOD-FLOW-METAB",	"J. Cereb. Blood Flow Metab.")

    define("j-J-CHEM-EDUC",			"Journal of Chemical Education")
    define("j-J-CHEM-EDUC",			"J. Chem. Educ.")

    define("j-J-CHEM-INFO-COMP-SCI",		"Journal of Chemical Information and Computer Sciences")
    define("j-J-CHEM-INFO-COMP-SCI",		"Journal of chemical information and computer sci")
    define("j-J-CHEM-INFO-COMP-SCI",		"J. Chem. Inf. Comput. Sci")

    define("j-J-CHEM-INFO-MODEL",		"Journal of Chemical Information and Modeling")
    define("j-J-CHEM-INFO-MODEL",		"J. Chem. Inf. Model.")

    define("j-J-CHEM-PHYS",			"Journal of Chemical Physics")
    define("j-J-CHEM-PHYS",			"J. Chem. Phys.")

    # 1926-Dec. 1965
    define("j-J-CHEM-SOC",			"Journal of the Chemical Society")
    define("j-J-CHEM-SOC",			"Journal of the Chemical Society (Resumed)")
    define("j-J-CHEM-SOC",			"J. Chem. Soc.")

    define("j-J-CHEM-SOC-FARADAY-TRANS",	"Journal of the Chemical Society --- Faraday Transactions")
    define("j-J-CHEM-SOC-FARADAY-TRANS",	"Journal of the Chemical Society: Faraday Transactions")
    define("j-J-CHEM-SOC-FARADAY-TRANS",	"J. Chem. Soc. Faraday Trans.")

    define("j-J-CHEM-SOC-FARADAY-TRANS-2",	"Journal of the Chemical Society --- Faraday Transactions II")
    define("j-J-CHEM-SOC-FARADAY-TRANS-2",	"Journal of the Chemical Society. Faraday transactions II")
    define("j-J-CHEM-SOC-FARADAY-TRANS-2",	"Journal of the Chemical Society. Faraday transactions. II, Molecular and chemical physics")
    define("j-J-CHEM-SOC-FARADAY-TRANS-2",	"J. Chem. Soc. Faraday Trans. 2")

    define("j-J-CHEM-SOC-TRANS",		"Journal of the Chemical Society, Transactions")
    define("j-J-CHEM-SOC-TRANS",		"J. Chem. Soc., Trans.")

    define("j-J-CHEM-THEORY-COMPUT",		"Journal of Chemical Theory and Computation")
    define("j-J-CHEM-THEORY-COMPUT",		"J. Chem. Theory and Comp.")
    define("j-J-CHEM-THEORY-COMPUT",		"J. Chem. Theory Comput.")

    define("j-J-CHEMOM",			"Journal of Chemometrics")
    define("j-J-CHEMOM",			"J. Chemom.")

    define("j-J-CHILD-MATH-BEHAV",		"Journal of children's mathematical behavior")
    define("j-J-CHILD-MATH-BEHAV",		"J. Child. Math. Behav.")
    define("j-J-CHILD-MATH-BEHAV",		"J. Child. Math. Behavior")

    define("j-J-CHINESE-INST-ENG",		"Journal of the Chinese Institute of Engineers = Chung-kuo kung ch'eng hsueh kan")
    define("j-J-CHINESE-INST-ENG",		"Journal of the Chinese Institute of Engineers = Kung ch'eng")
    define("j-J-CHINESE-INST-ENG",		"Journal of the Chinese Institute of Engineers")
    define("j-J-CHINESE-INST-ENG",		"J. Chin. Inst. Eng.")

    define("j-J-CHROMATOGR-A",			"Journal of Chromatography. A")
    define("j-J-CHROMATOGR-A",			"J. Chromatogr. A")

    define("j-J-CIV-DEF",			"Journal of Civil Defense")
    define("j-J-CIV-DEF",			"J. Civil Defense")
    define("j-J-CIV-DEF",			"J. Civ. Def.")

    define("j-J-CLIN-INVEST",			"Journal of Clinical Investigation")
    define("j-J-CLIN-INVEST",			"J Clin Invest (HS7)")
    define("j-J-CLIN-INVEST",			"J. clin. invest.")

    define("j-J-CLIN-PATHOL",			"Journal of Clinical Pathology")
    define("j-J-CLIN-PATHOL",			"J. clin. pathol.")
    define("j-J-CLIN-PATHOL",			"J. clin. path.")

    define("j-J-CLIN-PSYCHOL",			"Journal of Clinical Psychology")
    define("j-J-CLIN-PSYCHOL",			"J. Clin. Psychol.")

    define("j-J-COLD-REG-ENG",			"Journal of cold regions engineering")
    define("j-J-COLD-REG-ENG",			"J. cold reg. eng.")
    define("j-J-COLD-REG-ENG",			"J. Cold Regions Engng.")

    define("j-J-COLD-WAR-STUD",			"Journal of Cold War Studies")
    define("j-J-COLD-WAR-STUD",			"J. Cold War Stud.")

    define("j-J-COLL-SCI-TEACH",		"Journal of College Science Teaching")
    define("j-J-COLL-SCI-TEACH",		"J. Coll. Sci. Teach.")

    define("j-J-COLLOID-INTERFACE-SCI",		"Journal of Colloid and Interface Science")
    define("j-J-COLLOID-INTERFACE-SCI",		"J. Colloid Interface Sci.")

    define("j-J-COMB",				"Journal of Combinatorics")
    define("j-J-COMB",				"J. Comb.")

    define("j-J-COMB-DES",			"Journal of Combinatorial Designs")
    define("j-J-COMB-DES",			"J. comb. des.")

    define("j-J-COMB-OPTIM",			"Journal of Combinatorial Optimization")
    define("j-J-COMB-OPTIM",			"J. Comb. Optim.")

    define("j-J-COMB-THEORY",			"Journal of Combinatorial Theory")
    define("j-J-COMB-THEORY",			"J. Combinatorial Theory")

    define("j-J-COMB-THEORY-A",			"Journal of Combinatorial Theory (Series A)")
    define("j-J-COMB-THEORY-A",			"J. Combinatorial Theory Series A")
    define("j-J-COMB-THEORY-A",			"J. Combin. Theory Ser. A")
    define("j-J-COMB-THEORY-A",			"J. Combinatorial Theory Ser. A")
    define("j-J-COMB-THEORY-A",			"J. Comb. Theory, Ser. A")

    define("j-J-COMB-THEORY-B",			"Journal of Combinatorial Theory (Series B)")
    define("j-J-COMB-THEORY-B",			"J. Combinatorial Theory Series B")
    define("j-J-COMB-THEORY-B",			"J. comb. theory, Ser. B.")

    define("j-J-COMP-BASED-INST",		"Journal of Computer-Based Instruction")

    define("j-J-COMP-INFO",			"Journal of Computing and Information")
    define("j-J-COMP-INFO",			"J. Comput. Inform.")

    define("j-J-COMP-INFO-SYS",			"The Journal of Computer Information Systems")

    define("j-J-COMP-MATH",			"Journal of Computational Mathematics")
    define("j-J-COMP-MATH",			"J. Comput. Math.")
    define("j-J-COMP-MATH",			"J. Comp. Math.")

    define("j-J-COMP-NEUROL",                   "Journal of comparative neurology (1911)")
    define("j-J-COMP-NEUROL",                   "Journal of comparative neurology")
    define("j-J-COMP-NEUROL",                   "J Comp Neurol.")

    define("j-J-COMP-NEUROSCI",			"Journal of computational neuroscience")
    define("j-J-COMP-NEUROSCI",			"J. Computational Neurosci.")

    define("j-J-COMP-PHYSIOL",			"Journal of comparative physiology")
    define("j-J-COMP-PHYSIOL",			"J. Comp. Physiol.")

    define("j-J-COMP-PHYSIOL-A",		"Journal of Comparative Physiology, A")
    define("j-J-COMP-PHYSIOL-A",		"Journal of Comparative Physiology, A: Neuroethology, Sensory, Neural, and Behavioral Physiology")
    define("j-J-COMP-PHYSIOL-A",		"Journal of Comparative Physiology. A, Sensory, Neural, and Behavioral Physiology")
    define("j-J-COMP-PHYSIOL-A",		"J. comp. physiol., A")

    define("j-J-COMP-PHYSIOL-B",		"Journal of comparative physiology. B, Biochemical, systemic, and environmental physiology")
    define("j-J-COMP-PHYSIOL-B",		"J. comp. physiol., B Biochem. syst. environ. physiol.")

    define("j-J-COMP-SCI-TECH",			"Journal of computer science and technology")

    define("j-J-COMP-SECUR",			"Journal of Computer Security")
    define("j-J-COMP-SECUR",			"J. Comput. Secur.")
    define("j-J-COMP-SECUR",			"J. Comp. Secur.")

    define("j-J-COMP-SYS-SCI",			"Journal of Computer and System Sciences")
    define("j-J-COMP-SYS-SCI",			"J. Comp. System Sci.")
    define("j-J-COMP-SYS-SCI",			"J. Comput. Syst. Sci.")
    define("j-J-COMP-SYS-SCI",			"J. Comput. System Sci.")

    define("j-J-COMPLEX-NETWORKS",		"Journal of Complex Networks")
    define("j-J-COMPLEX-NETWORKS",		"J. Complex Netw.")

    define("j-J-COMPLEXITY",			"Journal of Complexity")

    define("j-J-COMPOS-MATER",			"Journal of Composite Materials")
    define("j-J-COMPOS-MATER",			"J. compos. mater.")
    define("j-J-COMPOS-MATER",			"J. Composite Mater.")

    define("j-J-COMPUT-AIDED-MATER-DES",	"Journal of Computer-Aided Materials Design")
    define("j-J-COMPUT-AIDED-MATER-DES",	"J. Comput.-Aided Mater. Des.")

    define("j-J-COMPUT-APPL-MATH",		"Journal of Computational and Applied Mathematics")
    define("j-J-COMPUT-APPL-MATH",		"J. Comp. Appl. Math.")
    define("j-J-COMPUT-APPL-MATH",		"J. Computational Applied Mathematics")
    define("j-J-COMPUT-APPL-MATH",		"J. Computational \\& Applied Math.")
    define("j-J-COMPUT-APPL-MATH",		"J. Computational and Applied Mathematics")
    define("j-J-COMPUT-APPL-MATH",		"J. of Computational and Applied Mathematics")
    define("j-J-COMPUT-APPL-MATH",		"Journal of Comp. and Appl. Math.")
    define("j-J-COMPUT-APPL-MATH",		"Journal of Comput. Appl. Math.")
    define("j-J-COMPUT-APPL-MATH",		"J. Comput. Appl. Math.")

    define("j-J-COMPUT-ASSIST-LEARNING",	"Journal of Computer Assisted Learning")

    define("j-J-COMPUT-ASSIST-MICROSC",		"Journal of computer-assisted microscopy")
    define("j-J-COMPUT-ASSIST-MICROSC",		"J. comput.-assist. microsc.")
    define("j-J-COMPUT-ASSIST-MICROSC",		"J. Comp. Asstd. Microscopy")

    define("j-J-COMPUT-ASSIST-TOMOGRAPHY",	"Journal of Computer Assisted Tomography")

    define("j-J-COMPUT-BIOL",			"Journal of Computational Biology")
    define("j-J-COMPUT-BIOL",			"J. Comput. Biol.")

    define("j-J-COMPUT-CHEM",			"Journal of Computational Chemistry")
    define("j-J-COMPUT-CHEM",			"J. Comp. Chem.")
    define("j-J-COMPUT-CHEM",			"J. Comput. Chem.")

    define("j-J-COMPUT-FINANCE",		"Journal of Computational Finance")
    define("j-J-COMPUT-FINANCE",		"J. Comput. Finance")

    define("j-J-COMPUT-GEOM",			"Journal of Computational Geometry")
    define("j-J-COMPUT-GEOM",			"J. Comput. Geom.")

    define("j-J-COMPUT-GRAPH-STAT",		"Journal of Computational and Graphical Statistics")
    define("j-J-COMPUT-GRAPH-STAT",		"J. comput. graph. stat.")
    define("j-J-COMPUT-GRAPH-STAT",		"J. Comput. Graph. Statist.")
    define("j-J-COMPUT-GRAPH-STAT",		"Journal of computational and graphical statistics: a joint publication of American Statistical Association, Institute of Mathematical Statistics, Interface Foundation of North America")

    define("j-J-COMPUT-METHODS-SCI-ENG",	"Journal of Computational Methods in Sciences and Engineering")
    define("j-J-COMPUT-METHODS-SCI-ENG",	"J. Comput. Methods Sci. Eng.")

    define("j-J-COMPUT-PHYS",			"Journal of Computational Physics")
    define("j-J-COMPUT-PHYS",			"J. Comput. Phys.")
    define("j-J-COMPUT-PHYS",			"J. Comp. Phys.")
    define("j-J-COMPUT-PHYS",			"J. Computational Phys.")
    define("j-J-COMPUT-PHYS",			"J. Computational Physics")
    define("j-J-COMPUT-PHYS",			"Journ. of Comp. Physics")
    define("j-J-COMPUT-PHYS",			"Journal of Comp. Physics")

    define("j-J-COMPUT-SCI",			"Journal of Computational Science")
    define("j-J-COMPUT-SCI",			"J. Comput. Sci.")

    define("j-J-COMPUT-SYST-SCI-INT",		"Journal of Computer and System Sciences International")
    define("j-J-COMPUT-SYST-SCI-INT",		"J. Comput. Syst. Sci. Int.")

    ## [29-Nov-2012] Preferred abbreviation changed to j-J-COMPUT-CHEM
    ## define("j-J-COMPUTATIONAL-CHEM",		"Journal of Computational Chemistry")

    define("j-J-CONFL-RESOLUT",			"Journal of Conflict Resolution")
    define("j-J-CONFL-RESOLUT",			"J. Confl. Resolut.")

    define("j-J-CONTEMP-HIST",			"Journal of Contemporary History")
    define("j-J-CONTEMP-HIST",			"J. Contemp. Hist.")

    define("j-J-CONTROL-THEORY-APPL",		"Journal of Control Theory and Applications")
    define("j-J-CONTROL-THEORY-APPL",		"J. Control Theory Appl.")

    define("j-J-CONVEX-ANAL",			"Journal of convex analysis")
    define("j-J-CONVEX-ANAL",			"J. convex anal.")

    ## Springer journal that is not in US Library of Congress, CASSI,
    ## or AMS MathSciNet, so preferred journal abbreviation is
    ## unknown.
    define("j-J-CRYPTO-ENG",			"Journal of Cryptographic Engineering")
    define("j-J-CRYPTO-ENG",			"J. Crypto. Eng.")

    define("j-J-CRYPTOLOGY",			"Journal of Cryptology")
    define("j-J-CRYPTOLOGY",			"J. Cryptology")
    define("j-J-CRYPTOLOGY",			"J. Cryptol.")
    define("j-J-CRYPTOLOGY",			"Journal of Cryptology: the Journal of the International Association for Cryptologic Research")

    define("j-J-CRYSTAL-GROWTH",		"Journal of Crystal Growth")
    define("j-J-CYCLIC-NUCLEOTIDE-PROTEIN-PHOSPHOR-RES","J Cyclic Nucleotide Protein Phosphor Res (HWO)")
    define("j-J-DAIRY-SCI",			"Journal of dairy science")

    define("j-J-DATA-COMP-COMM",		"Journal of Data and Computer Communications")

    define("j-J-DATABASE-ADM",			"Journal of Database Administration")
    define("j-J-DATABASE-ADM",			"J. Database Adm.")

    define("j-J-DES-HIST",			"Journal of Design History")
    define("j-J-DES-HIST",			"J. Des. Hist.")

    define("j-J-DIFFER-EQU",			"Journal of Differential Equations")
    define("j-J-DIFFER-EQU",			"J. Differ. Equ.")
    define("j-J-DIFFER-EQU",			"J. Diff. Equations")

    define("j-J-DIFFER-GEOM",			"Journal of Differential Geometry")
    define("j-J-DIFFER-GEOM",			"J. Differ. Geom.")
    define("j-J-DIFFER-GEOM",			"J. Diff. Geom.")

    define("j-J-DIFFERENCE-EQU-APPL",		"Journal of Difference Equations and Applications")
    define("j-J-DIFFERENCE-EQU-APPL",		"J. Difference Equ. Appl.")

    define("j-J-DIGITAL-IMAGING",		"Journal of Digital Imaging")
    define("j-J-DIGITAL-IMAGING",		"Journal of Digital Imaging: The Official Journal of the Society for Computer Applications in Radiology")

    define("j-J-DIGITAL-INFO",			"Journal of Digital Information")
    define("j-J-DIGITAL-INFO",			"J. Digit. Info.")

    # Elsevier journal, not to be confused with J. Discrete Algorithms (Oxf.)
    define("j-J-DISCRETE-ALGORITHMS",		"Journal of Discrete Algorithms")
    define("j-J-DISCRETE-ALGORITHMS",		"J. Discr. Algor.")
    define("j-J-DISCRETE-ALGORITHMS",		"J. Discrete Algorithms")

    define("j-J-DISCR-MATH-SCI-CRYPTO",		"Journal of Discrete Mathematical Sciences and Cryptography")
    define("j-J-DISCR-MATH-SCI-CRYPTO",		"Journal of Discrete Mathematical Sciences \\& Cryptography")
    define("j-J-DISCR-MATH-SCI-CRYPTO",		"J. Discrete Math. Sci. Cryptogr.")	# AMS MathSciNet abbreviation
    define("j-J-DISCR-MATH-SCI-CRYPTO",		"J. Discrete Math. Sci. Cryptography")	# AMS MathSciNet abbreviation
    define("j-J-DISCR-MATH-SCI-CRYPTO",		"J. Discr. Math. Sci. Crypto.")

    define("j-J-DOC",				"Journal of Documentation")

    define("j-J-DYN-CONTROL-SYST",		"Journal of dynamical and control systems")
    define("j-J-DYN-CONTROL-SYST",		"J. dyn. control syst.")
    define("j-J-DYN-CONTROL-SYST",		"J. Dynam. Control Systems")

    define("j-J-DYN-DIFFER-EQU",		"Journal of Dynamics and Differential Equations")
    define("j-J-DYN-DIFFER-EQU",		"J. Dynam. Differential Equations")
    define("j-J-DYN-DIFFER-EQU",		"J. Dyn. Differ. Equ.")
    define("j-J-DYN-DIFFER-EQU",		"J. Dynam. and Diff. Eqns.")
    define("j-J-DYN-DIFFER-EQU",		"J. Dynam. Diff. Eqs.")

    define("j-J-DYN-SYST-MEAS-CONTROL",		"Journal of Dynamic Systems, Measurement, and Control")
    define("j-J-DYN-SYST-MEAS-CONTROL",		"Journal of Dynamic Systems, Measurement and Control, Transactions of the ASME")
    define("j-J-DYN-SYST-MEAS-CONTROL",		"Journal of dynamic systems, measurement, and control")
    define("j-J-DYN-SYST-MEAS-CONTROL",		"J. dyn. syst. meas. control.")
    define("j-J-DYN-SYST-MEAS-CONTROL",		"Journal of Dynamic Systems, Measurement and Control, Transactions of the ASME")

    define("j-J-ECON-DYN-CONTROL",		"Journal of Economic Dynamics and Control")
    define("j-J-ECON-DYN-CONTROL",		"J. Econ. Dyn. Control")

    define("j-J-ECON-LIT",			"Journal of Economic Literature")

    define("j-J-ECON-THEORY",			"Journal of economic theory")
    define("j-J-ECON-THEORY",			"J. econ. theory")

    define("j-J-ECONOMETRICS",			"Journal of Econometrics")
    define("j-J-ECONOMETRICS",			"J. Econom.")
    define("j-J-ECONOMETRICS",			"J. Econometrics")
    define("j-J-ECONOMETRICS",			"J. of Econometrics")

    define("j-J-EDU-RESEARCH",			"The Journal of Educational Research")

    define("j-J-EDUC-BEHAV-STAT",		"Journal of Educational and Behavioral Statistics")
    define("j-J-EDUC-BEHAV-STAT",		"J. Educ. Behav. Stat.")

    define("j-J-EDUC-SOCIOL-NEW-YORK",		"Journal of Educational Sociology (New York)")
    define("j-J-EDUC-SOCIOL-NEW-YORK",		"Journal of Educational Sociology")
    define("j-J-EDUC-SOCIOL-NEW-YORK",		"J. Educ. Sociol. (New York)")
    define("j-J-EDUC-SOCIOL-NEW-YORK",		"J. Educ. Sociol. (N.Y.)")
    define("j-J-EDUC-SOCIOL-NEW-YORK",		"J. Educ. Sociol.")

    define("j-J-ELAST",				"Journal of Elasticity")
    define("j-J-ELAST",				"J. Elast.")
    define("j-J-ELAST",				"J. Elasticity")

    define("j-J-ELECTROCARDIOL",		"Journal of electrocardiology")
    define("j-J-ELECTROCARDIOL",		"J. Electrocardiol.")
    define("j-J-ELECTROCARDIOL",		"J. Electrocard.")

    define("j-J-ELECTROCHEM-SOC",		"Journal of the Electrochemical Society")
    define("j-J-ELECTROCHEM-SOC",		"J. Electrochem. Soc.")

    define("j-J-ELECTROMAGN-WAVES-APPL",	"Journal of Electromagnetic Waves and Applications")
    define("j-J-ELECTROMAGN-WAVES-APPL",	"J. Electromagn. Waves Appl.")

    define("j-J-ELECTRON-IMAGING",		"Journal of Electronic Imaging")
    define("j-J-ELECTRON-IMAGING",		"J. electron. imaging")

    define("j-J-ELECTRON-MICROSC-TECH",		"Journal of Electron Microscopy Technique")
    define("j-J-ELECTRON-MICROSC-TECH",		"J. electron microsc. tech.")
    define("j-J-ELECTRON-MICROSC-TECH",		"J Electron Microsc Tech (JEO)")

    define("j-J-ELECTRON-SPECTROSC-RELAT-PHENOM", "Journal of Electron Spectroscopy and Related Phenomena")
    define("j-J-ELECTRON-SPECTROSC-RELAT-PHENOM", "J. Electron Spectrosc. Relat. Phenom.")

    define("j-J-ELECTROST",			"Journal of Electrostatics")
    define("j-J-ELECTROST",			"J. Electrost.")

    define("j-J-ELISHA-MITCHELL-SCI-SOC",	"Journal of the Elisha Mitchell Scientific Society")
    define("j-J-ELISHA-MITCHELL-SCI-SOC",	"Journal of the elisha mitchell scientific societ")
    define("j-J-ELISHA-MITCHELL-SCI-SOC",	"J. Elisha Mitchell Sci. Soc.")

    define("j-J-EMBRYOL-EXP-MORPHOL",		"Journal of Embryology and Experimental Morphology")
    define("j-J-EMBRYOL-EXP-MORPHOL",		"J. Embryol. Exp. Morph.")
    define("j-J-EMBRYOL-EXP-MORPHOL",		"J. Embryol. Exp. Morphol.")
    define("j-J-EMBRYOL-EXP-MORPHOL",		"J Embryol Exp Morphol (I13)")

    define("j-J-EMPIR-FINANCE",			"Journal of Empirical Finance")
    define("j-J-EMPIR-FINANCE",			"J. Empir. Finance")

    define("j-J-ENG-MATER-TECHNOL",		"Journal of engineering materials and technology")
    define("j-J-ENG-MATER-TECHNOL",		"J. eng. mater. technol.")
    define("j-J-ENG-MATER-TECHNOL",		"ASME Journal of engineering materials and technology")

    define("j-J-ENG-MATH",			"Journal of Engineering Mathematics")
    define("j-J-ENG-MATH",			"J. Engrg. Math.")
    define("j-J-ENG-MATH",			"J. Eng. Math.")

    define("j-J-ENG-MECH",			"Journal of Engineering Mechanics")
    define("j-J-ENG-MECH",			"Journal of Engineering Mechanics / American Society of Civil Engineers")
    define("j-J-ENG-MECH",			"Journal of Engineering Mechanics / ASCE")
    define("j-J-ENG-MECH",			"J. Eng. Mech.")
    define("j-J-ENG-MECH",			"J. {Engng}. {Mech}. {Div}, {ASCE}")

    define("j-J-EUKARYOT-MICROBIOL",		"J Eukaryot Microbiol (BQT)")

    define("j-J-EXP-BIOL",			"Journal of Experimental Biology")
    define("j-J-EXP-BIOL",			"J. Exp. Biol.")
    define("j-J-EXP-BIOL",			"J. Exptl. Biol.")

    define("j-J-EXP-MED",			"Journal of Experimental Medicine")
    define("j-J-EXP-MED",			"J. exp. med.")

    define("j-J-EXP-PSYCH-GEN",			"Journal of Experimental Psychology: General")
    define("j-J-EXP-PSYCH-LMC",			"Journal of Experimental Psychology: Learning, Memory, and Cognition")

    define("j-J-EXP-THEOR-ARTIF-INTELL",	"Journal of experimental \\& theoretical artificial intelligence: JETAI")
    define("j-J-EXP-THEOR-ARTIF-INTELL",	"Journal of Experimental and Theoretical Artificial Intelligence")
    define("j-J-EXP-THEOR-ARTIF-INTELL",	"J. exp. theor. artif. intell.")

    define("j-J-EXP-THEOR-PHYS",		"Journal of experimental and theoretical physics")
    define("j-J-EXP-THEOR-PHYS",		"J. exp. theor. phys. (Print)")
    define("j-J-EXP-THEOR-PHYS",		"J. exp. theor. phys.")

    define("j-J-EXP-ZOOL",			"Journal of experimental zoology")
    define("j-J-EXP-ZOOL",			"J Exp Zool (I47)")
    define("j-J-EXP-ZOOL",			"J. Exp. Zool.")
    define("j-J-EXP-ZOOL",			"J. Exptl. Zool.")

    define("j-J-FINANC-ECON",			"Journal of Financial Economics")
    define("j-J-FINANC-ECON",			"J. Financ. Econ.")

    define("j-J-FISH-BIOL",			"J. Fish Biol.")
    define("j-J-FISH-BIOL",			"Journal of Fish Biology")

    define("j-J-FISH-DIS",			"Journal of Fish Diseases")
    define("j-J-FISH-DIS",			"J. Fish Dis.")

    define("j-J-FISH-RES-BOARD-CAN",		"Journal of the Fisheries Research Board of Canada = Journal de l'Office des recherches sur les p{\\^e}cheries du Canada")
    define("j-J-FISH-RES-BOARD-CAN",		"Journal of the Fisheries Research Board of Canada = Journal de l'Office des recherches sur les pecheries du Canada")
    define("j-J-FISH-RES-BOARD-CAN",		"J. Fish. Res. Board Can.")
    define("j-J-FISH-RES-BOARD-CAN",		"Journal of the Fisheries Research Board of Canada")

    define("j-J-FISHERIESCIENCES-COM",		"Journal of FisheriesSciences.com")
    define("j-J-FISHERIESCIENCES-COM",		"J. FisheriesSciences.com")

    define("j-J-FLUID-MECH",			"Journal of Fluid Mechanics")
    define("j-J-FLUID-MECH",			"Journal of Fluid Mech.")
    define("j-J-FLUID-MECH",			"J. Fluid Mech.")

    define("j-J-FLUIDS-ENG",			"Journal of fluids engineering")
    define("j-J-FLUIDS-ENG",			"J. fluids eng.")

    define("j-J-FORENSIC-ACCOUNT",		"Journal of Forensic Accounting")
    define("j-J-FORENSIC-ACCOUNT",		"J. Forensic Account.")

    define("j-J-FORTH-APPL-RES",		"Journal of FORTH Application and Research")
    define("j-J-FORTH-APPL-RES",		"J. Forth appl. res.")

    define("j-J-FUNCT-PROGRAM",			"Journal of Functional Programming")
    define("j-J-FUNCT-PROGRAM",			"J. Funct. Programming")
    define("j-J-FUNCT-PROGRAM",			"J. Funct. Program.")
    define("j-J-FUNCT-PROGRAM",			"J. Funct. Prog.")

    define("j-J-FRANKLIN-INST",			"Journal of {The Franklin Institute}")
    define("j-J-FRANKLIN-INST",			"Journal of the Franklin Institute")
    define("j-J-FRANKLIN-INST",			"J. Franklin Inst.")

    define("j-J-FUNCT-ANAL",			"Journal of functional analysis")
    define("j-J-FUNCT-ANAL",			"J. funct. anal.")
    define("j-J-FUNCT-ANAL",			"J. Functional Analysis")

    define("j-J-FUNCT-LOGIC-PROG",		"Journal of Functional and Logic Programming")
    define("j-J-FUNCT-LOGIC-PROG",		"J. Func. Logic Prog.")

    define("j-J-GAMBL-STUD",			"Journal of Gambling Studies")
    define("j-J-GAMBL-STUD",			"J. Gambl. Stud.")

    define("j-J-GEN-MICROBIOL",			"JGM, Journal of General Microbiology")
    define("j-J-GEN-MICROBIOL",			"J Gen Microbiol (I87)")
    define("j-J-GEN-MICROBIOL",			"J. Gen. Microbiol.")
    define("j-J-GEN-MICROBIOL",			"J. Gen. Microbiology")
    define("j-J-GEN-MICROBIOL",			"The Journal of General Microbiology")

    define("j-J-GEN-PHILOS-SCI",		"Journal for General Philosophy of Science = Zeitschrift f{\\\"u}r allgemeine Wissenschaftstheorie")
    define("j-J-GEN-PHILOS-SCI",		"Journal for General Philosophy of Science")
    define("j-J-GEN-PHILOS-SCI",		"J. gen. philos. sci.")

    define("j-J-GEN-PHYSIOL",			"Journal of General Physiology")
    define("j-J-GEN-PHYSIOL",			"J. Gen. Physiol.")

    define("j-J-GEN-PSYCH",			"The Journal of General Psychology")
    define("j-J-GEN-PSYCH",			"Journal of General Psychology")
    define("j-J-GEN-PSYCH",			"J. Gen. Psych.")

    define("j-J-GENET",				"Journal of Genetics")
    define("j-J-GENET",				"J. Genet.")
    define("j-J-GENET",				"J. Genetics")

    define("j-J-GEOCHEM-EXPLOR",		"Journal of Geochemical Exploration")
    define("j-J-GEOCHEM-EXPLOR",		"J. geochem. explor.")

    define("j-J-GEOL",				"The Journal of Geology")
    define("j-J-GEOL",				"Journal of Geology")
    define("j-J-GEOL",				"J. Geol.")

    define("j-J-GEOM-ANAL",			"Journal of Geometric Analysis")
    define("j-J-GEOM-ANAL",			"J. Geom. Anal.")
    define("j-J-GEOM-ANAL",			"J. Geometric Anal.")

    define("j-J-GEOM-PHYS",			"Journal of Geometry and Physics")
    define("j-J-GEOM-PHYS",			"J. Geom. Phys.")

    define("j-J-GEOMAGN-GEOELEC",		"Journal of Geomagnetism and Geoelectricity")
    define("j-J-GEOMAGN-GEOELEC",		"J. geomagn. geoelec.")

    define("j-J-GEOPHYS-RES",			"Journal of geophysical research")
    define("j-J-GEOPHYS-RES",			"J. of Geophysical Research")
    define("j-J-GEOPHYS-RES",			"J. geophys. res.")

    define("j-J-GEOPHYS-RES-A",			"Journal of geophysical research. A, Space physics")
    define("j-J-GEOPHYS-RES-A",			"Journal of geophysical research.  space physics")
    define("j-J-GEOPHYS-RES-A",			"J. of Geophysical Research, A, Space physics")
    define("j-J-GEOPHYS-RES-A",			"J. geophys. res., A, Space phys.")

    define("j-J-GEOPHYS-RES-D",			"Journal of geophysical research. D, Atmospheres")
    define("j-J-GEOPHYS-RES-D",			"Journal of geophysical research.  Atmospheres")
    define("j-J-GEOPHYS-RES-D",			"J. geophys. res., D, Atmos.")

    define("j-J-GEOPHYS-RES-OCEAN",		"Journal of Geophysical Research (Oceans)")
    define("j-J-GEOPHYS-RES-OCEAN",		"J. Geophys. Res. Ocean")

    define("j-J-GEOPHYS-RES-SOLID-EARTH",	"Journal of Geophysical Research. Solid Earth")
    define("j-J-GEOPHYS-RES-SOLID-EARTH",	"Journal of Geophysical Research --- Solid Earth")
    define("j-J-GEOPHYS-RES-SOLID-EARTH",	"Journal of Geophysical Research: Solid Earth")
    define("j-J-GEOPHYS-RES-SOLID-EARTH",	"JGR Solid Earth")
    define("j-J-GEOPHYS-RES-SOLID-EARTH",	"J. Geophys. Res. Solid Earth")

    define("j-J-GLOBAL-OPT",			"Journal of Global Optimization")
    define("j-J-GLOBAL-OPT",			"Journal of global optimization : an international journal dealing with theoretical and computational aspects of seeking global optima and their applications in science, management and engineering")
    define("j-J-GLOBAL-OPT",			"J. Global Optim.")

    define("j-J-GRAPH-TH",			"J. Graph Theory")

    define("j-J-GRAPHICS-TOOLS",		"Journal of Graphics Tools: JGT")
    define("j-J-GRAPHICS-TOOLS",		"J. Graphics Tools")

    define("j-J-GRID-COMP",			"Journal of Grid Computing")
    define("j-J-GRID-COMP",			"J. Grid Comp.")
    define("j-J-GRID-COMP",			"J. Grid Comput.")

    define("j-J-HEREDITY",			"The Journal of Heredity")
    define("j-J-HEREDITY",			"J Hered (IC7)")
    define("j-J-HEREDITY",			"J. Hered.")

    define("j-J-HEURISTICS",			"Journal of Heuristics")
    define("j-J-HEURISTICS",			"J. Heur.")
    define("j-J-HEURISTICS",			"J. Heuristics")

    define("j-J-HIGH-ENERGY-PHYS",		"Journal of High Energy Physics")
    define("j-J-HIGH-ENERGY-PHYS",		"J. High Energy Phys.")
    define("j-J-HIGH-ENERGY-PHYS",		"J. High Energy Phys., Pap. Arch.")
    define("j-J-HIGH-ENERGY-PHYS",		"JHEP")
    define("j-J-HIGH-ENERGY-PHYS",		"JHEP, Paper Version")
    define("j-J-HIGH-ENERGY-PHYS",		"Journal of High Energy Physics, Paper Archive")
    define("j-J-HIGH-ENERGY-PHYS",		"Pap. Arch. JHEP")
    define("j-J-HIGH-ENERGY-PHYS",		"Paper Archive of the JHEP")

    define("j-J-HIGH-ENERGY-PHYS-ONLINE",	"Journal of High Energy Physics (online)")
    define("j-J-HIGH-ENERGY-PHYS-ONLINE",	"J. High Energy Phys. (online)")
    define("j-J-HIGH-ENERGY-PHYS-ONLINE",	"JHEP (online)")

    define("j-J-HIST-ASTRON",			"Journal for the History of Astronomy")
    define("j-J-HIST-ASTRON",			"Journal for the History of Astronomy (JHA)")
    define("j-J-HIST-ASTRON",			"J. Hist. Astronom.")
    define("j-J-HIST-ASTRON",			"J. Hist. Astron.")

    define("j-J-HIST-BEHAV-SCI",		"Journal of the History of the Behavioral Sciences")
    define("j-J-HIST-BEHAV-SCI",		"J. Hist. Behav. Sci.")

    define("j-J-HIST-BIOL",			"Journal of the History of Biology")
    define("j-J-HIST-BIOL",			"J. Hist. Biol.")

    define("j-J-HIST-IDEAS",			"Journal of the History of Ideas")
    define("j-J-HIST-IDEAS",			"J. hist. ideas")

    define("j-J-HUM-HYPERTENS",			"Journal of Human Hypertension")
    define("j-J-HUM-HYPERTENS",			"J. Hum. Hypertens.")

    define("j-J-HUM-RESOUR",			"Journal of Human Resources")
    define("j-J-HUM-RESOUR",			"J. Hum. Resour.")

    define("j-J-HUMANIST-MATH",			"Journal of Humanistic Mathematics")
    define("j-J-HUMANIST-MATH",			"J. Humanist. Math.")

    define("j-J-HYDRAULICS-DIV",		"Journal of the Hydraulics Division")
    define("j-J-HYDRAULICS-DIV",		"J. Hydraul. Div.")
    define("j-J-HYDRAULICS-DIV",		"J. Hydraulic Div.")

    define("j-J-HYDROL",			"Journal of Hydrology")
    define("j-J-HYDROL",			"J. Hydrol")

    define("j-J-IEEE",				"J. of IEEE")
    define("j-J-IIEE-JAPAN",			"Journal of the Institute of Image Electronics Engineers of Japan")

    define("j-J-IND-MICROBIOL",			"Journal of industrial microbiology")
    define("j-J-IND-MICROBIOL",			"J. ind. microbiol.")

    define("j-J-INEQUAL-APPL",			"Journal of Inequalities and Applications")
    define("j-J-INEQUAL-APPL",			"J. Inequal. Appl.")

    define("j-J-INF-OPTIM-SCI",			"Journal of Information \\& Optimization Sciences")
    define("j-J-INF-OPTIM-SCI",			"Journal of Information and Optimization Sciences")
    define("j-J-INF-OPTIM-SCI",			"J. Inf. Optim. Sci.")

    define("j-J-INF-PROCESS",			"Journal of Information Processing")
    define("j-J-INF-PROCESS",			"J. inf. process.")
    define("j-J-INF-PROCESS",			"Journal of Information Processing = Joho Shori Gakkai")
    define("j-J-INF-PROCESS",			"Information Processing Society of Japan")

    define("j-J-INFO-ENG",			"Journal of Information and Engineering")

    define("j-J-INFO-ORG-SCI",			"Journal of Informational and Organizational Sciences")
    define("j-J-INFO-ORG-SCI",			"J. Info. Org. Sci.")

    define("j-J-INFO-PROC-CYBERNETICS-EIK",	"Journal of Information Processing and Cybernetics: EIK")
    define("j-J-INFO-PROC-CYBERNETICS-EIK",	"Journal of Information Processing and Cybernetics")

    define("j-J-INFO-PROC-CYBERNETICS-EIK",	"J. Information Processing and Cybernetics-EIK")

    define("j-J-INFO-PROC-SOC-JAPAN",		"Journal of Information Processing Society of Japan = Joho Shori")

    define("j-J-INFO-SCI-PRINCIPLES-PRACTICE",	"Journal of Information Science, Principles and Practice")
    define("j-J-INFO-SCI-PRINCIPLES-PRACTICE",	"J. Inf. Sci.")
    define("j-J-INFO-SCI-PRINCIPLES-PRACTICE",	"J. Info. Sci.")
    define("j-J-INFO-SCI-PRINCIPLES-PRACTICE",	"Journal of Information Science")

    define("j-J-INFO-SCI-ENG",			"Journal of information science and engineering")
    define("j-J-INFO-SCI-ENG",			"Journal of information science and engineering: JISE")
    define("j-J-INFO-SCI-ENG",			"J. Info. Sci. Eng.")
    define("j-J-INFO-SCI-ENG",			"JISE J. Inf. Sci. Eng.")

    define("j-J-INFO-SEC-APPL",			"Journal of Information Security and Applications (JISA)")
    define("j-J-INFO-SEC-APPL",			"Journal of Information Security and Applications")
    define("j-J-INFO-SEC-APPL",			"J. Info. Sec. Appl.")

    define("j-J-INFORMETRICS",			"Journal of Informetrics")
    define("j-J-INFORMETRICS",			"J. Informetrics")

    define("j-J-INST-ACTUARIES",		"Journal of the Institute of Actuaries")
    define("j-J-INST-ACTUARIES",		"J. Inst. Actuaries")

    define("j-J-INST-ELEC-INFO-COMM-ENG",	"Denshi Joho Tsushin Gakkai shi = Journal of the Institute of Electronics, Information and Communication Engineers. (JAPAN)")
    define("j-J-INST-ELEC-INFO-COMM-ENG",	"Journal of the Institute of Electronics, Information and Communication Engineers. (JAPAN)")

    define("j-J-INST-ELEC-TELECOMM-ENG",	"Journal of the Institution of Electronics and Telecommunication Engineers")
    define("j-J-INST-ELEC-TELECOMM-ENG",	"J. Inst. Electron. Telecommun. Eng")

    define("j-J-INST-ELECTR-ENG",		"Journal of the Institution of Electrical Engineers")
    define("j-J-INST-ELECTR-ENG",		"Journal of the Institution of Electrical Engineers (1949--1963)")
    define("j-J-INST-ELECTR-ENG",		"J. Inst. Electr. Eng.")
    define("j-J-INST-ELECTR-ENG",		"J. Inst. Electr. Eng. (1949--1963)")

    define("j-J-INST-MATH-APPL",		"Journal of the Institute of Mathematics and its Applications")
    define("j-J-INST-MATH-APPL",		"J. Inst. Math. Appl.")
    define("j-J-INST-MATH-APPL",		"J. Inst. Maths Applics")
    define("j-J-INST-MATH-APPL",		"J. Inst. Maths. Applics.")

    define("j-J-INST-PET",			"Journal of the Institute of Petroleum")
    define("j-J-INST-PET",			"J. Inst. Pet.")
    define("j-J-INST-PET",			"J. Inst. Petrol.")

    define("j-J-INT-ASSOC-MATH-GEOL",		"Journal of the {International Association for Mathematical Geology}")
    define("j-J-INT-ASSOC-MATH-GEOL",		"J. {Int. Assoc. Math. Geol.}")

    define("j-J-INT-ECON",			"Journal of International Economics")
    define("j-J-INT-ECON",			"J. Int. Econ.")

    define("j-J-INT-FINANC-MANAG-ACCOUNT",	"Journal of International Financial Management and Accounting")
    define("j-J-INT-FINANC-MANAG-ACCOUNT",	"Journal of International Financial Management \\& Accounting")
    define("j-J-INT-FINANC-MANAG-ACCOUNT",	"J. Int. Financ. Manag. Account.")

    define("j-J-INTEGER-SEQ",			"Journal of Integer Sequences")
    define("j-J-INTEGER-SEQ",			"J. Int. Seq.")
    define("j-J-INTEGER-SEQ",			"J. Integ. Seq.")
    define("j-J-INTEGER-SEQ",			"J. Integer Seq.")

    define("j-J-INTEGRAL-EQU-APPL",		"Journal of Integral Equations and Applications")
    define("j-J-INTEGRAL-EQU-APPL",		"J. integral equ. appl.")
    define("j-J-INTEGRAL-EQU-APPL",		"J. Integral Equations Appl.")
    define("j-J-INTEGRAL-EQU-APPL",		"J. of Integral Equations and Applications")

    define("j-J-INTELL-MATER-SYST-STRUCT",	"Journal of intelligent material systems and structures")
    define("j-J-INTELL-MATER-SYST-STRUCT",	"J. intell. mater. syst. struct.")
    define("j-J-INTELL-MATER-SYST-STRUCT",	"J. Intell. Material Systems and Structures")
    define("j-J-INTELL-MATER-SYST-STRUCT",	"J. Intelligent Mater. Syst. Struct.")

    define("j-J-INTERDISCIP-CYCLE-RES",		"Journal of interdisciplinary cycle research")
    define("j-J-INTERDISCIP-CYCLE-RES",		"J. interdiscip. cycle res.")

    define("j-J-INTERDISCIP-HIST",		"Journal of Interdisciplinary History")
    define("j-J-INTERDISCIP-HIST",		"J. Interdiscip. Hist.")

    define("j-J-INVERSE-ILL-POSED-PROBL",	"Journal of Inverse and Ill-Posed Problems")
    define("j-J-INVERSE-ILL-POSED-PROBL",	"J. Inverse Ill-Posed Probl.")

    define("j-J-INVESTMENT-MANAGE",		"Journal of Investment Management")
    define("j-J-INVESTMENT-MANAGE",		"J. Investment. Manage.")

    define("j-J-IRREPROD-RESULTS",		"Journal of Irreproducible Results")
    define("j-J-IRREPROD-RESULTS",		"J. Irreprod. Results")
    define("j-J-IRREPROD-RESULTS",		"J. of Irreproducible Results")

    define("j-J-JAPAN-SOC-COMPUT-STAT",		"Journal of Japanese Society of Computational Statistics")
    define("j-J-JAPAN-SOC-COMPUT-STAT",		"J. Japan. Soc. Comput. Stat.")

    define("j-J-JPN-INT-ECON",			"Journal of the {Japanese} and International Economies")
    define("j-J-JPN-INT-ECON",			"J. {Jpn}. Int. Econ.")

    define("j-J-KOREA-INFO-SCI-SOCIETY",	"Journal of the Korea Information Science Society = Chongbo Kwahakhoe nonmunji")
    define("j-J-KOREA-INFO-SCI-SOCIETY",	"Journal of the Korea Information Science Society")
    define("j-J-KOREA-INFO-SCI-SOCIETY",	"J. Korea Info. Sci. Soc. (Korea)")

    define("j-J-KOREAN-PHYS-SOC",		"Journal of the {Korean Physical Society}")
    define("j-J-KOREAN-PHYS-SOC",		"J. {Korean Phys. Soc.}")

    define("j-J-LAB-CLIN-MED",			"Journal of Laboratory and Clinical Medicine")
    define("j-J-LAB-CLIN-MED",			"J. Lab. Clin. Med.")

    define("j-J-LINUX-TECH",			"Journal of Linux Technology")
    define("j-J-LINUX-TECH",			"J. Linux Tech.")

    define("j-J-LOGIC-ALG-PROG",		"Journal of Logic and Algebraic Programming")
    define("j-J-LOGIC-ALG-PROG",		"J. Log. Algebr. Program.")
    define("j-J-LOGIC-ALG-PROG",		"J. Logic Alg. Prog.")

    define("j-J-LOGIC-LANGUAGE-INFO",		"Journal of Logic, Language, and Information")
    define("j-J-LOGIC-PROG",			"Journal of Logic Programming")

    define("j-J-LOND-MATH-SOC",			"Journal of the London Mathematical Society")
    define("j-J-LOND-MATH-SOC",			"J. Lond. Math. Soc.")
    define("j-J-LOND-MATH-SOC",			"J. London Math. Soc.")

    define("j-J-LOND-MATH-SOC-2",		"Journal of the London Mathematical Society. Second Series")
    define("j-J-LOND-MATH-SOC-2",		"J. London Math. Soc. (2)")

    define("j-J-MACH-LEARN-RES",		"Journal of Machine Learning Research (JMLR)")
    define("j-J-MACH-LEARN-RES",		"Journal of Machine Learning Research: JMLR")
    define("j-J-MACH-LEARN-RES",		"J. Mach. Learn. Res.")

    define("j-J-MAG-RES-A",			"Journal of Magnetic Resonance. Series A")

    define("j-J-MANUFACTURING-SYS",             "Journal of Manufacturing Systems")

    define("j-J-MAR-SYST",			"Journal of Marine Systems")
    define("j-J-MAR-SYST",			"J. Mar. Syst.")

    define("j-J-MATER",				"Journal of materials")
    define("j-J-MATER",				"J. mater.")

    define("j-J-MATER-RES",			"Journal of materials research")
    define("j-J-MATER-RES",			"J. mater. res.")

    define("j-J-MATER-SCI",			"Journal of materials science")
    define("j-J-MATER-SCI",			"J. mater. sci.")

    define("j-J-MATER-SCI-LETT",		"Journal of materials science letters")
    define("j-J-MATER-SCI-LETT",		"J. mater. sci. lett.")
    define("j-J-MATER-SCI-LETT",		"J. Mat. Sci. Lett.")

    define("j-J-MATH-ANAL-APPL",		"Journal of Mathematical Analysis and Applications")
    define("j-J-MATH-ANAL-APPL",		"J. Math. Anal. Appl.")
    define("j-J-MATH-ANAL-APPL",		"J. of Mathematical Analysis and Applications")
    define("j-J-MATH-ANAL-APPL",		"J. Math. Anal. Applic.")
    define("j-J-MATH-ANAL-APPL",		"J. Math. Anal. and Applic.")
    define("j-J-MATH-APPL-ANAL",		"J. Math. Appl. Anal.")

    define("j-J-MATH-ARTS",			"Journal of Mathematics and the Arts")
    define("j-J-MATH-ARTS",			"J. Math. Arts")

    define("j-J-MATH-BEHAV",			"Journal of Mathematical Behavior")
    define("j-J-MATH-BEHAV",			"J. Math. Behav.")
    define("j-J-MATH-BEHAV",			"J. Math. Behavior")

    define("j-J-MATH-BIOL",			"Journal of Mathematical Biology")
    define("j-J-MATH-BIOL",			"J. Math. Biol.")
    define("j-J-MATH-BIOL",			"J Math Biol (IYS)")
    define("j-J-MATH-BIOL",			"Jour. Math. Biol.")
    define("j-J-MATH-BIOL",			"J. of Math. Biology")
    define("j-J-MATH-BIOL",			"J. of Math. Biol.")

    define("j-J-MATH-CHEM",			"Journal of Mathematical Chemistry")
    define("j-J-MATH-CHEM",			"J. Math. Chem.")

    define("j-J-MATH-CRYPTOL",			"Journal of Mathematical Cryptology")
    define("j-J-MATH-CRYPTOL",			"J. Math. Cryptol.")

    define("j-J-MATH-IMAG-VIS",			"Journal of Mathematical Imaging and Vision: JMIV")
    define("j-J-MATH-IMAG-VIS",			"Journal of Mathematical Imaging and Vision")
    define("j-J-MATH-IMAG-VIS",			"J. Math. Imaging Vision")
    define("j-J-MATH-IMAG-VIS",			"J. Math. Imag. Vision")

    define("j-J-MATH-INEQUAL",			"Journal of Mathematical Inequalities")
    define("j-J-MATH-INEQUAL",			"J. Math. Inequal.")

    define("j-J-MATH-KYOTO-UNIV",		"Journal of mathematics of Kyoto University")
    define("j-J-MATH-KYOTO-UNIV",		"J. Math. Kyoto Univ.")
    define("j-J-MATH-KYOTO-UNIV",		"Jour. Math. Kyoto Univ.")

    define("j-J-MATH-MECH",			"Journal of Mathematics and Mechanics")
    define("j-J-MATH-MECH",			"J. Math. Mech.")

    define("j-J-MATH-PHYS",			"Journal of Mathematical Physics")
    define("j-J-MATH-PHYS",			"J. Mathematical Phys.")
    define("j-J-MATH-PHYS",			"J. Math. Phys.")

    # v1 Nov. 1921--v47 n4 1968.  Succeeded by j-STUD-APPL-MATH (Studies in Applied Mathematics)
    define("j-J-MATH-PHYS-MIT",			"Journal of Mathematics and Physics / Massachusetts Institute of Technology")
    define("j-J-MATH-PHYS-MIT",			"J. Math. Phys. Mass. Inst. Tech.")
    define("j-J-MATH-PHYS-MIT",			"J. Math. and Physics")
    define("j-J-MATH-PHYS-MIT",			"J. Math. and Phys.")
    define("j-J-MATH-PHYS-MIT",			"J. Math. \\& Phys.")

    define("j-J-MATH-PSYCHOL",			"Journal of Mathematical Psychology")
    define("j-J-MATH-PSYCHOL",			"J. Math. Psychol.")

    define("j-J-MATH-PURES-APPL",		"Journal de Math{\\'e}matiques Pures et Appliqu{\\'e}es")
    define("j-J-MATH-PURES-APPL",		"J. math. pures appl.")
    define("j-J-MATH-PURES-APPL",		"J. Math. Pures Appl. (9)")

    define("j-J-MATH-RES-APPL",			"Journal of Mathematical Research with Applications")
    define("j-J-MATH-RES-APPL",			"J. Math. Res. Appl.")

    define("j-J-MATH-SCI-ADV-APPL",		"Journal of Mathematical Sciences. Advances and Applications")
    define("j-J-MATH-SCI-ADV-APPL",		"J. Math. Sci. Adv. Appl.")

    define("j-J-MATH-SCI-NY-NY",		"Journal of mathematical sciences (New York, N.Y.)")
    define("j-J-MATH-SCI-NY-NY",		"Journal of mathematical sciences")
    define("j-J-MATH-SCI-NY-NY",		"J. math. sci. (N.Y. N.Y.)")

    define("j-J-MATH-SOC-JPN",			"Journal of the {Mathematical Society of Japan}")
    define("j-J-MATH-SOC-JPN",			"J. Math. Soc. {Jpn}.")

    define("j-J-MEC",				"Journal de m{\\'e}canique")
    define("j-J-MEC",				"Journal de mecanique")
    define("j-J-MEC",				"J. m{\\'e}c.")
    define("j-J-MEC",				"J. mec.")

    define("j-J-MECH-DESIGN",			"Journal of Mechanical Design")

    define("j-J-MECH-MATER-STRUCT",		"Journal of Mechanics of Materials and Structures")
    define("j-J-MECH-MATER-STRUCT",		"J. Mech. Mater. Struct.")

    define("j-J-MECH-PHYS-SOLIDS",		"Journal of the Mechanics and Physics of Solids")
    define("j-J-MECH-PHYS-SOLIDS",		"J. mech. phys. solids.")
    define("j-J-MECH-PHYS-SOLIDS",		"J. Mech. Phys. Solid")
    define("j-J-MECH-PHYS-SOLIDS",		"Journal of Phys. Mech. of Solids")
    define("j-J-MECH-PHYS-SOLIDS",		"Journal of Physics and Mechanics of Solids")

    define("j-J-MED-CHEM",			"Journal of medicinal chemistry")
    define("j-J-MED-CHEM",			"J. of med. chem.")

    define("j-J-MED-SYST",			"Journal of Medical Systems")
    define("j-J-MED-SYST",			"J. Med. Syst.")

    define("j-J-MEMBR-BIOL",			"Journal of Membrane Biology")
    define("j-J-MEMBR-BIOL",			"J. Membr. Bio.")
    define("j-J-MEMBR-BIOL",			"J. Memb. Biol.")
    define("j-J-MEMBR-BIOL",			"J. membrane Biol.")
    define("j-J-MEMBR-BIOL",			"J Membr Biol (J4E)")
    define("j-J-MEMBR-BIOL",			"J. Membr. Biol.")

    define("j-J-MICROELECTROMECHANICAL-SYSTEMS","Journal of microelectromechanical systems")
    define("j-J-MICROELECTROMECHANICAL-SYSTEMS","Journal of microelectromechanical systems: a joint IEEE/ASME publication on microstructures, microactuators, and microsystems")
    define("j-J-MICROELECTROMECHANICAL-SYSTEMS","J. Microelectromechanical Systems")

    define("j-J-MICROCOMPUT-APPL",		"Journal of Microcomputer Applications")
    define("j-J-MICROCOMPUT-APPL",		"J. microcomput. appl.")

    define("j-J-MIL-HIST",			"The Journal of Military History")
    define("j-J-MIL-HIST",			"Journal of Military History")
    define("j-J-MIL-HIST",			"J. Mil. Hist")

    # Journal Web site: http://tbf.coe.wayne.edu/jmasm/
    define("j-J-MOD-APPL-STAT-METH",		"Journal of Modern Applied Statistical Methods")
    define("j-J-MOD-APPL-STAT-METH",		"J. Mod. Appl. Stat. Meth.")

    define("j-J-MOD-ITAL-STUD",			"Journal of Modern Italian Studies")
    define("j-J-MOD-ITAL-STUD",			"J. Mod. Ital. Stud.")

    define("j-J-MOD-OPT",			"Journal of Modern Optics")
    define("j-J-MOD-OPT",			"J. Mod. Opt.")

    define("j-J-MOD-HIST",			"The Journal of Modern History")
    define("j-J-MOD-HIST",			"Journal of Modern History")
    define("j-J-MOD-HIST",			"J. Mod. Hist.")

    define("j-J-MOL-BIOL",			"Journal of Molecular Biology")
    define("j-J-MOL-BIOL",			"J. Mol. Biol.")
    define("j-J-MOL-BIOL",			"J. molec. Biol.")
    define("j-J-MOL-BIOL",			"J Mol Biol (J6V)")

    define("j-J-MOL-EVOL",			"Journal of molecular evolution")
    define("j-J-MOL-EVOL",			"J Mol Evol (J76)")

    define("j-J-MOL-MODEL",			"Journal of Molecular Modeling")
    define("j-J-MOL-MODEL",			"J. Mol. Model.")

    define("j-J-MOL-SPECTROSC",			"Journal of Molecular Spectroscopy")
    define("j-J-MOL-SPECTROSC",			"J. Mol. Spect.")

    define("j-J-MOL-STRUCT",			"Journal of Molecular Structure")
    define("j-J-MOL-STRUCT",			"J. mol. struct.")

    ## NB: This journal is peculiar: Theochem issues are superimposed
    ## irregularly on issues of the Journal of Molecular Structure,
    ## but with different volume and number values, sigh...  The
    ## journal cover page has the JMS volume/number in the upper left,
    ## and the Theochem volume/number in the upper right.  The top of
    ## the cover says Journal of Molecular Structure, and the bottom
    ## half says Theochem!  Because of the irregular appearance of
    ## Theochem issues, there is no simple correspondence between
    ## issue number of the two journals.
    define("j-J-MOL-STRUCT-THEOCHEM",		"Journal of Molecular Structure. Theochem")
    define("j-J-MOL-STRUCT-THEOCHEM",		"J. mol. struct., Theochem.")
    define("j-J-MOL-STRUCT-THEOCHEM",		"THEOCHEM")

    define("j-J-MULTIVAR-ANAL",			"Journal of Multivariate Analysis")
    define("j-J-MULTIVAR-ANAL",			"J. multivar. anal.")
    define("j-J-MULTIVAR-ANAL",			"J. Multivariate Analysis")

    define("j-J-MUSCLE-RES-CELL-MOTIL",		"J Muscle Res Cell Motil (HSN)")
    define("j-J-MUSCLE-RES-CELL-MOTIL",		"J. Muscle Res. Cell Motil")
    define("j-J-MUSCLE-RES-CELL-MOTIL",		"J. Muscle Res. Cell Motil.")

    define("j-J-NANOMATER",			"Journal of Nanomaterials")
    define("j-J-NANOMATER",			"J. Nanomater.")

    define("j-J-NANOSCI-NANOTECHNOL",		"Journal of Nanoscience and Nanotechnology")
    define("j-J-NANOSCI-NANOTECHNOL",		"J. Nanosci. Nanotechnol.")

    define("j-J-NAT-CANCER-INST",		"Journal of the National Cancer Institute: JNCI")
    define("j-J-NAT-CANCER-INST",		"Journal of the National Cancer Institute")
    define("j-J-NAT-CANCER-INST",		"J Natl Cancer Inst (J9J)")

    define("j-J-NAT-CANCER-INST-1978-1987",	"Journal of the National Cancer Institute (1978--1987)")
    define("j-J-NAT-CANCER-INST-1978-1987",	"J Natl Cancer Inst (1978--1987)")

    define("j-J-NAT-CANCER-INST-BETHESDA",	"Journal of the National Cancer Institute (Bethesda)")

    define("j-J-NAT-CANCER-INST-MONOGR",	"Journal of the National Cancer Institute. Monographs")
    define("j-J-NAT-CANCER-INST-MONOGR",	"J. Natl. Cancer Inst. Monogr.")

    define("j-J-NETW-COMPUT-APPL",		"Journal of Network and Computer Applications")
    define("j-J-NETW-COMPUT-APPL",		"J. Network Comp. Appl.")

    define("j-J-NUCL-ENERGY-1954",		"Journal of Nuclear Energy (1954)")
    define("j-J-NUCL-ENERGY-1954",		"Journal of Nuclear Energy")
    define("j-J-NUCL-ENERGY-1954",		"J. Nucl. Energy")
    define("j-J-NUCL-ENERGY-1954",		"J. Nucl. Energy (1954)")

    define("j-J-NUCL-MATER",			"Journal of Nuclear Materials")
    define("j-J-NUCL-MATER",			"J. Nucl. Mater.")

    define("j-J-NEURAL-TRANSM-SUPPL",		"Journal of neural transmission. Supplementum")
    define("j-J-NEURAL-TRANSM-SUPPL",		"J. Neural. Transm., Suppl.")
    define("j-J-NEURAL-TRANSM-SUPPL",		"J Neural Transm Suppl.")

    define("j-J-NEUROBIOL",			"Journal of neurobiology")
    define("j-J-NEUROBIOL",			"J. Neurobiol.")

    define("j-J-NEUROCHEM",			"Journal of neurochemistry")
    define("j-J-NEUROCHEM",			"J. Neurochem.")

    define("j-J-NEUROCYTOL",			"Journal of Neurocytology")
    define("j-J-NEUROCYTOL",			"J. neurocytol.")

    define("j-J-NEUROPHYSIOL",			"Journal of Neurophysiology")
    define("j-J-NEUROPHYSIOL",			"J. Neurophysiol.")
    define("j-J-NEUROPHYSIOL",			"J. Neurophysiology")

    define("j-J-NEUROSCI",			"Journal of Neuroscience")
    define("j-J-NEUROSCI",			"Journal of Neuroscience: the official journal of the Society for Neuroscience")
    define("j-J-NEUROSCI",			"J. Neurosci.")

    define("j-J-NEUROSCI-METHODS",		"Journal of Neuroscience Methods")
    define("j-J-NEUROSCI-METHODS",		"J. Neurosci. Methods")

    define("j-J-NON-CRYST-SOLIDS",		"Journal of Non-Crystalline Solids")
    define("j-J-NON-CRYST-SOLIDS",		"J. Non-Cryst. Solids")

    define("j-J-NON-NEWTONIAN-FLUID-MECH",	"Journal of non-Newtonian fluid mechanics")
    define("j-J-NON-NEWTONIAN-FLUID-MECH",	"J. non-Newton. fluid mech.")

    define("j-J-NONMETALS",			"Journal of nonmetals")
    define("j-J-NONMETALS",			"J. nonmetals")
    define("j-J-NONMETALS",			"Journal of non-metals")

    define("j-J-NONLINEAR-CONVEX-ANAL",		"Journal of Nonlinear and Convex Analysis")
    define("j-J-NONLINEAR-CONVEX-ANAL",		"Journal of Nonlinear and Convex Analysis. An International Journal")
    define("j-J-NONLINEAR-CONVEX-ANAL",		"J. Nonlinear Convex Anal.")

    define("j-J-NONLINEAR-SCI",			"Journal of nonlinear science")
    define("j-J-NONLINEAR-SCI",			"J. nonlinear sci.")

    define("j-J-NUMBER-THEORY",			"Journal of Number Theory")
    define("j-J-NUMBER-THEORY",			"J. Number Theory")

    define("j-J-NUMER-METHODS-COMPUT-APPL",	"Journal on Numerical Methods and Computer Applications")
    define("j-J-NUMER-METHODS-COMPUT-APPL",	"J. Numer. Methods Comput. Appl.")

    define("j-J-NUTR",				"Journal of nutrition")
    define("j-J-NUTR",				"J Nutr.")

    define("j-J-OCCUP-MED",			"JOM. Journal of occupational medicine")
    define("j-J-OCCUP-MED",			"J Occup Med (JFR)")

    define("j-J-OOP",				"Journal of Object Oriented Programming")

    define("j-J-OPEN-RES-SOFT",			"Journal of Open Research Software")
    define("j-J-OPEN-RES-SOFT",			"Journal of Open Research Software: JORS")
    define("j-J-OPEN-RES-SOFT",			"J. Open Res. Soft.: JORS")
    define("j-J-OPEN-RES-SOFT",			"J. Open Res. Softw.")
    define("j-J-OPEN-RES-SOFT",			"J. Open Res. Softw.: JORS")
    define("j-J-OPEN-RES-SOFT",			"JORS")
    define("j-J-OPEN-RES-SOFT",			"J. Open Res. Soft.")

    define("j-J-OPER-MANAGE",			"Journal of Operations Management")
    define("j-J-OPER-MANAGE",			"J. Op. Manage.")
    define("j-J-OPER-MANAGE",			"J. Oper. Manage.")

    define("j-J-OPER-RES-SOC",			"OR: the journal of the Operational Research Society")
    define("j-J-OPER-RES-SOC",			"Journal of the Operational Research Society")
    define("j-J-OPER-RES-SOC",			"J. Oper. Res. Soc.")
    define("j-J-OPER-RES-SOC",			"J. Opl. Res. Soc.")

    define("j-J-OPER-RESEARCH",			"Journal of Operations Research")

    define("j-J-OPER-RES-SOC-JPN",		"Journal of the Operations Research Society of Japan")
    define("j-J-OPER-RES-SOC-JPN",		"J. Oper. Res. Soc. Jpn.")
    define("j-J-OPER-RES-SOC-JPN",		"J. Oper. Res. Soc. Japan")

    define("j-J-OPT-A",				"Journal of Optics A: Pure and Applied Optics")
    define("j-J-OPT-A",				"Journal of Optics A")
    define("j-J-OPT-A",				"J. Opt. A")

    define("j-J-OPT-B",				"Journal of Optics B: Quantum and Semiclassical Optics")
    define("j-J-OPT-B",				"J. Opt. B: Quantum Semiclassical Opt.")
    define("j-J-OPT-B",				"J. Opt. B")

    define("j-J-OPT-SOC-AM-1917",		"Journal of the Optical Society of America (1917)")
    define("j-J-OPT-SOC-AM-1917",		"J. Opt. Soc. Am. (1917)")

    define("j-J-OPT-SOC-AM",			"Journal of the Optical Society of America")
    define("j-J-OPT-SOC-AM",			"J. Opt. Soc. Am. (1930)")
    define("j-J-OPT-SOC-AM",			"J. Opt. Soc. Am.")

    define("j-J-OPT-SOC-AM-A",			"Journal of the Optical Society of America. A, Optics, image science, and vision")
    define("j-J-OPT-SOC-AM-A",			"Journal of the Optical Society of America. A")
    define("j-J-OPT-SOC-AM-A",			"J. Opt. Soc. Amer. A")
    define("j-J-OPT-SOC-AM-A",			"Journal of the Optical Society of America. A, Optics and image science")

    define("j-J-OPT-SOC-AM-B",			"Journal of the Optical Society of America. B, Optical physics")
    define("j-J-OPT-SOC-AM-B",			"Journal of the Optical Society of America. B")
    define("j-J-OPT-SOC-AM-B",			"J. Opt. Soc. Am., B, Opt. phys.")

    define("j-J-OPT-SOC-AM-REV-SCI-INSTRUM",	"Journal of the Optical Society of America and Review of Scientific Instruments")
    define("j-J-OPT-SOC-AM-REV-SCI-INSTRUM",	"Journal of the Optical Society of America Review of Scientific Instruments")
    define("j-J-OPT-SOC-AM-REV-SCI-INSTRUM",	"J. Opt. Soc. Amer. and Rev. Sci. Instrum.")
    define("j-J-OPT-SOC-AM-REV-SCI-INSTRUM",	"J. Opt. Soc. Am. and Rev. Sci. Instrum.")
    define("j-J-OPT-SOC-AM-REV-SCI-INSTRUM",	"J. Opt. Soc. Amer. Rev. Sci. Instrum.")
    define("j-J-OPT-SOC-AM-REV-SCI-INSTRUM",	"J. Opt. Soc. Am. Rev. Sci. Instrum.")

    define("j-J-OPT-THEORY-APPL",		"Journal of Optimization Theory and Applications")
    define("j-J-OPT-THEORY-APPL",		"J. optim. theory appl.")
    define("j-J-OPT-THEORY-APPL",		"J. Opt. Th. Appl.")
    define("j-J-OPT-THEORY-APPL",		"J. Optimization Theory Appl.")

    define("j-J-ORG-CHEM",			"Journal of Organic Chemistry")
    define("j-J-ORG-CHEM",			"J. org. chem.")

    define("j-J-PAR-DIST-COMP",			"Journal of Parallel and Distributed Computing")

    define("j-J-PARAPSYCHOL",			"Journal of Parapsychology")
    define("j-J-PARAPSYCHOL",			"J. Parapsych.")
    define("j-J-PARAPSYCHOL",			"J. Parapsychol.")

    define("j-J-PAS-ADA",			"Journal of Pascal and Ada")
    define("j-J-PAS-ADA-MOD",			"Journal of Pascal, Ada and Modula-2")

    define("j-J-PATHOL",			"Journal of Pathology")
    define("j-J-PATHOL",			"J. Pathol.")

    define("j-J-PEACE-RES",			"Journal of Peace Research")
    define("j-J-PEACE-RES",			"J. Peace Res.")

    define("j-J-PERIODONTAL-RES",		"Journal of Periodontal Research")
    define("j-J-PERIODONTAL-RES",		"J. Periodont. Res.")
    define("j-J-PERIODONTAL-RES",		"J. Periodontal Res.")

    define("j-J-PET-TECHNOL",			"Journal of Petroleum Technology")
    define("j-J-PET-TECHNOL",			"J. Pet. Technol.")
    define("j-J-PET-TECHNOL",			"J. Pet. Tech.")

    define("j-J-PHARMACOL-EXP-THER",		"Journal of pharmacology and experimental therapeutics")
    define("j-J-PHARMACOL-EXP-THER",		"J Pharmacol Exp Ther (JP3)")
    define("j-J-PHARMACOL-EXP-THER",		"J. Pharmacol. Exptl. Thera.")

    define("j-J-PHILOS",			"The Journal of Philosophy")
    define("j-J-PHILOS",			"Journal of Philosophy")
    define("j-J-PHILOS",			"J. Philos.")

    define("j-J-PHILOS-LOGIC",			"Journal of Philosophical Logic")
    define("j-J-PHILOS-LOGIC",			"J. Philosophical Logic")
    define("j-J-PHILOS-LOGIC",			"J. Phil. Logic")
    define("j-J-PHILOS-LOGIC",			"J. Philos. Logic")

    define("j-J-PHON",				"Journal of Phonetics")
    define("j-J-PHON",				"J. Phon.")
    define("j-J-PHON",				"J. of Phonetics")

    ## Continuation of Journal of Physics A: Mathematical, Nuclear and General
    ## Published from volume 8 number 1 January 1975 to volume 39 number 50 December 2006
    define("j-J-PHYS-A",			"Journal of Physics A (Mathematical and General)")
    define("j-J-PHYS-A",			"Journal of Physics A: Mathematical and general")
    define("j-J-PHYS-A",			"J. Phys. A")
    define("j-J-PHYS-A",			"J. Phys. A: Math. Gen.")

    ## Continuation of Journal of Physics A: Mathematical and General
    ## New name from volume 40 number 1 January 2007
    define("j-J-PHYS-A-MATH-THEOR",		"Journal of Physics A: Mathematical and Theoretical")
    define("j-J-PHYS-A-MATH-THEOR",		"J. Phys. A: Math. Theor.")

    define("j-J-PHYS-B",			"Journal of Physics B: Atomic and Molecular Physics")
    define("j-J-PHYS-B",			"J. Phys. B: Atom. Molec. Phys.")
    define("j-J-PHYS-B",			"Journal of Physics. B, Atomic, molecular, and optical physics: an Institute of Physics journal")

    define("j-J-PHYS-B-AT-MOL-OPT-PHYS",	"Journal of Physics B: Atomic, Molecular and Optical Physics")
    define("j-J-PHYS-B-AT-MOL-OPT-PHYS",	"J. Phys. B: At., Mol. Opt. Phys.")

    define("j-J-PHYS-C",			"Journal of Physics C: Solid state physics")
    define("j-J-PHYS-C",			"J. Phys. C: Solid state phys.")
    define("j-J-PHYS-C",			"J. Phys. C")

    define("j-J-PHYS-CHEM",			"Journal of Physical Chemistry")
    define("j-J-PHYS-CHEM",			"J. Phys. Chem.")

    define("j-J-PHYS-CHEM-A",			"Journal of Physical Chemistry A")
    define("j-J-PHYS-CHEM-A",			"The Journal of Physical Chemistry A")
    define("j-J-PHYS-CHEM-A",			"J. Phys. Chem. A")

    define("j-J-PHYS-CHEM-B",			"Journal of Physical Chemistry. B. Condensed matter, materials, surfaces, interfaces \\& biophysical")
    define("j-J-PHYS-CHEM-B",			"Journal of Physical Chemistry. B")
    define("j-J-PHYS-CHEM-B",			"J. Phys. Chem. B")

    define("j-J-PHYS-CHEM-SOLIDS",		"The Journal of Physics and Chemistry of Solids")
    define("j-J-PHYS-CHEM-SOLIDS",		"Journal of Physics and Chemistry of Solids")
    define("j-J-PHYS-CHEM-SOLIDS",		"J. Phys. Chem. Solids")

    define("j-J-PHYS-COLLOQ",			"Journal de Physique, Colloque")
    define("j-J-PHYS-COLLOQ",			"Journal de Physique (Paris), Colloque")
    define("j-J-PHYS-COLLOQ",			"J. Phys. Colloques")
    define("j-J-PHYS-COLLOQ",			"J. Phys., Colloq.")

    define("j-J-PHYS-CONDENS-MATTER",		"Journal of Physics: Condensed Matter")
    define("j-J-PHYS-CONDENS-MATTER",		"Journal of physics. Condensed matter : an Institute of Physics journal")
    define("j-J-PHYS-CONDENS-MATTER",		"J. phys., Condens. matter")

    define("j-J-PHYS-CONF-SER",			"Journal of Physics: Conference Series")
    define("j-J-PHYS-CONF-SER",			"J. Phys.: Conf. Ser.")

    define("j-J-PHYS-D",			"Journal of Physics D: Applied Physics")
    define("j-J-PHYS-D",			"J. Phys. D.")
    define("j-J-PHYS-D",			"J. Phys. D: Appl. Phys.")

    define("j-J-PHYS-E-J-SCIENT-INSTRUM",	"Journal of Physics. E: Journal of Scientific Instruments")
    define("j-J-PHYS-E-J-SCIENT-INSTRUM",	"J. phys., E, J. scient. instrum.")

    define("j-J-PHYS-E",			"Journal of Physics. E: Scientific instruments")
    define("j-J-PHYS-E",			"J. Phys. E")
    define("j-J-PHYS-E",			"J. phys., E, scient. instrum.")

    define("j-J-PHYS-F",			"Journal of Physics. F, Metal physics")
    define("j-J-PHYS-F",			"J. phys. F. Met. phys.")

    define("j-J-PHYS-IV-COLLOQUE",		"Journal de physique. IV, Colloque")
    define("j-J-PHYS-IV-COLLOQUE",		"Journal de Physique IV [Colloque]")

    define("j-J-PHYS-LETT",			"Journal de Physique, Lettres")
    define("j-J-PHYS-LETT",			"J. Physique Lett.")
    define("j-J-PHYS-LETT",			"J. Phys., Lett.")

    define("j-J-PHYS-RADIUM",			"Journal de Physique et le Radium")
    define("j-J-PHYS-RADIUM",			"J. Phys. Radium")

    define("j-J-PHYS-SOC-JAP",			"Journal of the Physical Society of Japan")
    define("j-J-PHYS-SOC-JAP",			"J. Phys. Soc. Japan")

    define("j-J-PHYS-THEOR-APPL",		"Journal de Physique Th{\\'e}orique et Appliqu{\\'e}e")
    define("j-J-PHYS-THEOR-APPL",		"J. Phys. Theor. Appl.")

    define("j-J-PHYSIOL",			"Journal of Physiology")
    define("j-J-PHYSIOL",			"J. Physiol.")
    define("j-J-PHYSIOL",			"J. Physiol., Lond.")
    define("j-J-PHYSIOL",			"J. Physiol. (London)")

    define("j-J-PHYSIOLOGIE",			"Journal de physiologie")

    define("j-J-PHYSIQUE",			"Journal de physique (Paris)")
    define("j-J-PHYSIQUE",			"Journal de physique")
    define("j-J-PHYSIQUE",			"J. phys. (Paris)")
    define("j-J-PHYSIQUE",			"J. Physique")
    define("j-J-PHYSIQUE",			"Journal Physique")

    define("j-J-PLANKTON-RES",			"Journal of Plankton Research")
    define("j-J-PLANKTON-RES",			"J. Plankton Res.")

    define("j-J-PLASMA-PHYS",			"Journal of Plasma Physics")
    define("j-J-PLASMA-PHYS",			"J. Plasma Phys.")

    define("j-J-POLITICS",			"The Journal of Politics")
    define("j-J-POLITICS",			"Journal of Politics")
    define("j-J-POLITICS",			"J. Politics")

    ## j-J-POLYM-SCI: v1 n1 Jan. 1946-v62 n174 Dec. 1962, then divided into parts A, B, and C
    define("j-J-POLYM-SCI",			"Journal of Polymer Science")
    define("j-J-POLYM-SCI",			"J. Polymer Sci.")
    define("j-J-POLYM-SCI",			"J. Polym. Sci.")

    define("j-J-POLYM-SCI-POLYM-LETT-ED",	"Journal of Polymer Science, Polymer Letters Edition")
    define("j-J-POLYM-SCI-POLYM-LETT-ED",	"J. Polym. Sci., Polym. Lett. Ed.")

    define("j-J-POLYM-SCI-C-POLYM-LETT",	"Journal of Polymer Science Part C: Polymer Letters")
    define("j-J-POLYM-SCI-C-POLYM-LETT",	"J. Polym. Sci., Part C: Polym. Lett.")

    define("j-J-POP-CULT",			"The Journal of Popular Culture")
    define("j-J-POP-CULT",			"Journal of Popular Culture")
    define("j-J-POP-CULT",			"J. Pop. Cult.")

    define("j-J-PROD-BRAND-MANAG",		"Journal of Product \\& Brand Management")
    define("j-J-PROD-BRAND-MANAG",		"The Journal of Product \\& Brand Management")
    define("j-J-PROD-BRAND-MANAG",		"J. Prod. Brand Manag.")

    define("j-J-PROF-ISSUES-ENG",		"Journal of Professional Issues in Engineering")
    define("j-J-PROF-ISSUES-ENG",		"J. Prof. Issues Eng.")

    define("j-J-PROF-ISSUES-ENG-EDUC-PRACT",	"Journal of Professional Issues in Engineering Education and Practice")
    define("j-J-PROF-ISSUES-ENG-EDUC-PRACT",	"J. Prof. Issues Eng. Educ. Pract.")

    define("j-J-PROGRAM-LANG",			"Journal of Programming Languages")
    define("j-J-PROGRAM-LANG",			"J. program. lang.")

    define("j-J-PROTEIN-CHEM",			"J Protein Chem (AEJ)")

    define("j-J-PSYCHOL",			"Journal of Psychology")
    define("j-J-PSYCHOL",			"J. Psychol.")

    define("j-J-QUALITY-TECH",			"Journal of Quality Technology")

    define("j-J-QUANT-CRIMINOL",		"Journal of Quantitative Criminology")
    define("j-J-QUANT-CRIMINOL",		"J. Quant. Criminol.")

    define("j-J-QUANT-LINGUISTICS",		"Journal of Quantitative Linguistics")
    define("j-J-QUANT-LINGUISTICS",		"J. Quant. Linguist.")

    define("j-J-QUANT-SPECTROSC-RADIAT-TRANSFER","Journal of Quantitative Spectroscopy and Radiative Transfer")
    define("j-J-QUANT-SPECTROSC-RADIAT-TRANSFER","J. quant. spectrosc. radiat. transfer")

    define("j-J-R-AERONAUT-SOC",		"Journal of the Royal Aeronautical Society")
    define("j-J-R-AERONAUT-SOC",		"Journal of Royal Aeronautical Society")
    define("j-J-R-AERONAUT-SOC",		"J. R. Aeronaut. Soc.")

    define("j-J-R-ASTRON-SOC-CAN",		"Journal of the Royal Astronomical Society of Canada")
    define("j-J-R-ASTRON-SOC-CAN",		"J. R. Astron. Soc. Can.")

    define("j-J-R-COLL-PHYSICANS-LOND",		"Journal of the Royal College of Physicians of London")
    define("j-J-R-COLL-PHYSICANS-LOND",		"J. R. Coll. Physicans Lond.")
    define("j-J-R-COLL-PHYSICANS-LOND",		"J. Roy. Coll. Phys. (Lond)")
    define("j-J-R-COLL-PHYSICANS-LOND",		"J. Roy. Coll. Phys. Lond.")

    define("j-J-R-SOC-ARTS",			"Journal of the Royal Society of Arts")
    define("j-J-R-SOC-ARTS",			"Roy. Soc. Arts, Journ.")
    define("j-J-R-SOC-ARTS",			"J. R. Soc. Arts")

    define("j-J-R-STAT-SOC",			"Journal of the Royal Statistical Society")
    define("j-J-R-STAT-SOC",			"J. Roy. Stat. Soc.")
    define("j-J-R-STAT-SOC",			"J. R. Stat. Soc.")

    define("j-J-R-STAT-SOC-SER-A-GENERAL",	"Journal of the Royal Statistical Society. Series A (General)")
    define("j-J-R-STAT-SOC-SER-A-GENERAL",	"J. R. Stat. Soc. Ser. A. General")
    define("j-J-R-STAT-SOC-SER-A-GENERAL",	"J. Roy. Statist. Soc. Ser. A")
    define("j-J-R-STAT-SOC-SER-A-GENERAL",	"J. Roy. Stat. Soc. A")
    define("j-J-R-STAT-SOC-SER-A-GENERAL",	"J. Roy. Statist. Soc. A")

    define("j-J-R-STAT-SOC-SER-A-STAT-SOC",	"Journal of the Royal Statistical Society. Series A (Statistics in Society)")
    define("j-J-R-STAT-SOC-SER-A-STAT-SOC",	"J. R. Stat. Soc. Ser. A. Stat. Soc.")

    define("j-J-R-STAT-SOC-SER-B-METHODOL",	"Journal of the Royal Statistical Society. Series B (Methodological)")
    define("j-J-R-STAT-SOC-SER-B-METHODOL",	"Journal of the Royal Statistical Society Series B")
    define("j-J-R-STAT-SOC-SER-B-METHODOL",	"Journal of the Royal Statistical Society B")
    define("j-J-R-STAT-SOC-SER-B-METHODOL",	"J. R. Stat. Soc. Ser. B. Methodol")
    define("j-J-R-STAT-SOC-SER-B-METHODOL",	"J. R. Stat. Soc. B")
    define("j-J-R-STAT-SOC-SER-B-METHODOL",	"J. Roy. Statist. Soc. B")
    define("j-J-R-STAT-SOC-SER-B-METHODOL",	"J. R. Statist. Soc. B")
    define("j-J-R-STAT-SOC-SER-B-METHODOL",	"J. R. Stat. Soc., Ser. B")
    define("j-J-R-STAT-SOC-SER-B-METHODOL",	"J. Roy. Statist. Soc. Ser. B")
    define("j-J-R-STAT-SOC-SER-B-METHODOL",	"J. Roy. Stat. Soc. B")

    ## define("j-J-R-STAT-SOC-SER-C-APPL-STAT",	"Journal of the Royal Statistical Society. Series C (Applied Statistics)")
    ## define("j-J-R-STAT-SOC-SER-C-APPL-STAT",	"J. R. Stat. Soc. Ser. C. Appl. Stat.")
    ## define("j-J-R-STAT-SOC-SER-C-APPL-STAT",	"J. Roy. Statist. Soc. Ser. C")

    define("j-J-R-STAT-SOC-SER-D-STATISTICIAN",	"Journal of the Royal Statistical Society. Series D (The Statistician)")
    define("j-J-R-STAT-SOC-SER-D-STATISTICIAN",	"Journal of the Royal Statistical Society. Series D (Statistician)")
    define("j-J-R-STAT-SOC-SER-D-STATISTICIAN",	"J. R. Stat. Soc. Ser. D. Statistician")

    define("j-J-RADIAT-RES",			"J Radiat Res (Tokyo) (JVO)")

    define("j-J-RADIOANAL-NUCL-CHEM",		"Journal of Radioanalytical and Nuclear Chemistry")
    define("j-J-RADIOANAL-NUCL-CHEM",		"J. Radioanal. Nucl. Chem.")

    define("j-J-REC-MATH",			"Journal of Recreational Mathematics")

    define("j-J-REG-SCI",			"Journal of Regional Science")
    define("j-J-REG-SCI",			"J. Reg. Sci.")

    define("j-J-REINE-ANGEW-MATH",		"{Journal f{\\\"u}r die reine und angewandte Mathematik}")
    define("j-J-REINE-ANGEW-MATH",		"Journal f{\\\"u}r die reine und angewandte Mathematik")
    define("j-J-REINE-ANGEW-MATH",		"Journal fuer die reine und angewandte Mathematik")
    define("j-J-REINE-ANGEW-MATH",		"J. Reine Angew. Math.")
    define("j-J-REINE-ANGEW-MATH",		"J. f{\\\"u}r die Reine u. Angewandte Math.")

    define("j-J-REINF-PLAST-COMPOS",		"Journal of Reinforced Plastics and Composites")
    define("j-J-REINF-PLAST-COMPOS",		"J. Reinf. Plast. Compos.")

    define("j-J-RELIG-HEALTH",			"Journal of Religion and Health")
    define("j-J-RELIG-HEALTH",			"J. Relig. Health")

    define("j-J-RES-COMMUN-STUD",		"Journal of Research Communication Studies")
    define("j-J-RES-COMMUN-STUD",		"J. Res. Commun. Stud.")

    define("j-J-RES-COMP-EDU",			"Journal of Research on Computing in Education")

    define("j-J-RES-NATL-BUR-STAND-1934",	"Journal of Research of the National Bureau of Standards (1934)")
    define("j-J-RES-NATL-BUR-STAND-1934",	"Journal of Research of the National Bureau of Standards")
    define("j-J-RES-NATL-BUR-STAND-1934",	"J. res. Natl. Bur. Stand. (1934)")
    define("j-J-RES-NATL-BUR-STAND-1934",	"J. Res. Nat. Bur. Standards")
    define("j-J-RES-NATL-BUR-STAND-1934",	"J. Res. Nat. Bur. Stand.")
    define("j-J-RES-NATL-BUR-STAND-1934",	"J. Research Nat. Bur. Standards")

    define("j-J-RES-NATL-BUR-STAND-1977",	"Journal of Research of the National Bureau of Standards (1977)")
    define("j-J-RES-NATL-BUR-STAND-1977",	"J. res. Natl. Bur. Stand. (1977)")
    define("j-J-RES-NATL-BUR-STAND-1977",	"J. Res. Nat. Bur. Standards (1977)")

    define("j-J-RES-NATL-BUR-STAND-A",		"Journal of Research of the National Bureau of Standards, Section A: Physics and Chemistry")
    define("j-J-RES-NATL-BUR-STAND-A",		"Journal of Research of the National Bureau of Standards, Section A")
    define("j-J-RES-NATL-BUR-STAND-A",		"Journal of Research of the National Bureau of Standards, A")
    define("j-J-RES-NATL-BUR-STAND-A",		"J. Res. Natl. Bur. Stand., Sect. A")

    define("j-J-RES-NATL-BUR-STAND-B",		"Journal of Research of the National Bureau of Standards. Section B, Mathematics and Mathematical Physics")
    define("j-J-RES-NATL-BUR-STAND-B",		"J. Res. Nat. Bur. Standards Sect. B")
    define("j-J-RES-NATL-BUR-STAND-B",		"J. Res. National Bureau Standards--B")
    define("j-J-RES-NATL-BUR-STAND-B",		"J. Res. Nat. Bur. Standards B")

    define("j-J-RES-NATL-BUR-STAND-C",		"Journal of Research of the National Bureau of Standards. Section C, Engineering and Instrumentation")
    define("j-J-RES-NATL-BUR-STAND-C",		"J. Res. Nat. Bur. Standards Sect. C")

    define("j-J-RES-NATL-BUR-STAND-D",		"Journal of Research of the National Bureau of Standards. Section D, Radio Science")
    define("j-J-RES-NATL-BUR-STAND-D",		"J. Res. Nat. Bur. Standards Sect. D")

    define("j-J-RES-NATL-INST-STAND-TECHNOL",	"Journal of research of the National Institute of Standards and Technology")
    define("j-J-RES-NATL-INST-STAND-TECHNOL",	"J. res. Natl. Inst. Stand. Technol.")

    define("j-J-RES-SCI-TEACH",			"Journal of Research in Science Teaching")
    define("j-J-RES-SCI-TEACH",			"J. Res. Sci. Teach.")

    define("j-J-RISK-UNCERT",			"Journal of Risk and Uncertainty")
    define("j-J-RISK-UNCERT",			"J. Risk Uncert.")

    define("j-J-ROBOTIC-SYS",			"Journal of Robotic Systems")

    define("j-J-SCH-PUBL",			"Journal of Scholarly Publishing")
    define("j-J-SCH-PUBL",			"J. sch. publ.")

    define("j-SCI-CULT",			"Science as Culture")
    define("j-SCI-CULT",			"Sci. Cult.")

    ## The Wiley journal j-SCI-EDUC goes back before v13n4 May 1929
    define("j-SCI-EDUC",			"Science Education")
    define("j-SCI-EDUC",			"Sci. Edu.")
    define("j-SCI-EDUC",			"Sci. Educ.")

    ## The more recent Kluwer and then Springer journal began in 1992
    define("j-SCI-EDUC-SPRINGER",		"Science \\& Education (Springer)")
    define("j-SCI-EDUC-SPRINGER",		"Science \\& Education")
    define("j-SCI-EDUC-SPRINGER",		"Science \\& Education (Dordrecht)")
    define("j-SCI-EDUC-SPRINGER",		"Science & Education")
    define("j-SCI-EDUC-SPRINGER",		"Science & Education (Dordrecht)")
    define("j-SCI-EDUC-SPRINGER",		"Sci. \\& Edu.")
    define("j-SCI-EDUC-SPRINGER",		"Sci. \\& Educ.")
    define("j-SCI-EDUC-SPRINGER",		"Sci. & Edu.")
    define("j-SCI-EDUC-SPRINGER",		"Sci. & Educ.")

    define("j-J-SCI-COMPUT",			"Journal of Scientific Computing")
    define("j-J-SCI-COMPUT",			"J. Sci. Computing")
    define("j-J-SCI-COMPUT",			"J. Sci. Comp.")
    define("j-J-SCI-COMPUT",			"J. Sci. Comput.")

    define("j-J-SCI-EDUC-TECHNOL",		"Journal of Science Education and Technology")
    define("j-J-SCI-EDUC-TECHNOL",		"J. Sci. Educ. Technol.")

    define("j-J-SCI-IND-RES",			"Journal of Scientific and Industrial Research")

    define("j-J-SCIENT-INSTR",			"Journal of Scientific Instruments")
    define("j-J-SCIENT-INSTR",			"J. scient. Instrum.")

    define("j-J-SEISMIC-EXPLORATION",		"Journal of Seismic Exploration")

    define("j-J-SIAM",				"Journal of the Society for Industrial and Applied Mathematics")
    define("j-J-SIAM",				"J. Soc. Ind. Appl. Math.")
    define("j-J-SIAM",				"J. SIAM")
    define("j-J-SIAM",				"J. Soc. Indust. Appl. Math.")

    define("j-J-SIMUL",				"Journal of Simulation")
    define("j-J-SIMUL",				"Journal of Simulation (JOS)")
    define("j-J-SIMUL",				"J. Simulation")
    define("j-J-SIMUL",				"J of Sim")		# how the journal cites itself
    define("j-J-SIMUL",				"J. Simulat.")
    define("j-J-SIMUL",				"J. Simul.")

    define("j-J-SOC-BIOL-STRUCT",		"Journal of Social and Biological Structures")
    define("j-J-SOC-BIOL-STRUCT",		"J. Soc. Biol. Struct.")

    define("j-J-SOC-CHEM-IND-LONDON",		"Journal of the Society of Chemical Industry, London")
    define("j-J-SOC-CHEM-IND-LONDON",		"Journal of the Society of Chemical Industry")
    define("j-J-SOC-CHEM-IND-LONDON",		"J. Soc. Chem. Ind.")
    define("j-J-SOC-CHEM-IND-LONDON",		"J. Soc. Chem. Ind., London")

    define("j-J-SOC-HIST",			"Journal of Social History")
    define("j-J-SOC-HIST",			"J. Soc. Hist.")

    define("j-J-SOC-IND-APPL-MATH-A-ON-CONTROL","Journal of the Society for Industrial and Applied Mathematics. Series A, On control")
    define("j-J-SOC-IND-APPL-MATH-A-ON-CONTROL","J. Soc. Ind. Appl. Math., A, On control")
    define("j-J-SOC-IND-APPL-MATH-A-ON-CONTROL","J. SIAM Control Ser. A")

    define("j-J-SOC-INSTR-CONTROL-ENG",		"Keisoku Jido Seigyo Gakkai = Journal of the Society of Instrument and Control Engineers")
    define("j-J-SOC-INSTR-CONTROL-ENG",		"Journal of the Society of Instrument and Control Engineers")
    define("j-J-SOC-INSTR-CONTROL-ENG",		"J. Soc. Instr. Control Eng.")

    define("j-J-SOFTW-EVOL-PROC",		"Journal of Software: Evolution and Process")
    define("j-J-SOFTW-EVOL-PROC",		"J. Softw. Evol. Proc.")

    define("j-J-SOFTW-MAINT",			"Journal of Software Maintenance: Research and Practice")
    define("j-J-SOFTW-MAINT",			"J. Softw. Maint. Res. Pract.")
    define("j-J-SOFTW-MAINT",			"J. Softw. Maint.")

    define("j-J-SOFTW-MAINT-EVOL",		"Journal of Software Maintenance and Evolution: Research and Practice")
    define("j-J-SOFTW-MAINT-EVOL",		"Journal of Software Maintenance and Evolution")
    define("j-J-SOFTW-MAINT-EVOL",		"J. Softw. Maint. Evol.")

    define("j-J-SOFTWARE-ALGEBRA-GEOM",		"Journal of Software for Algebra and Geometry")
    define("j-J-SOFTWARE-ALGEBRA-GEOM",		"J. Softw. Algebra Geom.")

    define("j-J-SOFTWARE-MAINT",		"Journal of Software Maintenance: research and practice")
    define("j-J-SOFTWARE-MAINT",		"J. softw. maint.")

    define("j-J-SOUND-VIB",			"Journal of Sound and Vibration")
    define("j-J-SOUND-VIB",			"J. sound vib.")
    define("j-J-SOUND-VIB",			"J. Sound Vibration")

    define("j-J-SOV-MATH",			"Journal of Soviet Mathematics")
    define("j-J-SOV-MATH",			"J. Sov. Math.")
    define("j-J-SOV-MATH",			"J. of Soviet Mathematics")

    define("j-J-STAT-COMPUT-SIMUL",		"Journal of Statistical Computation and Simulation")
    define("j-J-STAT-COMPUT-SIMUL",		"Journal of Statistical Computing and Simulation") # incorrect 4th word
    define("j-J-STAT-COMPUT-SIMUL",		"J. Statist. Comput. Simulation")
    define("j-J-STAT-COMPUT-SIMUL",		"J. Stat. Comput. Simul.")
    define("j-J-STAT-COMPUT-SIMUL",		"J. Statist. Comput. Simul.")
    define("j-J-STAT-COMPUT-SIMUL",		"J. Stat. Comp. Simul.")

    define("j-J-STAT-MECH-THEORY-EXP",		"Journal of Statistical Mechanics: Theory and Experiment")
    define("j-J-STAT-MECH-THEORY-EXP",		"J. Statist. Mech.")
    define("j-J-STAT-MECH-THEORY-EXP",		"J. Stat. Mech. Theory Exp.")
    define("j-J-STAT-MECH-THEORY-EXP",		"J. Stat. Mech.: Theory Exp.")

    define("j-J-STAT-PHYS",			"Journal of Statistical Physics")
    define("j-J-STAT-PHYS",			"J. Stat. Phys.")
    define("j-J-STAT-PHYS",			"J. Statist. Phys.")

    define("j-J-STAT-PLANN-INFERENCE",		"Journal of Statistical Planning and Inference")
    define("j-J-STAT-PLANN-INFERENCE",		"Journal of Statistical Planning Inference") # older title form
    define("j-J-STAT-PLANN-INFERENCE",		"J. Statist. Plann. Inference")			# MathSciNet abbreviation
    define("j-J-STAT-PLANN-INFERENCE",		"J. Stat. Plann. Inference")			# Library of Congress, and old MathSciNet, abbreviation

    define("j-J-STAT-SOC-LONDON",		"Journal of the Statistical Society of London")
    define("j-J-STAT-SOC-LONDON",		"J. Statist. Soc. London")
    define("j-J-STAT-SOC-LONDON",		"J. Stat. Soc. London")

    define("j-J-STAT-SOFT",			"Journal of Statistical Software")
    define("j-J-STAT-SOFT",			"J. Stat. Soft.")

    define("j-J-STAT-THEORY-PRACT",		"Journal of Statistical Theory and Practice")
    define("j-J-STAT-THEORY-PRACT",		"J. Stat. Theory Pract.")

    define("j-J-STRATEG-STUD",			"Journal of Strategic Studies")
    define("j-J-STRATEG-STUD",			"J. Strateg. Stud.")

    define("j-J-STRUCT-BIO",			"Journal of structural biology")
    define("j-J-STRUCT-BIO",			"J Struct Biol (AUD)")

    define("j-J-STRUCT-ENG",			"Journal of structural engineering")
    define("j-J-STRUCT-ENG",			"J. struct. eng.")

    define("j-J-STRUCT-ENG-NY",			"Journal of structural engineering (New York, NY)")
    define("j-J-STRUCT-ENG-NY",			"J. struct. eng. (New York, NY)")

    define("j-J-STRUCT-MECH",			"Journal of structural mechanics")
    define("j-J-STRUCT-MECH",			"J. struct. mech.")
    define("j-J-STRUCT-MECH",			"J. Structural Mech.")

    define("j-J-SUPERCOMPUTING",		"The Journal of Supercomputing")
    define("j-J-SUPERCOMPUTING",		"J. Supercomputing")
    define("j-J-SUPERCOMPUTING",		"J. Supercomput.")

    define("j-J-SUPERCOND",			"Journal of Superconductivity")
    define("j-J-SUPERCOND",			"J. Supercond.")

    define("j-J-SUPERCOND-NOVEL-MAGN",		"Journal of Superconductivity and Novel Magnetism")
    define("j-J-SUPERCOND-NOVEL-MAGN",		"J. Supercond. Novel Magn.")

    define("j-J-SYMBOLIC-COMP",			"Journal of Symbolic Computation")
    define("j-J-SYMBOLIC-COMP",			"J. of Symbolic Computation")
    define("j-J-SYMBOLIC-COMP",			"J. of Symb. Comp.")
    define("j-J-SYMBOLIC-COMP",			"J. Symbolic Comput.")

    define("j-J-SYMBOLIC-LOGIC",		"Journal of Symbolic Logic")
    define("j-J-SYS-MANAGEMENT",		"Journal of systems management")

    define("j-J-SYST-ARCH",			"Journal of Systems Architecture")
    define("j-J-SYST-ARCH",			"J. Syst. Arch.")

    define("j-J-SYST-SOFTW",			"The Journal of systems and software")
    define("j-J-SYST-SOFTW",			"Journal of System Software")
    define("j-J-SYST-SOFTW",			"J. syst. softw.")
    define("j-J-SYST-SOFTW",			"J SYST SOFTWARE")

    define("j-J-THEOR-BIOL",			"Journal of Theoretical Biology")
    define("j-J-THEOR-BIOL",			"J Theor Biol (K8N)")
    define("j-J-THEOR-BIOL",			"J. Theor. Biol")
    define("j-J-THEOR-BIOL",			"J. Theoret. Biol")
    define("j-J-THEOR-BIOL",			"J. Theor. Biol.")
    define("j-J-THEOR-BIOL",			"Jour. of Theor. Biol.")

    define("j-J-THEOR-PROBAB",			"Journal of Theoretical Probability")
    define("j-J-THEOR-PROBAB",			"J. Theoret. Probab.")
    define("j-J-THEOR-PROBAB",			"J. Theor. Probab.")

    define("j-J-THERM-STRESS",			"Journal of thermal stresses")
    define("j-J-THERM-STRESS",			"J. therm. stress.")
    define("j-J-THERM-STRESS",			"J. Thermal Stresses")

    define("j-J-THORAC-CARDIOVASC-SURG",	"Journal of thoracic and cardiovascular surgery")
    define("j-J-THORAC-CARDIOVASC-SURG",	"J. thorac. cardiovasc. surg.")

    define("j-J-TIME-SER-ANAL",			"Journal of Time Series Analysis")
    define("j-J-TIME-SER-ANAL",			"J. Time Series Anal.")

    define("j-J-TIME-SER-ECONOM",		"Journal of Time Series Econometrics")
    define("j-J-TIME-SER-ECONOM",		"J. Time Ser. Econom.")

    define("j-J-TRANSPORT-ENG",			"Journal of transportation engineering")

    define("j-J-UCS",				"J.UCS: Journal of Universal Computer Science")
    define("j-J-UCS",				"Journal of Universal Computer Science")
    define("j-J-UCS",				"J.UCS")

    define("j-J-UNIV-SCI-TECHNOL-CHINA",	"Journal of University of Science and Technology of China. Zhongguo Kexue Jishu Daxue Xuebao")
    define("j-J-UNIV-SCI-TECHNOL-CHINA",	"Journal of University of Science and Technology of China")
    define("j-J-UNIV-SCI-TECHNOL-CHINA",	"J. Univ. Sci. Technol. China")

    define("j-J-URBAN-ECON",			"Journal of Urban Economics")
    define("j-J-URBAN-ECON",			"J. Urban Econ.")

    define("j-J-VAC-SCI-TECHNOL",		"Journal of Vacuum Science Technology")
    define("j-J-VAC-SCI-TECHNOL",		"J. Vac. Sci. Technol.")

    define("j-J-VAC-SCI-TECHNOL-A",		"Journal of Vacuum Science \\& Technology A: Vacuum, Surfaces, and Films")
    define("j-J-VAC-SCI-TECHNOL-A",		"J. Vac. Sci. Technol., A")

    define("j-J-VAC-SCI-TECHNOL-B",		"Journal of Vacuum Science \\& Technology, B: Microelectronics and Nanometer Structures--Processing, Measurement, and Phenomena")
    define("j-J-VAC-SCI-TECHNOL-B",		"J. Vac. Sci. Technol. B: Microelectron. Nanometer Struct.--Process., Meas., Phenom.")
    define("j-J-VAC-SCI-TECHNOL-B",		"J. Vac. Sci. Technol. B")

    define("j-J-VIRO",				"Journal of virology")
    define("j-J-VIRO",				"J Virol (KCV)")

    define("j-J-VIS-COMMUN-IMAGE-REPRESENT",	"Journal of Visual Communication and Image Representation")
    define("j-J-VIS-COMMUN-IMAGE-REPRESENT",	"J. vis. commun. image represent.")
    define("j-J-VIS-COMMUN-IMAGE-REPRESENT",	"J. Visual Communication and Image Representation")

    define("j-J-VIS-COMP-ANIMATION",		"Journal of Visualization and Computer Animation")
    define("j-J-VIS-LANG-COMPUTING",		"Journal of Visual Languages and Computing")

    define("j-J-VLSI-COMPUT-SYST",		"Journal of VLSI and Computer Systems")
    define("j-J-VLSI-COMPUT-SYST",		"J. VLSI Comput. Syst.")
    define("j-J-VLSI-COMPUT-SYST",		"J. VLSI and Computer Systems")

    define("j-J-VLSI-SIGNAL-PROC",		"Journal of VLSI Signal Processing")

    define("j-J-WASH-ACAD-SCI",			"Journal of the Washington Academy of Sciences")
    define("j-J-WASH-ACAD-SCI",			"J. Wash. Acad. Sci.")
    define("j-J-WASH-ACAD-SCI",			"J. Washington Acad. Sci.")

    define("j-JAARBOEKJE-LEIDEN",		"Jaarboekje voor geschiedenis en oudheidkunde van Leiden en omstreken")

    define("j-JABES",				"Journal of Agricultural, Biological and Environmental Statistics (JABES)")
    define("j-JABES",				"Journal of Agricultural, Biological and Environmental Statistics")
    define("j-JABES",				"J. Agric. Biol. Environ. Stat.")
    define("j-JABES",				"JABES")

    define("j-JACS",				"Journal of the American Chemical Society")
    define("j-JACS",				"J. Amer. Chem. Soc.")
    define("j-JACS",				"J. Am. Chem. Soc.")
    define("j-JACS",				"Am. Chem. Soc. J.")

    define("j-JAHRB-BAYER-AKAD-WISS",		"{Jahrbuch der Bayerischen Akademie der Wissenschaften}")
    define("j-JAHRB-BAYER-AKAD-WISS",		"{Jb. Bayer. Akad. Wiss.}")
    define("j-JAHRB-BAYER-AKAD-WISS",		"{Jahrb. Bayer. Akad. Wiss}")

    define("j-JAHRB-KGL-BAYER-AKAD-WISS",	"{Jahrbuch der K{\\\"o}niglich Bayerischen Akademie der Wissenschaften}")
    define("j-JAHRB-KGL-BAYER-AKAD-WISS",	"{Jahrbuch der K{\\\"o}niglich Bayerischen Akademie der Wissenschaften zu M{\\\"u}nchen}")
    define("j-JAHRB-KGL-BAYER-AKAD-WISS",	"{Jahrbuch Kgl. Bayer. Akad. Wiss}")

    ## history: v1 1904-v20 n4 Mar. 1924 (numbers 1--79), continued by Physikalische Zeitschrift
    define("j-JAHRB-RADIOAKT-ELECTRON",		"{Jahrbuch der Radioaktivit{\\\"a}t und Electronik}")
    define("j-JAHRB-RADIOAKT-ELECTRON",		"{Jahrbuch der Radioaktivit{\\\"a}t und Electronik, Leipzig}")
    define("j-JAHRB-RADIOAKT-ELECTRON",		"{Jahrbuch der Radioaktivit{\\\\\"a}t und Electronik, Leipzig}")
    define("j-JAHRB-RADIOAKT-ELECTRON",		"Jahrb. Radioakt. Elektron.")

    define("j-JAHRESBER-DEUTSCH-MATH-VEREIN",	"{Jahresbericht der Deutschen Mathematiker-Vereinigung}")
    define("j-JAHRESBER-DEUTSCH-MATH-VEREIN",	"{Jahresbericht der Deutschen Mathematiker-Vereinigung (DMV)}")
    define("j-JAHRESBER-DEUTSCH-MATH-VEREIN",	"{Jahresbericht der Deutschen Mathematiker-Vereinigung, Leipzig}")
    define("j-JAHRESBER-DEUTSCH-MATH-VEREIN",	"Jb. dtsch. Mat. Ver.")
    define("j-JAHRESBER-DEUTSCH-MATH-VEREIN",	"Jb. dtsch. Math. Ver.")
    define("j-JAHRESBER-DEUTSCH-MATH-VEREIN",	"Jber. dtsch. Mat. Ver.")
    define("j-JAHRESBER-DEUTSCH-MATH-VEREIN",	"Jber. dtsch. Math. Ver.")
    define("j-JAHRESBER-DEUTSCH-MATH-VEREIN",	"Jahresber. Dtsch. Math.-Ver.")
    define("j-JAHRESBER-DEUTSCH-MATH-VEREIN",	"Jahresber. Deutsch. Math.-Verein.")

    define("j-JAMA",				"{JAMA : the journal of the American Medical Association}")
    define("j-JAMA",				"{JAMA}")

    define("j-JAPAN-J-APPL-PHYS",		"Japanese journal of applied physics")
    define("j-JAPAN-J-APPL-PHYS",		"Jpn. j. appl. phys.")
    define("j-JAPAN-J-APPL-PHYS",		"Jap. J. Appl. Phys.")

    define("j-JAPAN-J-INDUST-APPL-MATH",	"Japan Journal of Industrial and Applied Mathematics")
    define("j-JAPAN-J-INDUST-APPL-MATH",	"Japan J. Indust. Appl. Math.")
    define("j-JAPAN-J-INDUST-APPL-MATH",	"Japan J. Ind. Appl. Math.")

    define("j-JAPAN-J-MATH-N-S",		"Japanese journal of mathematics. New series")
    define("j-JAPAN-J-MATH-N-S",		"Japan. j. math. (n. s.)")

    define("j-JARATAZA",			"Journal A. Revue A. Tijdschrift A. Zeitschrift A")

    define("j-JAVA-REPORT",			"Java Report")
    define("j-JCD",				"ACM Journal of Computer Documentation")
    define("j-JCLT",				"The Journal of {C} Language Translation")

    define("j-JDIQ",				"Journal of Data and Information Quality (JDIQ)")
    define("j-JDIQ",				"J. Data Info. Quality (JDIQ)")
    define("j-JDIQ",				"J. Data Info. Quality")
    define("j-JDIQ",				"JDIQ")

    define("j-JERIC",				"ACM Journal on Educational Resources in Computing (JERIC)")
    define("j-JERIC",				"ACM J. Educ. Resources Comp.")

    define("j-JETC",				"ACM Journal on Emerging Technologies in Computing Systems (JETC)")
    define("j-JETC",				"ACM Journal on Emerging Technologies in Computing Systems")
    define("j-JETC",				"ACM J. Emerg. Tech. Comput. Syst.")

    define("j-JETP-LETT",			"JETP Letters")
    define("j-JETP-LETT",			"JETP Lett.")

    define("j-JEWISH-SOCIAL-STUDIES",		"Jewish Social Studies")

    define("j-JHAPLTD",				"Johns Hopkins APL Technical Digest")
    define("j-JHAPLTD",				"Johns Hopkins APL Tech. Dig.")

    define("j-JIPAM-J-INEQUAL-PURE-APPL-MATH",	"IPAM. Journal of Inequalities in Pure and Applied Mathematics")
    define("j-JIPAM-J-INEQUAL-PURE-APPL-MATH",	"JIPAM. J. Inequal. Pure Appl. Math.")

    define("j-JNLAA",				"Journal of Numerical Linear Algebra with Applications")

    define("j-JOCCH",				"Journal on Computing and Cultural Heritage (JOCCH)")
    define("j-JOCCH",				"ACM Journal on Computing and Cultural Heritage (JOCCH)")
    define("j-JOCCH",				"Journal on Computing and Cultural Heritage")
    define("j-JOCCH",				"ACM J. Comput. Cult. Herit.")
    define("j-JOCCH",				"J. Comput. Cult. Herit.")

    define("j-JOHN-HOPKINS-MAG",		"Johns Hopkins Magazine")
    define("j-JOHN-HOPKINS-MAG",		"Johns Hopkins Mag.")

    define("j-JOHO-KANRI",			"Joho kanri = Information \\& documentation")
    define("j-JOHO-KANRI",			"Joho kanri")

    define("j-JOHO-SHORI",			"Joho-Shori (J. Information Processing Soc. Japan)")
    define("j-JOHO-SHORI",			"Joho Shori")

    # JOSA == Journal of the Optical Society of America??
    # no Communications journal found
    define("j-JOSA-COMM",			"JOSA Communications")

    define("j-JOURNAL-Q",			"Journalism Quarterly")
    define("j-JOURNAL-Q",			"Journal. Q.")

    define("j-JPN-HEART-J",			"Japanese heart journal")
    define("j-JPN-HEART-J",			"Jpn. heart j.")
    define("j-JPN-HEART-J",			"Japan. heart j.")

    define("j-JPN-STUD-HIST-SCI",		"Japanese Studies in the History of Science")
    define("j-JPN-STUD-HIST-SCI",		"Historia Sci.")
    define("j-JPN-STUD-HIST-SCI",		"Historia Scientiarum. International Journal of the History of Science Society of Japan")
    define("j-JPN-STUD-HIST-SCI",		"Jpn. Stud. Hist. Sci.")

    define("j-KERNTECHNIK",			"Kerntechnik")
    define("j-KIBERNETIKA",			"Kibernetika")
    define("j-KNOWL-ENG-REV",			"The Knowledge Engineering Review")

    define("j-KNOWL-INFO-SYS",			"Knowledge and Information Systems")
    define("j-KNOWL-INFO-SYS",			"Knowl. Info. Syst.")
    define("j-KNOWL-INFO-SYS",			"Knowl. Info. Sys.")

    define("j-KNOWL-ORGAN",			"Knowledge Organization: KO")
    define("j-KNOWL-ORGAN",			"Knowledge Organization")
    define("j-KNOWL-ORGAN",			"Knowl. organ.")

    define("j-KOMOEDIE",			"Die \\TeX nische Kom{\\\"o}die")

    define("j-KOREA-INFO-SCI-SOC-REV",		"Korea Information Science Society Review = Chongbo Kwahakhoe chi")
    define("j-KOREA-INFO-SCI-SOC-REV",		"Korea Information Science Society Review")

    define("j-KUNSTLICHE-INTELLIGENZ",		"K{\\\"u}nstliche Intelligenz")
    define("j-KVANT",				"Kvant")
    define("j-KYBER",				"Kybernetik")
    define("j-KYBERNETIKA",			"Kybernetika")
    define("j-LAB-MICROCOMP",			"Laboratory microcomputer")

    define("j-LAN",				"LAN: the network solutions magazine")
    define("j-LAN",				"LAN: the local area network magazine")
    define("j-LAN",				"The local area network magazine: LAN")
    define("j-LAN",				"LAN Magazine")

    define("j-LAN-TIMES",			"LAN times")

    define("j-LANCET",				"The Lancet (London, England)")
    define("j-LANCET",				"Lancet")

    define("j-LANG-SCI",			"Language Sciences")
    define("j-LANG-SCI",			"Lang. Sci.")

    define("j-LANGMUIR",			"Langmuir")

    define("j-LANGUAGE",			"Language: journal of the Linguistic Society of America")
    define("j-LANGUAGE",			"Language")

    define("j-LANGUAGE-INT",			"Language International")
    define("j-LANGUAGE-INT",			"Lang. Int.")

    define("j-LARGE-SCALE-SYSTEMS",		"Large Scale Systems")
    define("j-LASER-FOCUS-WORLD",		"Laser focus world")

    define("j-LASER-PART-BEAMS",		"Laser and Particle Beams")
    define("j-LASER-PART-BEAMS",		"Laser Part. Beams")

    define("j-LASER-PHYS-LETT",			"Laser Physics Letters")
    define("j-LASER-PHYS-LETT",			"Laser Phys. Lett.")

    define("j-LATV-MAT-EZEG",			"Latviiskii matematicheskii ezhegodnik")
    define("j-LATV-MAT-EZEG",			"Latv. mat. ezeg.")
    define("j-LATV-MAT-EZEG",			"Latv. Mat. Ezhegodnik")
    define("j-LATV-MAT-EZEG",			"Latvi\\u\\i sk. Mat. E\\v zegodnik")

    define("j-LAW-COMP-AI",			"Law, Computers, and Artificial Intelligence")

    define("j-LAW-LIBR-LONDON",			"Law librarian (London)")
    define("j-LAW-LIBR-LONDON",			"Law librarian")
    define("j-LAW-LIBR-LONDON",			"Law libr. (Lond.)")

    define("j-LAW-TECH",			"Law/technology /")
    define("j-LAWYERS-PC",			"The Lawyer's PC")

    define("j-LEAD-EDGE",			"Leading edge (Tulsa, OK)")
    define("j-LEAD-EDGE",			"Lead. edge (Tulsa, OK)")
    define("j-LEAD-EDGE",			"The leading edge")
    define("j-LEAD-EDGE",			"Leading edge (Tulsa, Okla.)")
    define("j-LEAD-EDGE",			"Lead. edge (Tulsa, Okla.)")
    define("j-LEAD-EDGE",			"Lead. edge")

    define("j-LEARN-PUBL",			"Learned Publishing")
    define("j-LEARN-PUBL",			"Learn. Publ.")
    define("j-LEARN-PUBL",			"Learned Publishing: Journal of the {Association of Learned and Professional Society Publishers}")

    define("j-LEARNING",			"Learning (Palo Alto, CA)")
    define("j-LEARNING",			"Learning (Palo Alto, Calif.)")
    define("j-LEARNING",			"Learning")

    define("j-LECT-APPL-MATH",			"Lectures in applied mathematics (American Mathematical Society)")
    define("j-LECT-APPL-MATH",			"Lectures in applied mathematics")
    define("j-LECT-APPL-MATH",			"Lect. appl. math.")
    define("j-LECT-APPL-MATH",			"Lectures App. Math")
    define("j-LECT-APPL-MATH",			"Lectures Appl. Math")

    define("j-LECT-NOTES-BIOMATH",		"Lecture Notes in Biomathematics")

    define("j-LECT-NOTES-COMP-SCI",		"Lecture Notes in Computer Science")
    define("j-LECT-NOTES-COMP-SCI",		"Lecture Notes in CS")
    define("j-LECT-NOTES-COMP-SCI",		"Lecture notes in computer science")

    define("j-LECT-NOTES-CONTROL-INF-SCI",	"Lecture Notes in Control and Information Sciences")
    define("j-LECT-NOTES-CONTROL-INF-SCI",	"Lect. Notes Control Inf. Sci.")

    define("j-LECT-NOTES-MATH",			"Lecture Notes in Mathematics")
    define("j-LECT-NOTES-PHYSICS",		"Lecture notes in physics")
    define("j-LECT-NOTES-STAT",			"Lecture notes in statistics")

    define("j-LECT-SER-COMPUT-COMPUT-SCI",	"Lecture Series in Computer and Computational Sciences")
    define("j-LECT-SER-COMPUT-COMPUT-SCI",	"Lect. Ser. Comput. Comput. Sci.")

    define("j-LEGAL-MANAGE",			"Legal management: the journal of the Association of Legal Administrators")
    define("j-LEGAL-MANAGE",			"Legal management: the journal of the associati")
    define("j-LEGAL-MANAGE",			"Legal management")
    define("j-LEGAL-MANAGE",			"Legal manage.")

    define("j-LEONARDO",			"Leonardo (Oxford, England)")
    define("j-LEONARDO",			"Leonardo (Oxf.)")
    define("j-LEONARDO",			"Leonardo (Oxford)")
    define("j-LEONARDO",			"Leonardo")

    define("j-LET-MATH-PHYS",			"Letters in Mathematical Physics")
    define("j-LET-MATH-PHYS",			"Lett. Math. Phys.")

    define("j-LETT-APPL-ENG-SCI",		"Letters in applied and engineering sciences: an international journal")
    define("j-LETT-APPL-ENG-SCI",		"Letters in applied and engineering sciences")
    define("j-LETT-APPL-ENG-SCI",		"Lett. appl. eng. sci.")
    define("j-LETT-APPL-ENG-SCI",		"Lett. Appl. Engng. Sci.")

    define("j-LETT-NUOVO-CIMENTO",		"Lettere al Nuovo Cimento")
    define("j-LETT-NUOVO-CIMENTO",		"Lett. Nuovo Cimento")

    ## series 2 v1 n1 Jan. 2, 1971--v44 1985, Superseded by Europhysics Letters
    define("j-LETT-NUOVO-CIMENTO-2",		"Lettere al Nuovo Cimento Series 2")
    define("j-LETT-NUOVO-CIMENTO-2",		"Lettere al Nuovo Cimento della Societa Italiana di Fisica")
    define("j-LETT-NUOVO-CIMENTO-2",		"Lett. Nuovo Cimento 2")

    define("j-LIB-COMP-SYS-EQUIP-REVIEW",	"Library Computer Systems and Equipment Review")
    define("j-LIB-HI-TECH",			"Library Hi Tech")
    define("j-LIB-HI-TECH-NEWS",		"Library Hi Tech News")
    define("j-LIB-RESOURCES-TECH-SERVICES",	"Library Resources and Technical Services")
    define("j-LIB-SYSTEMS",			"Library Systems")

    define("j-LIBERTAS-MATH",			"Libertas Mathematica")
    define("j-LIBERTAS-MATH",			"Libertas Math.")

    define("j-LIBR-J",				"Library journal")
    define("j-LIBR-J",				"Libr. j.")

    define("j-LIBR-SOFTW-REV",			"Library Software Review")
    define("j-LIBR-SOFTW-REV",			"Libr. softw. rev.")

    define("j-LIBR-TRENDS",			"Library Trends")
    define("j-LIBR-TRENDS",			"Libr. trends")

    define("j-LIFE-SUPPORT-SYST",		"Life support systems: the journal of the European Society for Artificial Organs")
    define("j-LIFE-SUPPORT-SYST",		"Life support syst.")
    define("j-LIFE-SUPPORT-SYST",		"Life support systems")

    define("j-LIGHT-SCI-APPL",			"Light: Science and Applications")
    define("j-LIGHT-SCI-APPL",			"Light: Sci. Appl.")

    define("j-LIGHTWAVE-TECHNOL",		"Journal of Lightwave Technology")
    define("j-LIGHTWAVE-TECHNOL",		"Journal of Lightwave Technology : a joint IEEE\\slash OSA publication")
    define("j-LIGHTWAVE-TECHNOL",		"J. Lightwave Technol.")

    define("j-LIMNOL-OCEANOGR",			"Limnology and Oceanography")
    define("j-LIMNOL-OCEANOGR",			"Limnol. Oceanogr.")

    define("j-LIMNOL-OCEANOGR-LETT",		"Limnology and Oceanography Letters")
    define("j-LIMNOL-OCEANOGR-LETT",		"Limnol. Oceanogr. Lett.")

    ## ``Linear and Multilinear Algebra'' was published by Gordon and
    ## Breach from volume 1 (1973) to volume 49 (2001).  Publication
    ## then moved to Taylor & Francis, and the name was shortened to
    ## ``Linear Multilinear Algebra'', without changing the CODEN or
    ## ISSN values.  The Taylor & Francis Web site offers coverage of,
    ## and access to, all issues from volume 1 (1973) to date.

    define("j-LIN-AND-MULT-ALGEBRA",		"Linear and Multilinear Algebra")
    define("j-LIN-AND-MULT-ALGEBRA",		"Linear \\& Multilinear Algbera")
    define("j-LIN-AND-MULT-ALGEBRA",		"Lin. Mult. Alg.")
    define("j-LIN-AND-MULT-ALGEBRA",		"Lin. Mult. Algebra")

    define("j-LIN-MULT-ALGEBRA",		"Linear Multilinear Algebra")
    define("j-LIN-MULT-ALGEBRA",		"Linear Multilinear Algbera")
    define("j-LIN-MULT-ALGEBRA",		"Lin. Mult. Alg.")
    define("j-LIN-MULT-ALGEBRA",		"Lin. Mult. Algebra")

    define("j-LINEAR-ALGEBRA-APPL",		"Linear Algebra and its Applications")
    define("j-LINEAR-ALGEBRA-APPL",		"Linear Algebra Appl.")
    define("j-LINEAR-ALGEBRA-APPL",		"Linear Alg. and its Appl.")
    define("j-LINEAR-ALGEBRA-APPL",		"Lin. Alg. Appl.")
    define("j-LINEAR-ALGEBRA-APPL",		"Lin. Alg. Applics.")
    define("j-LINEAR-ALGEBRA-APPL",		"Lin. Alg. and its Appl.")
    define("j-LINEAR-ALGEBRA-APPL",		"Lin.Alg. Appl.")
    define("j-LINEAR-ALGEBRA-APPL",		"Linear Alg. and its Appl.")
    define("j-LINEAR-ALGEBRA-APPL",		"Linear Algebra Appl.")

    define("j-LINUX-J",				"Linux Journal")
    define("j-LINUX-J",				"Linux J.")

    define("j-LISP-SYMB-COMPUT",		"Lisp and Symbolic Computation")
    define("j-LISP-SYMB-COMPUT",		"Lisp and Symbolic Computation: An International Journal")
    define("j-LISP-SYMB-COMPUT",		"Lisp Symb. Comput.")

    define("j-LIT-LING-COMP",			"Literary and Linguistic Computing")
    define("j-LIT-LING-COMP",			"Literary \\& Linguistic Computing: journal of the Association for Literary and Linguistic Computing")
    define("j-LIT-LING-COMP",			"Literary \\& Linguistic Computing: journal of th")
    define("j-LIT-LING-COMP",			"Literary & Linguistic Computing: journal of th")

    define("j-LIVING-REV-RELATIVITY",		"Living Reviews in Relativity")
    define("j-LIVING-REV-RELATIVITY",		"Living Rev. Relativity")

    define("j-LMS-J-COMPUT-MATH",		"LMS Journal of Computation and Mathematics")
    define("j-LMS-J-COMPUT-MATH",		"LMS J. Comput. Math.")

    define("j-LOG-INFO-MANAGEMENT",		"Logistics Information Management")
    define("j-LOGIC-PROG-ALP-NEWSLETTER",	"Logic Programming: The {ALP} Newsletter")

    define("j-LOGIN",				";login: the USENIX Association newsletter")
    define("j-LOGIN",				";login")

    define("j-LONDON-REV-BOOKS",		"London Review of Books")
    define("j-LONDON-REV-BOOKS",		"London Rev. Books")

    define("j-LOPLAS",				"ACM Letters on Programming Languages and Systems")
    define("j-LOPLAS",				"ACM lett. program. lang. syst.")

    define("j-LOS-ALAMOS-SCIENCE",		"Los Alamos Science")
    define("j-LOS-ALAMOS-SCIENCE",		"Los Alamos Sci.")

    # Which Lotus is this??  There are at least 4.  I'm assuming the one from Lotus Publishing Corporation in Cambridge, MA, 1992--date
    define("j-LOTUS",				"Lotus (Cambridge, MA)")
    define("j-LOTUS",				"Lotus")

    define("j-M-COMPUTING",                     "M Computing")

    define("j-MAA-STUD-MATH",			"MAA studies in mathematics")
    define("j-MAA-STUD-MATH",			"MAA Stud. Math")

    define("j-MACH-GRAPH-VIS",			"Machine Graphics \\& Vision")

    define("j-MACH-INTELL",			"Machine Intelligence")
    define("j-MACH-INTELL",			"Machine Intell.")
    define("j-MACH-INTELL",			"Mach. Intell.")

    define("j-MACH-TRANSL",			"Machine Translation")
    define("j-MACH-TRANSL",			"Mach. transl.")

    define("j-MACH-VIS-APPL",			"Machine Vision and Applications")
    define("j-MACH-VIS-APPL",			"Mach. Vis. Appl.")

    define("j-MACHINE-DESIGN",			"Machine Design")
    define("j-MACHINE-DESIGN",			"Mach. Des.")

    define("j-MACQUARIE-MATH-REP",		"Macquarie Mathematics Report")

    define("j-MACROMOLECULES",			"Macromolecules (Washington, DC, USA)")
    define("j-MACROMOLECULES",			"Macromolecules (Washington, DC, United States)")
    define("j-MACROMOLECULES",			"Macromolecules (Washington, DC, US)")
    define("j-MACROMOLECULES",			"Macromolecules")

    define("j-MACUSER",				"MacUser")
    define("j-MACWEEK",				"MacWEEK")

    define("j-MACWORLD",			"Macworld")
    define("j-MACWORLD",			"Macworld: the Macintosh magazine")

    define("j-MAD",				"MAD Magazine")	# E C Publications, 1700 Broadway, New York, NY 10019, Tel: (212) 506-4850 (Oct/Nov 1952--date)

    define("j-MAGMA",				"Magma")
    define("j-MAGMA",				"Magma (New York, NY)")

    define("j-MAGN-MAGN-MATER",			"Journal of Magnetism and Magnetic Materials")
    define("j-MAGN-MAGN-MATER",			"J. Magn. Magn. Mater.")

    define("j-MAGN-RESON",			"Journal of Magnetic Resonance")
    define("j-MAGN-RESON",			"Journal of Magnetic Resonance (1969)")
    define("j-MAGN-RESON",			"J. magn. reson. (1969)")
    define("j-MAGN-RESON",			"J. magn. reson.")

    define("j-MAGY-FIZ-FOLY",			"Magyar Fizikai Foly{\\'o}irat")
    define("j-MAGY-FIZ-FOLY",			"Magyar Fizikai Folyoirat")
    define("j-MAGY-FIZ-FOLY",			"Magy. Fiz. Foly{\\'o}irat")
    define("j-MAGY-FIZ-FOLY",			"M. fiz. f.")
    define("j-MAGY-FIZ-FOLY",			"Magy. Fiz. Foly.")

    define("j-MAGY-TUDOMANY",			"Magyar Tudom{\\'a}ny [{Hungarian} Science]")
    define("j-MAGY-TUDOMANY",			"Magyar Tudom{\\'a}ny")
    define("j-MAGY-TUDOMANY",			"Magy. Tudom{\\'a}ny [{Hungarian} Science]")
    define("j-MAGY-TUDOMANY",			"Magy. Tudom{\\'a}ny")

    define("j-MANAGEMENT-SCIENCE",		"Management Science")
    define("j-MANAGEMENT-SCIENCE",		"Management Sci.")

    define("j-MANCHESTER-GUARDIAN",		"Manchester Guardian")

    define("j-MANAGING-INFO",			"Managing Information")
    define("j-MANUFACTURING-SYSTEMS",		"Manufacturing systems")

    define("j-MANUSCR-MATH",			"Manuscripta Mathematica")
    define("j-MANUSCR-MATH",			"Manuscr. Math.")
    define("j-MANUSCR-MATH",			"Manuscripta Math.")

    define("j-MAPLE-NEWS",			"Maple newsletter")
    define("j-MAPLE-TECH-NEWS",			"Maple technical newsletter")

    define("j-MAR-BIOL-RES",			"Marine Biology Research")
    define("j-MAR-BIOL-RES",			"Mar. Biol. Res.")

    define("j-MAR-BIOTECHNOL",			"Marine Biotechnology")
    define("j-MAR-BIOTECHNOL",			"Mar. Biotechnol.")

    define("j-MAR-ECOL-PROG-SER",		"Marine Ecology Progress Series")
    define("j-MAR-ECOL-PROG-SER",		"Mar. Ecol. Prog. Ser.")

    define("j-MAR-POLICY",			"Marine Policy")
    define("j-MAR-POLICY",			"Mar. Policy")

    define("j-MARIN-RESOURC-ECON",		"Marine Resource Economics")
    define("j-MARIN-RESOURC-ECON",		"Marin. Resour. Econ.")

    define("j-MARKETING-COMP",			"Marketing computers")

    define("j-MARKUP-LANG",			"Markup languages: theory \\& practice")
    define("j-MARKUP-LANG",			"Markup lang.")

    define("j-MAT-CONTEMP",			"Matem{\\'a}tica Contempor{\\^a}nea")
    define("j-MAT-CONTEMP",			"Mat. Contemp.")

    define("j-MAT-SB",				"Matematicheskii sbornik")
    define("j-MAT-SB",				"Mat. Sb")
    define("j-MAT-SB",				"AMS Sbornik Math")

    define("j-MAT-SB-MOSK",			"Matematicheskii sbornik / izdavaemyi Moskovskim matematicheskim obshchestvom = Recueil math{\\'e}matique de la Soci{\\'e}t{\\'e} math{\\'e}matique de Moscou")
    define("j-MAT-SB-MOSK",			"Matematiceskij sbornik (Moskva)")
    define("j-MAT-SB-MOSK",			"Mat. sb. (Mosk.)")
    ## define("j-MAT-SB-MOSK",			"Mat. sb.")

    define("j-MAT-TERMESZETTUD-ERT",		"Matematikai {\\'e}s Term{\\'e}szettudomanyi {\\'E}rtes{\\'\\i}t{\\H{o}}")
    define("j-MAT-TERMESZETTUD-ERT",		"Matemat. {\\'e}s Term{\\'e}szettud. {\\'E}rtes{\\'\\i}t{\\H{o}}")
    define("j-MAT-TERMESZETTUD-ERT",		"Mat. Term{\\'e}szettud. {\\'E}rt.")

    define("j-MAT-ZAMETKI",			"Matematicheskie zametki")
    define("j-MAT-ZAMETKI",			"Mat. zametki")

    define("j-MATER-RES-SOC-SYMP-PROC",		"Materials Research Society Symposium Proceedings")
    define("j-MATER-RES-SOC-SYMP-PROC",		"Mater. Res. Soc. Symp. Proc.")

    define("j-MATER-SCI-ENG",			"Materials Science and Engineering")
    define("j-MATER-SCI-ENG",			"Mater. sci. eng.")

    define("j-MATER-SCI-ENG-A",			"Materials Science and Engineering: A. Structural Materials: Properties, Microstructure and Processing")
    define("j-MATER-SCI-ENG-A",			"Mater. Sci. Eng., A")

    define("j-MATER-SCI-FORUM",			"Materials Science Forum")
    define("j-MATER-SCI-FORUM",			"Mater. Sci. Forum")

    define("j-MATER-TODAY",			"Materials Today")
    define("j-MATER-TODAY",			"Mater. Today")

    define("j-MATH-ANN",			"Mathematische Annalen")
    define("j-MATH-ANN",			"Math. Ann.")
    define("j-MATH-ANN",			"Math. Annalen")

    define("j-MATH-APP-COMP",			"Mat. Aplic. Comput.")

    define("j-MATH-BIOSCI",			"Mathematical Biosciences")
    define("j-MATH-BIOSCI",			"Math. Biosciences")
    define("j-MATH-BIOSCI",			"Math. Biosci.")
    define("j-MATH-BIOSCI",			"Math. Bisci.")
    define("j-MATH-BIOSCI",			"Math Biosci (BET)")
    define("j-MATH-BIOSCI",			"Math. Biosciences")

    define("j-MATH-CLUJ",			"Mathematicae Cluj")
    define("j-MATH-CLUJ",			"Mathematica (Cluj)")
    define("j-MATH-CLUJ",			"Mathematica (Cluj, Romania: 1929)")

    define("j-MATH-COMPUT",			"Mathematics of Computation")
    define("j-MATH-COMPUT",			"Math. Comput.")
    define("j-MATH-COMPUT",			"Math. Comp.")
    define("j-MATH-COMPUT",			"Math. Comp")
    define("j-MATH-COMPUT",			"Mathematics of Computations")
    define("j-MATH-COMPUT",			"Mathematics of computation")

    define("j-MATH-COMPUT-SCI",			"Mathematics in Computer Science")
    define("j-MATH-COMPUT-SCI",			"Math. Comput. Sci.")

    define("j-MATH-COMP-EDU",			"Mathematics and computer education")

    define("j-MATH-COMP-MODELLING",		"Mathematical and computer modelling")
    define("j-MATH-COMP-MODELLING",		"Math. Comput. Modelling")
    define("j-MATH-COMP-MODELLING",		"Mathl. Comput. Modelling")
    define("j-MATH-COMP-MODELLING",		"Mathl. Computer Modelling")

    define("j-MATH-COMP-SIM",			"Mathematics and Computers in Simulation")
    define("j-MATH-COMP-SIM",			"Math. comput. simul.")
    define("j-MATH-COMP-SIM",			"Math. Comput. Simulation")
    define("j-MATH-COMP-SIM",			"Math. Comp. Simulation")

    define("j-MATH-CONTROL-SIGNALS-SYST",	"Mathematics of control, signals, and systems: MCSS")
    define("j-MATH-CONTROL-SIGNALS-SYST",	"Math. control signals syst.")
    define("j-MATH-CONTROL-SIGNALS-SYST",	"Math. Control, Signals and Sys.")
    define("j-MATH-CONTROL-SIGNALS-SYST",	"Math. Control Signals Systems")

    define("j-MATH-GAZ",			"Mathematical Gazette")
    define("j-MATH-GAZ",			"The Mathematical Gazette")
    define("j-MATH-GAZ",			"Math. Gaz.")
    define("j-MATH-GAZ",			"Math. Gazette")

    define("j-MATH-GEOL",			"Mathematical Geology")
    define("j-MATH-GEOL",			"Math. geol.")

    define("j-MATH-GEOSCI",			"Mathematical Geosciences")
    define("j-MATH-GEOSCI",			"Math. Geosci.")

    define("j-MATH-INEQUAL-APPL",		"Mathematical Inequalities \\& Applications")
    define("j-MATH-INEQUAL-APPL",		"Math. Inequal. Appl.")

    define("j-MATH-INTEL",			"The Mathematical Intelligencer")
    define("j-MATH-INTEL",			"Math. Intelligencer")

    define("j-MATH-JAPON",			"Mathematica Japonica")
    define("j-MATH-JAPON",			"Math. Jap.")
    define("j-MATH-JAPON",			"Math. Japonica")
    define("j-MATH-JAPON",			"Math. Japon.")

    define("j-MATH-LOGIC-QUART",		"Mathematical Logic Quarterly: MLQ")
    define("j-MATH-LOGIC-QUART",		"Mathematical Logic Quarterly")
    define("j-MATH-LOGIC-QUART",		"Math. Logic Q.")
    define("j-MATH-LOGIC-QUART",		"Math. Logic Quart.")

    define("j-MATH-MAG",			"Mathematics Magazine")
    define("j-MATH-MAG",			"Math. Mag.")

    define("j-MATH-MECH-COMPLEX-SYST",		"Mathematics and Mechanics of Complex Systems")
    define("j-MATH-MECH-COMPLEX-SYST",		"Math. Mech. Complex Syst.")

    define("j-MATH-MECH-SOLIDS",		"Mathematics and Mechanics of Solids : MMS")
    define("j-MATH-MECH-SOLIDS",		"Mathematics and Mechanics of Solids")
    define("j-MATH-MECH-SOLIDS",		"Math. Mech. Solids")

    define("j-MATH-MED-BIOL",			"Mathematical Medicine and Biology")
    define("j-MATH-MED-BIOL",			"Mathematical Medicine and Biology. A Journal of the IMA")
    define("j-MATH-MED-BIOL",			"Math. Med. Biol.")

    define("j-MATH-METHODS-APPL-SCI",		"Mathematical Methods in the Applied Sciences")
    define("j-MATH-METHODS-APPL-SCI",		"Math. Methods Appl. Sci.")
    define("j-MATH-METHODS-APPL-SCI",		"Math. Meth. in the Appl. Sci.")

    define("j-MATH-METHODS-STAT",		"Mathematical Methods of Statistics")
    define("j-MATH-METHODS-STAT",		"Math. Methods Statist.")
    define("j-MATH-METHODS-STAT",		"Math. Methods Stat.")

    define("j-MATH-MODEL",			"Mathematical Modeling")
    define("j-MATH-MODEL",			"Math. Modeling")
    define("j-MATH-MODEL",			"Math. Modelling")

    define("j-MATH-MODEL-NUM-ANA",		"Mathematical modelling and numerical analysis = Modelisation math{\\'e}matique et analyse num{\\'e}rique: $M^2AN$")
    define("j-MATH-MODEL-NUM-ANA",		"Mathematical modelling and numerical analysis = Modelisation mathematique et analyse numerique: $M^2AN$")
    define("j-MATH-MODEL-NUM-ANA",		"Mathematical modelling and numerical analysis")
    define("j-MATH-MODEL-NUM-ANA",		"Math. Model. Num. Anal.")
    define("j-MATH-MODEL-NUM-ANA",		"Math. Modelling and Numer. Anal.")
    define("j-MATH-MODEL-NUM-ANA",		"$M^{2}AN$: Modelisation math{\\'e}matique et analyse num{\\'e}rique = Mathematical modelling and numerical analysis")
    define("j-MATH-MODEL-NUM-ANA",		"$M^{2}AN$")
    define("j-MATH-MODEL-NUM-ANA",		"M2AN")
    define("j-MATH-MODEL-NUM-ANA",		"RAIRO Mod{\\'e}lisation Math{\\'e}matique et Analyse Num{\\'e}rique")
    define("j-MATH-MODEL-NUM-ANA",		"RAIRO Mod{\\'e}l. Math. Anal. Num{\\'e}r.")
    define("j-MATH-MODEL-NUM-ANA",		"R.A.I.R.O. Mathematical Modelling and Numerical Analysis")
    define("j-MATH-MODEL-NUM-ANA",		"M2AN Math. Model. Numer. Anal.")
    define("j-MATH-MODEL-NUM-ANA",		"ESAIM Math. Model. Numer. Anal.")
    define("j-MATH-MODEL-NUM-ANA",		"ESAIM: Mathematical Modelling and Numerical Analysis")

    define("j-MATH-MODELS-METHODS-APPL-SCI",	"Mathematical Models and Methods in Applied Sciences")
    define("j-MATH-MODELS-METHODS-APPL-SCI",	"Math. Models Methods Appl. Sci.")
    define("j-MATH-MODELS-METHODS-APPL-SCI",	"Math. Models and Meth in Appl. Sci.")

    define("j-MATH-NACHR",			"Mathematische Nachrichten")
    define("j-MATH-NACHR",			"Math. Nachr.")

    define("j-MATH-NATURWISS-UNTERR",		"Mathematische und Naturwissenschaftliche Unterricht")
    define("j-MATH-NATURWISS-UNTERR",		"Math. Naturwiss. Unterr.")
    define("j-MATH-NATURWISS-UNTERR",		"Math. Naturwiss. Unterr.")
    define("j-MATH-NATURWISS-UNTERR",		"Math. u. Naturw. Unterr")

    define("j-MATH-NOTES",			"Mathematical notes = Matematicheskie zametki")
    define("j-MATH-NOTES",			"Math. notes (Ross. akad.)")

    define("j-MATH-NOTES-ACAD-SCI-USSR",	"Mathematical Notes of the {Academy of Sciences of the USSR = Matematicheskie Zametki}")
    define("j-MATH-NOTES-ACAD-SCI-USSR",	"Mathematical Notes")

    define("j-MATH-OP-RES",			"Mathematics of Operations Research")
    define("j-MATH-OP-RES",			"Math. Oper. Res.")

    define("j-MATH-OPERATIONSFORSCH-STAT",	"Mathematische Operationsforschung und Statistik")
    define("j-MATH-OPERATIONSFORSCH-STAT",	"Math. Operationsforsch. Statist.")
    define("j-MATH-OPERATIONSFORSCH-STAT",	"Math. Operationsforsch. Stat.")

    define("j-MATH-PHYS-SEMESTERBERICHTE",	"Mathematisch-physikalische Semesterberichte")
    define("j-MATH-PHYS-SEMESTERBERICHTE",	"Math.-Phys. Semesterber.")

    define("j-MATH-PHYSICS",			"Math. Phys.")

    define("j-MATH-PROC-CAMB-PHILOS-SOC",	"Mathematical Proceedings of the Cambridge Philosophical Society")
    define("j-MATH-PROC-CAMB-PHILOS-SOC",	"Math. Proc. Cambridge Philos. Soc.")
    define("j-MATH-PROC-CAMB-PHILOS-SOC",	"Math. Proc. Camb. Philos. Soc.")
    define("j-MATH-PROC-CAMB-PHILOS-SOC",	"Math. Proc. Camb. Phil. Soc.")

    define("j-MATH-PROG",			"Mathematical Programming")
    define("j-MATH-PROG",			"Math. Prog.")
    define("j-MATH-PROG",			"Math. Programming")
    define("j-MATH-PROG",			"Math. Program.")

    define("j-MATH-PROG-SOC-COAL-NEWSLETTER",	"Mathematical Programming Society Committee on Algorithms Newsletter")
    define("j-MATH-PROG-SOC-COAL-NEWSLETTER",	"Mathematical Programming Society COAL Newsletter")

    define("j-MATH-PROG-STUDY",			"Mathematical Programming Study")
    define("j-MATH-PROG-STUDY",			"Math. Programming Stud.")
    define("j-MATH-PROG-STUDY",			"Math. Prog. Study")

    define("j-MATH-PROGRAM-COMPUT",		"Mathematical Programming Computation")
    define("j-MATH-PROGRAM-COMPUT",		"Math. Program. Comput.")

    define("j-MATH-RECR-ESSAYS",		"Mathematical Recreations and Essays")

    define("j-MATH-RES-LETT",			"Mathematical Research Letters")
    define("j-MATH-RES-LETT",			"Math. Res. Lett.")

    define("j-MATH-REV",			"Mathematical Reviews")
    define("j-MATH-REV",			"Math. Rev.")

    define("j-MATH-SCAND",			"Mathematica Scandinavica")
    define("j-MATH-SCAND",			"Math. Scand")

    define("j-MATH-SCHULE",			"Mathematik In Der Schule")

    define("j-MATH-SCI",			"The Mathematical Scientist")
    define("j-MATH-SCI",			"Mathematical Scientist")
    define("j-MATH-SCI",			"Math. Sci.")

    define("j-MATH-SCI-ENG",			"Mathematics in Science and Engineering")

    define("j-MATH-SEMESTERBER",		"Mathematische Semesterberichte")
    define("j-MATH-SEMESTERBER",		"Math. Semesterber.")

    define("j-MATH-SLOVACA",			"Mathematica Slovaca")
    define("j-MATH-SLOVACA",			"Math. Slovaca")

    define("j-MATH-SOC-SCI",			"Mathematical Social Sciences")
    define("j-MATH-SOC-SCI",			"Math. Soc. Sci.")

    define("j-MATH-STOS",			"Math. Stos.")

    define("j-MATH-STUDENT",			"The Mathematics Student")
    define("j-MATH-STUDENT",			"Math. Student")

    define("j-MATH-SYS-THEORY",			"Mathematical Systems Theory")
    define("j-MATH-SYS-THEORY",			"Math. Syst. Theory")
    define("j-MATH-SYS-THEORY",			"Math. Systems Theory")

    define("j-MATH-TABLES-OTHER-AIDS-COMPUT",	"Mathematical Tables and Other Aids to Computation")
    define("j-MATH-TABLES-OTHER-AIDS-COMPUT",	"Math. Tables and Other Aids To Comp.")
    define("j-MATH-TABLES-OTHER-AIDS-COMPUT",	"Math. tables other aids comput.")
    define("j-MATH-TABLES-OTHER-AIDS-COMPUT",	"Math. Tables Aids Comput.")

    define("j-MATH-TEACH",			"The Mathematics Teacher")
    define("j-MATH-TEACH",			"Math. Teach.")

    define("j-MATH-TODAY",			"Mathematics Today")
    define("j-MATH-TODAY",			"Math. Today (Southend-on-Sea)")
    define("j-MATH-TODAY",			"Math. Today")

    define("j-MATH-USSR-IZV",			"Mathematics of the {USSR} --- Izvestiya")
    define("j-MATH-USSR-IZV",			"Math. {USSR} Izv.")

    define("j-MATH-USSR-SBORNIK",		"Mathematics of the USSR. Sbornik")
    define("j-MATH-USSR-SBORNIK",		"Math. USSR Sbornik")

    define("j-MATH-Z",				"Mathematische Zeitschrift")
    define("j-MATH-Z",				"Math. Z.")
    define("j-MATH-Z",				"Math. Zeitschr.")

    define("j-MATHEMATECH",			"Mathematech: the global review of mathematics and its applications (London, UK)")
    define("j-MATHEMATECH",			"Mathematech")

    define("j-MATHEMATICA-EDUC",		"Mathematica in Education")
    define("j-MATHEMATICA-EDUC",		"Math. Educ.")

    define("j-MATHEMATICA-J",			"Mathematica Journal")

    define("j-MATHEMATIKA",			"Mathematika")
    define("j-MATHWORKS-NEWSLETTER",		"The MathWorks Newsletter")
    define("j-MAYFLOWER-QUARTERLY",		"Mayflower Quarterly")

    define("j-MAYO-CLIN-PROC",			"Mayo Clinic Proceedings")
    define("j-MAYO-CLIN-PROC",			"Mayo Clin. Proc.")

    define("j-MC",				"MC: Die Mikrocomputer-Zeitschrift")
    define("j-MC",				"M C: Computer Praxis f{\\\"u}r Anwender") # (1981--199x; ceased publication)
    define("j-MC",				"mc")
    define("j-MC",				"Mikrocomputer Zeitschrift")

    define("j-MD-COMPUTING-CMP",		"M.D. computing: computers in medical practice")
    define("j-MD-COMPUTING-CMP",		"M.D. computing")
    define("j-MD-COMPUTING-CMP",		"MD Comput.")
    define("j-MD-COMPUTING-CMP",		"MD Comput (MDC)")

    define("j-MDMV",				"Mitteilungen der Deutschen Mathematiker-Vereinigung")
    define("j-MDMV",				"Mitt. Dtsch. Math.-Ver.")

    define("j-MEASUREMENT",			"Measurement: Journal of the International Measurement Confederation")
    define("j-MEASUREMENT",			"Measurement")

    define("j-MEASUREMENT-CONTROL",		"Measurement and control")
    define("j-MEASUREMENTS-CONTROL",		"M and C, Measurements and Control")

    define("j-MECCANICA-MILAN",			"Meccanica (Milan)")
    define("j-MECCANICA-MILAN",			"Meccanica")

    define("j-MECH-AGEING-DEV",			"Mechanisms of ageing and development")
    define("j-MECH-AGEING-DEV",			"Mech. Ageing Dev.")

    define("j-MECH-DEVEL",			"Mechanisms of development")
    define("j-MECH-DEVEL",			"Mech Dev (AXF)")
    define("j-MECH-DEVEL",			"Mech. Dev.")

    define("j-MECH-ENG",			"Mechanical Engineering: the journal of the American Society of Mechanical Engineers")
    define("j-MECH-ENG",			"Mechanical Engineering")

    define("j-MECH-ENG-BULL",			"Mechanical Engineering Bulletin")
    define("j-MECH-ENG-BULL",			"Mechanical Engineering Bulletin ({India})")
    define("j-MECH-ENG-BULL",			"Mech. Eng. Bull.")

    define("j-MECH-MATER",			"Mechanics of Materials: an International Journal")
    define("j-MECH-MATER",			"Mechanics of Materials")
    define("j-MECH-MATER",			"Mech. Mater.")
    define("j-MECH-MATER",			"Mech. Mat.")

    define("j-MECH-RESEARCH-COMM",		"Mechanics Research Communications")
    define("j-MECH-RESEARCH-COMM",		"Mech. Res. Comm.")

    define("j-MECH-SOLIDS",			"Mechanics of solids")
    define("j-MECH-SOLIDS",			"Mech. solids.")
    define("j-MECH-SOLIDS",			"Izvestiia. Mekhanika tverdogo tela. English.")
    define("j-MECH-SOLIDS",			"Mechanics of Solids (Izv. Acad. Sci. USSR)")
    define("j-MECH-SOLIDS",			"Mechanics of Solids (Izv. Acad. Sci. USSR, MTT)")

    define("j-MECHAN-STRUCT-MACH",		"Mechanics of structures and machines")
    define("j-MECHAN-STRUCT-MACH",		"Mechan. struct. mach.")
    define("j-MECHAN-STRUCT-MACH",		"Mech. Structures Mach.")

    define("j-MED-DECIS-MAKING",		"Medical Decision Making")
    define("j-MED-DECIS-MAKING",		"Medical Decision Making : an international journal of the Society for Medical Decision Making")
    define("j-MED-DECIS-MAKING",		"Med. Decis. Making")

    define("j-MED-ELECT",			"Medical Electronics")

    define("j-MED-BIOL-ENG-COMPUT",		"Medical \\& biological engineering \\& computing")
    define("j-MED-BIOL-ENG-COMPUT",		"Med. biol. eng. comput.")
    define("j-MED-BIOL-ENG-COMPUT",		"Med. Biol. Engng. Comp.")

    define("j-MED-HYPOTH",			"Medical Hypotheses")
    define("j-MED-HYPOTH",			"Med. Hypoth.")

    define("j-MED-INSTRUM",			"Medical instrumentation")
    define("j-MED-INSTRUM",			"Med. Instrum.")

    define("j-MED-J-AUST",			"The Medical Journal of Australia")
    define("j-MED-J-AUST",			"Medical journal of Australia")
    define("j-MED-J-AUST",			"Med. J. Aust.")

    define("j-MED-OPIN-REV",			"Medical Opinion \\& Review")
    define("j-MED-OPIN-REV",			"Medical Opinion and Review")
    define("j-MED-OPIN-REV",			"Med. Opin. Rev.")

    define("j-MED-PHYS",			"Medical Physics")
    define("j-MED-PHYS",			"Med. Phys.")

    define("j-MED-REF-SERV-Q",			"Medical reference services quarterly")
    define("j-MED-REF-SERV-Q",			"Med. ref. serv. q.")

    define("j-MED-WAR",				"Medicine and War")
    define("j-MED-WAR",				"Med. War")

    ## continues Studies in Newspaper and Periodical History (1993--1997)
    define("j-MEDIA-HIST",			"Media History")	# 1998--current
    define("j-MEDIA-HIST",			"Media Hist.")

    define("j-MEDIA-INF-AUST",			"Media information Australia")
    define("j-MEDIA-INF-AUST",			"Media inf. Aust.")

    define("j-MEDIA-METHODS",			"Media and methods")
    define("j-MEDIA-METHODS",			"Media methods")

    define("j-MEDIAWEEK",			"Mediaweek")

    define("j-MEDICINE",			"Medicine (Baltimore)")
    define("j-MEDICINE",			"Medicine")

    define("j-MEM-AMS",				"Memoirs of the American Mathematical Society")
    define("j-MEM-AMS",				"Mem. Am. Math Soc.")

    define("j-MEM-COG",				"Memory and Cognition")

    define("j-MEM-FAC-SCI-KYUSHU-UNIV",		"Memoirs of the Faculty of Science, Kyushu Imperial University")
    define("j-MEM-FAC-SCI-KYUSHU-UNIV",		"Mem. Fac. Sci. Kyushu Univ.")

    define("j-MEM-FAC-SCI-KYUSHU-UNIV-A",	"Memoirs of the Faculty of Science, Kyushu Imperial University. Series A, Mathematics = Kyushu Teikoku Daigaku Rigakubu kiyo")
    define("j-MEM-FAC-SCI-KYUSHU-UNIV-A",	"Mem. Fac. Sci. Kyushu Univ. Ser. A")

    ## NB: The journal j-MEM-PROC-MANCHESTER-LIT-PHILOS-SOC has two
    ## parts in the same bound volumes: "Memoirs and Proceedings ..."
    ## papers have volume and issue numbers, and arabic page numbers.
    ## The "Proceedings ..." papers (j-PROC-MANCHESTER-LIT-PHILOS-SOC)
    ## have volume numbers without issue numbers, and roman page
    ## numbers.  Both have day and month values.

    define("j-MEM-PROC-MANCHESTER-LIT-PHILOS-SOC", "Memoirs and Proceedings of the Manchester Literary and Philosophical Society (Manchester Memoirs)")
    define("j-MEM-PROC-MANCHESTER-LIT-PHILOS-SOC", "Memoirs and Proceedings of the Manchester Literary and Philosophical Society")
    define("j-MEM-PROC-MANCHESTER-LIT-PHILOS-SOC", "Mem. Proc. Manchester Lit. Philos. Soc.")

    define("j-METAB-CLIN-EXP",			"Metabolism, Clinical and Experimental")
    define("j-METAB-CLIN-EXP",			"Metabolism")
    define("j-METAB-CLIN-EXP",			"Metab. Clin. Exp.")

    ## v1 n1 Jan. 1970--v5 n12 Dec. 1974: then split into parts A and B
    define("j-METALL-TRANS",			"Metallurgical Transactions")
    define("j-METALL-TRANS",			"Metall. Trans.")

    define("j-METALL-MATER-TRANS-A",		"Metallurgical and Materials Transactions A: Physical Metallurgy and Materials Science")
    define("j-METALL-MATER-TRANS-A",		"Metallurgical and Materials Transactions A")
    define("j-METALL-MATER-TRANS-A",		"Metall. Mater. Trans. A")

    define("j-METALL-TRANS-A-PHYS-METALL-MATER-SCI", "Metallurgical transactions. A, Physical metallurgy and materials science")
    define("j-METALL-TRANS-A-PHYS-METALL-MATER-SCI", "Metall. trans., A, Phys. metall. mater. sci.")
    define("j-METALL-TRANS-A-PHYS-METALL-MATER-SCI", "Metall. Trans. A")

    define("j-METALLWIRTSCH-METALLWISS-METALLTECH",	"{Metallwirtschaft, Metallwissenschaft, Metalltechnik}")
    define("j-METALLWIRTSCH-METALLWISS-METALLTECH",	"{Metallwirtschaft, -wissenschaft, -technik}")
    define("j-METALLWIRTSCH-METALLWISS-METALLTECH",	"{Metallwirtsch., Metallwiss., Metalltech.}")

    define("j-METAPHILOSOPHY",			"Metaphilosophy")

    define("j-METH-INFO-MED",			"Methods of Information in Medicine = Methodik der Information in der Medizin")
    define("j-METH-INFO-MED",			"Methods of Information in Medicine")

    define("j-METH-MOL-BIOL",			"Methods in molecular biology")
    define("j-METH-MOL-BIOL",			"Methods Mol Biol (BU3)")

    define("j-METH-MOL-BIOL-CLIFTON",		"Methods in molecular biology (Clifton, NJ)")

    define("j-METHODS-APPL-ANAL",		"Methods and Applications of Analysis")
    define("j-METHODS-APPL-ANAL",		"Meth. Appl. Anal.")
    define("j-METHODS-APPL-ANAL",		"Methods Appl. Anal.")

    define("j-METHODS-CELL-BIOL",		"Methods in Cell Biology")
    define("j-METHODS-CELL-BIOL",		"Methods Cell Biol.")
    define("j-METHODS-CELL-BIOL",		"Methods Cell Biol (MV4)")

    define("j-METHODS-ENZYMOL",			"Methods in Enzymology")
    define("j-METHODS-ENZYMOL",			"Methods Enzymol.")
    define("j-METHODS-ENZYMOL",			"Methods Enzymol (MVA)")

    define("j-METRIKA",				"Metrika. International Journal for Theoretical and Applied Statistics")
    define("j-METRIKA",				"Metrika")

    define("j-METRON",				"Metron")

    define("j-MICH-MATH-J",			"Michigan Mathematical Journal")
    define("j-MICH-MATH-J",			"Mich. Math. J.")
    define("j-MICH-MATH-J",			"Michigan Math. J.")

    define("j-MICRO-CORNUCOPIA",		"Micro Cornucopia")

    define("j-MICROBIOL",			"Microbiology")
    define("j-MICROBIOL",			"Microbiology (BXW)")

    define("j-MICROBIOL-REV",			"Microbiological reviews")
    define("j-MICROBIOL-REV",			"Microbiol Rev (M9M)")

    define("j-MICROBIOL-SCI",			"Microbiological Sciences")
    define("j-MICROBIOL-SCI",			"Microbiol Sci (ATY)")

    define("j-MICROBIOLOGICA",			"Microbiologica (MXR)")

    define("j-MICROBIOS",			"Microbios")
    define("j-MICROBIOS",			"Microbios (MXS)")

    define("j-MICROCHIM-ACTA",			"Microchimica Acta")
    define("j-MICROCHIM-ACTA",			"Microchim. Acta")

    define("j-MICROCOMP-CIVIL-ENG",		"Microcomputers in Civil Engineering")

    define("j-MICROCOMPUT-APPL",		"Microcomputer Applications")
    define("j-MICROCOMPUT-APPL",		"Microcomput. appl. (Anaheim)")
    define("j-MICROCOMPUT-APPL",		"Microcomputer Applications: an official journal of the International Society for Mini and Microcomputers")

    define("j-MICROCOMPUT-INF-MANAGE",		"Microcomputers for Information Management")
    define("j-MICROCOMPUT-INF-MANAGE",		"Microcomput. inf. manage.")

    define("j-MICROELECT-RELIABILITY",		"Microelectronics and Reliability")

    define("j-MICROELECT-J",			"Microelectronics Journal")
    define("j-MICROELECT-J",			"Microelect. J.")

    define("j-MICROPROC-MICROPROG",		"Microprocessing and Microprogramming")
    define("j-MICROPROC-MICROPROG",		"Microprocess. Microprogr. (Netherlands), Microprocessing and Microprogramming")

    define("j-MICROPROC-MICROSYS",		"Microprocessors and Microsystems")
    define("j-MICROPROC-MICROSYS",		"Microprocessors \\& Microsystems")

    define("j-MICROPROC-REP",			"Microprocessor report")
    define("j-MICROPROC-REP",			"Microprocess. rep.")

    define("j-MICROSC-RES-TECH",		"Microscopy Research and Technique")
    define("j-MICROSC-RES-TECH",		"Microsc. Res. Tech.")

    define("j-MICROSOFT-SYS-J",			"Microsoft Systems Journal")

    define("j-MICROSYS-TECH",			"Microsystem Technologies: Sensors, Actuators, Systems Integration")
    define("j-MICROSYS-TECH",			"Microsystem Technologies")
    define("j-MICROSYS-TECH",			"Microsyst. Technol.")
    define("j-MICROSYS-TECH",			"Microsys. Technol.")
    define("j-MICROSYS-TECH",			"Microsys. Tech.")

    define("j-MICROW-OPT-TECHNOL-LETT",		"Microwave and Optical Technology Letters")
    define("j-MICROW-OPT-TECHNOL-LETT",		"Microw. opt. technol. lett. (Print)")
    define("j-MICROW-OPT-TECHNOL-LETT",		"Microw. opt. technol. lett.")

    define("j-MIENTRAS-TANTO",			"Mientras Tanto")

    define("j-MIKROBIOLOGIIA",			"Mikrobiologiia (Moscow, Russia: 1932)")
    define("j-MIKROBIOLOGIIA",			"Mikrobiologiia")

    define("j-MIDDLE-EAST-STUDIES-ASSOC-BULL",	"Middle East Studies Association bulletin")

    define("j-MIDWEST-STUD-PHILOS",		"Midwest Studies in Philosophy")
    define("j-MIDWEST-STUD-PHILOS",		"Midwest Stud. Philos.")

    define("j-MIKROLAN",			"Mikrolan")

    define("j-MIND",				"MIND: A Quarterly Review of Pyschology and Philosophy")
    define("j-MIND",				"MIND: {A} Quarterly Review of Pyschology and Philosophy")
    define("j-MIND",				"Mind")

    define("j-MINDS-MACH",			"Minds and Machines")
    define("j-MINDS-MACH",			"Minds Mach.")

    define("j-MINERALS-BASEL",			"Minerals (Basel)")
    define("j-MINERALS-BASEL",			"Minerals")

    define("j-MINERVA-WASHINGTON",		"Minerva [{Washington, DC}]")
    define("j-MINERVA-WASHINGTON",		"Minerva")

    define("j-MINI-MICRO-SYSTEMS",		"Mini-Micro Systems")

    define("j-MINI-REV-MED-CHEM",		"Mini Reviews in Medicinal Chemistry")
    define("j-MINI-REV-MED-CHEM",		"Mini Rev. Med. Chem.")

    define("j-MITT-MATH-GES-HAMBURG",		"Mitteilungen der Mathematischen Gesellschaft in Hamburg")
    define("j-MITT-MATH-GES-HAMBURG",		"Mitt. Math. Ges. Hamburg")

    define("j-MMT",				"Inzhenernyi zhurnal. Mekhanika tverdogo tela: MTT")
    define("j-MMT",				"MMT")
    define("j-MMT",				"Mekhanika tverdogo tela")

    define("j-MOD-HEALTHC",			"Modern healthcare")
    define("j-MOD-HEALTHC",			"Mod. healthc.")

    ## Vol. 1, no. 1 (Apr. 2004) - No journal abbreviation found in numerous library catalogs and databases
    define("j-MOD-INTELL-HIST",			"Modern Intellectual History: {MIH}")
    define("j-MOD-INTELL-HIST",			"Modern Intellectual History")
    define("j-MOD-INTELL-HIST",			"Mod. Intell. Hist.")

    define("j-MOD-ITALY",			"Modern Italy")
    define("j-MOD-ITALY",			"Mod. Italy")

    define("j-MOD-PHYS-LETT-A",			"Modern Physics Letters A (MPLA)")
    define("j-MOD-PHYS-LETT-A",			"Modern Physics Letters A")
    define("j-MOD-PHYS-LETT-A",			"Mod. Phys. Lett. A (MPLA)")
    define("j-MOD-PHYS-LETT-A",			"Mod. Phys. Lett. A")

    define("j-MOD-PHYS-LETT-B",			"Modern Physics Letters B")
    define("j-MOD-PHYS-LETT-B",			"Mod. Phys. Lett. B")

    define("j-MOD-PLAST",			"Modern plastics")
    define("j-MOD-PLAST",			"Mod. plast.")

    define("j-MODEL-SIMUL",			"Modeling and simulation")
    define("j-MODEL-SIMUL",			"Model. simul.")

    define("j-MODEL-SIMUL-SCI-ENG",		"Modelling and simulation in materials science and engineering")
    define("j-MODEL-SIMUL-SCI-ENG",		"Modelling Simul. Mater. Sci. Eng.")
    define("j-MODEL-SIMUL-SCI-ENG",		"Modeling Simul. Mater. Sci. Eng.")

    define("j-MODELLING-MEASUREMENT-CONTROL-B", "Modelling, Measurement \\& Control B: Solid \\& Fluid Mechanics \\& Thermics, Mechanical Systems")

    define("j-MOL-BIO-CELL",			"Mol Biol Cell (BAU)")
    define("j-MOL-BIO-EVOL",			"Mol Biol Evol (MOB)")
    define("j-MOL-BIOCHEM-PARASITOL",		"Mol Biochem Parasitol (NOR)")
    define("j-MOL-BIOL",			"Molecular biology")

    define("j-MOL-BIOSYST",			"Molecular BioSystems")
    define("j-MOL-BIOSYST",			"Mol. BioSyst.")

    define("j-MOL-CELL-BIOCHEM",		"Molecular and Cellular Biochemistry")
    define("j-MOL-CELL-BIOCHEM",		"Mol Cell Biochem (NGU)")
    define("j-MOL-CELL-BIOCHEM",		"Mol. cell. biochem.")
    define("j-MOL-CELL-BIOCHEM",		"Molecular and Cellular Biochem.")

    define("j-MOL-CELL-BIOL",			"Molecular and cellular biology")
    define("j-MOL-CELL-BIOL",			"Mol. Cell. Biol.")
    define("j-MOL-CELL-BIOL",			"Mol Cell Biol (NGY)")
    define("j-MOL-CELL-BIOL",			"Molec and Cell. Biol.")

    define("j-MOL-CELL-CARDIOL",		"Journal of molecular and cellular cardiology")
    define("j-MOL-CELL-CARDIOL",		"J. mol. cell. cardiol.")

    define("j-MOL-CELL-ENDOCRINOL",		"Mol Cell Endocrinol (E69)")
    define("j-MOL-ECOL",			"Mol Ecol (BYN)")

    define("j-MOL-ENDOCRINOL",			"Molecular endocrinology")
    define("j-MOL-ENDOCRINOL",			"Mol Endocrinol.")
    define("j-MOL-ENDOCRINOL",			"Mol Endocrinol. (Baltimore, Md.)")
    define("j-MOL-ENDOCRINOL",			"Mol Endocrinol. (Baltim., Md.)")

    define("j-MOL-GENERAL-GENET",		"Molecular and general genetics: MGG")
    define("j-MOL-GENERAL-GENET",		"Mol Gen Genet (NGP)")

    define("j-MOL-INF",				"Molecular Informatics")
    define("j-MOL-INF",				"Mol. Inf.")

    define("j-MOL-MICROBIOL",			"Molecular microbiology")
    define("j-MOL-MICROBIOL",			"Mol Microbiol (MOM)")
    define("j-MOL-MICROBIOL",			"Mol. Microbiol.")

    define("j-MOL-PHARMACOL",			"Molecular pharmacology")
    define("j-MOL-PHARMACOL",			"Mol Pharmacol (NGR)")
    define("j-MOL-PHARMACOL",			"Mol. Pharmacol.")
    define("j-MOL-PHARMACOL",			"Molec. Pharmacol.")

    define("j-MOL-PHYLOGENET-EVOL",		"Mol Phylogenet Evol (BYP)")

    define("j-MOL-PHYS",			"Molecular Physics")
    define("j-MOL-PHYS",			"Mol. Phys.")

    define("j-MOL-PSYCHIATRY",			"Molecular Psychiatry")
    define("j-MOL-PSYCHIATRY",			"Mol. Psychiatry")

    define("j-MOL-SIM",				"Molecular simulation")

    define("j-MOLECULES",			"Molecules")

    define("j-MON-BER-DTSCH-AKAD-WISS-BERL",	"Monatsberichte der Deutschen Akademie der Wissenschaften zu Berlin")
    define("j-MON-BER-DTSCH-AKAD-WISS-BERL",	"Mon. ber. Dtsch. Akad. Wiss. Berl.")
    define("j-MON-BER-DTSCH-AKAD-WISS-BERL",	"Monatsber. Deutsch. Akad. Wiss.")

    define("j-MONAT-MATH",			"Monatshefte f{\\\"u}r Mathematik")
    define("j-MONAT-MATH",			"Monatshefte fur Mathematik")
    define("j-MONAT-MATH",			"Monatsh. f{\\\"u}r Math.")
    define("j-MONAT-MATH",			"Monatsh. Math.")

    define("j-MONAT-MATH-PHYSIK",		"Monatshefte f{\\\"u}r Mathematik und Physik")
    define("j-MONAT-MATH-PHYSIK",		"Monatshefte fur Mathematik und Physik")
    define("j-MONAT-MATH-PHYSIK",		"Monatsch. Math. u. Physik")
    define("j-MONAT-MATH-PHYSIK",		"Monatsh. Math. Phys.")

    define("j-MONIST",				"The Monist")
    define("j-MONIST",				"Monist")

    define("j-MONTE-CARLO-METHODS-APPL",	"Monte Carlo Methods and Applications")
    define("j-MONTE-CARLO-METHODS-APPL",	"Monte Carlo Methods Appl.")

    define("j-MONTHLY-NOT-ASTRON-SOC-SOUTH-AFRICA", "Monthly Notes of the Astronomical Society of South Africa")
    define("j-MONTHLY-NOT-ASTRON-SOC-SOUTH-AFRICA", "Monthly Not. Astron Soc. South Africa")

    define("j-MONTHLY-NOT-ROY-ASTRON-SOC",	"Monthly Notices of the Royal Astronomical Society")
    define("j-MONTHLY-NOT-ROY-ASTRON-SOC",	"Monthly Notices of the Royal Astronomical Society of London")
    define("j-MONTHLY-NOT-ROY-ASTRON-SOC",	"Mon. Not. R. Astron. Soc.")
    define("j-MONTHLY-NOT-ROY-ASTRON-SOC",	"Mon. Not. R. Astron. Soc. Lond.")
    define("j-MONTHLY-NOT-ROY-ASTRON-SOC",	"Mon. Not. R. Astron. Soc. London")
    define("j-MONTHLY-NOT-ROY-ASTRON-SOC",	"Monthly Not. Roy. Astron. Soc. London")
    define("j-MONTHLY-NOT-ROY-ASTRON-SOC",	"Monthly Not. Roy. Astron. Soc. Lond.")
    define("j-MONTHLY-NOT-ROY-ASTRON-SOC",	"Monthly Not. Roy. Astron. Soc.")

    define("j-MONTHLY-WEATHER-REVIEW",		"Monthly Weather Review")

    define("j-MOSCOW-UNIV-MECH-BULL",		"Moscow University Mechanics Bulletin")
    define("j-MOSCOW-UNIV-MECH-BULL",		"Moscow Univ. Mech. Bull.")

    define("j-MOTHER-JONES",			"Mother Jones")
    define("j-MTNRCW",				"Mathl Tabl. Natn. Res. Coun., Wash.")

    define("j-MULTIBODY-SYST-DYN",		"Multibody System Dynamics")
    define("j-MULTIBODY-SYST-DYN",		"Multibody Syst. Dyn.")

    define("j-MULTIMEDIA-SYSTEMS",		"Multimedia Systems")

    define("j-MULTIMEDIA-TOOLS-APPLIC",		"Multimedia Tools and Applications")
    define("j-MULTIMEDIA-TOOLS-APPLIC",		"Multimedia Tools Applic.")

    define("j-MULTISCALE-MODELING-SIMUL",	"Multiscale Modeling and Simulation")
    define("j-MULTISCALE-MODELING-SIMUL",	"Multiscale Model. Simul.")
    define("j-MULTISCALE-MODELING-SIMUL",	"Multiscale Modeling \\& Simulation")

    define("j-MULTIVARIATE-BEHAV-RES",		"Multivariate behavioral research")
    define("j-MUSIC",				"Music")

    define("j-MUTAT-RES",			"Mutation Research")
    define("j-MUTAT-RES",			"Mutation Research/Fundamental and Molecular Mechanisms of Mutagenesis")
    define("j-MUTAT-RES",			"Mutat Res (NNA)")
    define("j-MUTAT-RES",			"Mutat. Res.")

    define("j-MUTAT-RES-GENETIC-TOXIC-TEST-BIOMON-ENV-OCC-EXPOSURE", "Mutation research. Genetic toxicology testing and biomonitoring of environmental or occupational exposure")
    define("j-MUTAT-RES-GENETIC-TOXIC-TEST-BIOMON-ENV-OCC-EXPOSURE", "Mutat. res., Genet. toxicol. test.")

    define("j-N-AM-J-FISH-MANAG",		"North American Journal of Fisheries Management")
    define("j-N-AM-J-FISH-MANAG",		"N. Am. J. Fish. Manag.")

    define("j-N-I-A-CR",			"Newsletter of the International Association for Cryptologic Research")
    define("j-NA-DIGEST",			"NA Digest")

    define("j-NACH-DOK",			"Nachrichten f{\\\"u}r Dokumentation")
    define("j-NACH-DOK",			"Nachrichten fur Dokumentation")

    define("j-NACH-ELEK",			"Nachrichtentechnik Elektronik")

    define("j-NACHR-AKAD-WISS-GOTTINGEN-MATH-PHYS-KL-II",	"Nachrichten der Akademie der Wissenschaften zu G{\\\"o}ttingen. II. Mathematisch-Physikalische Klasse")
    define("j-NACHR-AKAD-WISS-GOTTINGEN-MATH-PHYS-KL-II",	"Nachr. Akad. Wiss. G{\\\"o}ttingen Math.-Phys. Kl. II")

    define("j-NACHR-CHEM",			"{Nachrichten aus der Chemie}")
    define("j-NACHR-CHEM",			"Nachrichten aus der Chemie")
    define("j-NACHR-CHEM",			"Nachr. Chem.")
    define("j-NACHR-CHEM",			"{Nachr. Chem.}")

    define("j-NACHR-CHEM-TECH",			"{Nachrichten aus Chemie und Technik}")
    define("j-NACHR-CHEM-TECH",			"{Nachr. Chem. Tech.}")

    define("j-NACHR-CHEM-TECH-LAB",		"Nachrichten aus Chemie, Technik und Laboratorium")
    define("j-NACHR-CHEM-TECH-LAB",		"Nachr. Chem., Tech. Lab.")

    ## issued 1894--1933
    define("j-NACHR-GES-WISS-GOETTINGEN-MATH-PHYS-KL",	"{Nachrichten von der Gesellschaft der Wissenschaften zu G{\\\"o}ttingen. Mathematisch-Physikalische Klasse}")
    define("j-NACHR-GES-WISS-GOETTINGEN-MATH-PHYS-KL",	"{Nachrichten von der Gesellschaft der Wissenschaften zu Goettingen, Mathematisch-Physikalische Klasse}")
    define("j-NACHR-GES-WISS-GOETTINGEN-MATH-PHYS-KL",	"{Nachr. Ges. Wiss. Goettingen, Math.-Phys. Kl.}")

    define("j-NAG-NEWSLETTER",			"NAG Newsletter") # 1979--1991; ceased publication

    define("j-NAMS",				"Notices of the American Mathematical Society")
    define("j-NAMS",				"Notices Amer. Math. Soc.")
    define("j-NAMS",				"Notices of AMS")
    define("j-NAMS",				"American Mathematical Society Notices")

    define("j-NANO-LETT",			"Nano Letters")
    define("j-NANO-LETT",			"Nano Lett.")

    define("j-NANOBIOL",			"Nanobiology")

    define("j-NANOTECHNOL",			"Nanotechnology (Bristol)")
    define("j-NANOTECHNOL",			"Nanotechnology")

    define("j-NASA-CONF-PUBL",			"NASA conference publication")
    define("j-NASA-CONF-PUBL",			"NASA conf. publ.")

    define("j-NASA-TECH-BRIEFS",		"NASA tech briefs")

    define("j-NAT-COMPUT",			"Natural Computing")
    define("j-NAT-COMPUT",			"Nat. Comput.")

    define("j-NAT-J",				"National journal")
    define("j-NAT-J",				"Nat. j.")

    define("j-NAT-INTEREST",			"The National Interest")
    define("j-NAT-INTEREST",			"National Interest")
    define("j-NAT-INTEREST",			"Nat. Interest")

    define("j-NAT-LAMPOON",			"National Lampoon")

    define("j-NAT-PHILOS",			"The Natural Philosopher")
    define("j-NAT-PHILOS",			"The Natural Philosopher: a Series of Volumes Devoted to the History of Physics and to the Influence of Physics on Human Thought and Affairs through the Ages")
    define("j-NAT-PHILOS",			"Nat. Philos.")

    define("j-NAT-RESOUR-MODEL",		"Nat. Resour. Model.")
    define("j-NAT-RESOUR-MODEL",		"Natur. Resource. Modeling")
    define("j-NAT-RESOUR-MODEL",		"Natural Resource Modeling")

    define("j-NAT-REV",				"National Review")
    define("j-NAT-REV",				"Nat. Rev.")

    define("j-NAT-VERDEN",			"Naturens Verden")
    define("j-NAT-VERDEN",			"Nat. Verden")

    define("j-NAT-TECH-REP",			"National Technical Report")

    define("j-NATION",				"The Nation")
    define("j-NATION",				"The Nation (New York, NY)")
    define("j-NATION",				"Nation")

    define("j-NATL-BUR-STAND-CIRC",		"National Bureau of Standards circular")
    define("j-NATL-BUR-STAND-CIRC",		"Natl. Bur. Stand. circ.")
    define("j-NATL-BUR-STAND-CIRC",		"Nat. Bur. Stand. Circ.")

    define("j-NATL-CONF-PUBL-INST-ENG-AUST",	"National Conference Publication --- Institution of Engineers, Australia")
    define("j-NATL-CONF-PUBL-INST-ENG-AUST",	"Natl. Conf. Publ. Inst. Eng. Aust.")

    define("j-NATL-DEF-WASHINGTON",		"National defense (Washington)")
    define("j-NATL-DEF-WASHINGTON",		"Natl. def. (Washington)")
    define("j-NATL-DEF-WASHINGTON",		"National defense")

    define("j-NATL-SCI-REV",			"National Science Review")
    define("j-NATL-SCI-REV",			"Natl. Sci. Rev.")

    define("j-NATO-ASI-B",			"NATO advanced study institutes series. Series B, Physics")
    define("j-NATO-ASI-F",			"NATO ASI series. Series F, Computer and system sciences")

    define("j-NATUR-SCI-J-XIANGTAN-UNIV",	"Natural Science Journal of Xiangtan University = Xiangtan Daxue Ziran Kexue Xuebao")
    define("j-NATUR-SCI-J-XIANGTAN-UNIV",	"Natur. Sci. J. Xiangtan Univ.")

    define("j-NATURE",				"Nature")
    define("j-NATURE",				"Nature (NSC)")
    define("j-NATURE",				"Nature, London")
    define("j-NATURE",				"Nature, Lond.")

    define("j-NATURE-BIOTECH",			"Nature Biotechnology")
    define("j-NATURE-BIOTECH",			"Nature Biotech.")

    define("j-NATURE-CELL-BIOL",		"Nature Cell Biology")
    define("j-NATURE-CELL-BIOL",		"Nature Cell Biol.")
    define("j-NATURE-CELL-BIOL",		"Nat. Cell Biol.")

    define("j-NATURE-CHEM",			"Nature Chemistry")
    define("j-NATURE-CHEM",			"Nature Chem.")
    define("j-NATURE-CHEM",			"Nat. Chem.")

    define("j-NATURE-COMMUN",			"Nature Communications")
    define("j-NATURE-COMMUN",			"Nature Commun.")
    define("j-NATURE-COMMUN",			"Nat. Commun.")

    define("j-NATURE-GENETICS",			"Nature Genetics")
    define("j-NATURE-GENETICS",			"Nature Genet.")
    define("j-NATURE-GENETICS",			"Nat. Genet.")

    define("j-NATURE-GEOSCI",			"Nature Geoscience")
    define("j-NATURE-GEOSCI",			"Nature Geosci.")
    define("j-NATURE-GEOSCI",			"Nat. Geosci.")

    define("j-NATURE-MATER",			"Nature Materials")
    define("j-NATURE-MATER",			"Nat. Mater.")

    define("j-NATURE-METHODS",			"Nature Methods")
    define("j-NATURE-METHODS",			"Nat. Methods")

    define("j-NATURE-NANOTECHNOL",		"Nature Nanotechnology")
    define("j-NATURE-NANOTECHNOL",		"Nature Nanotechnol.")
    define("j-NATURE-NANOTECHNOL",		"Nat. Nanotechnol.")

    define("j-NATURE-NEW-BIOL",			"Nature: New Biology")
    define("j-NATURE-NEW-BIOL",			"Nature: New Biology (London)")
    define("j-NATURE-NEW-BIOL",			"Nature, Lond. (New Biol.)")
    define("j-NATURE-NEW-BIOL",			"Nature, New Biol.")

    define("j-NATURE-PHOTONICS",		"Nature Photonics")
    define("j-NATURE-PHOTONICS",		"Nat. Photonics")

    define("j-NATURE-PHYS-SCI",			"Nature Physical Science")
    define("j-NATURE-PHYS-SCI",			"Nature (London), Physical Science")
    define("j-NATURE-PHYS-SCI",			"Nature Phys. Sci.")
    define("j-NATURE-PHYS-SCI",			"Nature (London), Phys. Sci.")

    define("j-NATURE-PHYSICS",			"Nature Physics")
    define("j-NATURE-PHYSICS",			"Nature Phys.")
    define("j-NATURE-PHYSICS",			"Nat. Phys.")

    define("j-NATURE-REV-CARDIOL",		"Nature Reviews Cardiology")
    define("j-NATURE-REV-CARDIOL",		"Nat. Rev. Cardiol.")

    define("j-NATURE-REV-GENET",		"Nature Reviews Genetics")
    define("j-NATURE-REV-GENET",		"Nature Rev. Genet.")
    define("j-NATURE-REV-GENET",		"Nat. Rev. Genet.")

    define("j-NATURE-REV-MOL-CELL-BIOL",	"Nature Reviews Molecular Cell Biology")
    define("j-NATURE-REV-MOL-CELL-BIOL",	"Nat. Rev. Mol. Cell Biol.")

    define("j-NATURE-REV-NEUROSCI",		"Nature Reviews Neuroscience")
    define("j-NATURE-REV-NEUROSCI",		"Nature Rev. Neurosci.")
    define("j-NATURE-REV-NEUROSCI",		"Nat. Rev. Neurosci.")

    define("j-NATURE-REV-PHYS",			"Nature Reviews Physics")
    define("j-NATURE-REV-PHYS",			"Nature Rev. Phys.")

    define("j-NATURWISS-RUNDSCH",		"Naturwissenschaftliche Rundschau")
    define("j-NATURWISS-RUNDSCH",		"Naturwiss. Rundsch.")
    define("j-NATURWISS-RUNDSCH",		"Naturw. Rundschau")
    define("j-NATURWISS-RUNDSCH",		"Naturwiss. Rdsch.")
    define("j-NATURWISS-RUNDSCH",		"Natw. Rdsch.")
    define("j-NATURWISS-RUNDSCH",		"Natw. Rundsch.")
    define("j-NATURWISS-RUNDSCH",		"Naturw. Rundsch.")

    define("j-NATURWISSENSCHAFTEN",		"Naturwissenschaften")
    define("j-NATURWISSENSCHAFTEN",		"Die Naturwissenschaften")
    define("j-NATURWISSENSCHAFTEN",		"Naturwiss.")

    define("j-NEC-RES-DEV",			"Nippon Electric Company research and development")
    define("j-NEC-RES-DEV",			"NEC research \\& development")
    define("j-NEC-RES-DEV",			"NEC res. dev.")

    define("j-NEC-TECH-J",			"NEC Technical Journal = NEC giho")
    define("j-NEC-TECH-J",			"NEC Technical Journal")
    define("j-NEC-TECH-J",			"NEC giho = NEC technical journal")
    define("j-NEC-TECH-J",			"NEC Tech. J.")

    define("j-NED-TIJDSCHR-NATUURKD",		"Nederlands Tijdschrift voor Natuurkunde")
    define("j-NED-TIJDSCHR-NATUURKD",		"Ned. Tijdschr. Natuurk.")
    define("j-NED-TIJDSCHR-NATUURKD",		"Ned. Tijdschr. Natuurkd.")

    define("j-NEDERLAND-ARCH",			"Nederlandse Archievenblad, Tijdschrift van de Vereniging van Archivarissen in Nederland")
    define("j-NEDERLAND-KUNST-JAARBOEK",	"Nederlands Kunsthistorisch Jaarboek")

    define("j-NETW-HETEROG-MEDIA",		"Networks and Heterogeneous Media (NHM)")
    define("j-NETW-HETEROG-MEDIA",		"Networks and Heterogeneous Media")
    define("j-NETW-HETEROG-MEDIA",		"Netw. Heterog. Media")

    define("j-NETWORK-COMPUTING",		"Network Computing")

    define("j-NETWORK-MANAGE",			"Networking management")
    define("j-NETWORK-MANAGE",			"Netw. manage.")

    define("j-NETWORK-SECURITY",		"Network Security")
    define("j-NETWORK-SECURITY",		"Netw. Secur.")

    define("j-NETWORK-WEEK",                    "Network Week")
    define("j-NETWORK-WORLD",			"Network World")
    define("j-NETWORKS",			"Networks")
    define("j-NEURAL-COMP",			"Neural Computation")
    define("j-NEURAL-NETWORKS",			"Neural Networks")

    define("j-NEURAL-PAR-SCI-COMPUT",		"Neural, Parallel and Scientific Computations")
    define("j-NEURAL-PAR-SCI-COMPUT",		"Neural, Parallel and Scientific Computing")

    define("j-NEUROCOMPUTING",			"Neurocomputing")
    define("j-NEUROIMAGE",			"NeuroImage")
    define("j-NEUROCHEM-RES",			"Neurochem Res (NX9)")
    define("j-NEUROREPORT",                     "Neuroreport.")

    define("j-NEUROSCI-LETT",			"Neuroscience letters")
    define("j-NEUROSCI-LETT",			"Neurosci. Lett.")

    define("j-NEUROSCI-LETT-SUPPL",		"Neuroscience letters. Supplement.")
    define("j-NEUROSCI-LETT-SUPPL",		"Neurosci. Lett., Suppl.")
    define("j-NEUROSCI-LETT-SUPPL",		"Neurosci. Lett. Suppl.")

    define("j-NEUROSCIENCE",			"Neuroscience")
    define("j-NEUROSCIENCE",			"Neurosci.")

    define("j-NEUROSURGERY",			"Neurosurgery")
    define("j-NEUROSURGERY",			"Neurosurg.")

    define("j-NEW-ASTRON",			"New Astronomy")
    define("j-NEW-ASTRON",			"New Astron.")

    define("j-NEW-BIO",				"New Biol (AZH)")
    define("j-NEW-BLACKFRIARS",			"New Blackfriars")
    define("j-NEW-ENGLAND-HIST",		"New England Historical and Genealogical Register")
    define("j-NEW-ENGLAND-J-MED",		"The New England Journal of Medicine")

    define("j-NEW-GEN-COMP",			"New Generation Computing")
    define("j-NEW-GEN-COMP",			"New Generation Comput. (Japan)")

    define("j-NEW-IDEAS-PSYCHOL",		"New Ideas in Psychology")
    define("j-NEW-IDEAS-PSYCHOL",		"New Ideas Psychol.")

    define("j-NEW-J-PHYS",			"New Journal of Physics")
    define("j-NEW-J-PHYS",			"New J. Phys.")

    define("j-NEW-HUNG-Q",			"The New Hungarian Quarterly")
    define("j-NEW-HUNG-Q",			"NHQ: The New Hungarian Quarterly")
    define("j-NEW-HUNG-Q",			"New Hungarian Quarterly")
    define("j-NEW-HUNG-Q",			"New Hung. Q.")

    define("j-NEW-ORLEANS-REV",			"The New Orleans review")

    define("j-NEW-PERSPECT-Q",			"New Perspectives Quarterly: {NPQ}")
    define("j-NEW-PERSPECT-Q",			"New Perspectives Quarterly")
    define("j-NEW-PERSPECT-Q",			"New Perspect. Q.")

    define("j-NEW-REPUBLIC",			"New Republic")
    define("j-NEW-SCIENTIST",			"New Scientist")
    define("j-NEW-STATESMAN-SOC",		"New Statesman Society")

    define("j-NEW-TECH-WORK-EMPLOYMENT",	"New Technology, Work, and Employment")

    define("j-NEW-YORK",			"New York")

    define("j-NEW-YORK-REV-BOOKS",		"New York Review of Books")
    define("j-NEW-YORK-REV-BOOKS",		"The New York Review of Books")
    define("j-NEW-YORK-REV-BOOKS",		"New York Rev. Books")

    define("j-NEW-YORK-TIMES-BOOK-REVIEW",	"New York Times Book Review")

    define("j-NEW-YORK-TIMES-MAGAZINE",		"The New York Times Magazine")
    define("j-NEW-YORK-TIMES-MAGAZINE",		"New York Times Magazine")

    define("j-NEW-YORK-TIMES-SYNDICATE",	"New York Times Syndicate")

    define("j-NEW-YORKER",			"The New Yorker")
    define("j-NEW-YORKER",			"New Yorker")

    define("j-NEW-ZEALAND-J-MATH",		"New Zealand Journal of Mathematics")
    define("j-NEW-ZEALAND-J-MATH",		"New Zealand J. Math.")

    define("j-NEW-ZEALAND-MATH-MAG",		"The New Zealand mathematics magazine")

    define("j-NEW-ZEALAND-SCI-REV",		"New Zealand Science Review")
    define("j-NEW-ZEALAND-SCI-REV",		"N. Z. Sci. Rev")
    define("j-NEW-ZEALAND-SCI-REV",		"New Zealand Sci. Rev")

    define("j-NEWS-3X-400",			"News 3X/400")

    define("j-NEWS-PHYSIOL-SCI",		"News in Physiological Sciences")
    define("j-NEWS-PHYSIOL-SCI",		"News physiol. sci.")

    define("j-NEWSWEEK",			"Newsweek")

    define("j-NEWSL-SCI-TECHNOL-HUMAN-VALUES",	"Newsletter on Science, Technology, \\& Human Values")
    define("j-NEWSL-SCI-TECHNOL-HUMAN-VALUES",	"Newsl. sci., technol. human values")

    define("j-NIEMAN-REP",			"Nieman reports")
    define("j-NIEMAN-REP",			"Nieman rep.")

    define("j-NIEUW-ARCHIEF-WISKUNDE",		"Nieuw Archief voor Wiskunde (Groningen)")
    define("j-NIEUW-ARCHIEF-WISKUNDE",		"Nieuw Archief voor Wiskunde")

    define("j-NIEUW-ARCHIEF-WISKUNDE-4",	"Nieuw Archief voor Wiskunde. Vierde Serie")
    define("j-NIEUW-ARCHIEF-WISKUNDE-4",	"Nieuw Arch. Wisk. (4)")

    define("j-NIEUW-ARCHIEF-WISKUNDE-5",	"Nieuw Archief voor Wiskunde. Vijfde Serie")
    define("j-NIEUW-ARCHIEF-WISKUNDE-5",	"Nieuw Arch. Wisk. (5)")

    define("j-NIKKEI-ELECTRONICS",		"Nikkei Electronics")

    define("j-NIST-SPEC-PUBL",			"NIST special publication")
    define("j-NIST-SPEC-PUBL",			"NIST spec. publ.")

    define("j-NONLINEAR-ANAL",			"Nonlinear Analysis, Theory, Methods and Applications")
    define("j-NONLINEAR-ANAL",			"Nonlinear Analysis")
    define("j-NONLINEAR-ANAL",			"Nonlinear Anal., Theory, Methods and Applications")
    define("j-NONLINEAR-ANAL",			"Nonlinear Anal.")
    define("j-NONLINEAR-ANAL",			"Nonlinear Anal., TMA")
    define("j-NONLINEAR-ANAL",			"Nonlinear Analysis, Theory Methods and Appl.")

    define("j-NONLINEAR-DYN",			"Nonlinear Dynamics")
    define("j-NONLINEAR-DYN",			"Nonlinear Dyn.")

    define("j-NONLINEAR-THEORY-APPL",		"Nonlinear Theory and Its Applications, {IEICE}")
    define("j-NONLINEAR-THEORY-APPL",		"Nonlinear Theory and Its Applications")
    define("j-NONLINEAR-THEORY-APPL",		"Nonlinear Theory Appl.")

    define("j-NONLINEARITY",			"Nonlinearity (Bristol)")
    define("j-NONLINEARITY",			"Nonlinearity")

    define("j-NORDIC-J-COMPUT",			"Nordic Journal of Computing")
    define("j-NORDIC-J-COMPUT",			"Nordic J. Comput.")

    define("j-NORDISK-MATH-TIDSKR",		"Nordisk Matematisk Tidskrift")
    define("j-NORDISK-MATH-TIDSKR",		"Nordisk Mat. Tidskr.")

    define("j-NORMAT",				"Normat: Nordisk matematisk tidskrift")
    define("j-NORMAT",				"Normat")

    ## 1919--1952; then renamed to Nordisk Matematisk Tidskrift
    define("j-NORSK-MAT-TIDSSKR",		"Norsk Matematisk Tidsskrift")
    define("j-NORSK-MAT-TIDSSKR",		"Norsk Mat. Tidsskr.")

    define("j-NOTES-CRAS",			"Notes au Compte-Rendu de l'Academie Des Sciences")
    define("j-NOTES-MLA",			"Notes --- Music Library Association")

    define("j-NOTES-REC-R-SOC-LOND",		"Notes and Records of the Royal Society of London")
    define("j-NOTES-REC-R-SOC-LOND",		"Notes and Records of the Royal Society")
    define("j-NOTES-REC-R-SOC-LOND",		"Notes and Records Roy. Soc. London")
    define("j-NOTES-REC-R-SOC-LOND",		"Notes Rec. Roy. Soc. (London)")
    define("j-NOTES-REC-R-SOC-LOND",		"Notes rec. R. Soc. Lond.")

    define("j-NOTRE-DAME-J-FORM-LOG",		"Notre Dame journal of formal logic")
    define("j-NOTRE-DAME-J-FORM-LOG",		"Notre Dame j. form. log.")

    define("j-NOUS",				"No{\\^u}s")

    define("j-NOUV-REV-FR-HEMATOL",		"Nouvelle revue fran{\\c{c}}aise d'hematologie")
    define("j-NOUV-REV-FR-HEMATOL",		"Nouv. rev. fr. hematol.")
    define("j-NOUV-REV-FR-HEMATOL",		"Nouv. Rev. franc. Hemat.")
    define("j-NOUV-REV-FR-HEMATOL",		"Nouvelle revue francaise d'hematologie")

    define("j-NRL",				"Naval Research Logistics")
    define("j-NRLQ",				"Naval Research Logistics Quarterly")
    define("j-NTG",				"Nederlandstalige {\\TeX} Gebruikersgroep (Dutch-speaking {\\TeX} Users Group)")

    define("j-NTM",				"NTM: Schriftenreihe f{\\\"u}r Geschichte der Naturwissenschaften, Technik und Medizin")
    define("j-NTM",				"NTM: Zeitschrift f{\\\"u}r Geschichte der Naturwissenschaften Technik und Medizin")
    define("j-NTM",				"Zeitschrift f{\\\"u}r Geschichte der Naturwissenschaften Technik und Medizin")
    define("j-NTM",				"NTM, Schriftenr. Gesch. Naturwiss. Tech. Med.")
    define("j-NTM",				"NTM, Z. Gesch. Naturwiss. Tech. Med.")
    define("j-NTM",				"Z. Gesch. Naturwiss. Tech. Med.")

    define("j-NTT-R-D",                         "NTT R\\&D")
    define("j-NTT-R-D",                         "NTT R and D")

    define("j-NUCL-ENERGY",			"Journal of Nuclear Energy (1954)")
    define("j-NUCL-ENERGY",			"J. Nuclear Energy (1954)")
    define("j-NUCL-ENERGY",			"J. Nucl. Energy (1954)")
    define("j-NUCL-ENERGY",			"J. Nucl. Energy")

    define("j-NUCL-ENERGY-PART-A",		"Journal of Nuclear Energy. Part A. Reactor Science")
    define("j-NUCL-ENERGY-PART-A",		"J. Nucl. Energy. Part A. Reactor Science")
    define("j-NUCL-ENERGY-PART-A",		"J. Nucl. Energy. Part A")

    define("j-NUCL-GEOPHYS",			"Nuclear Geophysics")
    define("j-NUCL-GEOPHYS",			"Nuclear Geophys.")
    define("j-NUCL-GEOPHYS",			"Nucl. Geophys.")

    define("j-NUCL-INSTR-METH",			"Nuclear Instruments and Methods")
    define("j-NUCL-INSTR-METH",			"Nucl. Instr. Methods")
    define("j-NUCL-INSTR-METH",			"Nucl. Instr. Meth.")

    define("j-NUCL-INSTRUM-METHODS-PHYS-RES",	"Nuclear Instruments and Methods in Physics Research (Netherlands)")
    define("j-NUCL-INSTRUM-METHODS-PHYS-RES",	"Nuclear Instruments \\& Methods in Physics Research")
    define("j-NUCL-INSTRUM-METHODS-PHYS-RES",	"Nuclear Instruments and Methods in Physics Research")
    define("j-NUCL-INSTRUM-METHODS-PHYS-RES",	"Nucl. Instrum. Methods Phys. Res.")

    define("j-NUCL-INSTRUM-METHODS-PHYS-RES-SECT-A", "Nuclear Instruments and Methods in Physics Research Section A: Accelerators, Spectrometers, Detectors and Associated Equipment")
    define("j-NUCL-INSTRUM-METHODS-PHYS-RES-SECT-A", "Nucl. Instrum. Methods Phys. Res., Sect. A")

    define("j-NUCL-INSTRUM-METHODS-PHYS-RES-SECT-B", "Nuclear Instruments and Methods in Physics Research Section B: Beam Interactions with Materials and Atoms")
    define("j-NUCL-INSTRUM-METHODS-PHYS-RES-SECT-B", "Nucl. Instrum. Methods Phys. Res., Sect. B")

    define("j-NUCL-MED",			"Journal of Nuclear Medicine")
    define("j-NUCL-MED",			"J. Nucl. Med.")
    define("j-NUCL-MED",			"J. Nuclear Med.")

    define("j-NUCL-NEWS",			"Nuclear News")
    define("j-NUCL-NEWS",			"Nucl. News")

    define("j-NUCL-PHYS",			"Nuclear Physics")
    define("j-NUCL-PHYS",			"Nuclear Phys.")
    define("j-NUCL-PHYS",			"Nucl. Phys.")

    define("j-NUCL-PHYS-A",			"Nuclear Physics A")
    define("j-NUCL-PHYS-A",			"Nucl. Phys. A")

    define("j-NUCL-PHYS-B",			"Nuclear Physics B")
    define("j-NUCL-PHYS-B",			"Nucl. Phys. B")
    define("j-NUCL-PHYS-B",			"Nuclear Phys. B")

    define("j-NUCL-PHYS-B-PROC-SUPPL",		"Nuclear Physics B, Proceedings Supplements")
    define("j-NUCL-PHYS-B-PROC-SUPPL",		"Nuclear Physics B --- Proceedings Supplements")
    define("j-NUCL-PHYS-B-PROC-SUPPL",		"Nucl. Phys. B, Proc. Suppl.")

    define("j-NUCL-SCI-ENG",			"Nuclear Science and Engineering")
    define("j-NUCL-SCI-ENG",			"Nucl. sci. eng.")
    define("j-NUCL-SCI-ENG",			"Nucl. Sci. Engng.")
    define("j-NUCL-SCI-ENG",			"Nuclear science and engineering: the journal of the American Nuclear Society")

    define("j-NUCL-TECHNOL",			"Nuclear Technology")
    define("j-NUCL-TECHNOL",			"Nucl. Technol.")
    define("j-NUCL-TECHNOL",			"Nucl. Tech.")

    define("j-NUCLEAR-INSTR-METH-PHYS-RES-A",	"Nuclear instruments and methods in physics research. Section A, Accelerators, spectrometers, detectors and associated equipment")
    define("j-NUCLEAR-SAFETY",			"Nuclear safety")

    define("j-NUCLEIC-ACIDS-RES",		"Nucleic Acids Research")
    define("j-NUCLEIC-ACIDS-RES",		"Nucleic Acids Res.")
    define("j-NUCLEIC-ACIDS-RES",		"Nucl. Acid Res.")
    define("j-NUCLEIC-ACIDS-RES",		"Nucl. Acids Res.")
    define("j-NUCLEIC-ACIDS-RES",		"Nucl. Acids. Res.")
    define("j-NUCLEIC-ACIDS-RES",		"Nucleic Acids Res (O8L)")

    define("j-NUM-LIN-ALG-APPL",		"Numerical Linear Algebra with Applications")
    define("j-NUM-LIN-ALG-APPL",		"Numer. Linear Algebra Appl.")

    define("j-NUM-MATH",			"Numerische Mathematik")
    define("j-NUM-MATH",			"Numer. Math.")
    define("j-NUM-MATH",			"Num. Math")
    define("j-NUM-MATH",			"Num. Math.")
    define("j-NUM-MATH",			"Numer. Math")

    define("j-NUMER-ALGEBRA-CONTROL-OPTIM",	"Numerical Algebra, Control and Optimization")
    define("j-NUMER-ALGEBRA-CONTROL-OPTIM",	"Numer. Algebra Control Optim.")

    define("j-NUMER-ALGORITHMS",		"Numerical Algorithms")
    define("j-NUMER-ALGORITHMS",		"Numer. Algorithms")
    define("j-NUMER-ALGORITHMS",		"Numer. Algor.")

    define("j-NUMER-FUNCT-ANAL-OPTIM",		"Numerical Functional Analysis and Optimization")
    define("j-NUMER-FUNCT-ANAL-OPTIM",		"Numer. funct. anal. optim.")
    define("j-NUMER-FUNCT-ANAL-OPTIM",		"Numer. Func. Anal. Opt.")

    define("j-NUMER-HEAT-TRANSFER-B",		"Numerical Heat Transfer, Part B (Fundamentals)")
    define("j-NUMER-HEAT-TRANSFER-B",		"Numer. Heat Transfer B")

    define("j-NUM-MATH-THEORY-METHODS-APPL",	"Numerical Mathematics. Theory, Methods and Applications")
    define("j-NUM-MATH-THEORY-METHODS-APPL",	"Numer. Math. Theory Methods Appl.")

    define("j-NUMER-METHODS-PARTIAL-DIFFER-EQU","Numerical Methods for Partial Differential Equations")
    define("j-NUMER-METHODS-PARTIAL-DIFFER-EQU","Numer. Methods Partial Differ. Equations")
    define("j-NUMER-METHODS-PARTIAL-DIFFER-EQU","Numer. Methods Partial Differential Equations")
    define("j-NUMER-METHODS-PARTIAL-DIFFER-EQU","Numer. methods partial differ. equ.")

    define("j-NUNCIUS",				"Nuncius")
    define("j-NUNCIUS",				"Nuncius / Istituto e museo di storia della scienza")
    define("j-NUNCIUS",				"Nuncius")

    ### From http://www.math.utah.edu/pub/bibnet/authors/f/fermi-enrico.bib:
    ###
    ### Il Nuovo Cimento archive: http://www.springerlink.com/content/120827/
    ###
    ### Il Nuovo Cimento was published between 1855 and 1965 in 10 series,
    ### divided as follows, with volume numbering beginning from 1 in each
    ### series:
    ###
    ### series  1: (1855--1868);
    ### series  2: (1869--1876);
    ### series  3: (1877--1894);
    ### series  4: (1895--1900);
    ### series  5: (1901--1910);
    ### series  6: (1911--1922);
    ### series  7: (1923)
    ### series  8: (1924--1942);
    ### series  9: (1943--1954);
    ### series 10: (1955--1965).
    ###
    ### In 1965, the journal was split into Nuovo Cimento Section A and
    ### Section B, available at Section A and Section B.

    define("j-NUOVO-CIMENTO-1",			"Il Nuovo Cimento (1)")
    define("j-NUOVO-CIMENTO-1",			"Il Nuovo Cimento (1855--1868)")
    define("j-NUOVO-CIMENTO-1",			"Nuovo Cimento (1)")

    define("j-NUOVO-CIMENTO-2",			"Il Nuovo Cimento (2)")
    define("j-NUOVO-CIMENTO-2",			"Il Nuovo Cimento (1869--1876)")
    define("j-NUOVO-CIMENTO-2",			"Nuovo Cimento (2)")

    define("j-NUOVO-CIMENTO-3",			"Il Nuovo Cimento (3)")
    define("j-NUOVO-CIMENTO-3",			"Il Nuovo Cimento (1877--1894)")
    define("j-NUOVO-CIMENTO-3",			"Nuovo Cimento (3)")

    define("j-NUOVO-CIMENTO-4",			"Il Nuovo Cimento (4)")
    define("j-NUOVO-CIMENTO-4",			"Il Nuovo Cimento (1895--1900)")
    define("j-NUOVO-CIMENTO-4",			"Nuovo Cimento (4)")

    define("j-NUOVO-CIMENTO-5",			"Il Nuovo Cimento (5)")
    define("j-NUOVO-CIMENTO-5",			"Il Nuovo Cimento (1901--1910)")
    define("j-NUOVO-CIMENTO-5",			"Nuovo Cimento (5)")

    define("j-NUOVO-CIMENTO-6",			"Il Nuovo Cimento (6)")
    define("j-NUOVO-CIMENTO-6",			"Il Nuovo Cimento (1911--1923)")
    define("j-NUOVO-CIMENTO-6",			"Nuovo Cimento (6)")

    define("j-NUOVO-CIMENTO-7",			"Il Nuovo Cimento (7)")
    define("j-NUOVO-CIMENTO-7",			"Il Nuovo Cimento (1923)")
    define("j-NUOVO-CIMENTO-7",			"Nuovo Cimento (7)")

    define("j-NUOVO-CIMENTO-8",			"Il Nuovo Cimento (8)")
    define("j-NUOVO-CIMENTO-8",			"Il Nuovo Cimento (1924--1942)")
    define("j-NUOVO-CIMENTO-8",			"Nuovo Cimento (8)")

    define("j-NUOVO-CIMENTO-9",			"Il Nuovo Cimento (9)")
    define("j-NUOVO-CIMENTO-9",			"Il Nuovo Cimento (1943--1953)")
    define("j-NUOVO-CIMENTO-9",			"Nuovo Cimento (9)")

    define("j-NUOVO-CIMENTO-10",		"Il Nuovo Cimento (10)")
    define("j-NUOVO-CIMENTO-10",		"Il Nuovo Cimento (1955--1965)")
    define("j-NUOVO-CIMENTO-10",		"Nuovo Cimento (10)")

#    define("j-NUOVO-CIMENTO-1955-1965",		"Il Nuovo Cimento (1955--1965)")
#    define("j-NUOVO-CIMENTO-1955-1965",		"Nuovo Cimento (1955--1965)")

    define("j-NUOVO-CIMENTO-A",			"Il Nuovo Cimento A")
    define("j-NUOVO-CIMENTO-A",			"Il Nuovo Cimento A Series 11")

    define("j-NUOVO-CIMENTO-B",			"Il Nuovo Cimento B Series 11")
    define("j-NUOVO-CIMENTO-B",			"Il Nuovo Cimento B")
    define("j-NUOVO-CIMENTO-B",			"Nuovo Cimento [Sezione] B")
    define("j-NUOVO-CIMENTO-B",			"Nuovo Cimento B")

    define("j-NUOVO-CIMENTO-B-11",		"Il Nuovo Cimento B (11)")
    define("j-NUOVO-CIMENTO-B-11",		"Nuovo Cimento B (11)")
    define("j-NUOVO-CIMENTO-B-11",		"Il Nuovo Cimento B (1971--1996)")
    define("j-NUOVO-CIMENTO-B-11",		"Nuovo Cimento B (1971--1996)")

    define("j-NUOVO-CIMENTO-D",			"Nuovo Cimento della Societa Italiana di Fisica, D: Condensed Matter, Atomic, Molecular and Chemical Physics, Fluids, Plasmas, Biophysics")
    define("j-NUOVO-CIMENTO-D",			"Il Nuovo Cimento D")
    define("j-NUOVO-CIMENTO-D",			"Nuovo Cimento Soc. Ital. Fis., D")

    define("j-NUOVO-CIMENTO-SOC-ITAL-FIS-B",	"Nuovo Cimento della Societa Italiana di Fisica B --- General Physics Relativity Astronomy and Mathematical Physics and Methods")
    define("j-NUOVO-CIMENTO-SOC-ITAL-FIS-B",	"Nuovo Cimento della Societa Italiana di Fisica, B: General Physics, Relativity, Astronomy, and Plasmas")
    define("j-NUOVO-CIMENTO-SOC-ITAL-FIS-B",	"Nuovo Cimento Soc. Ital. Fis., B")

    define("j-NUOVO-CIMENTO-SUPPL",		"Nuovo Cimento, Supplemento")
    define("j-NUOVO-CIMENTO-SUPPL",		"Nuovo Cimento (Supplemento)")
    define("j-NUOVO-CIMENTO-SUPPL",		"Nuovo Cimento, Suppl.")

    define("j-NUOVO-SAGGIATORE",		"Il Nuovo Saggiatore") # == "The new assayer"
    define("j-NUOVO-SAGGIATORE",		"Il Nuovo Saggiatore: Bollettino della {Societ{\\`a} italiana di fisica}")
    define("j-NUOVO-SAGGIATORE",		"Nuovo sag.")

    define("j-NY-TIMES",			"New York Times")

    define("j-OAK-RIDGER",			"The {Oak Ridger}")
    define("j-OAK-RIDGER",			"{Oak Ridger}")

    define("j-OBIT-NOTICES-FELLOWS-ROY-SOC",	"Obituary Notices of Fellows of the Royal Society")
    define("j-OBIT-NOTICES-FELLOWS-ROY-SOC",	"Obit. Notices Fellows Roy. Soc.")
    define("j-OBIT-NOTICES-FELLOWS-ROY-SOC",	"Obit. Not. R. Soc. Lond")

    define("j-OBJECT-EXPERT",			"Object Expert")

    define("j-OBJECT-MAG",			"Object Magazine")
    define("j-OBJECT-MAG",			"Object Mag.")

    define("j-OBSERVATORY",			"The Observatory")
    define("j-OBSERVATORY",			"Observatory")

    define("j-OBZORNIK-MAT-FIZ",		"Obzornik Mat. Fiz.")
    define("j-OBZORNIK-MAT-FIZ",		"Dru{\\v{s}}tvo Matematikov, Fizikov in Astronomov SRS. Obzornik za Matematiko in Fiziko")

    define("j-OCEAN",				"Oceans Conference Record (IEEE)")
    define("j-OCEAN",				"Ocean")

    define("j-OCLC-MICRO",			"OCLC Micro")
    define("j-OCLC-NEWSLETTER",			"OCLC Newsletter")
    define("j-OCTOBER",				"October")

    define("j-OCTOGON-MATH-MAG",		"Octogon Mathematical Magazine")
    define("j-OCTOGON-MATH-MAG",		"Octogon Math. Mag.")

    define("j-OECOLOGIA",			"Oecologia")

    define("j-OFF-OUR-BACKS",			"Off our backs")
    define("j-OFFICE-SYS",			"Office systems: the magazine for small and medium offices")
    define("j-OIKOS",				"Oikos")
    define("j-OIL-GAS-INVESTOR",		"Oil \\& gas investor")
    define("j-OIL-GAS-J",			"The Oil and Gas Journal")

    define("j-OHIO-J-SCI",			"Ohio Journal of Science")
    define("j-OHIO-J-SCI",			"Ohio J. Sci.")

    define("j-OMEGA",				"OMEGA")

    define("j-ONCOGENE",			"Oncogene")
    define("j-ONCOGENE",			"Oncogene (ONC)")

    define("j-ONLINE",				"Online")

    define("j-ONLINE-CDROM-REV",		"Online \\& CDROM review: the international journal of online \\& optical information systems")
    define("j-ONLINE-CDROM-REV",		"Online \\& CDROM review")
    define("j-ONLINE-CDROM-REV",		"Online & CDROM review")
    define("j-ONLINE-CDROM-REV",		"Online CDROM rev.")

    define("j-OOPS-MESSENGER",			"OOPS Messenger")
    define("j-OPEN-COMPUTING",			"Open Computing")

    define("j-OPEN-J-DISCRETE-MATH",		"Open Journal of Discrete Mathematics")
    define("j-OPEN-J-DISCRETE-MATH",		"Open J. Discrete Math.")

    define("j-OPEN-SYSTEMS-TODAY",		"Open Systems Today")
    define("j-OPEN-SYSTEMS-TODAY",		"Open Systems Today: The Newspaper of UNIX and Open Computing")

    define("j-OPER-MATRICES",			"Operators and Matrices")
    define("j-OPER-MATRICES",			"Oper. Matrices")

    define("j-OPER-RES",			"Operations Research")
    define("j-OPER-RES",			"Operations Res.")
    define("j-OPER-RES",			"Oper. Res.")
    define("j-OPER-RES",			"Op. Res.")

    define("j-OPER-RES-LETT",			"Operations Research Letters")

    define("j-OPER-RES-VERFAHREN",		"{Operations Research-Verfahren}")
    define("j-OPER-RES-VERFAHREN",		"{Operations Research Verfahren}")
    define("j-OPER-RES-VERFAHREN",		"Op. Res. Verfahren")
    define("j-OPER-RES-VERFAHREN",		"Oper. Res.-Verfahren")

    define("j-OPER-SYS-REV",			"Operating Systems Review")
    define("j-OPER-SYS-REV",			"ACM SIGOPS Operating Systems Review")
    define("j-OPER-SYS-REV",			"Operating Systems Review (ACM)")
    define("j-OPER-SYS-REV",			"Oper. syst. rev.")
    define("j-OPER-SYS-REV",			"Operating Systems Review, SIGOPS")

    define("j-OPT-COMM",			"Optics Communications")
    define("j-OPT-COMM",			"Opt. Commun.")

    define("j-OPT-CTL-APPL-METH",		"Optimal Control Applications and Methods")
    define("j-OPT-CTL-APPL-METH",		"Optimal Control Appl. Meth.")
    define("j-OPT-CTL-APPL-METH",		"Optim. Control Appl. Methods")
    define("j-OPT-CTL-APPL-METH",		"Optimal Control Appl. Methods")

    define("j-OPT-EXPRESS",			"Optics Express")
    define("j-OPT-EXPRESS",			"Opt. Express")

    define("j-OPT-LET",				"Optics Letters")
    define("j-OPT-LET",				"Opt. Lett.")

    define("j-OPTICA",				"Optica")
    define("j-OPTICA-ACTA",			"Optica Acta")

    define("j-OPTICAL-ENG",			"Optical Engineering")
    define("j-OPTICAL-ENG",			"Optical Eng.")
    define("j-OPTICAL-ENG",			"Opt. Eng.")

    # V. [1]--15 ; Feb. 1975--Dec. 1989.  Succeeded by Optics & Photonics News
    define("j-OPTICS-NEWS",			"Optics News")

    # Issues for Feb. 1990-<June 2004> have title: Optics & Photonics News
    # but & becomes "and" in later issues
    define("j-OPTICS-PHOTONICS-NEWS",		"Optics and Photonics News")
    define("j-OPTICS-PHOTONICS-NEWS",		"Optics \\& Photonics News")

    define("j-OPTICAL-QUANTUM-ELECT",		"Optical and Quantum Electronics")
    define("j-OPTIK",				"Optik")

    define("j-OPTIM-ENG",			"Optimization and Engineering")
    define("j-OPTIM-ENG",			"Optimization and Engineering. International Multidisciplinary Journal to Promote Optimization Theory \\& Applications in Engineering Sciences")
    define("j-OPTIM-ENG",			"Optim. Eng.")

    define("j-OPTIM-LETT",			"Optimization Letters")
    define("j-OPTIM-LETT",			"Optim. Lett.")

    define("j-OPTIM-METHODS-SOFTW",		"Optimization Methods and Software")
    define("j-OPTIM-METHODS-SOFTW",		"Optimization Methods \\& Software")
    define("j-OPTIM-METHODS-SOFTW",		"Optim. Methods Softw.")
    ## define("j-OPTIM-METHODS-SOFTW",		"Optimization Methods and their Applications")

    define("j-OPTIMIZATION",			"Optimization")
    define("j-OPTIMIZATION",			"Mathematische Operationsforschung und Statistik. Series optimization")
    define("j-OPTIMIZATION",			"Mathematische Operationsforschung und Statistik. Series optimization 1977-")
    define("j-OPTIMIZATION",			"Math. Operationsforsch. Statist. Ser. Optim.")

    define("j-OPTIMIZATSIIA",			"Optimizatsiya")
    define("j-OPTIMIZATSIIA",			"Optimizacija")
    define("j-OPTIMIZATSIIA",			"Optimizatsiia")

    define("j-OPUSCULA-ROMANA",			"Opuscula Romana")
    define("j-ORACLE-INTEGRATOR",		"Oracle Integrator")

    define("j-ORDER-DORDRECHT",			"Order (Dordrecht)")
    define("j-ORDER-DORDRECHT",			"Order")

    define("j-ORG-BEHAV-HUM-DECIS-PROCESS",	"Organizational Behavior and Human Decision Processes")
    define("j-ORG-BEHAV-HUM-DECIS-PROCESS",	"Org. Behav. Hum. Decis. Process.")

    define("j-ORG-GEOCHEM",			"Organic Geochemistry")
    define("j-ORG-GEOCHEM",			"Org. Geochem.")

    define("j-ORGAN-DYN",			"Organizational Dynamics")
    define("j-ORGAN-DYN",			"Organ. Dyn.")

    define("j-ORIG-LIFE-EVOL-BIOSPH",		"Origins of Life and Evolution of the Biosphere")
    define("j-ORIG-LIFE-EVOL-BIOSPH",		"Orig. Life Evol. Biosph.")

    define("j-ORSA-J-COMPUT",			"ORSA Journal on Computing")
    define("j-ORSA-J-COMPUT",			"ORSA J. Comput.")

    define("j-OSIRIS",				"Osiris")
    define("j-OSIRIS",				"Osiris: a research journal devoted to the history of science and its cultural influences")
    define("j-OSIRIS",				"Osiris: a research journal devoted to the history of science and its cultural influences; a publication of the History of Science Society (1936)")
    define("j-OSIRIS",				"Osiris: a research journal devoted to the history of science and its cultural influences; Second series")
    define("j-OSIRIS",				"Osiris (Chicago, IL)")
    define("j-OSIRIS",				"Osiris (Philadelphia, PA)")
    define("j-OSIRIS",				"Osiris (Bruges)")
    define("j-OSIRIS",				"Osiris (Bruges, Belgium)")
    define("j-OSIRIS-2",			"Osiris (Series 2)")

    define("j-OTOLARYNGOL-CLIN-NORTH-AM",	"The Otolaryngologic clinics of North America")
    define("j-OTOLARYNGOL-CLIN-NORTH-AM",	"Otolaryngol. clin. North Am.")

    define("j-OUD-HOLLAND",			"Oud Holland")

    define("j-OVERS-DAN-VIDENSK-SELSK-VIRKS",	"Oversigt over det Kongelige Danske Videnskabernes Selskabs Virksomhed")
    define("j-OVERS-DAN-VIDENSK-SELSK-VIRKS",	"Overs. Dan. Vidensk. Selsk. Virks.")

    define("j-OXF-SURV-EVOL-BIOL",		"Oxford surveys in evolutionary biology")
    define("j-OXF-SURV-EVOL-BIOL",		"Oxf. surv. evol. biol.")

    define("j-PAC-HIST-REV",			"Pacific Historical Review")
    define("j-PAC-HIST-REV",			"Pac. Hist. Rev.")

    define("j-PAC-J-APPL-MATH",			"Pacific Journal of Applied Mathematics")
    define("j-PAC-J-APPL-MATH",			"Pac. J. Appl. Math.")

    define("j-PAC-J-MATH",			"Pacific Journal of Mathematics")
    define("j-PAC-J-MATH",			"Pacific J. Math.")
    define("j-PAC-J-MATH",			"Pac. J. Math.")

    define("j-PAC-NORTHWEST-Q",			"Pacific Northwest Quarterly")
    define("j-PAC-NORTHWEST-Q",			"Pac. Northwest Q.")

    define("j-PACE",				"Pacing and clinical electrophysiology: PACE")
    define("j-PACE",				"PACE")
    define("j-PACE",				"Pacing and clinical electrophysiology")

    define("j-PACMPL",				"Proceedings of the ACM on Programming Languages (PACMPL)")
    define("j-PACMPL",				"Proceedings of the ACM on Programming Languages")
    define("j-PACMPL",				"Proc. ACM Prog. Lang.")

    define("j-PAMM",				"Proceedings in Applied Mathematics and Mechanics")
    define("j-PAMM",				"PAMM")

    define("j-PAP-REG-SCI",			"Papers in Regional Science")
    define("j-PAP-REG-SCI",			"Papers Reg. Sci.")

    define("j-PARALLEL-ALGORITHMS-APPL",	"Parallel Algorithms and Applications")
    define("j-PARALLEL-ALGORITHMS-APPL",	"Parallel algorithms appl.")

    define("j-PARALLEL-COMPUTING",		"Parallel Computing")
    define("j-PARALLEL-COMPUTING",		"Parallel Comput.")
    define("j-PARALLEL-COMPUTING",		"Parallel Comput. (Netherlands), Parallel Computing")

    # Journal Web site: http://www.cs.okstate.edu/~pdcp/
    define("j-PARALLEL-DIST-COMP-PRACT",	"PDCP: Parallel and Distributed Computing Practices")
    define("j-PARALLEL-DIST-COMP-PRACT",	"Parallel and Distributed Computing Practices")
    define("j-PARALLEL-DIST-COMP-PRACT",	"Parallel Dist. Comput. Pract.")

    define("j-PARALLEL-PROCESS-LETT",		"Parallel Processing Letters")
    define("j-PARALLEL-PROCESS-LETT",		"Parallel Process. Lett.")
    define("j-PARALLEL-PROCESS-LETT",		"Parallel Process. Lett. (Singapore), Parallel Processing Letters")

    define("j-PARALLELOGRAM",			"Parallelogram")

    define("j-PATTERN-RECOGN",			"Pattern Recognition")
    define("j-PATTERN-RECOGN-LETT",		"Pattern Recognition Letters")

    define("j-PC-COMPUTING",			"PC\\slash Computing")
    define("j-PC-COMPUTING",			"PC/Computing")

    define("j-PC-KURIER",			"PC Kurier (Warsaw)")
    define("j-PC-KURIER",			"PCkurier")

    define("j-PC-MAGAZINE",			"PC Magazine")
    define("j-PC-MAGAZINE",			"PC magazine: the independent guide to IBM-standard personal computing")
    define("j-PC-MAGAZINE",			"PC magazine: the independent guide to IBM-stan")

    define("j-PC-PUB",				"PC Publishing")
    define("j-PC-PUB",				"PC Publ.")

    define("j-PC-PUBL-PRESENT",			"PC Publishing and Presentations")
    define("j-PC-PUBL-PRESENT",			"PC publ. present.")

    define("j-PC-TECH-J",			"PC Tech Journal")
    define("j-PC-TECH-J",			"PC Tech J.")

    define("j-PC-TECH",				"PC Techniques")
    define("j-PC-TECH",				"PC tech.")

    define("j-PC-USER",                         "PC User")
    define("j-PC-WEEK",				"PC Week")
    define("j-PC-WORLD",			"PC World")

    ## OBSOLETE: define("j-PDCP",				"PDCP: Parallel and Distributed Computing Practices")
    ## OBSOLETE: define("j-PDCP",				"Parallel and Distributed Computing Practices")

    define("j-PEDIATRIC-RES",			"Pediatric Research")
    define("j-PEDIATRIC-RES",			"Pediatric Res.")

    define("j-PENTAGON",			"The Pentagon")
    define("j-PERCEPTION-PSYCHOPHYSICS",	"Perception \\& Psychophysics")
    define("j-PERCEPTUAL-MOTOR-SKILLS",		"Perceptual and Motor Skills")
    define("j-PERF-EVAL",			"Performance evaluation")

    define("j-PERF-EVAL-REV",			"Performance evaluation review: a quarterly publication of the Special Interest Committee on Measurement and Evaluation")
    define("j-PERF-EVAL-REV",			"ACM SIGMETRICS Perform. Eval. Rev")
    define("j-PERF-EVAL-REV",			"Performance Evaluation Review")
    define("j-PERF-EVAL-REV",			"Performance evaluation review")
    define("j-PERF-EVAL-REV",			"Perform. Eval. Rev.")

    define("j-PERFORM-COMPUT",			"Performance Computing")
    define("j-PERFORM-COMPUT",			"Performance Computing (formerly, UNIX Review)")
    define("j-PERFORM-COMPUT",			"Perform. Comput.")

    define("j-PERFORM-INSTR",			"Performance + Instruction")
    define("j-PERFORM-INSTR",			"Perform. Instr.")

    define("j-PERFORM-INSTR-J",			"Performance \\& Instruction Journal")
    define("j-PERFORM-INSTR-J",			"Performance and Instruction")
    define("j-PERFORM-INSTR-J",			"Perform. Instr. J.")

    define("j-PERIOD-MATH-HUNGAR",		"Periodica Mathematica Hungarica")
    define("j-PERIOD-MATH-HUNGAR",		"Period. Math. Hungar.")

    define("j-PERS-COMP",			"Personal Computing")

    define("j-PERS-COMPUT-WORLD",		"Personal computer world")

    define("j-PERSPECT-SCI",			"Perspectives on Science")
    define("j-PERSPECT-SCI",			"Perspectives on Science: Historical, Philosophical, Social")
    define("j-PERSPECT-SCI",			"Perspect. Sci.")

    define("j-PERSPECT-SCI-CHRIST-FAITH",	"Perspectives on Science and {Christian} Faith")
    define("j-PERSPECT-SCI-CHRIST-FAITH",	"Perspectives on Science and {Christian} Faith: journal of the {American Scientific Affiliation}")
    define("j-PERSPECT-SCI-CHRIST-FAITH",	"Perspect. Sci. Christ. Faith")

    define("j-PERSPECTIVES-BIO-MED",		"Perspectives in Biology and Medicine")

    define("j-PESC-RECORD",			"PESC record")
    define("j-PESC-RECORD",			"Power Electronics Specialists Conference record")

    define("j-PFLUGERS-ARCH",			"Pfl{\\\"u}gers Archiv: European journal of physiology")
    define("j-PFLUGERS-ARCH",			"Pflugers Archiv: European journal of physiology")
    define("j-PFLUGERS-ARCH",			"Pflugers Arch. - Eur. J. Physiol.")
    define("j-PFLUGERS-ARCH",			"Pflugers Arch.")
    define("j-PFLUGERS-ARCH",			"Pflugers Arch (OZX)")
    define("j-PFLUGERS-ARCH",			"Pfl{\\\"u}gers Arch.")

    define("j-PHARM-J",				"Pharmaceutical journal")
    define("j-PHARM-J",				"Pharmaceutical journal.  London")
    define("j-PHARM-J",				"Pharm. j. (1933)")
    define("j-PHARM-J",				"Pharm. j.")

    define("j-PHARM-RES",			"Pharmaceutical research")
    define("j-PHARM-RES",			"Pharm. res.")

    define("j-PHARMACOL-THER-OXF",		"Pharmacology and therapeutics")
    define("j-PHARMACOL-THER-OXF",		"Pharmacol. ther.")
    define("j-PHARMACOL-THER-OXF",		"Pharmacol. ther. (Oxf.).")

    define("j-PHARMAZIE",			"Die Pharmazie")
    define("j-PHARMAZIE",			"Pharmazie (P4D)")

    define("j-PHASE-TRANSIT",			"Phase transitions")
    define("j-PHASE-TRANSIT",			"Phase transit.")

    define("j-PHIL-MAGAZINE-5",			"Philosophical Magazine (5)")
    define("j-PHIL-MAGAZINE-5",			"Philosophical Magazine (series 5)")
    define("j-PHIL-MAGAZINE-5",			"Philos. Mag. (5)")
    define("j-PHIL-MAGAZINE-5",			"Philos. Mag. (series 5)")

    define("j-PHIL-MAGAZINE-6",			"Philosophical Magazine (6)")
    define("j-PHIL-MAGAZINE-6",			"Philosophical Magazine (series 6)")
    define("j-PHIL-MAGAZINE-6",			"Philos. Mag. (6)")
    define("j-PHIL-MAGAZINE-6",			"Philos. Mag. (series 6)")

    define("j-PHILIPS-J-RES",			"Philips Journal of Research")
    define("j-PHILIPS-J-RES",			"Philips J. Res.")
    define("j-PHILIPS-J-RES",			"Philips J. of Research")

    ##	Continued as
    ##
    ##	    Philosophical Magazine A (1978 - 2002)
    ##	    Philosophical Magazine Part B (1978 - 2002)
    ##
    ##	Formerly known as
    ##
    ##	    Philosophical Magazine (1956 - 1977)
    ##	    Philosophical Magazine Series 7 (1926 - 1955)
    ##	    Philosophical Magazine Series 6 (1901 - 1925)
    ##	    Philosophical Magazine Series 5 (1876 - 1900)
    ##	    Philosophical Magazine Series 4 (1851 - 1875)
    ##	    Philosophical Magazine Series 3 (1832 - 1850)
    ##	    Philosophical Magazine Series 2 (1827 - 1832)
    ##	    Philosophical Magazine Series 1 (1798 - 1826)

    define("j-PHILOS-MAG",			"Philosophical Magazine")
    define("j-PHILOS-MAG",			"Philosophical Magazine (London, England: 1945)")
    define("j-PHILOS-MAG",			"Philos. Mag.")
    define("j-PHILOS-MAG",			"Phil. Mag.")

    define("j-PHILOS-MAG-4",			"Philosophical Magazine (Series 4 (1851--1875))")
    define("j-PHILOS-MAG-4",			"Philos. Mag. Ser 4")

    define("j-PHILOS-MAG-6",			"Philosophical Magazine Series 6")
    define("j-PHILOS-MAG-6",			"Philos. Mag. Ser. 6")
    define("j-PHILOS-MAG-6",			"Philos. Mag., VI. Ser.")

    define("j-PHILOS-MAG-7",			"Philosophical Magazine Series 7 (1926--1955)")
    define("j-PHILOS-MAG-7",			"Philosophical Magazine Series 7")
    define("j-PHILOS-MAG-7",			"Philos. Mag. Ser. 7")
    define("j-PHILOS-MAG-7",			"Philos. Mag., VII. Ser.")

    define("j-PHILOS-MAG-8",			"Philosophical Magazine Series 8 (1956--1977)")
    define("j-PHILOS-MAG-8",			"Philosophical Magazine Series 8")
    define("j-PHILOS-MAG-8",			"Philos. Mag. Ser. 8")
    define("j-PHILOS-MAG-8",			"Philos. Mag., VIII. Ser.")

    define("j-PHILOS-MAG-A",			"Philosophical Magazine A: Physics of Condensed Matter: Structure, Defects and Mechanical Properties")
    define("j-PHILOS-MAG-A",			"Philosophical Magazine A")
    define("j-PHILOS-MAG-A",			"Phil. Mag. A")
    define("j-PHILOS-MAG-A",			"Philos. Mag. A")

    define("j-PHILOS-MAG-B",			"Philosophical Magazine B: Physics of Condensed Matter: Statistical Mechanics, Electronic, Optical and Magnetic Properties")
    define("j-PHILOS-MAG-B",			"Philosophical Magazine B: Physics of Condensed Matter: Statistical")
    define("j-PHILOS-MAG-B",			"Philosophical Magazine B")
    define("j-PHILOS-MAG-B",			"Philos. Mag. B")

    define("j-PHILOS-MAG-LETT",			"Philosophical Magazine Letters")
    define("j-PHILOS-MAG-LETT",			"Philos. Mag. Lett.")

    define("j-PHILOS-MATH-3",			"Philosophia Mathematica. Series III")
    define("j-PHILOS-MATH-3",			"Philos. Math. (3)")
    define("j-PHILOS-MATH-3",			"Philosophia Mathematica. Philosophy of Mathematics, its Learning, and its Applications. Series III")

    ## 50 volumes illustrations 24 cm Some vols. and no. combined. One
    ## vol. every 3 years, 1950-<54> Irregular, 1950-<54>, Quarterly,
    ## 19<73->, 2 no. a year, -2013 Vol. 25 (1988). Continued without
    ## ISSN changes as Philosophia Naturalis. Journal for the
    ## Philosophy of Nature (v26 1989 to v50 2013, publication ceased)
    define("j-PHILOS-NATUR",			"Philosophia Naturalis")
    define("j-PHILOS-NATUR",			"Philosophia Naturalis. Archiv f{\\\"u}r Naturphilosophie und die Philosophischen Grenzgebiete der Exakten Wissenschaften und Wissenschaftsgeschichte")
    define("j-PHILOS-NATUR",			"Philos. Natur.")

    define("j-PHILOS-PHENOMENOL-RES",		"Philosophy and Phenomenological Research")
    define("j-PHILOS-PHENOMENOL-RES",		"Philos. Phenomenol. Res.")

    define("j-PHILOS-PSYCHOL",			"Philosophical Psychology")
    define("j-PHILOS-PSYCHOL",			"Phil. Psych.")
    define("j-PHILOS-PSYCHOL",			"Phil. Psychol.")
    define("j-PHILOS-PSYCHOL",			"Philos. Psych.")
    define("j-PHILOS-PSYCHOL",			"Philos. Psychol.")

    define("j-PHILOS-SCI",			"Philosophy of Science")
    define("j-PHILOS-SCI",			"Phil. Sci.")
    define("j-PHILOS-SCI",			"Philos. Sci.")

    define("j-PHILOS-SOC-SCI",			"Philosophy of the Social Sciences = Philosophie des sciences sociales")
    define("j-PHILOS-SOC-SCI",			"Philosophy of the Social Sciences")
    define("j-PHILOS-SOC-SCI",			"Philos. Soc. Sci.")

    define("j-PHILOS-STUD",			"Philosophical Studies")
    define("j-PHILOS-STUD",			"Philos. Stud.")

    define("j-PHILOS-TOP",			"Philosophical Topics")
    define("j-PHILOS-TOP",			"Phil. Top.")
    define("j-PHILOS-TOP",			"Philos. Top.")

    define("j-PHILOS-TRANS-R-SOC-LOND",		"Philosophical transactions of the Royal Society of London")
    define("j-PHILOS-TRANS-R-SOC-LOND",		"Philos. trans. R. Soc. Lond.")
    define("j-PHILOS-TRANS-R-SOC-LOND",		"Phil. Trans. R. Soc. Lond.")
    define("j-PHILOS-TRANS-R-SOC-LOND",		"Phil Trans. Roy. Soc. Lond.")
    define("j-PHILOS-TRANS-R-SOC-LOND",		"Philos. Trans. Roy. Soc. Lond.")
    define("j-PHILOS-TRANS-R-SOC-LOND",		"Phil. Trans. Roy. Soc.")
    define("j-PHILOS-TRANS-R-SOC-LOND",		"Phil. Trans. R. Soc.")
    define("j-PHILOS-TRANS-R-SOC-LOND",		"Phil. Trans. Roy. Soc. Lon.")

    define("j-PHILOS-TRANS-R-SOC-LOND-A-CONTAIN-PAP-MATH-PHYS-CHARACTER",	"Philosophical Transactions of the Royal Society of London. Series A, Containing Papers of a Mathematical or Physical Character")
    define("j-PHILOS-TRANS-R-SOC-LOND-A-CONTAIN-PAP-MATH-PHYS-CHARACTER",	"Philos. Trans. R. Soc. Lond., A Contain. Pap. Math. Phys. Character")

    define("j-PHILOS-TRANS-R-SOC-LOND-PHYS-SCI-ENG",	"Philosophical Transactions of the Royal Society of London: Physical Sciences and Engineering")
    define("j-PHILOS-TRANS-R-SOC-LOND-PHYS-SCI-ENG",	"Philosophical Transactions: Physical Sciences and Engineering")
    define("j-PHILOS-TRANS-R-SOC-LOND-PHYS-SCI-ENG",	"Philos. Trans. R. Soc. Lond. Phys. Sci. Eng.")

    define("j-PHILOS-TRANS-R-SOC-LOND-SER-A",	"Philosophical Transactions of the Royal Society A: Mathematical, Physical, and Engineering Sciences")
    define("j-PHILOS-TRANS-R-SOC-LOND-SER-A",	"Philosophical Transactions of the Royal Society A --- Mathematical, Physical, and Engineering Sciences")
    define("j-PHILOS-TRANS-R-SOC-LOND-SER-A",	"Philosophical Transactions of the Royal Society of London A: Mathematical, Physical, and Engineering Sciences")
    define("j-PHILOS-TRANS-R-SOC-LOND-SER-A",	"Philosophical transactions of the Royal Society of London Series A")
    define("j-PHILOS-TRANS-R-SOC-LOND-SER-A",	"Philosophical transactions. Mathematical, physical, and engineering sciences.")
    define("j-PHILOS-TRANS-R-SOC-LOND-SER-A",	"Phil. Trans. R. Soc. Lond. A")
    define("j-PHILOS-TRANS-R-SOC-LOND-SER-A",	"Philos. Trans. Roy. Soc. London Ser. A")
    define("j-PHILOS-TRANS-R-SOC-LOND-SER-A",	"Philos. Trans. R. Soc. Lond. Ser. A Math. Phys. Eng. Sci.")
    define("j-PHILOS-TRANS-R-SOC-LOND-SER-A",	"Phil. Trans. R. Soc. A")
    define("j-PHILOS-TRANS-R-SOC-LOND-SER-A",	"Royal Society of London Philosophical Transactions Series A")
    define("j-PHILOS-TRANS-R-SOC-LOND-SER-A",	"R. Soc. Lond. Philos. Trans. Ser. A Math. Phys. Eng. Sci.")

    define("j-PHILOS-TRANS-R-SOC-LOND-SER-A-MATH-PHYS-SCI",	"Philosophical Transactions of the Royal Society of London. Series A, Mathematical and Physical Sciences")
    define("j-PHILOS-TRANS-R-SOC-LOND-SER-A-MATH-PHYS-SCI",	"Phil. Trans. R. Soc. Lond. A. Math. Phys. Sci.")

    define("j-PHILOS-TRANS-R-SOC-LOND-SER-B-BIO-SCI",	"Philosophical transactions of the Royal Society of London Series B, Biological sciences")
    define("j-PHILOS-TRANS-R-SOC-LOND-SER-B-BIO-SCI",	"Philosophical Transactions of the Royal Society B")
    define("j-PHILOS-TRANS-R-SOC-LOND-SER-B-BIO-SCI",	"Philos Trans R Soc Lond B Biol Sci (P5Z)")
    define("j-PHILOS-TRANS-R-SOC-LOND-SER-B-BIO-SCI",	"Phil. Trans. R. Soc. Lond. B")
    define("j-PHILOS-TRANS-R-SOC-LOND-SER-B-BIO-SCI",	"Philosophical Transactions of the Royal Society of London B")

    define("j-PHOTOCHEM-PHOTOBIO",		"Photochemistry and photobiology")
    define("j-PHOTOCHEM-PHOTOBIO",		"Photochem Photobiol (P69)")

    define("j-PHOTO-ELECTRON-IMAGING",		"Photo Electronic Imaging")
    define("j-PHOTO-ELECTRON-IMAGING",		"Photo electron. imaging")

    define("j-PHOTOGR-SCI-ENG",			"Photographic Science and Engineering")
    define("j-PHOTOGR-SCI-ENG",			"Photogr. Sci. Eng.")

    # NB: j-PHOTOMETHODS (1974--1991) is continued by j-PHOTO-ELECTRON-IMAGING
    define("j-PHOTOMETHODS",			"Photomethods")

    define("j-PHOTONICS-NANOSTRUCT",		"Photonics and Nanostructures --- Fundamentals and Applications")
    define("j-PHOTONICS-NANOSTRUCT",		"Photonics Nanostruct.")

    define("j-PHOTONIQUES",			"Photoniques")

    define("j-PHYS-AT-NUCL",			"Physics of Atomic Nuclei")
    define("j-PHYS-AT-NUCL",			"Phys. At. Nucl.")

    define("j-PHYS-BL",				"{Physikalische Bl{\\\"a}tter}")
    define("j-PHYS-BL",				"Physikalische Bl{\\\"a}tter")
    define("j-PHYS-BL",				"Physikalische Blatter")
    define("j-PHYS-BL",				"Physikalische Blaetter")
    define("j-PHYS-BL",				"Phys. Bl.")

    define("j-PHYS-BULL",			"Physics Bulletin")
    define("j-PHYS-BULL",			"Physics Bull.")
    define("j-PHYS-BULL",			"Phys. Bull.")

    define("j-PHYS-CANADA",			"Physics in Canada = La Physique au Canada")
    define("j-PHYS-CANADA",			"Physics in Canada (PiC)")
    define("j-PHYS-CANADA",			"Physics in Canada")
    define("j-PHYS-CANADA",			"Phys. Canada")

    define("j-PHYS-CHEM-CHEM-PHYS",		"Physical Chemistry Chemical Physics: PCCP")
    define("j-PHYS-CHEM-CHEM-PHYS",		"Physical Chemistry Chemical Physics")
    define("j-PHYS-CHEM-CHEM-PHYS",		"Phys. Chem. Chem. Phys.")
    define("j-PHYS-CHEM-CHEM-PHYS",		"Phys. Chem. Chem. Phys.: PCCP")

    define("j-PHYS-CHEM-LIQ",			"Physics and Chemistry of Liquids")
    define("j-PHYS-CHEM-LIQ",			"Phys. Chem. Liq.")

    define("j-PHYS-CHEM-MINERALS",		"Physics and Chemistry of Minerals")
    define("j-PHYS-CHEM-MINERALS",		"Phys. chem. miner.")

    define("j-PHYS-EARTH-PLANET-INTER",		"Physics of the Earth and Planetary Interiors")
    define("j-PHYS-EARTH-PLANET-INTER",		"Phys. Earth Planet. Inter.")

    define("j-PHYS-EDUC",			"Physics Education")
    define("j-PHYS-EDUC",			"Phys. Educ.")

    define("j-PHYS-ESSAYS",			"Physics Essays")
    define("j-PHYS-ESSAYS",			"Phys. Essays")

    define("j-PHYS-FLUIDS",			"The Physics of Fluids")
    define("j-PHYS-FLUIDS",			"Physics of Fluids")
    define("j-PHYS-FLUIDS",			"Phys. of Fluids")
    define("j-PHYS-FLUIDS",			"Phys. of Fluids (1994)")
    define("j-PHYS-FLUIDS",			"Phys. Fluids (1994)")

    define("j-PHYS-FLUIDS-1958",		"Physics of Fluids (1958)")
    define("j-PHYS-FLUIDS-1958",		"Phys. of Fluids (1958)")

    define("j-PHYS-FLUIDS-A",			"Physics of Fluids A: Fluid Dynamics (1989--1993)")
    define("j-PHYS-FLUIDS-A",			"Physics of Fluids A: Fluid Dynamics")
    define("j-PHYS-FLUIDS-A",			"Physics of Fluids A")
    define("j-PHYS-FLUIDS-A",			"Phys. Fluids A")
    define("j-PHYS-FLUIDS-A",			"Phys. Fluids A: Fluid Dyn.")

    define("j-PHYS-J",				"Physik Journal")
    define("j-PHYS-J",				"Phys. J.")

    define("j-PHYS-LET",			"Physics Letters")
    define("j-PHYS-LET",			"Phys. Lett.")

    define("j-PHYS-LET-A",			"Physics Letters A")
    define("j-PHYS-LET-A",			"Phys. Lett. A")

    define("j-PHYS-LET-B",			"Physics Letters B")
    define("j-PHYS-LET-B",			"Phys. Lett. B")

    define("j-PHYS-MED-BIOL",			"Physics in Medicine and Biology")
    define("j-PHYS-MED-BIOL",			"Phys. Med. Biol.")

    ## v1 n1 1961/62-v8 n4 1977 [I cannot find any online archive: [24-Apr-2019]]
    define("j-PHYS-NORVEG",			"Physica Norvegica")
    define("j-PHYS-NORVEG",			"Phys. Norvegica")
    define("j-PHYS-NORVEG",			"Phys. Norv.")
    define("j-PHYS-NORVEG",			"Phys. Norveg.")

    ## Former Title(s)	Soviet Journal of Particles and Nuclei
    ## New journal continues with v24 n1 Jan./Feb. 1993+
    define("j-PHYS-PART-NUCL",			"Physics of Particles and Nuclei")
    define("j-PHYS-PART-NUCL",			"Phys. Part. Nucl.")

    define("j-PHYS-PERSPECT",			"Physics in Perspective (PIP)")
    define("j-PHYS-PERSPECT",			"Physics in Perspective")
    define("j-PHYS-PERSPECT",			"Phys. Perspect.")

    define("j-PHYS-PLASMAS",			"Physics of Plasmas")
    define("j-PHYS-PLASMAS",			"Phys. Plasmas")

    define("j-PHYS-PROCEDIA",			"Physics Procedia")
    define("j-PHYS-PROCEDIA",			"Phys. Procedia")

    define("j-PHYS-REP",			"Physics Reports")
    define("j-PHYS-REP",			"Physics Reports --- Review Section of Physics Letters")
    define("j-PHYS-REP",			"Phys. Rep.")

    define("j-PHYS-REV",			"Physical Review")
    define("j-PHYS-REV",			"Phys. Rev.")

    ## From Library of Congress:
    ##
    ## Physical Review
    ## v. 1--35, July 1893-Dec. 1912;
    ##
    ## Physical Review (2)
    ## ser. 2, v. 1--188, no. 5, Jan. 1913--Dec. 25, 1969.
    ## Vols. 133--140 issued in two sections: A and B.
    ##
    ## Physical review. A, General physics. Ser. 3, v. 1, no. 1
    ## (Jan. 1970)-v. 40, no. 12 (Dec. 15, 1989)
    ##
    ## Physical review. B, Solid state. Began with v. 1, issue for
    ## Jan. 1, 1970; ceased with v. 17, no. 12, issue for June 15,
    ## 1978.
    ##
    ## Physical review. C, Nuclear
    ## physics. ser.3:v.1:no.1-ser.3:v.22:no.1 (1970:Jan.-1980:July),
    ## ser.3:v.22:no.3-ser.3:v.41:no.6 (1980:Sept.-1990:June),
    ## ser.3:v.44:no.3-ser.3:v.59 (1991:Sept.-1999:Jan./Feb.)  v.60
    ## (1999:July/Aug.-1999:Nov./Dec.), v.61-v.67:no.3
    ## (2000:May/June-2003:Mar.)  ser.3:v.67:no.5-ser.3:v.84
    ## (2003:May-2010)
    ##
    ## Physical review. D, Particles and fields.
    ## 3rd. ser., v. 1, no. 1 (1 Jan. 1970)- Ceased with <3rd ser.>,
    ## v. 68, no. 12 (Dec. 15, 2003)

    define("j-PHYS-REV-1",			"Physical Review (Series I)")
    define("j-PHYS-REV-1",			"Physical Review (1)")
    define("j-PHYS-REV-1",			"Phys. Rev. (Series I)")
    define("j-PHYS-REV-1",			"Phys. Rev. (Ser. I)")

    define("j-PHYS-REV-2",			"Physical Review (2)")
    define("j-PHYS-REV-2",			"Physical Rev. (2)")
    define("j-PHYS-REV-2",			"Phys. Rev. (2)")
    define("j-PHYS-REV-2",			"Phys. Rev., II. Ser.")
    define("j-PHYS-REV-2",			"Phys. Rev., Minneapolis, II. Ser.")

    define("j-PHYS-REV-A",			"Physical Review A (Atomic, Molecular, and Optical Physics)")
    define("j-PHYS-REV-A",			"Phys. Rev. A")
    define("j-PHYS-REV-A",			"Physical Review A")

    define("j-PHYS-REV-A-3",			"Physical Review A (3)")
    define("j-PHYS-REV-A-3",			"Physical Review. A. General Physics. Third Series")
    define("j-PHYS-REV-A-3",			"Phys. Rev. A (3)")

    # Phys. Rev. B: s3 v93 n1 Jan. 2016+
    define("j-PHYS-REV-B",			"Physical Review B")

    ## Phys. Rev. B: Condens. Matter Mater. Phys. PRBMDO 1098-0121 s3 v18 n1 July 1, 1978+
    define("j-PHYS-REV-B-CMMP",			"Physical Review B: Condensed Matter and Materials Physics")
    define("j-PHYS-REV-B-CMMP",			"Physical Review B (Condensed Matter and Materials Physics)")
    define("j-PHYS-REV-B-CMMP",			"Phys. Rev. B: Condens. Matter Mater. Phys.")

    ## Physical Review B: Solid State		 PLRBAQ 0556-2805 s3 v1 n1 Jan. 1, 1970--s3 v17 n12 June 15, 1978
    define("j-PHYS-REV-B-SS",			"Physical Review B: Solid State")
    define("j-PHYS-REV-B-SS",			"Physical Review B (Solid State)")
    define("j-PHYS-REV-B-SS",			"Phys. Rev. B: Solid State")

    define("j-PHYS-REV-C",			"Physical Review C (Nuclear Physics)")
    define("j-PHYS-REV-C",			"Phys. Rev. C")
    define("j-PHYS-REV-C",			"Physical Review C")

    define("j-PHYS-REV-D",			"Physical Review D (Particles and Fields)")
    define("j-PHYS-REV-D",			"Phys. Rev. D")
    define("j-PHYS-REV-D",			"Physical Review D")

    define("j-PHYS-REV-E",			"Physical Review E (Statistical physics, plasmas, fluids, and related interdisciplinary topics)")
    define("j-PHYS-REV-E",			"Physical review. E, Statistical, nonlinear, and soft matter physics")
    define("j-PHYS-REV-E",			"Phys. Rev. E")
    define("j-PHYS-REV-E",			"Phys. Rev. E (3)")
    define("j-PHYS-REV-E",			"Physical Review E")

    define("j-PHYS-REV-FOCUS",			"Physical Review Focus")
    define("j-PHYS-REV-FOCUS",			"Phys. Rev. Focus")

    define("j-PHYS-REV-LET",			"Physical Review Letters")
    define("j-PHYS-REV-LET",			"Phys. Rev. Lett")
    define("j-PHYS-REV-LET",			"Phys. Rev. Let.")
    define("j-PHYS-REV-LET",			"Phys. Rev. Lett.")
    define("j-PHYS-REV-LET",			"Phys. Rev. Letters")

    define("j-PHYS-REV-X",			"Physical Review X")
    define("j-PHYS-REV-X",			"Phys. Rev. X")

    define("j-PHYS-STATUS-SOLIDI",		"Physica status solidi")
    define("j-PHYS-STATUS-SOLIDI",		"Phys. status solidi")

    define("j-PHYS-STATUS-SOLIDI-A-APPL-RES",	"Physica Status Solidi. A, Applied Research")
    define("j-PHYS-STATUS-SOLIDI-A-APPL-RES",	"Phys. status solidi. A, Appl. res")

    define("j-PHYS-STATUS-SOLIDI-B-BASIC-RES",	"Physica Status Solidi. B, Basic Research")
    define("j-PHYS-STATUS-SOLIDI-B-BASIC-RES",	"Phys. Status Solidi, B Basic Res")
    define("j-PHYS-STATUS-SOLIDI-B-BASIC-RES",	"Physica Status Solidi (B)")
    define("j-PHYS-STATUS-SOLIDI-B-BASIC-RES",	"Phys. Stat. Sol. (B)")

    define("j-PHYS-STATUS-SOLIDI-RAPID-RES-LETT",	"Physica Status Solidi (RRL) Rapid Research Letters")
    define("j-PHYS-STATUS-SOLIDI-RAPID-RES-LETT",	"Physica Status Solidi Rapid Research Letters")
    define("j-PHYS-STATUS-SOLIDI-RAPID-RES-LETT",	"Phys. Status Solidi, Rapid Res. Lett.")

    define("j-PHYS-TEACHER",			"The Physics Teacher")
    define("j-PHYS-TEACHER",			"Physics Teacher")
    define("j-PHYS-TEACHER",			"Phys. Teach.")

    define("j-PHYS-TODAY",			"Physics Today")
    define("j-PHYS-TODAY",			"Phys. Today")

    define("j-PHYS-UNSERER-ZEIT",		"{Physik in unserer Zeit}")
    define("j-PHYS-UNSERER-ZEIT",		"{Phys unserer Zeit}")

    define("j-PHYS-USPEKHI",			"Physics-Uspekhi")
    define("j-PHYS-USPEKHI",			"Phys. Uspekhi")

    define("j-PHYS-WORLD",			"Physics World")

    define("j-PHYS-Z-SOWJETUNION",		"Physikalische Zeitschrift der Sowjetunion")
    define("j-PHYS-Z-SOWJETUNION",		"Phys. Z. Sowjetunion")

    ## Physica series:
    ##    Physica	vol 1 December 1933--vol 78 December 1974
    ##    Physica A	vol 79 January 1975--
    ##                  1975--1988          subtitle:  Theoretical and statistical physics
    ##                  Nov 1988--May 1998  subtitle:  Statistical and theoretical physics
    ##                  Jun 1988--20xx      subtitle:  Statistical mechanics and its applications
    ##    Physica B + C: 					1975--1988
    ##    Physica B: Condensed Matter				1988--20xx
    ##    Physica C: Superconductivity				1988--2014
    ##    Physica C: Superconductivity and its Applications	vol 310--date
    ##    Physica D: Nonlinear phenomena			1980--20xx

    define("j-PHYSICA",				"Physica")
    define("j-PHYSICA-A",			"Physica A")
    define("j-PHYSICA-A",			"Physica A Statistical Mechanics and its Applications")
    define("j-PHYSICA-A",			"Physica A: Statistical Mechanics and its Applications")
    define("j-PHYSICA-A",			"Phys. A")

    define("j-PHYSICA-B",			"Physica. B, Condensed matter")
    define("j-PHYSICA-B",			"Physica, B, Condens. matter")
    define("j-PHYSICA-B",			"Physica B")

    define("j-PHYSICA-B-PLUS-C",		"Physica. B + C; B: Physics of condensed matter. C: Atomic, molecular and plasma physics; optics")
    define("j-PHYSICA-B-PLUS-C",		"Physica B \\& C")
    define("j-PHYSICA-B-PLUS-C",		"Physica B + C")

    define("j-PHYSICA-C",			"Physica. C, Superconductivity")
    define("j-PHYSICA-C",			"Phys. C, Supercond.")
    define("j-PHYSICA-C",			"Physica C")

    define("j-PHYSICA-D",			"Physica. D, Nonlinear phenomena")
    define("j-PHYSICA-D",			"Physica D")

    define("j-PHYSICA-SCRIPTA",			"Physica Scripta")
    define("j-PHYSICA-SCRIPTA",			"Phys. Scripta")

    ## v1 Apr. 1921-v13 n10 Dec. 1933 Superseded by Physica (Amsterdam) and
    ## Nederlands Tijdschrift voor Natuurkunde (1934-1976)
    define("j-PHYSICA-THE-HAGUE",		"Physica (The Hague)")

    define("j-PHYSICS",				"Physics")

    define("j-PHYSIKAL-Z",			"Physikalische Zeitschrift")
    define("j-PHYSIKAL-Z",			"Physik. Zs.")
    define("j-PHYSIKAL-Z",			"Physik. Z.")
    define("j-PHYSIKAL-Z",			"Physikal. Z.")
    define("j-PHYSIKAL-Z",			"Phys. Zeit.")
    define("j-PHYSIKAL-Z",			"Phys. Z.")

    define("j-PHYSIS",				"Physis: Rivista Internazionale di Storia della Scienza")
    define("j-PHYSIS",				"Physis (Florence)")
    define("j-PHYSIS",				"Physis (Firenze)")
    define("j-PHYSIS",				"Physis. Rivista Internazionale di Storia della Scienza")
    define("j-PHYSIS",				"Physis: Rivista di Storia della Scienza")
    define("j-PHYSIS",				"Physis---Riv. Internaz. Storia Sci.")
    define("j-PHYSIS",				"Phys.---Riv. Internaz. Storia Sci.")
    define("j-PHYSIS",				"Physis")

    define("j-PHYSIS-NS",			"Physis: Rivista Internazionale di Storia della Scienza. Nuova Serie")
    define("j-PHYSIS-NS",			"Physis --- Rivista Internazionale di Storia della Scienza. Nuova Serie")
    define("j-PHYSIS-NS",			"Physis (N.S.) (Florence)")
    define("j-PHYSIS-NS",			"Physis Riv. Internaz. Storia Sci. (N.S.)")

    define("j-PHYSIOL-CHEM-PHYS",		"Physiological Chemistry and Physics")
    define("j-PHYSIOL-CHEM-PHYS",		"Physiol. Chem. Phys.")

    define("j-PHYSIOL-REV",			"Physiological Reviews")
    define("j-PHYSIOL-REV",			"Physiol. Rev.")

    define("j-PI-MU-EPSILON-J",			"Pi Mu Epsilon Journal")
    define("j-PI-MU-EPSILON-J",			"Pi Mu Eps. J.")
    define("j-PI-MU-EPSILON-J",			"J. Pi Mu Epsilon")
    define("j-PI-MU-EPSILON-J",			"Pi Mu Epsilon J.")

    define("j-PITMAN-RES-NOTES-MATH-SER",	"Pitman Research Notes in Mathematics Series")
    define("j-PITMAN-RES-NOTES-MATH-SER",	"Pitman Research Notes in Mathematics")
    define("j-PITMAN-RES-NOTES-MATH-SER",	"Pitman res. notes math. ser.")
    define("j-PITMAN-RES-NOTES-MATH-SER",	"Pitman Research Notes in Math.")

    define("j-PLANET-SPACE-SCI",		"Planetary and Space Science")
    define("j-PLANET-SPACE-SCI",		"Planet. Space Sci.")

    define("j-PLANT-J",				"Plant journal: for cell and molecular biology")
    define("j-PLANT-J",				"Plant J (BRU)")

    define("j-PLANT-MOL-BIO",			"Plant molecular biology")
    define("j-PLANT-MOL-BIO",			"Plant Mol Biol (A6O)")

    define("j-PLANTA",				"Planta")

    define("j-PLASMA-IONS",			"Plasmas \\& Ions")
    define("j-PLASMA-IONS",			"Plasmas & Ions")

    define("j-PLASMA-PHYS",			"Plasma Physics")
    define("j-PLASMA-PHYS",			"Plasma Phys.")

    define("j-PLASMA-PHYS-CONTROL-FUSION",	"Plasma Physics and Controlled Fusion")
    define("j-PLASMA-PHYS-CONTROL-FUSION",	"Plasma Phys. Controll. Fusion")
    define("j-PLASMA-PHYS-CONTROL-FUSION",	"Plasma phys. control. fusion")

    define("j-PLASMID",				"Plasmid")
    define("j-PLASMID",				"Plasmid (P8P)")

    ## j-PLATIN-MET-REV: v1n1 January 1957--v58n2 April 2014 (ceased)
    ## Formerly Johnson Matthey Technology Review
    define("j-PLATIN-MET-REV",			"Platinum Metals Review")
    define("j-PLATIN-MET-REV",			"Platinum Met. Rev.")
    define("j-PLATIN-MET-REV",			"Platin. Met. Rev.")

    define("j-PLI-BULL",			"PL/I Bulletin")

    define("j-PLISKA-STUD-MATH-BULGAR",		"Pliska, Studia mathematica Bulgarica")
    define("j-PLISKA-STUD-MATH-BULGAR",		"Pliska")
    define("j-PLISKA-STUD-MATH-BULGAR",		"Pliiska")
    define("j-PLISKA-STUD-MATH-BULGAR",		"Pliska, Stud. Math. Bulgar.")

    define("j-PLOS-COMPUT-BIOL",		"PLoS Computational Biology")
    define("j-PLOS-COMPUT-BIOL",		"PLoS Comp. Biol.")
    define("j-PLOS-COMPUT-BIOL",		"PLoS Comput. Biol.")

    define("j-PLOS-MED",			"PLoS Medicine")
    define("j-PLOS-MED",			"PLoS Med.")

    define("j-PLOS-ONE",			"PLoS One")

    define("j-POKROKY-MAT-FYS-ASTRON",		"Pokroky Matematiky, Fyziky a Astronomie")
    define("j-POKROKY-MAT-FYS-ASTRON",		"Pokroky Mat. Fyz. Astron.")
    define("j-POKROKY-MAT-FYS-ASTRON",		"Pokr. Mat., Fys. Astron.")

    define("j-POLIT-ANAL",			"Political Analysis")
    define("j-POLIT-ANAL",			"Polit. Anal.")

    define("j-POLITY",				"Polity")
    define("j-POLITY",				"Polity: Journal of the Northeastern Political Science Association")

    # NB: UC Melvyl has incorrect Guilford: should be Guildford! Full UC
    # entry is correct, as is LC.
    define("j-POLYMER",				"Polymer (Guildford)")
    define("j-POLYMER",				"Polymer")

    define("j-POLYMER-J-TOKYO",			"Polymer Journal (Tokyo, Japan)")
    define("j-POLYMER-J-TOKYO",			"Polym. J. (Tokyo, Jpn.)")

    define("j-POMACS",				"Proceedings of the ACM on Measurement and Analysis of Computing Systems (POMACS)")
    define("j-POMACS",				"Proceedings of the ACM on Measurement and Analysis of Computing Systems")
    define("j-POMACS",				"Proc. ACM Measurement Anal. Comput. Syst.")

    define("j-POP-COMP",			"Popular Computing (Peterborough)")
    define("j-POP-COMP",			"Popular Computing")

    define("j-POP-COMP-CALABASAS",		"Popular Computing (Calabasas, CA)")

    define("j-PORT-MATH",			"Portugaliae Mathematica")
    define("j-PORT-MATH",			"Portugaliae Mathematica. A Journal of the Portuguese Mathematical Society")
    define("j-PORT-MATH",			"Port. Math.")

    define("j-POSITIVITY",			"Positivity")

    define("j-POSTSCRIPT-LANG-J",		"PostScript Language Journal")
    define("j-POSTSCRIPT-LANG-J",		"The PostScript Language Journal")
    define("j-POSTSCRIPT-LANG-J",		"The {\\POSTSCRIPT} Language Journal")
    define("j-POSTSCRIPT-LANG-J",		"PostScript Lang. J.")

    define("j-POTENTIAL-ANAL",			"Potential analysis : an international journal devoted to the interactions between potential theory, probability theory, geometry and functional analysis")
    define("j-POTENTIAL-ANAL",			"Potential analysis")
    define("j-POTENTIAL-ANAL",			"Potential anal.")

    define("j-POWDER-DIFF",			"Powder Diffraction")
    define("j-PRAGMATICS-COGNITION",		"Pragmatics and Cognition")

    define("j-PRAMANA",				"Pramana: Journal of Physics")
    define("j-PRAMANA",				"Pramana")

    define("j-PRIKL-MAT-MEH",			"Prikladnaia matematika i mekhanika (Leningrad, R.S.F.S.R.)")
    define("j-PRIKL-MAT-MEH",			"Prikladnaia matematika i mekhanika : sbornik izdavaemyi pri blizhaishem uchastii Leningradskogo mekhanicheskogo NIT obshchestva = Applied mathematics and mechanics")
    define("j-PRIKL-MAT-MEH",			"Prikl. mat. meh.")
    define("j-PRIKL-MAT-MEH",			"Prikl. Mat. Mekh.")
    define("j-PRIKL-MAT-MEH",			"Prikl. Matem. Mekhan.")
    define("j-PRIKL-MAT-MEH",			"Prikladnaya Matematika i Mechanika")
    define("j-PRIKL-MAT-MEH",			"Prikladnaya Matematika i Mekhanika")

    define("j-PRIKL-PROBLEMY-PROCH-I-PLAST",	"Gor\\cprime kovski\\u\\i\\ Gosudarstvenny\\u\\i\\ Universitet imeni N. I. Lobachevskogo. Prikladnye Problemy Prochnosti i Plastichnosti")
    define("j-PRIKL-PROBLEMY-PROCH-I-PLAST",	"Prikl. Problemy Proch. i Plast.")

    define("j-PRIMUS",				"PRIMUS (Problems Resources and Issues in Mathematics Undergraduate Studies)")
    define("j-PRIMUS",				"PRIMUS: Problems, Resources, and Issues in Mathematics Undergraduate Studies")
    define("j-PRIMUS",				"PRIMUS")

    define("j-PRINT",				"Print")
    define("j-PRINTING-PRODUCTION",		"Printing Production")
    define("j-PRINTING-WORLD",			"Printing World")

    define("j-PRIRODA-MOSCOW",			"Priroda (Moscow, Russian Federation) [Nature]")
    define("j-PRIRODA-MOSCOW",			"Priroda (Moscow, Russian Federation)")
    define("j-PRIRODA-MOSCOW",			"Priroda (Moscow, Russ. Fed.)")
    define("j-PRIRODA-MOSCOW",			"Priroda (Nature)")

    define("j-PROB-ENG-MECH",			"Probabilistic engineering mechanics")
    define("j-PROB-ENG-MECH",			"Prob. eng. mech.")
    define("j-PROB-ENG-MECH",			"J. Probabilistic Engineering Mechanics")

    define("j-PROB-ENG-INFO-SCI",		"Probability in the Engineering and Informational Sciences")
    define("j-PROB-ENG-INFO-SCI",		"Probab. Engrg. Inform. Sci.")

    define("j-PROBAB-SURV",			"Probabability Surveys")
    define("j-PROBAB-SURV",			"Probab. Surveys")
    define("j-PROBAB-SURV",			"Probab. Surv.")

    define("j-PROBAB-ENGRG-INFORM-SCI",		"Probability in the Engineering and Informational Sciences")
    define("j-PROBAB-ENGRG-INFORM-SCI",		"Probab. Engrg. Inform. Sci.")

    # Before 1986, j-PROBAB-THEORY-RELAT-FIELDS was j-Z-WAHRSCHEINLICHKEITSTHEOR-VERW-GEB
    define("j-PROBAB-THEORY-RELAT-FIELDS",	"Probability theory and related fields")
    define("j-PROBAB-THEORY-RELAT-FIELDS",	"Probab. theory relat. fields.")
    define("j-PROBAB-THEORY-RELAT-FIELDS",	"Prob. Th. Rel. Fields")
    define("j-PROBAB-THEORY-RELAT-FIELDS",	"Probab. Theory Related Fields")

    define("j-PROBL-INF-TRANSM",		"Problems of Information Transmission")
    define("j-PROBL-INF-TRANSM",		"Probl. inf. transm.")

    define("j-PROBL-PEREDA-INF",		"Problemy Peredachi Informatsii")
    define("j-PROBL-PEREDA-INF",		"Probl. pereda. inf.")
    define("j-PROBL-PEREDA-INF",		"Probl. Peredachi Inf.")

    define("j-PROC-ACM-SYMP-APPL-COMPUTING",	"Proceedings of the ACM Symposium on Applied Computing")

    define("j-PROC-AM-ACAD-ARTS-SCI",		"Proceedings of the American Academy of Arts and Sciences")
    define("j-PROC-AM-ACAD-ARTS-SCI",		"Proc. Am. Acad. Arts Sci.")

    define("j-PROC-AM-CONTROL-CONF",		"Proceedings of the American Control Conference")
    define("j-PROC-AM-CONTROL-CONF",		"Proc. Am. Control Conf.")

    define("j-PROC-AM-MATH-SOC",		"Proceedings of the American Mathematical Society")
    define("j-PROC-AM-MATH-SOC",		"Proc. American Math. Soc.")
    define("j-PROC-AM-MATH-SOC",		"Proc. Am. Math. Soc.")
    define("j-PROC-AM-MATH-SOC",		"Proc. Amer. Math. Soc.")

    define("j-PROC-AMER-PHIL-SOC",		"Proceedings of the American Philosophical Society")
    define("j-PROC-AMER-PHIL-SOC",		"Proceedings of the {American Philosophical Society} held at {Philadelphia} for promoting useful knowledge")
    define("j-PROC-AMER-PHIL-SOC",		"Proc. Am. Philosophical Soc.")
    define("j-PROC-AMER-PHIL-SOC",		"Proc. Am. Philosoph. Soc.")
    define("j-PROC-AMER-PHIL-SOC",		"Proc. Am. Philos. Soc.")
    define("j-PROC-AMER-PHIL-SOC",		"Proc. Am. Phil. Soc.")
    define("j-PROC-AMER-PHIL-SOC",		"Proc. Amer. Philosophical Soc.")
    define("j-PROC-AMER-PHIL-SOC",		"Proc. Amer. Philosoph. Soc.")
    define("j-PROC-AMER-PHIL-SOC",		"Proc. Amer. Philos. Soc.")
    define("j-PROC-AMER-PHIL-SOC",		"Proc. Amer. Phil. Soc.")

    define("j-PROC-ANN-SYMP-COMPUT-APPL-MED-CARE", "Proceedings of the Annual Symposium on Computer Applications in Medical Care")
    define("j-PROC-ANN-SYMP-COMPUT-APPL-MED-CARE", "Proc Annu Symp Comput Appl Med Care (BGL)")

    define("j-PROC-ANNUAL-SOUTHEAST-CONFERENCE","Proceedings of the Annual Southeast Conference")

    define("j-PROC-ASEE-ANNU-CONF",		"American Society for Engineering Education Annual Conference. Proceedings")
    define("j-PROC-ASEE-ANNU-CONF",		"Proceedings, ASEE annual conference")
    define("j-PROC-ASEE-ANNU-CONF",		"Proc., ASEE annu. conf.")
    define("j-PROC-ASEE-ANNU-CONF",		"ASEE Annual Conference Proceedings")

    define("j-PROC-ASIS-AM",			"Proceedings of the ASIS annual meeting")

    ## Proceedings of the Cambridge Philosophical Society. Mathematical and physical sciences
    ##		vol 1 1843/1865--vol 76 November 1974
    ## Mathematical proceedings of the Cambridge Philosophical Society
    ##		vol 77 Jan 1975--20xx

    define("j-PROC-CAMBRIDGE-PHIL-SOC",		"Proceedings of the Cambridge Philosophical Society. Mathematical and physical sciences")
    define("j-PROC-CAMBRIDGE-PHIL-SOC",		"Proceedings of the Cambridge Philosophical Society")
    define("j-PROC-CAMBRIDGE-PHIL-SOC",		"Proc. Camb. Phil. Soc.")
    define("j-PROC-CAMBRIDGE-PHIL-SOC",		"Proc. Camb. Philos. Soc.")
    define("j-PROC-CAMBRIDGE-PHIL-SOC",		"Proc. Cambridge Phil. Soc.")
    define("j-PROC-CAMBRIDGE-PHIL-SOC",		"Proc. Cambridge Philos. Soc.")

    define("j-PROC-CHEM-SOC-LONDON",		"Proceedings of the Chemical Society, London")
    define("j-PROC-CHEM-SOC-LONDON",		"Proceedings of the Chemical Society")
    define("j-PROC-CHEM-SOC-LONDON",		"Proc. Chem. Soc.")
    define("j-PROC-CHEM-SOC-LONDON",		"Proc. Chem. Soc., London")

    define("j-PROC-CMAANU",			"Proceedings of the Centre for Mathematical Analysis, Australian National University")
    define("j-PROC-CMAANU",			"Proc. Centre for Mathematical Analysis of the Australian  National University")

    define("j-PROC-CONTROL-AUTOMATION",		"Process Control and Automation")

    define("j-PROC-EDINBURGH-MATH-SOC",		"Proceedings of the Edinburgh Mathematical Society")
    define("j-PROC-EDINBURGH-MATH-SOC",		"Proc. Edinburgh Math. Soc.")
    define("j-PROC-EDINBURGH-MATH-SOC",		"Proc. Edinb. Math. Soc.")

    define("j-PROC-EDINBURGH-MATH-SOC-2",	"Proceedings of the Edinburgh Mathematical Society (2)")
    define("j-PROC-EDINBURGH-MATH-SOC-2",	"Proceedings of the Edinburgh Mathematical Society. Series II")
    define("j-PROC-EDINBURGH-MATH-SOC-2",	"Proc. Edinb. Math. Soc., II. Ser.")
    define("j-PROC-EDINBURGH-MATH-SOC-2",	"Proc. Edinb. Math. Soc. (2)")
    define("j-PROC-EDINBURGH-MATH-SOC-2",	"Proc. Edinburgh Math. Soc. (2)")

    define("j-PROC-GRAPHICS-INTERFACE",		"Proceedings / Graphics Interface = Comptes rendus / Interface graphique")

    define("j-PROC-ICASSP",			"Proceedings of the International Conference on Acoustics, Speech, and Signal Processing")
    define("j-PROC-ICASSP",			"Proceedings --- ICASSP, IEEE International Conference on Acoustics, Speech and Signal Processing")
    define("j-PROC-ICASSP",			"ICASSP, IEEE International Conference on Acoustics, Speech and Signal Processing --- Proceedings")
    define("j-PROC-ICASSP",			"Proceedings / ICASSP")
    define("j-PROC-ICASSP",			"Proc. ICASSP")

    define("j-PROC-IEE",			"Proceedings of the Institution of Electrical Engineers")
    define("j-PROC-IEE",			"Proc. Inst. Electr. Eng.")

    define("j-PROC-IEEE",			"Proceedings of the IEEE")
    define("j-PROC-IEEE",			"IEEE Proceedings")
    define("j-PROC-IEEE",			"Proc. IEEE")
    define("j-PROC-IEEE",			"Proc IEEE")

    define("j-PROC-IEEE-INT-COMP-SOFTWARE-APPL-CONF","Proceedings --- IEEE Computer Society's International Computer Software \\& Applications Conference")

    define("j-PROC-IEEE-CONF-DECISION-CONTROL",	"Proceedings of the IEEE Conference on Decision and Control")

    define("j-PROC-IEEE-CONF-SYST-MAN-CYBERN",	"Proceedings of the IEEE International Conference on Systems, Man and Cybernetics")
    define("j-PROC-IEEE-CONF-SYST-MAN-CYBERN",	"Proc. IEEE Int. Conf. Syst. Man Cybern.")

    define("j-PROC-IEEE-INT-SOFTWARE-ENG-STAND-SYMP","Proceedings of the IEEE International Software Engineering Standards Symposium")
    define("j-PROC-IEEE-WORK-REAL-TIME-OPER-SYS-SOFTWARE","Proceedings of the IEEE Workshop on Real-Time Operating Systems and Software")
    define("j-PROC-IMP-ACAD-TOKYO",		"Proc. Imp. Acad. Tokyo")

    define("j-PROC-INDIAN-ACAD-SCI-CHEM-SCI",	"Proceedings of the Indian Academy of Sciences. Chemical sciences.")
    define("j-PROC-INDIAN-ACAD-SCI-CHEM-SCI",	"Proc. Indian Acad. Sci., Chem. sci.")
    define("j-PROC-INDIAN-ACAD-SCI-CHEM-SCI",	"Proceedings. Chemical sciences / Indian Academy of Sciences")

    define("j-PROC-INDIAN-ACAD-SCI-SECT-A",	"Proceedings --- Indian Academy of Sciences, Section A")
    define("j-PROC-INDIAN-ACAD-SCI-SECT-A",	"Proc. - Indian Acad. Sci., Sect. A")
    define("j-PROC-INDIAN-ACAD-SCI-SECT-A",	"Proc. Indian Acad. Sci., Sect. A")

    define("j-PROC-INST-STATIST-MATH",		"Proceedings of the Institute of Statistical Mathematics")
    define("j-PROC-INST-STATIST-MATH",		"Proc. Inst. Statist. Math.")
    define("j-PROC-INST-STATIST-MATH",		"Proc. Inst. Stat. Math.")

    define("j-PROC-INT-CONF-DIST-COMPUT-SYS",	"Proceedings --- International Conference on Distributed Computing Systems")
    define("j-PROC-INT-CONF-PAR-PROC",		"Proceedings of the International Conference on Parallel Processing")
    define("j-PROC-INT-CONF-REQUIREMENTS-ENG",	"Proceedings of the International Conference on Requirements Engineering")

    define("j-PROC-INT-CONF-SOFTWARE-ENG",	"Proceedings --- International Conference on Software Engineering")
    define("j-PROC-INT-CONF-SOFTWARE-ENG",	"Proc. --- Int. Conf. Softw. Eng.")

    define("j-PROC-INT-CONF-SUPERCOMPUTING",	"Proceedings of the International Conference on Supercomputing")
    define("j-PROC-INT-MEETING-PETROLEUM-ENG",	"Proceedings of the International Meeting on Petroleum Engineering")
    define("j-PROC-INT-TEST-CONF",		"Proceedings of the International Test Conference")

    define("j-PROC-IRE",			"Proceedings of the Institute of Radio Engineers")
    define("j-PROC-IRE",			"Proceedings of the IRE")
    define("j-PROC-IRE",			"Proc. IRE")

    define("j-PROC-J-MATH",			"Proc. J. Math.")

    define("j-PROC-JAPAN-ACAD-SER-A-MATH-SCI",	"Proceedings of the Japan Academy of Sciences. Series A. Mathematical Sciences")
    define("j-PROC-JAPAN-ACAD-SER-A-MATH-SCI",	"Japan Academy. Proceedings. Series A. Mathematical Sciences")
    define("j-PROC-JAPAN-ACAD-SER-A-MATH-SCI",	"Proc. Japan Acad. Ser. A Math. Sci.")

    ## Proc. LMS: series 1: volumes 1--35 1865--1903;
    ## series 2: volumes 1--54, 1904--1953;
    ## series 3: volumes 1--current, 1951--date

    define("j-PROC-LINN-SOC-LONDON",		"Proceedings of the Linnean Society of London")
    define("j-PROC-LINN-SOC-LONDON",		"Proc. Linn. Soc. London")

    define("j-PROC-LONDON-MATH-SOC-1",		"Proceedings of the London Mathematical Society. First Series")
    define("j-PROC-LONDON-MATH-SOC-1",		"Proceedings of the London Mathematical Society")

    define("j-PROC-LONDON-MATH-SOC-2",		"Proceedings of the London Mathematical Society. Second Series")
    define("j-PROC-LONDON-MATH-SOC-2",		"Proceedings of the London Mathematical Society. Series 2.")
    define("j-PROC-LONDON-MATH-SOC-3",		"Proc. London Math. Soc. (2)")

    define("j-PROC-LONDON-MATH-SOC-3",		"Proceedings of the London Mathematical Society. Third Series")
    define("j-PROC-LONDON-MATH-SOC-3",		"Proceedings of the London Mathematical Society")
    define("j-PROC-LONDON-MATH-SOC-3",		"Proc. London Math. Soc. (3)")
    define("j-PROC-LONDON-MATH-SOC-3",		"Proc. London Math. Soc.")
    define("j-PROC-LONDON-MATH-SOC-3",		"Proc. Lond. Math. Soc.")

    define("j-PROC-MANCHESTER-LIT-PHILOS-SOC",	"Proceedings of the Manchester Literary and Philosophical Society (Manchester Memoirs)")
    define("j-PROC-MANCHESTER-LIT-PHILOS-SOC",	"Proceedings of the Manchester Literary and Philosophical Society")
    define("j-PROC-MANCHESTER-LIT-PHILOS-SOC",	"Proc. Manchester Lit. Philos. Soc.")

    define("j-PROC-NATL-ACAD-SCI-USA",		"Proceedings of the National Academy of Sciences of the United States of America")
    define("j-PROC-NATL-ACAD-SCI-USA",		"Proceedings of the National Academy of Science")
    define("j-PROC-NATL-ACAD-SCI-USA",		"Proc. Natl. Acad. Sci. USA")
    define("j-PROC-NATL-ACAD-SCI-USA",		"Proc Natl Acad Sci U S A (PV3)")
    define("j-PROC-NATL-ACAD-SCI-USA",		"Proc. Nat. Acad. Sci. (U.S.A.)")
    define("j-PROC-NATL-ACAD-SCI-USA",		"Proc. Nat. Acad. Sci. (USA)")
    define("j-PROC-NATL-ACAD-SCI-USA",		"Proc. Nat. Acad. Sci. USA")
    define("j-PROC-NATL-ACAD-SCI-USA",		"Proc. Nat. Acad. Sci. Wash.")
    define("j-PROC-NATL-ACAD-SCI-USA",		"Proc. Nat. Acad. Sci.")
    define("j-PROC-NATL-ACAD-SCI-USA",		"Proc. Natl. Acad. Sci. (U.S.A.)")
    define("j-PROC-NATL-ACAD-SCI-USA",		"Proc. Natl. Acad. Sci. U. S. A.")
    define("j-PROC-NATL-ACAD-SCI-USA",		"Proc. Natl. Acad. Sci. USA")
    define("j-PROC-NATL-ACAD-SCI-USA",		"Proc. Natl. Acad. Sci.")
    define("j-PROC-NATL-ACAD-SCI-USA",		"Proc. Natl. Acad. Sciences USA")
    define("j-PROC-NATL-ACAD-SCI-USA",		"Proc. Natn. Acad. Sci. (U.S.A.)")
    define("j-PROC-NATL-ACAD-SCI-USA",		"Proc. Natn. Acad. Sci. U. S. A.")
    define("j-PROC-NATL-ACAD-SCI-USA",		"Proc. Natn. Acad. Sci., U. S. A.")
    define("j-PROC-NATL-ACAD-SCI-USA",		"Proceedings of the National Academy of Sciences")
    define("j-PROC-NATL-ACAD-SCI-USA",		"Proceedings of the National Academy of Sciences, USA")
    define("j-PROC-NATL-ACAD-SCI-USA",		"PNAS")
    define("j-PROC-NATL-ACAD-SCI-USA",		"Proceedings National Academy of Natural Science. USA")

    define("j-PROC-NATL-ONLINE-MEET",		"Proceedings --- National Online Meeting")
    define("j-PROC-NATL-ONLINE-MEET",		"Proc. Natl. Online Meet.")

    define("j-PROC-PETROLEUM-COMPUT-CONF",	"Proceedings --- Petroleum Computer Conference")

    define("j-PROC-PHYS-SOC",			"Proceedings of the Physical Society, London")
    define("j-PROC-PHYS-SOC",			"Proceedings of the Physical Society")
    define("j-PROC-PHYS-SOC",			"Proc. Phys. Soc. Lond.")
    define("j-PROC-PHYS-SOC",			"Proc. Phys. Soc.")

    define("j-PROC-PHYS-SOC-LONDON-SECT-A",	"Proceedings of the Physical Society, London, Section A")
    define("j-PROC-PHYS-SOC-LONDON-SECT-A",	"Proceedings of the Physical Society. Section A")
    define("j-PROC-PHYS-SOC-LONDON-SECT-A",	"Proc. Phys. Soc., London, Sect. A")
    define("j-PROC-PHYS-SOC-LONDON-SECT-A",	"Proc. Phys. Soc., Sect. A")
    define("j-PROC-PHYS-SOC-LONDON-SECT-A",	"Proc. Phys. Soc. A")

    define("j-PROC-PHYS-SOC-LONDON-SECT-B",	"Proceedings of the Physical Society, London, Section B")
    define("j-PROC-PHYS-SOC-LONDON-SECT-B",	"Proceedings of the Physical Society. Section B")
    define("j-PROC-PHYS-SOC-LONDON-SECT-B",	"Proc. Phys. Soc., Sect. B")
    define("j-PROC-PHYS-SOC-LONDON-SECT-B",	"Proc. Phys. Soc., London, Sect. B")

    define("j-PROC-R-INST-G-B",			"Proceedings of the Royal Institution of Great Britain")
    define("j-PROC-R-INST-G-B",			"Proceedings of the Royal Institution")
    define("j-PROC-R-INST-G-B",			"Proc. Roy. Inst.")
    define("j-PROC-R-INST-G-B",			"Proc. R. Instn Gt. Br.")
    define("j-PROC-R-INST-G-B",			"Proc. R. Instn")
    define("j-PROC-R-INST-G-B",			"Proc. R. I. of G. B.")
    define("j-PROC-R-INST-G-B",			"Proc. Roy. Inst. Gr. Brit.")
    define("j-PROC-R-INST-G-B",			"Proc. Roy. Inst. of G. B.")
    define("j-PROC-R-INST-G-B",			"Proc. R. Inst. G. B.")

    define("j-PROC-R-IR-ACAD-SECT-A",		"Proceedings of the Royal Irish Academy, Section A: Mathematical and Physical Sciences")
    define("j-PROC-R-IR-ACAD-SECT-A",		"Proc. R. Ir. Acad., Sect. A")
    define("j-PROC-R-IR-ACAD-SECT-A",		"Proc. R. Irish Acad")	# temporary for schroedinger-erwin.bib

    ## From http://rspl.royalsocietypublishing.org/site/misc/historicaltimeline.xhtml
    ##
    ##     Proceedings of the Royal Society A: Mathematical, Physical and Engineering Sciences
    ##     ISSN: 1364–5021
    ##     Volumes 452–
    ##
    ##     1996 Renamed
    ##
    ##     Proceedings of the Royal Society A: Mathematical and Physical Sciences (1990–1995)
    ##     ISSN: 0962–8444
    ##     Volumes 430–451
    ##
    ##     Proceedings of the Royal Society B: Biological Sciences
    ##     ISSN: 0962–8452
    ##     Volumes 241–
    ##
    ##     1990 Renamed
    ##
    ##     Proceedings of the Royal Society of London. Series A, Mathematical and Physical Sciences (1934–1990)
    ##     ISSN: 0080–4630
    ##     Volumes 147–429
    ##
    ##     Proceedings of the Royal Society of London. Series B, Biological Sciences (1934–1990)
    ##     ISSN: 0080–4649
    ##     Volumes 116–240
    ##
    ##     1934 Renamed
    ##
    ##     Proceedings of the Royal Society of London. Series A, Containing Papers of a Mathematical and Physical Character (1905–1934)
    ##     ISSN: 0950–1207
    ##     Volumes 76–146
    ##
    ##     Proceedings of the Royal Society of London. Series B, Containing Papers of a Biological Character (1905–1934)
    ##     ISSN: 0950–1193
    ##     Volumes 76–115
    ##
    ##     1905 Split
    ##
    ##     Proceedings of the Royal Society of London (1854–1905)
    ##     ISSN: 0370–1662
    ##     Volumes 7–75
    ##
    ##     1854 Renamed
    ##
    ##     Abstracts of the Papers Communicated to the Royal Society of London (1843–1854)
    ##     ISSN: 0365–0855
    ##     Volumes 5–6
    ##
    ##     1843 Renamed
    ##
    ##     Abstracts of the Papers Printed in the Philosophical Transactions of the Royal Society of London (1800–1843)
    ##     ISSN: 0365–5695
    ##     Volumes 1–4

    define("j-PROC-R-SOC-B",			"Proceedings of the Royal Society B: Biological Sciences")
    define("j-PROC-R-SOC-B",			"Proc. R. Soc. B")
    define("j-PROC-R-SOC-B",			"Proceedings of the Royal Society B")
    define("j-PROC-R-SOC-B",			"Proc. R. Soc. Lond. Ser. B. Biol. sci.")

    define("j-PROC-R-SOC-EDINB",		"Proceedings of the Royal Society of Edinburgh")
    define("j-PROC-R-SOC-EDINB",		"Proc. Royal Soc. Edin.")
    define("j-PROC-R-SOC-EDINB",		"Proc. Royal Soc. Edinburgh")
    define("j-PROC-R-SOC-EDINB",		"Proc. Roy. Soc. Edinburgh")
    define("j-PROC-R-SOC-EDINB",		"Proc. R. Soc. Edinb.")
    define("j-PROC-R-SOC-EDINB",		"Proc. Roy. Soc. Edinb.")

    ## define("j-PROC-R-SOC-EDINB-A",		"Proceedings of the Royal Society of Edinburgh --- Section A: Mathematical and physical sciences")
    ## define("j-PROC-R-SOC-EDINB-A",		"Proc. R. Soc. Edinb., A.")
    ## define("j-PROC-R-SOC-EDINB-A",		"Proceedings. Section A, Mathematical and physical sciences / The Royal Society of Edinburgh")
    ## define("j-PROC-R-SOC-EDINB-A",		"Proceedings of the Royal Society of Edinburgh. Section A")

    ## v72 n1 1974 to date
    ## Preceded by Proceedings - Royal Society of Edinburgh, Section A: Mathematical and Physical Sciences
    define("j-PROC-R-SOC-EDINB-SECT-A-MATH",	"Proceedings of the Royal Society of Edinburgh. Section A, Mathematical and Physical Sciences")
    define("j-PROC-R-SOC-EDINB-SECT-A-MATH",	"Proceedings of the Royal Society of Edinburgh: Section A Mathematics")
    define("j-PROC-R-SOC-EDINB-SECT-A-MATH",	"Proc. R. Soc. Edinb., Sect. A, Math.")
    define("j-PROC-R-SOC-EDINB-SECT-A-MATH",	"Proc. R. Soc. Edinb., Sect. A, Math. Phys. Sci.")
    define("j-PROC-R-SOC-EDINB-SECT-A-MATH",	"Proc. Roy. Soc. Edinburgh Sect. A")

    ## v61 1941 (Pub. 1943)-v71 n4 1974
    ## Preceded by Proceedings of the Royal Society of Edinburgh
    ## Followed by Proceedings - Royal Society of Edinburgh, Section A: Mathematics Communications - Royal Society of Edinburgh, Physical Sciences
    define("j-PROC-R-SOC-EDINB-SECT-A-MATH-PHYS-SCI",	"Proceedings - Royal Society of Edinburgh, Section A: Mathematical and Physical Sciences")
    define("j-PROC-R-SOC-EDINB-SECT-A-MATH-PHYS-SCI",	"Proc. - R. Soc. Edinburgh, Sect. A: Math. Phys. Sci.")

    define("j-PROC-R-SOC-EDINB-SECT-B-BIOL-SCI","Proceedings of the Royal Society of Edinburgh. Section B, Biological sciences")
    define("j-PROC-R-SOC-EDINB-SECT-B-BIOL-SCI","Proc. R. Soc. Edinb., Sect. B Biol. sci.")

    define("j-PROC-R-SOC-EDINB-SECT-B-NAT-ENVIRON", "Proceedings of the Royal Society of Edinburgh. Section B, Natural Environment")
    define("j-PROC-R-SOC-EDINB-SECT-B-NAT-ENVIRON", "Proc. R. Soc. Edinb. Sec. B. Nat. Environ.")

    define("j-PROC-R-PHILOS-SOC-GLASGOW",	"Proceedings of the Royal Philosophical Society of Glasgow")
    define("j-PROC-R-PHILOS-SOC-GLASGOW",	"Proc. R. Philos. Soc. Glasgow")
    define("j-PROC-R-PHILOS-SOC-GLASGOW",	"Proc. Roy. Philos. Soc. Glasgow")

    define("j-PROC-R-SOC-LOND",			"Proceedings of the Royal Society of London")
    define("j-PROC-R-SOC-LOND",			"Proc. Roy. Soc. London")
    define("j-PROC-R-SOC-LOND",			"Proc. Roy. Soc. Lond.")
    define("j-PROC-R-SOC-LOND",			"Proc. Roy. Soc. (Lon)")

    define("j-PROC-R-SOC-LOND-SER-A",		"Proceedings of the Royal Society of London. Series A")
    define("j-PROC-R-SOC-LOND-SER-A",		"Proceedings of the Royal Society of London A")
    define("j-PROC-R-SOC-LOND-SER-A",		"Proc. R. Soc. London, Ser. A")

    define("j-PROC-R-SOC-LOND-SER-A-MATH-PHYS",	"Proceedings of the Royal Society of London. Series A, Containing Papers of a Mathematical and Physical Character")
    define("j-PROC-R-SOC-LOND-SER-A-MATH-PHYS",	"Proc. R. Soc. Lond. Ser. A Math. Phys.")
    define("j-PROC-R-SOC-LOND-SER-A-MATH-PHYS",	"R. Soc. Lond. Proc. Ser. A Math. Phys.")

    define("j-PROC-R-SOC-LOND-SER-A-MATH-PHYS-ENG-SCI", "Proceedings of the Royal Society A: Mathematical, Physical, and Engineering Sciences")
    define("j-PROC-R-SOC-LOND-SER-A-MATH-PHYS-ENG-SCI", "Proceedings of the Royal Society A: Mathematical, Physical, \\& Engineering Sciences")
    define("j-PROC-R-SOC-LOND-SER-A-MATH-PHYS-ENG-SCI", "Proceedings of the Royal Society A: Mathematical, Physical, and Engineering Science")
    define("j-PROC-R-SOC-LOND-SER-A-MATH-PHYS-ENG-SCI", "Proceedings of the Royal Society of London A: Mathematical, Physical, \\& Engineering Sciences")
    define("j-PROC-R-SOC-LOND-SER-A-MATH-PHYS-ENG-SCI", "Proceedings of the Royal Society of London A: Mathematical, Physical, and Engineering Sciences")
    define("j-PROC-R-SOC-LOND-SER-A-MATH-PHYS-ENG-SCI", "Proc. R. Soc. Lond., Ser. A, Math. Phys. Eng. Sci.")
    define("j-PROC-R-SOC-LOND-SER-A-MATH-PHYS-ENG-SCI", "Proc. R. Soc. Lond. Ser. A Math. Phys. Eng. Sci.")
    define("j-PROC-R-SOC-LOND-SER-A-MATH-PHYS-ENG-SCI", "R. Soc. Lond. Proc. Ser. A Math. Phys. Eng. Sci.")

    define("j-PROC-R-SOC-LOND-SER-A-MATH-PHYS-SCI", "Proceedings of the Royal Society of London. Series A, Mathematical and physical sciences")
    define("j-PROC-R-SOC-LOND-SER-A-MATH-PHYS-SCI", "Proc. R. Soc. A")
    define("j-PROC-R-SOC-LOND-SER-A-MATH-PHYS-SCI", "Proc. R. Soc. Lond. A")
    define("j-PROC-R-SOC-LOND-SER-A-MATH-PHYS-SCI", "Proc. R. Soc. Lond. A.")
    define("j-PROC-R-SOC-LOND-SER-A-MATH-PHYS-SCI", "Proc. R. Soc. Lond., Ser. A")
    define("j-PROC-R-SOC-LOND-SER-A-MATH-PHYS-SCI", "Proc. R. Soc. Lond., Ser. A, Math. phys. sci.")
    define("j-PROC-R-SOC-LOND-SER-A-MATH-PHYS-SCI", "Proc. Roy. Soc. Lond. A")
    define("j-PROC-R-SOC-LOND-SER-A-MATH-PHYS-SCI", "Proc. Roy. Soc. London Ser. A")
    define("j-PROC-R-SOC-LOND-SER-A-MATH-PHYS-SCI", "Proc. Roy. Soc. London, Series A")
    define("j-PROC-R-SOC-LOND-SER-A-MATH-PHYS-SCI", "Proceedings of the Royal Society A")

    define("j-PROC-R-SOC-LOND-SER-B",		"Proceedings of the Royal Society of London Series B")
    define("j-PROC-R-SOC-LOND-SER-B",		"Proc. R. Soc. Lond. Ser. B")

    define("j-PROC-R-SOC-LOND-SER-B-BIO-SCI",	"Proceedings of the Royal Society of London. Series B. Biological sciences")
    define("j-PROC-R-SOC-LOND-SER-B-BIO-SCI",	"Proceedings of the Royal Society of London. Series B, Containing Papers of a Biological Character")
    define("j-PROC-R-SOC-LOND-SER-B-BIO-SCI",	"Proceedings of the Royal Society of London. B. Biological Sciences")
    define("j-PROC-R-SOC-LOND-SER-B-BIO-SCI",	"Proc R Soc Lond B Biol Sci (PXF)")
    define("j-PROC-R-SOC-LOND-SER-B-BIO-SCI",	"Proc. R. Soc. Lond. Ser. B. Biol. Sci.")
    define("j-PROC-R-SOC-LOND-SER-B-BIO-SCI",	"Proc. Roy. Soc. London B.")
    define("j-PROC-R-SOC-LOND-SER-B-BIO-SCI",	"Proc. Roy. Soc. Lond. B.")
    define("j-PROC-R-SOC-LOND-SER-B-BIO-SCI",	"Proceedings. Biological sciences")
    define("j-PROC-R-SOC-LOND-SER-B-BIO-SCI",	"Proc. Roy. Soc. B")
    define("j-PROC-R-SOC-LOND-SER-B-BIO-SCI",	"Proceedings of the Royal Society of London B")
    define("j-PROC-R-SOC-LOND-SER-B-BIO-SCI",	"Proceedings of the Royal Society B")
    define("j-PROC-R-SOC-LOND-SER-B-BIO-SCI",	"Royal Society of London B")

    define("j-PROC-REAL-TIME-SYS-SYMP",		"Proceedings --- Real-Time Systems Symposium")
    define("j-PROC-SID",			"Proceedings of the Society for Information Display")

    define("j-PROC-SOC-EXP-BIOL-MED",		"Proceedings of the Society for Experimental Biology and Medicine")
    define("j-PROC-SOC-EXP-BIOL-MED",		"Proc. Soc. Exp. Biol. Med.")

    define("j-PROC-SOC-PSYCH-RES",		"Proceedings of the Society for Psychical Research")
    define("j-PROC-SOC-PSYCH-RES",		"Proc. Soc. Psych. Res.")

    define("j-PROC-SOIL-SCI-SOC-AM",		"Proceedings --- Soil Science Society of America")
    define("j-PROC-SOIL-SCI-SOC-AM",		"Proc. --- Soil Sci. Soc. Am.")
    define("j-PROC-SOIL-SCI-SOC-AM",		"Proc. Soil Sci. Soc. Amer.")

    define("j-PROC-SPIE",			"Proceedings of the SPIE --- The International Society for Optical Engineering")
    define("j-PROC-SPIE",			"Proc. SPIE Int. Soc. Opt. Eng.")

    define("j-PROC-STEKLOV-INST-MATH",		"Trudy Matematicheskogo instituta imeni V. A. Steklova = Proceedings of the Steklov Institute of Mathematics")
    define("j-PROC-STEKLOV-INST-MATH",		"Trudy Matem. Inst. Steklov")
    define("j-PROC-STEKLOV-INST-MATH",		"Proc. Steklov Inst. Math.")
    define("j-PROC-STEKLOV-INST-MATH",		"Trudy Mat. Inst. Steklov.")

    define("j-PROC-SUPERCOMPUT",		"Proceedings of the Supercomputing Conference")
    define("j-PROC-SUPERCOMPUT",		"Proc. - Supercomput.")

    define("j-PROC-SYMP-APPL-MATH",		"Proceedings of Symposia in Applied Mathematics")
    define("j-PROC-SYMP-APPL-MATH",		"Proc. Sympos. Appl. Math.")
    define("j-PROC-SYMP-APPL-MATH",		"Proc. symp. appl. math.")
    define("j-PROC-SYMP-APPL-MATH",		"Proc. Symp. appl. Math. Am. Math. Soc.")

    define("j-PROC-SYMP-PURE-MATH",		"Proceedings of Symposia in Pure Mathematics")
    define("j-PROC-SYMP-PURE-MATH",		"Proc. Sympos. Pure Math.")
    define("j-PROC-SYMP-PURE-MATH",		"Proc. of Symp. Pure Math.")

    define("j-PROC-VLDB-ENDOWMENT",		"Proceedings of the VLDB Endowment")
    define("j-PROC-VLDB-ENDOWMENT",		"Proc. VLDB Endowment")

    define("j-PROCEDIA-SOC-BEHAV-SCI",		"Procedia --- Social and Behavioral Sciences")
    define("j-PROCEDIA-SOC-BEHAV-SCI",		"Procedia Soc. Behav. Sci.")

    define("j-PROG-ASTRONAUT-AERONAUT",		"Progress in astronautics and aeronautics")
    define("j-PROG-ASTRONAUT-AERONAUT",		"Progress in astronautics and aeronautics: an American Institute of Aeronautics and Astronautics series")
    define("j-PROG-ASTRONAUT-AERONAUT",		"Prog. astronaut. aeronaut.")

    define("j-PROG-BIOPHYS-MOL-BIOL",		"Progress in Biophysics and Molecular Biology")
    define("j-PROG-BIOPHYS-MOL-BIOL",		"Prog. Biophys. Mol. Biol.")
    define("j-PROG-BIOPHYS-MOL-BIOL",		"Prog. Biophys. Molec. Biol.")

    define("j-PROG-BIOPHYS-BIOPHYS-CHEM",	"Progress in biophysics and biophysical chemistry")
    define("j-PROG-BIOPHYS-BIOPHYS-CHEM",	"Prog. Biophys. Biophys. Chem.")

    define("j-PROG-CELL-CYCLE-RES",		"Progress in Cell Cycle Research")
    define("j-PROG-CELL-CYCLE-RES",		"Prog. Cell Cycle Res.")

    define("j-PROG-CLIN-BIO-RES",		"Progress in clinical and biological research")
    define("j-PROG-CLIN-BIO-RES",		"Prog Clin Biol Res (PZ5)")

    define("j-PROG-COMP-SOFT",			"Programming and Computer Software; translation of Programmirovaniye (Moscow, USSR) Plenum")
    define("j-PROG-COMP-SOFT",			"Program. Comp. Software")
    define("j-PROG-COMP-SOFT",			"Program. Comput. Software")
    define("j-PROG-COMP-SOFT",			"Programming and Computer Software")
    define("j-PROG-COMP-SOFT",			"Program. Comput. Softw.")
    define("j-PROG-COMP-SOFT",			"Prog. Comp. Softw.")

    define("j-PROG-ELECTROMAGN-RES",		"Progress in Electromagnetics Research (PIER)")
    define("j-PROG-ELECTROMAGN-RES",		"Progress in Electromagnetics Research")
    define("j-PROG-ELECTROMAGN-RES",		"Prog. Electromagn. Res.")

    define("j-PROG-NUCL-PHYS",			"Progress in Nuclear Physics")
    define("j-PROG-NUCL-PHYS",			"Prog. nucl. Phys.")

    define("j-PROG-NUCLEIC-ACID-RES-MOL-BIO",	"Progress in nucleic acid research and molecular biology")
    define("j-PROG-NUCLEIC-ACID-RES-MOL-BIO",	"Prog Nucleic Acid Res Mol Biol (Q4X)")

    define("j-PROG-PART-NUCL-PHYS",		"Progress in Particle and Nuclear Physics")
    define("j-PROG-PART-NUCL-PHYS",		"Prog. Part. Nucl. Phys.")

    define("j-PROG-SURF-SCI",			"Progress in Surface Science")
    define("j-PROG-SURF-SCI",			"Prog. surf. sci.")

    define("j-PROG-THEOR-PHYS",			"Progress of Theoretical Physics")
    define("j-PROG-THEOR-PHYS",			"Progress Theoret. Physics")
    define("j-PROG-THEOR-PHYS",			"Progr. Theoret. Phys.")
    define("j-PROG-THEOR-PHYS",			"Prog. Theor. Phys.")

    define("j-PROGR-OCEANOGR",			"Progress in Oceanography")
    define("j-PROGR-OCEANOGR",			"Prog. Oceanogr.")

    define("j-PROGRAM",				"Program")

    # Vol. 1 (Jan. 1983) --- Ceased with vol. 9, no. 6 (Nov./Dec. 1991)
    define("j-PROGRAM-J",			"Programmer's Journal")
    define("j-PROGRAM-J",			"Program. j.")

    define("j-PROGRAMMIROVANIE",		"Programmirovanie")
    define("j-PROGRESS-NUCLEAR-ENERGY",		"Progress in Nuclear Energy")
    define("j-PROLOGUE",			"Prologue: the journal of the National Archives")
    define("j-PROTEIN-SEQ-DATA-ANAL",		"Protein Seq Data Anal (PSA)")

    define("j-PROTEIN-STRUCT-FUNCT-BIOINF",	"Proteins: Structure, Function, and Bioinformatics")
    define("j-PROTEIN-STRUCT-FUNCT-BIOINF",	"Proteins: Struct., Funct., Bioinf.")

    define("j-PROTEIN-STRUCT-MOL-ENZYM",	"Protein structure and molecular enzymology")
    define("j-PROTEINS",			"Proteins (PTS)")
    define("j-PROTOPLASMA",			"Protoplasma")

    define("j-PSYCH-WOMEN",			"Psychology of Women Quarterly")

    define("j-PSYCHIATRY",                      "Psychiatry (Washington, D.C.)")
    define("j-PSYCHIATRY",                      "Psychiatry")
    define("j-PSYCHIATRY",                      "Psychiatry (Wash. D.C.)")

    define("j-PSYCHOL-METHODS",			"Psychological Methods")
    define("j-PSYCHOL-METHODS",			"Psychol. Methods")

    define("j-PSYCHOL-REP",			"Psychological Reports")
    define("j-PSYCHOL-REP",			"Psychol. Rep.")

    define("j-PSYCHOL-REV",			"Psychological Review")
    define("j-PSYCHOL-REV",			"Psychol. Rev.")

    define("j-PSYCHOMETRIKA",			"Psychometrika")
    define("j-PTERIDINES",			"Pteridines")
    define("j-PUB-AFFAIRS-QUART",		"Public Affairs Quarterly")
    define("j-PUB-CENTRE-EUR-ETUDES-BURGONDO-MEDIANES", "Publication du Centre Europ{\\'e}en d'{\\'E}tudes Burgondo-M{\\'e}dianes")
    define("j-PUB-MAT",				"Publicacions Matematiques")
    define("j-PUB-RELATIONS-REV",		"Public Relations Review")

    define("j-PUBL-ASTRON-SOC-JPN",		"Publications of the {Astronomical Society of Japan}")
    define("j-PUBL-ASTRON-SOC-JPN",		"Publ. of the Astron. Society of Japan")
    define("j-PUBL-ASTRON-SOC-JPN",		"Publ. {Astron. Soc. Jpn.}")

    define("j-PUBL-ASTRON-SOC-PAC",		"Publications of the {Astronomical Society of the Pacific}")
    define("j-PUBL-ASTRON-SOC-PAC",		"Publ. {Astron. Soc. Pac.}")

    define("j-PUBL-MATH-DEBRECEN",		"Publicationes Mathematicae Debrecen")
    define("j-PUBL-MATH-DEBRECEN",		"Publ. Math. Debrecen")

    define("j-PUBL-RELAT-J",			"The Public relations journal")
    define("j-PUBL-RELAT-J",			"Publ. relat. j.")

    define("j-PUBLIC-ACCESS-COMPUT-SYST-REV",	"Public-access Computer Systems Review")
    define("j-PUBLIC-ACCESS-COMPUT-SYST-REV",	"Public-access Comput. Syst. Rev.")

    define("j-PUBLIC-MANAGE",			"Public management")
    define("j-PUBLIC-MANAGE",			"Public manage.")

    define("j-PUBLISH",				"Publish!: the how-to magazine of desktop publishing")
    define("j-PUBLISH",				"Publish!: the how-to magazine of desktop publi")
    define("j-PUBLISH",				"Publish!")

    define("j-PUBLISHERS-WEEKLY",		"Publishers weekly")
    define("j-PUBLISHING",			"Publishing")
    define("j-PUBLISHING-PROD-EXEC",		"Publishing and production executive")

    define("j-PUGET-SOUND-BUS-J",		"Puget Sound business journal")
    define("j-PUGET-SOUND-BUS-J",		"Puget Sound bus. j.")

    define("j-PURE-APPL-CHEM",			"Pure and Applied Chemistry")
    define("j-PURE-APPL-CHEM",			"Pure. Appl. Chem.")

    define("j-PURE-APPL-GEOPHYS",		"Pure and Applied Geophysics")
    define("j-PURE-APPL-GEOPHYS",		"Pure Appl. Geophys.")

    define("j-PYRODYNAMICS",			"Pyrodynamics")

    define("j-Q-J-ECON",			"The Quarterly Journal of Economics")
    define("j-Q-J-ECON",			"Quarterly Journal of Economics")
    define("j-Q-J-ECON",			"Q. J. Econ.")

    define("j-Q-J-R-ASTRON-SOC",		"Quarterly Journal of the Royal Astronomical Society")
    define("j-Q-J-R-ASTRON-SOC",		"Royal Astronomical Society, Quarterly Journal")
    define("j-Q-J-R-ASTRON-SOC",		"Quart. Journ. Roy. Astron. Soc.")
    define("j-Q-J-R-ASTRON-SOC",		"Q. J. Roy. Astron. Soc.")
    define("j-Q-J-R-ASTRON-SOC",		"Q. Jl. R. Astr. Soc.")
    define("j-Q-J-R-ASTRON-SOC",		"Q. J. R. Astron. Soc.")

    define("j-Q-REV-BIOL",			"Quarterly Review of Biology")
    define("j-Q-REV-BIOL",			"Q. Rev. Biol.")

    define("j-QCPE",				"Quantum Chemistry Program Exchange Newsletter")
    define("j-QCPE",				"Quantum Chemistry Program Exchange Bulletin")

    define("j-QJM",				"Quarterly Journal of Medicine")
    define("j-QJM",				"QJM")

    define("j-QRB",				"QRB. Quality review bulletin")

    define("j-QSAR",				"Quantitative structure-activity relationships including molecular modelling and applications of computer graphics in pharmacology, chemistry, and biology: QSAR")
    define("j-QSAR",				"Quantitative structure-activity relationships")
    define("j-QSAR",				"QSAR")

    define("j-QUAD-STORIA-FISICA",		"Quaderni di Storia della fisica")
    define("j-QUAD-STORIA-FISICA",		"Quad. Storia Fis.")
    define("j-QUAD-STORIA-FISICA",		"Quad. Storia fisica")

    define("j-QUAD-UNIONE-MAT-ITAL",		"Quaderni dell'Unione matematica italiana")
    define("j-QUAD-UNIONE-MAT-ITAL",		"Quad. Unione Mat. Italiana")

    define("j-QUAERENDO",			"Quaerendo, A Quarterly Journal from the Low Countries Devoted to Manuscripts and Printed Books")

    define("j-QUAL-QUANT",			"Quality \\& Quantity")
    define("j-QUAL-QUANT",			"Quality and Quantity")
    define("j-QUAL-QUANT",			"Qual. Quant.")

    define("j-QUANT-FINANCE",			"Quantitative Finance")
    define("j-QUANT-FINANCE",			"Quant. Finance")

    define("j-QUANTUM-INF-PROCESS",		"Quantum Information Processing")
    define("j-QUANTUM-INF-PROCESS",		"Quantum Inf. Process.")

    define("j-QUART-APPL-MATH",			"Quarterly of Applied Mathematics")
    define("j-QUART-APPL-MATH",			"Quart. Appl. Math.")
    define("j-QUART-APPL-MATH",			"Quarterly appl. Math.")
    define("j-QUART-APPL-MATH",			"Q. Appl. Math.")

    define("j-QUART-J-MATH",			"Quarterly Journal of Mathematics")
    define("j-QUART-J-MATH",			"Quart. J. Math.")
    define("j-QUART-J-MATH",			"Quarterly J. of Math.")

    define("j-QUART-J-MATH-OXFORD",		"Quarterly Journal of Mathematics.  Oxford series.")
    define("j-QUART-J-MATH-OXFORD",		"Quart. J. Math. Oxford Ser.")
    define("j-QUART-J-MATH-OXFORD",		"Quarterly J. of Math. Oxford")

    define("j-QUART-J-MECH-APPLIED-MATH",	"Quarterly Journal of Mechanics and Applied Mathematics")
    define("j-QUART-J-MECH-APPLIED-MATH",	"Q. J. Mech. appl. Math.")
    define("j-QUART-J-MECH-APPLIED-MATH",	"Quart. J. Mech. Applied Math.")
    define("j-QUART-J-MECH-APPLIED-MATH",	"Quart. J. Mech. and Applied Math.")
    define("j-QUART-J-MECH-APPLIED-MATH",	"Quart. J. Mech. Appl. Math.")

    define("j-QUART-J-MICROSCOP-SCI",		"Quarterly journal of microscopical science")
    define("j-QUART-J-MICROSCOP-SCI",		"Q. J. Microscop. Sci.")

    define("j-QUART-J-ROY-METEOROL-SOC",	"Quarterly journal of the Royal Meteorological Society")
    define("j-QUART-J-ROY-METEOROL-SOC",	"Quart. J. Roy. Met. Soc.")
    define("j-QUART-J-ROY-METEOROL-SOC",	"Q. J. R. Meteorol. Soc.")

    define("j-QUEUE",				"ACM Queue: Tomorrow's Computing Today")
    define("j-QUEUE",				"Queue")
    define("j-QUEUE",				"ACM Queue")

    define("j-QUILL",				"The quill")

    define("j-R-SOC-OPEN-SCI",			"Royal Society Open Science")
    define("j-R-SOC-OPEN-SCI",			"R. Soc. Open Sci.")

    define("j-RADIAT-PHYS-CHEM",		"Radiation Physics and Chemistry")
    define("j-RADIAT-PHYS-CHEM",		"Radiat. Phys. Chem.")

    define("j-RADIAT-RES",			"Radiation Research")
    define("j-RADIAT-RES",			"Radiat. Res.")

    define("j-RADIO-ELECTRON-ENG",		"The Radio and electronic engineer")
    define("j-RADIO-ELECTRON-ENG",		"Radio electron. eng.")
    define("j-RADIO-ELECTRON-ENG",		"Radio electron. Engr")

    define("j-RADIO-SCI",			"Radio Science")

    define("j-RADIOCHIM-ACTA",			"Radiochimica Acta")
    define("j-RADIOCHIM-ACTA",			"Radiochim. Acta")

    define("j-RADIOLOGY",			"Radiology")
    define("j-RADIOLOGY",			"Radiology (Oak Brook, IL, U. S.)")
    define("j-RADIOLOGY",			"Radiology (Oak Brook, IL, USA)")
    define("j-RADIOLOGY",			"Radiology (Easton, PA, U. S.)")
    define("j-RADIOLOGY",			"Radiology (Easton, PA, USA)")
    define("j-RADIOLOGY",			"Radiology")

    define("j-RADIUM-PARIS",			"Radium (Paris)")
    define("j-RADIUM-PARIS",			"Le Radium")

    define("j-RAIRO-AUTOMATIQUE-SYSTEMS-ANA-CONTROL","R.A.I.R.O. Automatique/Systems Analysis and Control")
    define("j-RAIRO-NUM-ANA",			"R.A.I.R.O. Numerical Analysis")
    define("j-RAIRO-RECH-OPER",			"RAIRO: Recherche operationnelle. RAIRO: Operations research")

    define("j-RAMANUJAN-J",			"The {Ramanujan} Journal")
    define("j-RAMANUJAN-J",			"{Ramanujan} Journal")
    define("j-RAMANUJAN-J",			"{Ramanujan} J.")

    define("j-RAND-COMP-DYN",			"Random and Computational Dynamics")
    define("j-RAND-COMP-DYN",			"Rand. Comp. Dyn.")

    define("j-RAND-STRUCT",			"Random Structures and Algorithms")
    define("j-RAND-STRUCT",			"Random Struct. Algorithms")

    define("j-RAPP-RECH",			"Rapport de Recherche")

    define("j-RCA-REV",				"RCA review")
    define("j-RCA-REV",				"RCA review; a technical journal")
    define("j-RCA-REV",				"RCA review; a quarterly journal of radio progress")
    define("j-RCA-REV",				"RCA rev.")

    define("j-READERS-DIGEST",			"Reader's Digest")
    define("j-REAL-TIME-IMAGING",		"Real-Time Imaging")

    define("j-REAL-TIME-SYST",			"Real-Time Systems")
    define("j-REAL-TIME-SYST",			"Real-Time Syst.")

    define("j-REC-MATH-MAG",			"Recreational Mathematics Magazine")

    define("j-RECHENTECH-DATENVERARB",		"Rechentechnik Datenverarbeitung")
    define("j-RECHENTECH-DATENVERARB",		"Rechentech. Datenverarb.")

    define("j-RECHERCHE",			"La Recherche")

    define("j-REF-LIBR",			"The reference librarian")
    define("j-REF-LIBR",			"Ref. libr.")

    define("j-REG-SCI-URBAN-ECON",		"Regional Science and Urban Economics")
    define("j-REG-SCI-URBAN-ECON",		"Reg. Sci. Urban Econ.")

    define("j-REGISTER",			"The Register")
    define("j-REGISTER",			"Register")

    define("j-RELIABLE-COMPUTING",		"Reliable Computing = Nadezhnye vychisleniia")
    define("j-RELIABLE-COMPUTING",		"Reliab. Comput./Nadezhn. Vychisl.")
    define("j-RELIABLE-COMPUTING",		"Reliab. Comput.")
    define("j-RELIABLE-COMPUTING",		"Reliable Computing")

    define("j-RENAISSANCE-Q",			"Renaissance Quarterly")

    define("j-REND-CIRC-MAT",			"Rendiconti del Circolo matematico di Palermo")
    define("j-REND-CIRC-MAT",			"Rend. Circ. Mat. Palermo")

    define("j-REND-CIRC-MAT-II",		"Rendiconti del Circolo matematico di Palermo, Series II")
    define("j-REND-CIRC-MAT-II",		"Rend. Circ. Mat. Palermo, Ser. II")

    ## This journal in which Enrico Fermi published many of his
    ## Italian works has many names, but his Collected Papers volumes
    ## refer to them as "Rend. Lincei".  This list of alternate names
    ## is taken from http://cassi.cas.org/
    define("j-REND-LINCEI",			"Rendiconti dell'Accademia Nazionale dei Lincei")
    define("j-REND-LINCEI",			"Accademia Nazionale dei Lincei, Classe di Scienze Fisiche, Matematiche e Naturali, Atti, Rendiconti")
    define("j-REND-LINCEI",			"Atti della Accademia Nazionale dei Lincei, Classe di Scienze Fisiche, Matematiche e Naturali, Rendiconti")
    define("j-REND-LINCEI",			"Atti della Accademia Nazionale dei Lincei, Rendiconti, Classe di Scienze Fisiche, Matematiche e Naturali")
    define("j-REND-LINCEI",			"Atti della Reale Accademia Nazionale dei Lincei")
    define("j-REND-LINCEI",			"Atti della Reale Accademia Nazionale dei Lincei, Rendiconti, Classe di Scienze Fisiche, Matematiche e Naturali")
    define("j-REND-LINCEI",			"Atti della Reale Accademia dei Lincei")
    define("j-REND-LINCEI",			"Rendiconti dell'Accademia dei Lincei")
    define("j-REND-LINCEI",			"Rendiconti della Reale Accademia Nazionale dei Lincei")
    define("j-REND-LINCEI",			"Rendiconti delle Sedute della Accademia Nazionale dei Lincei, Classe di Scienze Fisiche, Matematiche e Naturali")
    define("j-REND-LINCEI",			"Accad. Lincei, Atti")
    define("j-REND-LINCEI",			"Accad. Naz. Lincei, Cl. Sci. Fis., Mat. Nat., Atti, Rend.")
    define("j-REND-LINCEI",			"Atti Accad. Naz. Lincei, Rend., Cl. Sci. Fis., Mat. Nat.")
    define("j-REND-LINCEI",			"Atti R. Accad. Lincei")
    define("j-REND-LINCEI",			"Atti R. Accad. Naz. Lincei")
    define("j-REND-LINCEI",			"Atti R. Accad. Naz. Lincei, Rend., Cl. Sci. Fis., Mat. Nat.")
    define("j-REND-LINCEI",			"Rend. Accad. Naz. Lincei")
    define("j-REND-LINCEI",			"Rend. R. Accad. Naz. Lincei")
    define("j-REND-LINCEI",			"Rend. Sedute Accad. Naz. Lincei, Cl. Sci. Fis., Mat. Nat.")
    define("j-REND-LINCEI",			"Rend. Lincei")

    define("j-REND-MAT-APPL-1981",		"Rendiconti di matematica e delle sue applicazioni (1981)")
    define("j-REND-MAT-APPL-1981",		"Rend. mat. appl. (1981)")
    define("j-REND-MAT-APPL-1981",		"Rendiconti di Matematica e delle sue Applicazioni. Serie VII")
    define("j-REND-MAT-APPL-1981",		"Rend. Mat. Appl. (7)")

    ## 3rd (1833)-86th (Sept. 5-9, 1916).
    ## Journal appears in annual volumes without separate volume/number/month data
    define("j-REP-BRIT-ASSOC-ADV-SCI",		"Report of the British Association for the Advancement of Science")
    define("j-REP-BRIT-ASSOC-ADV-SCI",		"Report of the British Association")
    define("j-REP-BRIT-ASSOC-ADV-SCI",		"Rep. Brit. Assoc.")
    define("j-REP-BRIT-ASSOC-ADV-SCI",		"Rep. Brit. Assoc. Adv. Sci.")

    define("j-REP-MATH-PHYS",			"Reports on Mathematical Physics")
    define("j-REP-MATH-PHYS",			"Reports on Math. Physics")
    define("j-REP-MATH-PHYS",			"Rep. math. phys.")

    define("j-REP-OBJECT-ANA-DESIGN",           "Report on Object Analysis and Design")

    define("j-REP-PROG-PHYS",			"Reports on Progress in Physics")
    define("j-REP-PROG-PHYS",			"Rep. Prog. Phys.")
    define("j-REP-PROG-PHYS",			"Rep. Progr. Phys.")

    define("j-RES-DEV",				"Research \\& Development")
    define("j-RES-DEV",				"Res. Dev.")
    define("j-RES-DEV",				"R \\& D")
    define("j-RES-DEV",				"R \\& D Magazine")

    define("j-RES-MATH-SCI",			"Research in the Mathematical Sciences")
    define("j-RES-MATH-SCI",			"Res. Math. Sci")

    define("j-RES-MICROBIOL",			"Research in microbiology")
    define("j-RES-MICROBIOL",			"Res Microbiol (R6F)")

    define("j-RES-NOTES-MATH",			"Research notes in mathematics")
    define("j-RES-NOTES-MATH",			"Res. notes math.")

    define("j-RES-OP",				"Recherche op{\\'e}rationelle\\slash Operations Research")

    define("j-RES-POLICY",			"Research Policy")
    define("j-RES-POLICY",			"Res. Policy")

    define("j-RESONANCE",			"Resonance")

    define("j-RESOUR-SHAR-INF-NETW",		"Resource sharing \\& information networks")
    define("j-RESOUR-SHAR-INF-NETW",		"Resour. shar. inf. netw.")

    define("j-RESULTS-MATH",			"Results in Mathematics = Resultate der Mathematik")
    define("j-RESULTS-MATH",			"Results in Mathematics")
    define("j-RESULTS-MATH",			"Results in Math.")
    define("j-RESULTS-MATH",			"Resultate der Mathematik = Mathematical results")
    define("j-RESULTS-MATH",			"Resultate Math.")
    define("j-RESULTS-MATH",			"Result. Math.")

    define("j-RESUSCITATION",			"Resuscitation")

    define("j-RETE",				"{RETE: Strukturgeschichte der Naturwissenschaften}")
    define("j-RETE",				"RETE")

    define("j-REV-AM-HIST",			"Reviews in American History")
    define("j-REV-AM-HIST",			"Rev. Amer. Hist.")
    define("j-REV-AM-HIST",			"Rev. Am. Hist.")

    define("j-REV-ANAL-NUMER-TEORIA-APROX",	"Revista de analiza numerica si teoria aproximatiei")
    define("j-REV-ANAL-NUMER-TEORIA-APROX",	"Rev. Anal. Numer. Teoria Aproximatiei")
    define("j-REV-ANAL-NUMER-TEORIA-APROX",	"Rev. Anal. Numer. Theor. Approx.")
    define("j-REV-ANAL-NUMER-TEORIA-APROX",	"Rev. Anal. Numer. Theor. Aprox.")
    define("j-REV-ANAL-NUMER-TEORIA-APROX",	"Rev. Anal. Numer. Theorie Approximation (Cluj)")

    define("j-REV-BRAS-FIS",			"Revista Brasileira de F{\\'\\i}sica")
    define("j-REV-BRAS-FIS",			"Rev. Bras. Fis.")

    define("j-REV-ECON-STAT",			"Review of Economics and Statistics")
    define("j-REV-ECON-STAT",			"The Review of Economics and Statistics")
    define("j-REV-ECON-STAT",			"Rev. Econ. Stat.")

    define("j-REV-ECON-STUD",			"Review of Economic Studies")
    define("j-REV-ECON-STUD",			"Rev. Econ. Stud")

    define("j-REV-ELECTR-COMMUN-LAB",		"Review of the electrical communication laboratories")
    define("j-REV-ELECTR-COMMUN-LAB",		"Rev. Electr. Commun. Lab.")
    define("j-REV-ELECTR-COMMUN-LAB",		"Rev. of the El. Commun. Lab.")

    define("j-REV-ESP-ELECT",			"Revista espa{\\~n}ola de electronica")
    define("j-REV-ESP-ELECT",			"Revista espanola de electronica")

    define("j-REV-ESP-FISIOL",			"Rev Esp Fisiol (RU9)")

    define("j-REV-FINANCE",			"Review of Finance")
    define("j-REV-FINANCE",			"Rev. Finance")

    define("j-REV-FISH-BIOL-FISH",		"Reviews in Fish Biology and Fisheries")
    define("j-REV-FISH-BIOL-FISH",		"Rev. Fish Biol. Fish.")

    ## NB: publisher uses ampersand, not "and", in journal name
    define("j-REV-FISH-SCI-AQUAC",		"Reviews in Fisheries Science \\& Aquaculture")
    define("j-REV-FISH-SCI-AQUAC",		"Reviews in Fisheries Science and Aquaculture")
    define("j-REV-FISH-SCI-AQUAC",		"Rev. Fish. Sci. Aquac.")

    define("j-REV-GEN-ELECTR",			"Revue G{\\`e}n{\\`e}rale de l'{\\'E}lectricit{\\`e}")
    define("j-REV-GEN-ELECTR",			"Revue Generale de l'Electricite")
    define("j-REV-GEN-ELECTR",			"Rev. g{\\'e}n{\\'e}r. {\\'E}lectr.")
    define("j-REV-GEN-ELECTR",			"RGE")
    define("j-REV-GEN-ELECTR",			"Rev. g{\\'e}n{\\'e}r. {\\'E}lectr., {Paris}")
    define("j-REV-GEN-ELECTR",			"Rev. g{\\'e}n{\\'e}r. {\\'E}lectr. {France}")

    define("j-REV-GEN-SCI-PURES-APPL",		"Revue G{\\'e}n{\\'e}rale des Sciences Pures et Appliqu{\\'e}es")
    define("j-REV-GEN-SCI-PURES-APPL",		"Rev. G{\\'e}n. Sci. Pures Appl.")

    define("j-REV-GEOPHYS-SPACE-PHYS",		"Reviews of geophysics and space physics")
    define("j-REV-GEOPHYS-SPACE-PHYS",		"Rev. geophys. space phys.")

    define("j-REV-HIST-MATH",			"Revue d'Histoire des Math{\\'e}matiques = Journal for the History of Mathematics")
    define("j-REV-HIST-MATH",			"Revue d'Histoire des Math{\\'e}matiques")
    define("j-REV-HIST-MATH",			"Rev. Histoire Math.")
    define("j-REV-HIST-MATH",			"Rev. Hist. Math")

    define("j-REV-HIST-SCI-LEURS-APPL",		"Revue d'Histoire des Sciences et de Leurs Applications")
    define("j-REV-HIST-SCI-LEURS-APPL",		"Rev. Hist. Sci. Appl.")
    define("j-REV-HIST-SCI-LEURS-APPL",		"Rev. Histoire Sci. Appl.")
    define("j-REV-HIST-SCI-LEURS-APPL",		"Rev. Hist. Sci. Leurs Appl.")

    define("j-REV-HIST-SCI",			"Revue d'Histoire des Sciences")
    define("j-REV-HIST-SCI",			"Rev. Histoire Sci.")
    define("j-REV-HIST-SCI",			"Rev. Hist. Sci.")

    define("j-REV-INST-INT-STATIST",		"Revue de l'Institut international de statistique = Review of the International Statistical Institute")
    define("j-REV-INST-INT-STATIST",		"Revue de l'Institut International de Statistique / Review of the International Statistical Institute")
    define("j-REV-INST-INT-STATIST",		"Revue de l'Institut international de statistique")
    define("j-REV-INST-INT-STATIST",		"Review of the International Statistical Institute")
    define("j-REV-INST-INT-STATIST",		"Review of the I.S.I.")
    define("j-REV-INST-INT-STATIST",		"Rev. Inst. Int. Statist.")

    define("j-REV-INT-ECON",			"Review of International Economics")
    define("j-REV-INT-ECON",			"Rev. Int. Econ.")

    define("j-REV-MATH-IBER",			"Revista Matem{\\'a}tica Iberoamericana")
    define("j-REV-MATH-IBER",			"Revista Matematica Iberoamericana")
    define("j-REV-MATH-IBER",			"Revista Math. Iberoamericana")
    define("j-REV-MATH-IBER",			"Revista Mat. Iberoamericana")
    define("j-REV-MATH-IBER",			"Rev. Mat. Iberoamericana")

    define("j-REV-MATH-PHYS",			"Reviews in Mathematical Physics")
    define("j-REV-MATH-PHYS",			"Rev. Math. Phys.")

    define("j-REV-METAPHYS",			"Review of Metaphysics")
    define("j-REV-METAPHYS",			"The Review of Metaphysics")
    define("j-REV-METAPHYS",			"Rev. Metaphys.")

    define("j-REV-METAPHYS-MORALE",		"Revue de m{\\'e}taphysique et de morale")
    define("j-REV-METAPHYS-MORALE",		"Rev. metaphys. morale")
    define("j-REV-METAPHYS-MORALE",		"Rev. m{\\'e}́taphys. morale")

    define("j-REV-MEX-FIS",			"Revista Mexicana de F{\\'\\i}sica")
    define("j-REV-MEX-FIS",			"Rev. Mexicana Fis.")
    define("j-REV-MEX-FIS",			"Rev. Mex. Fis.")

    define("j-REV-MOD-PHYS",			"Reviews of Modern Physics")
    define("j-REV-MOD-PHYS",			"Rev. Mod. Phys.")
    define("j-REV-MOD-PHYS",			"Rev. Modern Phys.")
    define("j-REV-MOD-PHYS",			"Rev. Modern Physics")

    define("j-REV-NETW-ECON",			"Review of Network Economics")
    define("j-REV-NETW-ECON",			"Rev. Net. Econ.")
    define("j-REV-NETW-ECON",			"Rev. Netw. Econ.")

    define("j-REV-PHILOS-FR-ETRANG",		"Revue philosophique de la France et de l'{\\'E}tranger")
    define("j-REV-PHILOS-FR-ETRANG",		"Rev. philos. Fr. Etrang.")
    define("j-REV-PHILOS-FR-ETRANG",		"Rev. philos. Fr. {\\'E}trang.")

    define("j-REV-PORT-PHILOS",			"Revista portuguesa de filosofia")
    define("j-REV-PORT-PHILOS",			"Rev. port. filos.")

    define("j-REV-QUEST-SCI",			"Revue des Questions Scientifiques")
    define("j-REV-QUEST-SCI",			"Rev. Quest. Sci.")

    define("j-REV-SCI-INSTRUM",			"Review of scientific instruments")
    define("j-REV-SCI-INSTRUM",			"Rev. sci. instrum.")
    define("j-REV-SCI-INSTRUM",			"Rev. sci. insts.")

    define("j-REV-SYMB-LOG",			"The Review of Symbolic Logic")
    define("j-REV-SYMB-LOG",			"Rev. Symb. Log.")

    define("j-REV-SYNTH",			"Revue de Synth{\\`e}se")
    define("j-REV-SYNTH",			"Rev. Synth.")

    define("j-REV-TUN",				"Revue Tunisienne d'{\\'E}conomie et de Gestion")
    define("j-REV-TUN",				"Rev. tunis. {\\'e}con. gest.")
    define("j-RF-DESIGN",			"R.F. design")

    define("j-RHEOL-ACTA",			"Rheologica acta")
    define("j-RHEOL-ACTA",			"Rheol. acta")

    define("j-RHET-SOC-Q",			"{Rhetoric Society} Quarterly")
    define("j-RHET-SOC-Q",			"Rhet. Soc. Q.")

    define("j-RIC-MAT",				"Ricerche di Matematica (Napoli)")
    define("j-RIC-MAT",				"Ricerche di Matematica")
    define("j-RIC-MAT",				"Ric. mat.")
    define("j-RIC-MAT",				"Ricerche Mat.")

    define("j-RIC-SCI",				"La Ricerca Scientifica")
    define("j-RIC-SCI",				"Ricerca Scientifica")
    define("j-RIC-SCI",				"Ric. Sci.")

    define("j-RIC-SCI-PROG-TEC",		"Ricerca Scientifica ed il Progresso Tecnico")
    define("j-RIC-SCI-PROG-TEC",		"Ricerca Scientifica ed il Progresso Technico nell' Economia Nazionale (1932--1940)")
    define("j-RIC-SCI-PROG-TEC",		"Ric. Sci. Prog. Tec.")
    define("j-RIC-SCI-PROG-TEC",		"Ric. Sci. Progr. Tecn. Econom. Naz.")

    define("j-RISK-ANAL",			"Risk Analysis")
    define("j-RISK-ANAL",			"Risk Analysis: an official publication of the {Society for Risk Analysis}")
    define("j-RISK-ANAL",			"Risk Anal.")

    define("j-RISK-MANAGEMENT",			"Risk Management")

    define("j-RISKNEWS",			"RiskNews")

    define("j-RIV-INFO-FIRENZE",		"Rivista di Informatica (Firenze)")
    define("j-RIV-INFO-FIRENZE",		"Riv. Inf. (Firenze)")

    # Silvia Veronese got this from a colleague in Italy [25-Jan-1996]:
    # Rivista di Informatica Masson S.p.A.  Divisione periodici (Milano)
    define("j-RIV-INFO-MILANO",			"Rivista di Informatica (Milano)")
    define("j-RIV-INFO-MILANO",			"Riv. Inf. (Milan)")

    define("j-RIV-MAT-UNIV-PARMA",		"Rivista di matematica della Universita di Parma")
    define("j-RIV-MAT-UNIV-PARMA",		"Riv. mat. Univ. Parma")

    define("j-RIV-NUOVO-CIMENTO",		"Rivista del Nuovo Cimento")
    define("j-RIV-NUOVO-CIMENTO",		"Rivista del Nuovo Cimento della Societa Italiana di Fisica")
    define("j-RIV-NUOVO-CIMENTO",		"Riv. Nuovo Cimento")
    define("j-RIV-NUOVO-CIMENTO",		"Riv. Nuovo Cim.")

    define("j-ROBOTICS-AGE",			"Robotics Age (USA)")

    define("j-ROCKY-MOUNTAIN-J-MATH",		"Rocky Mountain Journal of Mathematics")
    define("j-ROCKY-MOUNTAIN-J-MATH",		"Rocky Mountain J. of Math.")
    define("j-ROCKY-MOUNTAIN-J-MATH",		"Rocky Mountain J. Math.")

    define("j-ROCZ-FILOZ",			"Roczniki Filozoficzne / Annales de Philosophie / Annals of Philosophy")
    define("j-ROCZ-FILOZ",			"Roczniki Filozoficzne")
    define("j-ROCZ-FILOZ",			"Rocz. Filoz.")

    define("j-ROCZ-POL-TOW-MAT-SER-2",		"Roczniki. Seria 2: Wiadomo\\'sci Matematyczne")
    define("j-ROCZ-POL-TOW-MAT-SER-2",		"Rocz. Pol. Tow. Mat., Ser. 2.")
    define("j-ROCZ-POL-TOW-MAT-SER-2",		"Wiadomo\\'sci Matematyczne")

    define("j-ROUX-ARCH-DEV-BIOL",		"Roux's archives of developmental biology")
    define("j-ROUX-ARCH-DEV-BIOL",		"Roux's Arch. Dev. Biol.")

    define("j-RS-MAGAZINE",			"RS\\slash Magazine")

    define("j-RS-POWER-PC-MAGAZINE",		"RS\\slash the PowerPC magazine")

    define("j-RSR",				"RSR: Reference Services Review")
    define("j-RSR",				"Ref. serv. rev.")

    define("j-RUSS-J-MATH-PHYS",		"Russian Journal of Mathematical Physics")
    define("j-RUSS-J-MATH-PHYS",		"Russ. j. math. phys.")
    define("j-RUSS-J-MATH-PHYS",		"Russian J. Math. Phys.")

    define("j-RUSS-J-NUM-ANAL-MATH-MODEL",	"Russian Journal of Numerical Analysis and Mathematical Modelling")
    define("j-RUSS-J-NUM-ANAL-MATH-MODEL",	"Numerical analysis and mathematical modelling")
    define("j-RUSS-J-NUM-ANAL-MATH-MODEL",	"Russ. j. num. anal. math. model.")
    define("j-RUSS-J-NUM-ANAL-MATH-MODEL",	"Russ. J. Numer. Anal Math. Modelling")
    define("j-RUSS-J-NUM-ANAL-MATH-MODEL",	"Russian J. Numer. Anal. Math. Modelling")

    define("j-RUSS-J-PHYS-CHEM-A",		"Russian Journal of Physical Chemistry A")
    define("j-RUSS-J-PHYS-CHEM-A",		"Russ. J. Phys. Chem. A")

    define("j-RUSS-J-PHYS-CHEM-B",		"Russian Journal of Physical Chemistry B")
    define("j-RUSS-J-PHYS-CHEM-B",		"Russ. J. Phys. Chem. B")

    define("j-RUSS-LIT",			"Russian Literature")
    define("j-RUSS-LIT",			"Russ. Lit.")

    define("j-RUSS-MATH",			"Russian Mathematics (Iz VUZ)")
    define("j-RUSS-MATH",			"Russian Mathematics")
    define("j-RUSS-MATH",			"Russ. math.")

    define("j-RUSS-MATH-SURV",			"Russian Mathematical Surveys")
    define("j-RUSS-MATH-SURV",			"Russian mathematical surveys; a translation of the survey articles and of selected biographical articles in Uspekhi matematicheskikh nauk")
    define("j-RUSS-MATH-SURV",			"Russ. math. surv.")
    define("j-RUSS-MATH-SURV",			"Russian Math Surveys")
    define("j-RUSS-MATH-SURV",			"Uspekhi Mat. Nauk")

    define("j-RUTGERS-COMPUT-TECHNOL-LAW-J",	"Rutgers Computer Technology and Law Journal")
    define("j-RUTGERS-COMPUT-TECHNOL-LAW-J",	"Rutgers Comput. Technol. Law J.")

    define("j-RUTGERS-J-COMP-TECH-LAW",		"Rutgers Journal of Computers, Technology, and the Law")
    define("j-RUTGERS-J-COMP-TECH-LAW",		"Rutgers J. Comput. Technol. Law")
    define("j-RUTGERS-J-COMP-TECH-LAW",		"Rutgers J. of Computer Technology and the Law")

    define("j-S-B-AKAD-WISS-WIEN-MATH-NATURWISS-KL-ABT-2A",	"{Sitzungsberichte der Akademie der Wissenschaften in Wien, Mathematisch-Naturwissenschaftliche Klasse, Abteilung 2A: Mathematik, Astronomie, Physik, Meteorologie und Technik}")
    define("j-S-B-AKAD-WISS-WIEN-MATH-NATURWISS-KL-ABT-2A",	"{Sitzungsber. Akad. Wiss. Wien, Math.-Naturwiss. Kl., Abt. 2A}")

    define("j-S-B-KAISERL-AKAD-WISS",		"Sitzungsberichte der Kaiserlichen Akademie der Wissenschaften. Mathematisch-Naturwissenschaftliche Klasse")
    define("j-S-B-KAISERL-AKAD-WISS",		"S. B. Kaiserl. Akad. Wiss.")

    ## Sitzungsberichte der Königlich Preussischen Akademie der Wissenschaften zu Berlin v1 (1882)-v44 (1918).
    ## Königlich dropped in [late] 1918
    ## Replaces Monatsberichte der Koeniglichen Preussischen Akademie der Wissenschaften zu Berlin (1856--1882 or 1865--1881??)

    define("j-S-B-KONIG-PREUSS-AKAD-WISS",	"{Sitzungsberichte der K{\\\"o}niglich Preussischen Akademie der Wissenschaften}")
    define("j-S-B-KONIG-PREUSS-AKAD-WISS",	"{S. B. Konig. Preuss. Akad. Wiss.}")
    define("j-S-B-KONIG-PREUSS-AKAD-WISS",	"{S. B. K{\\\"o}nig. Preuss. Akad. Wiss.}")

    define("j-S-B-KONIG-PREUSS-AKAD-WISS-BERLIN",	"{Sitzungsberichte der K{\\\"o}niglich Preussischen Akademie der Wissenschaften zu Berlin}")
    define("j-S-B-KONIG-PREUSS-AKAD-WISS-BERLIN",	"{Sitzungsberichte der Königlich Preussischen Akademie der Wissenschaften zu Berlin}")
    define("j-S-B-KONIG-PREUSS-AKAD-WISS-BERLIN",	"{S. B. Konig. Preuss. Akad. Wiss.}")

    define("j-S-B-MATH-NATURWISS-KL-KAISERL-AKAD-WISS",	"{Sitzungsberichte der Mathematisch-Naturwissenschaftliche Klasse der Kaiserlichen Akademie der Wissenschaften}")
    define("j-S-B-MATH-NATURWISS-KL-KAISERL-AKAD-WISS",	"{S. B. Math. Naturwiss. Kl. Kaiserl. Akad. Wiss.}")

    ## Sitzungsberichte 1882--1921, then split into j-S-B-PREUSS-AKAD-WISS-PHYS-MATH-KL and
    ## j-S-B-PREUSS-AKAD-WISS-PHIL-HIST-KL. "zu Berlin" dropped 1918--1921

    define("j-S-B-PREUSS-AKAD-WISS", "{Sitzungsberichte der Preu{\\ss}ischen Akademie der Wissenschaften}")
    define("j-S-B-PREUSS-AKAD-WISS", "{Sitzungsberichte der Preussischen Akademie der Wissenschaften}")
    define("j-S-B-PREUSS-AKAD-WISS", "{Sitzungsberichte der Preussischen Akademie der Wissenschaften}")
    define("j-S-B-PREUSS-AKAD-WISS", "{Sitzungsberichte der Preussichen Akademie der Wissenschaften}")
    define("j-S-B-PREUSS-AKAD-WISS", "{S. B. Preuss. Aka. Wiss.}")
    define("j-S-B-PREUSS-AKAD-WISS", "{Sitzungsber. Preuss. Akad. Wiss.}")

    define("j-S-B-PREUSS-AKAD-WISS-BERLIN", "{Sitzungsberichte der Preu{\\ss}ischen Akademie der Wissenschaften zu Berlin}")
    define("j-S-B-PREUSS-AKAD-WISS-BERLIN", "{Sitzungsberichte der Preussischen Akademie der Wissenschaften zu Berlin}")

    define("j-S-B-PREUSS-AKAD-WISS-PHYS-MATH-KL", "Sitzungsberichte der Preu{\\ss}ischen Akademie der Wissenschaften: Physikalisch-Mathematische Klasse")
    define("j-S-B-PREUSS-AKAD-WISS-PHYS-MATH-KL", "Sitzungsberichte der Preussischen Akademie der Wissenschaften: Physikalisch-Mathematische Klasse")
    define("j-S-B-PREUSS-AKAD-WISS-PHYS-MATH-KL", "Sitzungsberichte der Preussischen Akademie der Wissenschaften, Physikalisch-Mathematische Klasse")
    define("j-S-B-PREUSS-AKAD-WISS-PHYS-MATH-KL", "S. B. Preuss. Aka. Wiss. Phys. Math. Kl.")
    define("j-S-B-PREUSS-AKAD-WISS-PHYS-MATH-KL", "Sitzungsberichte der Preussichen Akademie der Wissenschaften physikalisch-mathematische Klasse")
    define("j-S-B-PREUSS-AKAD-WISS-PHYS-MATH-KL", "Sitzungsber. Preuss. Akad. Wiss., Phys.-Math. Kl.")

    define("j-SAMPL-THEORY-SIGNAL-IMAGE-PROCESS", "Sampling Theory in Signal and Image Processing")
    define("j-SAMPL-THEORY-SIGNAL-IMAGE-PROCESS", "Sampling Theory in Signal and Image Processing. An International Journal")
    define("j-SAMPL-THEORY-SIGNAL-IMAGE-PROCESS", "Sampl. Theory Signal Image Process.")

    define("j-SAN-JOSE-MERCURY-NEWS",		"San Jose Mercury News")

    # v1 June 1933-v22 1960
    define("j-SANKHYA",				"Sankhy{\\=a} (Indian Journal of Statistics)")
    define("j-SANKHYA",				"{Sankhy{\\=a}}: The {Indian Journal of Statistics} (1933--1960)")
    define("j-SANKHYA",				"Sankhy{\\=a}")

    # v23 n1 1961--date
    define("j-SANKHYA-A",			"Sankhy{\\=a} (Indian Journal of Statistics), Series A. Methods and Techniques")
    define("j-SANKHYA-A",			"Sankhy\\=a Ser. A")
    define("j-SANKHYA-A",			"Sankhya, Ser. A")
    define("j-SANKHYA-A",			"Sankhya A")

    # v23 n1 1961--date
    define("j-SANKHYA-B",			"Sankhy{\\=a} (Indian Journal of Statistics), Series B. Methodological")
    define("j-SANKHYA-B",			"Sankhya B")

    define("j-SANTA-CLARA-COMP-HI-TECH-LAW-J",	"Santa Clara Computer and High-Technology Law Journal")

    define("j-SCAND-ACTUAR-J",			"Scandinavian Actuarial Journal")
    define("j-SCAND-ACTUAR-J",			"Scand. Actuar. J.")

    define("j-SCAND-J-HAEMATOL",		"Scandinavian journal of haematology")
    define("j-SCAND-J-HAEMATOL",		"Scand. j. haematol.")
    define("j-SCAND-J-HAEMATOL",		"Scand. j. haemat.")

    define("j-SCAND-J-STAT",			"Scandinavian Journal of Statistics. Theory and Applications")
    define("j-SCAND-J-STAT",			"Scandinavian Journal of Statistics")
    define("j-SCAND-J-STAT",			"Scand J. Statist.")
    define("j-SCAND-J-STAT",			"Scand J. Stat.")

    define("j-SCAND-J-THORAC-CARDIOVASC-SURG",	"Scandinavian Journal of Thoracic and Cardiovascular Surgery")
    define("j-SCAND-J-THORAC-CARDIOVASC-SURG",	"Scand. j. thoracic cardiovasc. surg.")
    define("j-SCAND-J-THORAC-CARDIOVASC-SURG",	"Scand. j. thor. cardiovasc. surg.")

    define("j-SCANNING-MICROSCOPY",		"Scanning microscopy")

    define("j-SCH-PUBL",			"Scholarly Publishing")
    define("j-SCH-PUBL",			"Sch. Publ.")

    define("j-SCH-REV",				"The School Review (Ithaca, NY)")
    define("j-SCH-REV",				"The School Review")
    define("j-SCH-REV",				"School Review (Ithaca, NY)")
    define("j-SCH-REV",				"School Review")
    define("j-SCH-REV",				"Sch. rev.")

    define("j-SCHOOL-LIBR-J",			"School library journal: SLJ")
    define("j-SCHOOL-LIBR-J",			"School library journal")
    define("j-SCHOOL-LIBR-J",			"School libr. j.")

    define("j-SCHOOL-SCI-MATH",			"School science and mathematics")

    define("j-SCHWEIZ-TECH-Z",			"Schweizerische technische Zeitschrift. Revue technique suisse. Rivista tecnica svizzera.")
    define("j-SCHWEIZ-TECH-Z",			"Schweiz. tech. Z.")

    define("j-SCI-ADV",				"Science Advances")
    define("j-SCI-ADV",				"Sci. Adv.")

    define("j-SCI-AMER",			"Scientific American")
    define("j-SCI-AMER",			"Sci. Amer.")

    define("j-SCI-CHINA-MATH",			"Science China. Mathematics")
    define("j-SCI-CHINA-MATH",			"Sci. China Math.")

    ## Vol. 39, no. 1 (Feb. 1996)--v. 47, no. 1 (Feb. 2004)
    define("j-SCI-CHINA-SER-E-TECH-SCI",	"Science in {China}. Series {E}, Technological sciences")
    define("j-SCI-CHINA-SER-E-TECH-SCI",	"Science in {China}. Series {E}")
    define("j-SCI-CHINA-SER-E-TECH-SCI",	"Scientia Sinica. Series E")
    define("j-SCI-CHINA-SER-E-TECH-SCI",	"Sci. China Ser. E.")
    define("j-SCI-CHINA-SER-E-TECH-SCI",	"Sci. China Ser. E. Tech. Sci.")

    define("j-SCI-CITIZEN",			"Scientist and Citizen")
    define("j-SCI-CITIZEN",			"Sci. Citizen")

    define("j-SCI-COMPUT",			"Scientific Computing")
    define("j-SCI-COMPUT",			"Scientific Computing (Rockaway, NJ, USA)")
    define("j-SCI-COMPUT",			"Sci. Comput. (Rockaway, NJ, USA)")
    define("j-SCI-COMPUT",			"Sci. Comput.")

    define("j-SCI-COMPUT-PROGRAM",		"Science of Computer Programming")
    define("j-SCI-COMPUT-PROGRAM",		"Sci. Comput. Program")
    define("j-SCI-COMPUT-PROGRAM",		"Sci. Comput. Programming")

    define("j-SCI-CONTEXT",			"Science in Context")
    define("j-SCI-CONTEXT",			"Sci. Context")

    define("j-SCI-FICT-STUD",			"Science Fiction Studies")
    define("j-SCI-FICT-STUD",			"Sci. Fict. Stud.")

    define("j-SCI-INF-BULL",			"Scientific information bulletin")
    define("j-SCI-INF-BULL",			"Sci. inf. bull.")

    define("j-SCI-LIGHT-TOKYO",			"Science of Light (Tokyo)")
    define("j-SCI-LIGHT-TOKYO",			"Science of Light (Japan)")
    define("j-SCI-LIGHT-TOKYO",			"Sci. Light (Tokyo)")
    define("j-SCI-LIGHT-TOKYO",			"Sci. Light (Japan)")

    define("j-SCI-MATH-JPN",			"Scientiae Mathematicae Japonicae")
    define("j-SCI-MATH-JPN",			"Sci. Math. Jpn.")

    define("j-SCI-MONTHLY",			"The Scientific Monthly")
    define("j-SCI-MONTHLY",			"Scientific Monthly")
    define("j-SCI-MONTHLY",			"Sci. Monthly")

    define("j-SCI-NEWS-LETT",			"The Science News-Letter")
    define("j-SCI-NEWS-LETT",			"Science News-Letter")
    define("j-SCI-NEWS-LETT",			"Sci. News Lett.")

    define("j-SCI-PROC-ROY-DUBLIN-SOC",		"Scientific proceedings of the Royal Dublin Society")
    define("j-SCI-PROC-ROY-DUBLIN-SOC",		"Sci. Proc. Roy. Dublin Soc.")

    define("j-SCI-PROG",			"Scientific Programming")

    define("j-SCI-PROG-RUSHDEN-UK",		"Science Progress (1933--)")
    define("j-SCI-PROG-RUSHDEN-UK",		"Sci. Prog. (Rushden, UK)")
    define("j-SCI-PROG-RUSHDEN-UK",		"Sci. Prog. (1933--)")

    define("j-SCI-PUBLIC-POL",			"Science and Public Policy")
    define("j-SCI-PUBLIC-POL",			"Science \\& Public Policy")
    define("j-SCI-PUBLIC-POL",			"Sci. public pol.")

    define("j-SCI-REP",				"Scientific Reports")
    define("j-SCI-REP",				"Sci. Rep.")

    define("j-SCI-REV-MENT-HEALTH-PRAC",	"Scientific Review of Mental Health Practice")
    define("j-SCI-REV-MENT-HEALTH-PRAC",	"Sci. Rev. Ment. Health Prac.")

    define("j-SCI-SOC",				"Science \\& Society")
    define("j-SCI-SOC",				"Science {\\&} Society")
    define("j-SCI-SOC",				"Sci. Soc.")

    define("j-SCI-STUD",			"Science Studies")
    define("j-SCI-STUD",			"Sci. Stud")

    define("j-SCI-TEACHER",			"The Science teacher (Washington, DC)")
    define("j-SCI-TEACHER",			"The Science teacher")
    define("j-SCI-TEACHER",			"Sci. teach. (Wash. DC)")

    define("j-SCI-TECHNOL-HUMAN-VALUES",	"Science, Technology and Human Values")
    define("j-SCI-TECHNOL-HUMAN-VALUES",	"Science, Technology \\& Human Values")
    define("j-SCI-TECHNOL-HUMAN-VALUES",	"Sci. Technol. Human Values")

    define("j-SCI-TECHNOL-JPN",			"Science and technology in Japan")
    define("j-SCI-TECHNOL-JPN",			"Sci. technol. Jpn. (Tokyo, 1982)")

    define("j-SCI-TECHNOL-LIB",			"Science \\& Technology Libraries")
    define("j-SCI-TECHNOL-LIB",			"Sci. Technol. Lib.")

    define("j-SCIENCE",				"Science")
    define("j-SCIENCE",				"Science (N.S.)")
    define("j-SCIENCE",				"Science (UJ7)")
    define("j-SCIENCE",				"Science (Wash. DC)")
    define("j-SCIENCE",				"Science (Washington, DC)")
    define("j-SCIENCE",				"Science, Wash.")
    define("j-SCIENCE",				"Science (New York, NY)")
    define("j-SCIENCE",				"Science (New York, N.Y.)")
    define("j-SCIENCE",				"Science, Washington")

    define("j-SCIENCE-NEWS",			"Science News (Washington, DC)")
    define("j-SCIENCE-NEWS",			"Science News ({Washington, DC})")
    define("j-SCIENCE-NEWS",			"Science News")
    define("j-SCIENCE-NEWS",			"Science News Magazine")
    define("j-SCIENCE-NEWS",			"Sci. News (Washington, DC)")
    define("j-SCIENCE-NEWS",			"Sci. News ({Washington})")
    define("j-SCIENCE-NEWS",			"Sci. News")

    define("j-SCIENCE-SOFTWARE",		"Science Software")

    define("j-SCIENCES",			"The Sciences (New York)")
    define("j-SCIENCES",			"The Sciences")
    define("j-SCIENCES",			"Sciences (New York)")

    define("j-SCIENTIA-MILAN",			"Scientia (Milan)")
    define("j-SCIENTIA-MILAN",			"Scientia (Milano)")
    define("j-SCIENTIA-MILAN",			"Scientia: rivista di scienza: rivista internazionale di sintesi scientifica")
    define("j-SCIENTIA-MILAN",			"Scientia. Milan")

    define("j-SCIENTIST",			"The Scientist (Philadelphia, PA)")
    define("j-SCIENTIST",			"The Scientist")
    define("j-SCIENTIST",			"Scientist")

    define("j-SCIENTOMETRICS",			"Scientometrics")
    define("j-SCITECH-J",			"SciTech Journal")

    define("j-SCR-METALL",			"Scripta metallurgica")
    define("j-SCR-METALL",			"Scr. metall.")
    define("j-SCR-METALL",			"Scripta Metall.")

    define("j-SCR-METALL-MATER",		"Scripta metallurigica et materialia")
    define("j-SCR-METALL-MATER",		"Scr. metall. mater.")

    define("j-SCREEN",				"Screen: the journal of the Society for Education in Film and Television")
    define("j-SCREEN",				"Screen")

    define("j-SEARCHER",			"Searcher: the magazine for database professionals")
    define("j-SEARCHER",			"Searcher: the magazine for database profession")
    define("j-SEARCHER",			"Searcher (Medford, NJ)")

    define("j-SECOND-MESSENGERS-PHOSPHOPROTEINS","Second Messengers Phosphoproteins (JSP)")
    define("j-SECURITY",			"Security")
    define("j-SEJ",				"Software Engineering Journal")

    define("j-SEM-CELL-BIOL",			"Seminars in Cell Biology")
    define("j-SEM-CELL-BIOL",			"Semin Cell Biol (A60)")
    define("j-SEM-CELL-BIOL",			"Sem. Cell Biol.")
    define("j-SEM-CELL-BIOL",			"Seminars in Cell Biol.")

    define("j-SEM-HOP-PARIS",			"La Semaine des h{\\^o}pitaux de Paris")
    define("j-SEM-HOP-PARIS",			"La Semaine des hopitaux de Paris")
    define("j-SEM-HOP-PARIS",			"Sem. hop.")
    define("j-SEM-HOP-PARIS",			"Sem. Hop. Paris")

    define("j-SEMIN-HEMATOL",			"Seminars in hematology")
    define("j-SEMIN-HEMATOL",			"Semin. hematol.")

    define("j-SEMIOTICA",			"Semiotica")
    define("j-SEMIOTICA",			"Semiotica: journal of the International Association for Semiotic Studies = revue de l'Association Internationale de S{\\'e}miotique")
    define("j-SEMIOTICA",			"Semiotica")

    define("j-SENSORS-BASEL",			"Sensors (Basel)")
    define("j-SENSORS-BASEL",			"Sensors")

    define("j-SER-REV",				"Serials review")
    define("j-SER-REV",				"Ser. rev.")

    define("j-SERB-ASTRON-J",			"Serbian Astronomical Journal")
    define("j-SERB-ASTRON-J",			"Serb. Astron. J.")

    define("j-SERDICA-MATH-J",			"Serdica. Mathematical Journal. Serdika. Matematichesko Spisanie")
    define("j-SERDICA-MATH-J",			"Serdica Math. J.")

    define("j-SERIALS-LIBRARIAN",		"The Serials Librarian")
    define("j-SERIF",				"Serif: The Magazine of Type and Typography")
    define("j-SERVICE-NEWS-CESSP",		"Service News: For Computer/Electronic Service and Support Professionals")

    define("j-SET-VALUED-ANAL",			"Set-Valued Analysis")
    define("j-SET-VALUED-ANAL",			"Set-Valued analysis / an international journal devoted to the theory of multifunctions and its applications")
    define("j-SET-VALUED-ANAL",			"Set-valued Anal.")

    ## j-SET-VALUED-VAR-ANAL begins with volume 17, number 2, June 2009 as a continuation of j-SET-VALUED-ANAL
    define("j-SET-VALUED-VAR-ANAL",		"Set-Valued and Variational Analysis")
    define("j-SET-VALUED-VAR-ANAL",		"Set-Valued Var. Anal.")

    define("j-SEX-ROLES",			"Sex Roles")
    define("j-SEYBOLD-REP-DESKTOP-PUB",		"Seybold Report on Desktop Publishing")
    define("j-SEYBOLD-REP-INTERNET-PUBLISHING", "Seybold Report on Internet Publishing")
    define("j-SEYBOLD-REP-PUB-SYS",		"Seybold Report on Publishing Systems")

    define("j-SIAM-ASA-J-UNCERTAIN-QUANTIF",	"SIAM/ASA Journal on Uncertainty Quantification")
    define("j-SIAM-ASA-J-UNCERTAIN-QUANTIF",	"SIAM/ASA J. Uncertain. Quantif.")
    define("j-SIAM-ASA-J-UNCERTAIN-QUANTIF",	"SIAM\\slash ASA Journal on Uncertainty Quantification")
    define("j-SIAM-ASA-J-UNCERTAIN-QUANTIF",	"SIAM\\slash ASA J. Uncertain. Quantif.")

    define("j-SIAM-J-ALG-DISC-METH",		"SIAM Journal on Algebraic and Discrete Methods")
    define("j-SIAM-J-ALG-DISC-METH",		"SIAM J. Alg. Disc. Meth.")
    define("j-SIAM-J-ALG-DISC-METH",		"SIAM j. algebr. discrete methods")
    define("j-SIAM-J-ALG-DISC-METH",		"SIAM Journal of Algebraic Discrete Methods")

    define("j-SIAM-J-APPL-ALGEBR-GEOM",		"SIAM Journal on Applied Algebra and Geometry")
    define("j-SIAM-J-APPL-ALGEBR-GEOM",		"SIAM J. Appl. Algebr. Geom.")

    define("j-SIAM-J-APPL-DYN-SYST",		"SIAM Journal on Applied Dynamical Systems")
    define("j-SIAM-J-APPL-DYN-SYST",		"SIAM J. Appl. Dyn. Syst.")

    define("j-SIAM-J-APPL-MATH",		"SIAM Journal on Applied Mathematics")
    define("j-SIAM-J-APPL-MATH",		"SIAM J. of Applied Math.")
    define("j-SIAM-J-APPL-MATH",		"SIAM J. Appl. Math.")

    define("j-SIAM-J-COMPUT",			"SIAM Journal on Computing")
    define("j-SIAM-J-COMPUT",			"SIAM Journal of Computing")
    define("j-SIAM-J-COMPUT",			"SIAM J. Comput.")

    define("j-SIAM-J-CONTROL",			"SIAM Journal on Control")
    define("j-SIAM-J-CONTROL",			"SIAM J Contr")

    define("j-SIAM-J-CONTROL-OPTIM",		"SIAM Journal on Control and Optimization")
    define("j-SIAM-J-CONTROL-OPTIM",		"SIAM Journal on Control and Optimization: a publication of the Society for Industrial and Applied Mathematics")
    define("j-SIAM-J-CONTROL-OPTIM",		"SIAM J. Control Optim.")

    define("j-SIAM-J-DISCR-MATH",		"SIAM Journal on Discrete Mathematics")
    define("j-SIAM-J-DISCR-MATH",		"SIAM J. Disc. Math.")
    define("j-SIAM-J-DISCR-MATH",		"SIAM J. Discrete Math.")

    define("j-SIAM-J-FINANCIAL-MATH",		"SIAM J. Financial Math.")
    define("j-SIAM-J-FINANCIAL-MATH",		"SIAM Journal on Financial Mathematics")

    define("j-SIAM-J-IMAGING-SCI",		"SIAM Journal on Imaging Sciences")
    define("j-SIAM-J-IMAGING-SCI",		"SIAM J. Imaging Sci.")
    define("j-SIAM-J-IMAGING-SCI",		"SIAM J. Imag. Sci.")

    define("j-SIAM-J-MAT-ANA-APPL",		"SIAM Journal on Matrix Analysis and Applications")
    define("j-SIAM-J-MAT-ANA-APPL",		"SIAM J. Matrix Anal. Applics.")
    define("j-SIAM-J-MAT-ANA-APPL",		"SIAM J. Matrix Anal. Appl.")
    define("j-SIAM-J-MAT-ANA-APPL",		"SIAM J. Matrix Anal. and Appplics")
    define("j-SIAM-J-MAT-ANA-APPL",		"SIAM J. on Matrix Analysis and Applications")
    define("j-SIAM-J-MAT-ANA-APPL",		"SIAM journal on matrix analysis and applications: a publication of the Society for Industrial and Applied Mathematics")

    define("j-SIAM-J-MATH-ANA",			"SIAM Journal on Mathematical Analysis")
    define("j-SIAM-J-MATH-ANA",			"SIAM J. Math. Anal")
    define("j-SIAM-J-MATH-ANA",			"SIAM J. Math. Anal.")

    define("j-SIAM-J-MATH-DATA-SCI",		"SIAM Journal on Mathematics of Data Science")
    define("j-SIAM-J-MATH-DATA-SCI",		"SIAM J. Math. Data Sci.")

    define("j-SIAM-J-NUMER-ANAL",		"SIAM Journal on Numerical Analysis")
    define("j-SIAM-J-NUMER-ANAL",		"SIAM J. Numer. Anal.")
    define("j-SIAM-J-NUMER-ANAL",		"SIAM J. Num. Anal.")
    define("j-SIAM-J-NUMER-ANAL",		"SIAM J. Numer. Analysis")
    define("j-SIAM-J-NUMER-ANAL",		"SIAM J. Numr. Anal.")
    define("j-SIAM-J-NUMER-ANAL",		"SIAM J. on Numerical Analysis")
    define("j-SIAM-J-NUMER-ANAL",		"SIAM Journal of Numerical Analysis")
    define("j-SIAM-J-NUMER-ANAL",		"SIAM journal on numerical analysis: a publication of the Society of Industrial and Applied Mathematics")

    define("j-SIAM-J-NUM-ANALYSIS-B",		"Journal of the Society for Industrial and Applied Mathematics:  Series B, Numerical Analysis")
    define("j-SIAM-J-NUM-ANALYSIS-B",		"J. Soc. Ind. Appl. Math., Ser. B Numer. anal.")
    define("j-SIAM-J-NUM-ANALYSIS-B",		"SIAM Journal on Numerical Analysis (Series B)")

    define("j-SIAM-J-OPT",			"SIAM Journal on Optimization")
    define("j-SIAM-J-OPT",			"SIAM J. Optimization")
    define("j-SIAM-J-OPT",			"SIAM J. Optim.")

    define("j-SIAM-J-SCI-COMP",			"SIAM Journal on Scientific Computing")
    define("j-SIAM-J-SCI-COMP",			"SIAM J. Sci. Comput.")

    define("j-SIAM-J-SCI-STAT-COMP",		"SIAM Journal on Scientific and Statistical Computing")
    define("j-SIAM-J-SCI-STAT-COMP",		"SIAM J. Sci. Stat. Comp.")
    define("j-SIAM-J-SCI-STAT-COMP",		"SIAM J. Sci. Stat. Comput")
    define("j-SIAM-J-SCI-STAT-COMP",		"SIAM J. Sci. Stat. Comput.")
    define("j-SIAM-J-SCI-STAT-COMP",		"SIAM J. Sci. Statist. Comp")
    define("j-SIAM-J-SCI-STAT-COMP",		"SIAM J. Sci. Statist. Comput.")
    define("j-SIAM-J-SCI-STAT-COMP",		"SIAM J. Sci. Statist. Computing")
    define("j-SIAM-J-SCI-STAT-COMP",		"SIAM J. Sci.~Stat.~Comput.")
    define("j-SIAM-J-SCI-STAT-COMP",		"SIAM J. Scient. Stat. Comput.")
    define("j-SIAM-J-SCI-STAT-COMP",		"SIAM J. Stat. Sci. Comput.")
    define("j-SIAM-J-SCI-STAT-COMP",		"SIAM J. on Sci. Statist. Comput.")
    define("j-SIAM-J-SCI-STAT-COMP",		"SIAM J. on Scientific and Statistical Computation")
    define("j-SIAM-J-SCI-STAT-COMP",		"SIAM J. on Scientific and Statistical Computing")
    define("j-SIAM-J-SCI-STAT-COMP",		"SIAM J.~Sci.~Stat.~Comput.")
    define("j-SIAM-J-SCI-STAT-COMP",		"SIAM j. on Statistical and Scientific Computing")
    define("j-SIAM-J-SCI-STAT-COMP",		"SIAM journal on scientific and statistical computing")

    define("j-SIAM-NEWS",			"SIAM News")
    define("j-SIAM-NEWS",			"SIAM News: The Newsjournal of the Society for Industrial and Applied Mathematics")

    define("j-SIAM-REVIEW",			"SIAM Review")
    define("j-SIAM-REVIEW",			"SIAM Rev.")

    define("j-SIAM-THEOR-PROB-APPL",		"SIAM Theor. Probab. Appl")

    define("j-SIB-MAT-Z",			"Sibirskii matematicheskii zhurnal")
    define("j-SIB-MAT-Z",			"Sibirskii matematicheskii zhurnal / Akademiia nauk SSSR, Sibirskoe otdelenie")
    define("j-SIB-MAT-Z",			"Sibirskij matematiceskij zurnal")
    define("j-SIB-MAT-Z",			"Sib. mat. z.")
    define("j-SIB-MAT-Z",			"Sibirsk. Mat. Zh.")
    define("j-SIB-MAT-Z",			"Sibirskii Math. J")

    define("j-SIB-MATH-J",			"Siberian Mathematical Journal")
    define("j-SIB-MATH-J",			"Sib. Math. J.")

    define("j-SIBERIAN-ADV-MATH",		"Siberian Advances in Mathematics")
    define("j-SID-DIG-TECH-PAP",		"SID International Symposium. Digest of technical papers")
    define("j-SID-DIG-TECH-PAP",		"SID Int. Symp.. Dig. tech. pap.")

    define("j-SIG-PROC",			"Signal Processing")

    define("j-SIGACT",				"ACM SIGACT News")
    define("j-SIGACT",				"SIGACT News")
    define("j-SIGACT",				"SIGACT News (ACM Special Interest Group on Automata and Computability Theory)")

    define("j-SIGADA-LETTERS",			"ACM SIGADA Ada Letters")
    define("j-SIGADA-LETTERS",			"Ada Letters")
    define("j-SIGADA-LETTERS",			"Ada letters: a bimonthly publication of AdaTEC")

    define("j-SIGAPP",				"ACM SIGAPP Applied Computing Review")
    define("j-SIGAPP",				"SIGAPP Applied Computing Review")
    define("j-SIGAPP",				"Applied Computing Review")
    define("j-SIGAPP",				"Appl. Comput. Rev.")
    define("j-SIGAPP",				"SIGAPP")

    define("j-SIGBIO-NEWSLETTER",		"ACM SIGBIO Newsletter")
    define("j-SIGBIO-NEWSLETTER",		"SIGBIO Newsletter")
    define("j-SIGBIO-NEWSLETTER",		"SIGBIO Newsl.")

    define("j-SIGCAPH",				"SIGCAPH Newsletter")

    define("j-SIGCHI",				"ACM SIGCHI Bulletin")
    define("j-SIGCHI",				"SIGCHI bulletin: [a quarterly publication of the Special Interest Group on Computer and Human Interaction]")
    define("j-SIGCHI",				"SIGCHI Bulletin")
    define("j-SIGCHI",				"SIGCHI Bull.")

    define("j-SIGCSE",				"SIGCSE Bulletin (ACM Special Interest Group on Computer Science Education)")
    define("j-SIGCSE",				"SIGCSE Bulletin (Association for Computing Machinery, Special Interest Group on Computer Science Education)")
    define("j-SIGCSE",				"ACM SIGCSE Bull.")
    define("j-SIGCSE",				"ACM SIGCSE Bulletin")
    define("j-SIGCSE",				"SIGCSE Bulletin")
    define("j-SIGCSE",				"SIGCSE Bull.")
    define("j-SIGCSE",				"SIGCSEB: SIGCSE Bulletin (ACM Special Interest Group on Computer Science Education)")
    define("j-SIGCSE",				"SIGCSE Bull. (USA)")
    define("j-SIGCSE",				"SIGCSE")
    define("j-SIGCSE",				"SIGCSE Bull. (USA), SIGCSE Bulletin")

    # j-SIGDOC renamed to j-ASTERISK in March 1991 without ISSN change
    define("j-SIGDOC",				"ACM SIGDOC Asterisk*")

    define("j-SIGIR-FORUM",			"SIGIR Forum (ACM Special Interest Group on Information Retrieval)")
    define("j-SIGIR-FORUM",			"SIGIR forum")

    define("j-SIGKDD",				"ACM SIGKDD Explorations Newsletter")
    define("j-SIGKDD",				"ACM SIGKDD Newsletter")
    define("j-SIGKDD",				"SIGKDD Newsletter")

    define("j-SIGMA-CHI-Q",			"Sigma Xi Quarterly")
    define("j-SIGMA-CHI-Q",			"Sigma Xi Q.")

    define("j-SIGMAP-NEWSLETTER",		"SIGMAP Newsletter")

    define("j-SIGMETRICS",			"ACM SIGMETRICS Performance Evaluation Review")
    define("j-SIGMETRICS",			"SIGMETRICS")

    define("j-SIGMICRO",			"ACM SIG Micro Newsletter")
    define("j-SIGMICRO",			"SIGMICRO newsl.")

    define("j-SIGMOD",				"ACM SIGMOD Record")
    define("j-SIGMOD",				"SIGMOD Record")
    define("j-SIGMOD",				"SIGMOD Record (ACM Special Interest Group on Management of Data)")

    define("j-SIGNAL-PROCESS-IMAGE-COMMUN",	"Signal Processing: Image Communication")
    define("j-SIGNAL-PROCESS-IMAGE-COMMUN",	"Signal process., Image commun.")

    define("j-SIGNIF",				"Significance ({Oxford, England})")
    define("j-SIGNIF",				"Significance. Statistics Making Sense")
    define("j-SIGNIF",				"Significance [Magazine of the {Royal Statistical Society}]")
    define("j-SIGNIF",				"Significance")
    define("j-SIGNIF",				"Signif.")

    define("j-SIGNUM",				"ACM SIGNUM Newsletter")
    define("j-SIGNUM",				"SIGNUM Newsletter")
    define("j-SIGNUM",				"SIGNUM Newsl.")

    define("j-SIGOIS",				"SIGOIS Bulletin")

    ## See note in ISSN section
    define("j-SIGPLAN",				"ACM SIGPLAN Notices")
    define("j-SIGPLAN",				"ACM SIG{\\-}PLAN Notices")
    define("j-SIGPLAN",				"SIGPLAN Notices")
    define("j-SIGPLAN",				"ACM SIGPLAN notices: a monthly publication of the Special Interest Group on Programming Languages")
    define("j-SIGPLAN",				"SIGPLAN Notices (ACM Special Interest Group on Programming Languages)")

    define("j-SIGSAC-REVIEW",			"SIG security, audit \\& control review")
    define("j-SIGSAC-REVIEW",			"SIG secur., audit, control rev.")
    define("j-SIGSAC-REVIEW",			"SIGSAC Review")

    define("j-SIGSAM",				"SIGSAM Bulletin")
    define("j-SIGSAM",				"SIGSAM")
    define("j-SIGSAM",				"SIGSAM Bulletin (ACM Special Group on Symbolic and Algebraic Manipulation)")
    define("j-SIGSAM",				"SIGSAM Bulletin (ACM Special Interest Group on Symbolic and Algebraic Manipulation)")
    define("j-SIGSAM",				"SIGSAM bulletin: a quarterly publication of the Special Interest Group on Symbolic and Algebraic Manipulation")
    define("j-SIGSAM",				"ACM SIGSAM Bulletin")
    define("j-SIGSAM",				"ACM SIGSAM")

    define("j-SIGSMALL-PC-NOTES",		"SIGSMALL\\slash PC Notes")
    define("j-SIGSMALL-PC-NOTES",		"SIGSMALL/PC Notes")

    define("j-SIGSOFT",				"ACM SIGSOFT Software Engineering Notes")
    define("j-SIGSOFT",				"SIGSOFT Software Engineering Notes")
    define("j-SIGSOFT",				"Software engineering notes: an informal newsletter of the Special Interest Committee on Software Engineering")
    define("j-SIGSOFT",				"Softw. Eng. Notes")
    define("j-SIGSOFT",				"ACM SIGSOFT Softw. Eng. Notes")

    define("j-SIGUCCS-NEWSL",			"SIGUCCS newsletter")
    define("j-SIGUCCS-NEWSL",			"SIGUCCS newsl.")

    define("j-SILICON-GRAPHICS-WORLD",		"Silicon Graphics World")

    define("j-SIM-MODEL-PRACT-THEORY",		"Simulation Modelling Practice and Theory")
    define("j-SIM-MODEL-PRACT-THEORY",		"Sim. Model. Pract. Theory")

    define("j-SIM-NEWS-EUROPE",			"Simulation news Europe, SCS")
    define("j-SIM-NEWS-EUROPE",			"EUROSIM, simulation news Europe: a European forum on simulation activities")

    define("j-SIM-PRACT-THEORY",		"Simulation Practice and Theory")
    define("j-SIM-PRACT-THEORY",		"Sim. Pract. Theory")

    define("j-SIM-SERIES",			"Simulation series")
    define("j-SIMON-STEVIN",			"Simon Stevin")
    define("j-SIMULATION",			"Simulation")

    define("j-SIMULETTER",			"ACM Simuletter")
    define("j-SIMULETTER",			"SIGSIM Simulation Digest")
    define("j-SIMULETTER",			"Simuletter")
    define("j-SIMULETTER",			"SIGSIM newsletter")

    define("j-SJCC",				"Spring Joint Computer Conference")
    define("j-SJCC",				"Spring Joint Comput. Conf.")

    define("j-SKEPT-INQ",			"The Skeptical Inquirer")
    define("j-SKEPT-INQ",			"Skeptical Inquirer")
    define("j-SKEPT-INQ",			"Skept. Inq.")

    define("j-SKY-TELESC",			"Sky and Telescope")
    define("j-SKY-TELESC",			"Sky. Telesc.")

    define("j-SMART-MAT-STRUCT",		"Smart Materials and Structures")

    define("j-SMITHSON-INST-ANNU-REP",		"Smithsonian Institution, Annual Report")
    define("j-SMITHSON-INST-ANNU-REP",		"Smithson. Inst., Annu. Rep.")

    define("j-SMITHSONIAN",			"Smithsonian")

    define("j-SOC-INDIC-RES",			"Social Indicators Research")
    define("j-SOC-INDIC-RES",			"Social Indicators Research: An International and Interdisciplinary Journal for Quality-of-Life Measurement")
    define("j-SOC-INDIC-RES",			"Soc. Indic. Res.")

    define("j-SOC-METH-RES",			"Sociological Methods and Research")
    define("j-SOC-METH-RES",			"Soc. Meth. Res.")

    define("j-SOC-PET-ENG-J",			"Society of Petroleum Engineers journal")
    define("j-SOC-PET-ENG-J",			"SPEJ, Society of Petroleum Engineers journal")
    define("j-SOC-PET-ENG-J",			"Soc. Pet. Eng. j.")

    define("j-SOC-PROBL",			"Social Problems")
    define("j-SOC-PROBL",			"Soc. Prob.")
    define("j-SOC-PROBL",			"Soc. Probl.")

    define("j-SOC-SCI",				"Social Scientist")
    define("j-SOC-SCI",				"Soc. Sci.")

    define("j-SOC-SCI-INFO",			"Social Science Information = Information sur les sciences sociales")
    define("j-SOC-SCI-INFO",			"Soc. Sci. Info.")

    define("j-SOC-STUD-SCI",			"Social Studies of Science")
    define("j-SOC-STUD-SCI",			"Soc. Stud. Sci.")

    define("j-SOC-TEXT",			"Social Text")
    define("j-SOC-TEXT",			"Soc. Text")

    define("j-SOCIAL-SCI-COMP-REV",		"Social science computer review")

    define("j-SOCIO-ECON",			"Journal of Socio-Economics")
    define("j-SOCIO-ECON",			"The Journal of Socio-Economics")
    define("j-SOCIO-ECON",			"J. Socio-Econ.")

    define("j-SOCIO-ECON-PLANN-SCI",		"Socio-Economic Planning Sciences")
    define("j-SOCIO-ECON-PLANN-SCI",		"Socio-econ. plann. sci.")
    define("j-SOCIO-ECON-PLANN-SCI",		"Socio-Economic Planning")

    define("j-SOCIOL-METHODS-RES",		"Sociological Methods \\& Research")
    define("j-SOCIOL-METHODS-RES",		"Sociological Methods and Research")
    define("j-SOCIOL-METHODS-RES",		"Sociol. Methods Res.")

    define("j-SOFT-COMP",			"Soft computing: newsletter of the {Canadian Society for Fuzzy Information and Neural Systems}")
    define("j-SOFT-COMP",			"Soft Computing")

    define("j-SOFT-PROT",			"Software Protection")

    define("j-SOFTWARE-CONCEPTS-TOOLS",		"Software---Concepts and Tools")
    define("j-SOFTWARE-ECONOMICS-LETTER",	"Software Economics Letter")
    define("j-SOFTWARE-ENG-WORKSTATIONS",	"Software for Engineering Workstations")
    define("j-SOFTWARE-LAW-J",			"Software law journal")
    define("j-SOFTWARE-MAG",			"Software Magazine")

    define("j-SOFTWARE-NEWS",			"Software News")

    define("j-SOFTWARE-SYST-MODEL",		"Software and Systems Modeling")
    define("j-SOFTWARE-SYST-MODEL",		"Software \\& Systems Modeling")
    define("j-SOFTWARE-SYST-MODEL",		"Software Syst. Model.")

    define("j-SOGO-RINSHO",			"Sogo Rinsho = Clinic all-round")
    define("j-SOGO-RINSHO",			"Sogo Rinsho")

    define("j-SOLID-STATE-COMMUN",		"Solid State Communications")
    define("j-SOLID-STATE-COMMUN",		"Solid State Comm.")
    define("j-SOLID-STATE-COMMUN",		"Solid State Commun.")

    define("j-SOLID-STATE-PHYS-N-Y-1955",	"Solid state physics (New York. 1955)")
    define("j-SOLID-STATE-PHYS-N-Y-1955",	"Solid state physics")
    define("j-SOLID-STATE-PHYS-N-Y-1955",	"Solid state phys.")
    define("j-SOLID-STATE-PHYS-N-Y-1955",	"Solid state phys. (N. Y., 1955)")

    define("j-SOURCE-ART",			"Source, Notes in the History of Art")
    define("j-SOUTH-AFRICAN-COMP-J",		"South African computer journal = Suid-Afrikaanse rekenaartydskrif")

    define("j-SOUTHCON",			"Southcon Conference Record")

    define("j-SOV-J-COMP-SYS-SCI",		"Soviet Journal of Computer and Systems Sciences")
    define("j-SOV-J-NUM-ANA-MATH-MOD",		"Soviet Journal of Numerical Analysis and Mathematical Modelling")

    define("j-SOV-J-QUANTUM-ELECTRON",		"Soviet journal of quantum electronics")
    define("j-SOV-J-QUANTUM-ELECTRON",		"Sov. j. quantum electron.")

    define("j-SOV-MATH-NY",			"Soviet Mathematics (New York)")
    define("j-SOV-MATH-NY",			"Soviet Mathematics (New York) = Izvestiya vysshikh uchebnykh zavedenii. Matematika")
    define("j-SOV-MATH-PROVIDENCE",		"Soviet Mathematics")
    define("j-SOV-MATH-PROVIDENCE",		"Soviet Mathematics (Providence)")

    define("j-SOV-PHYS-JETP",			"Soviet physics, JETP")
    define("j-SOV-PHYS-JETP",			"Soviet physics, Journal of experimental and theoretical physics")
    define("j-SOV-PHYS-JETP",			"Sov. phys. JETP")

    define("j-SOV-PHYS-SOLID-STATE",		"Soviet physics, Solid state")
    define("j-SOV-PHYS-SOLID-STATE",		"Sov. phys., Solid state")

    define("j-SOV-PHYS-USP",			"Soviet Physics. Uspekhi")
    define("j-SOV-PHYS-USP",			"Soviet Phys. Uspekhi")
    define("j-SOV-PHYS-USP",			"Sov. Phys. Usp.")

    define("j-SOVIET-J-DEVEL-BIO",		"The Soviet journal of developmental biology")

    define("j-SOVIET-MATH-DOKL",		"Soviet Mathematics. Doklady")
    define("j-SOVIET-MATH-DOKL",		"Soviet Math. Dokl.")
    define("j-SOVIET-MATH-DOKL",		"Soviet Math. Doklady")

    define("j-SOVIET-PHYS-DOKL",		"Soviet Physics---Doklady")
    define("j-SOVIET-PHYS-DOKL",		"Soviet Phys. Doklady")
    define("j-SOVIET-PHYS-DOKL",		"Sov. Phys. Dokl.")

    define("j-SPACE-SCI-REV",			"Space Science Reviews")
    define("j-SPACE-SCI-REV",			"Space Sci. Rev.")

    define("j-SPATIAL-VIS",			"Spatial Vision")

    define("j-SPE",				"Software---Practice and Experience")
    define("j-SPE",				"Soft{\\-}ware\\emdash Prac{\\-}tice and Experience")
    define("j-SPE",				"Software\\emdash Practice and Experience")
    define("j-SPE",				"Software: Practice and Experience")
    define("j-SPE",				"Software, practice & experience")
    define("j-SPE",				"Software, practice \\& experience")
    define("j-SPE",				"Softw. Pract. Exp.")

    define("j-SPE-ASIA-PACIFIC-OIL-GAS-CONF",	"SPE --- Asia Pacific Oil \\& Gas Conference")

    define("j-SPEC-LIBR",			"Special Libraries")
    define("j-SPEC-LIBR",			"Spec. Libr.")

    define("j-SPECTROCHIM-ACTA",		"Spectrochimica Acta")
    define("j-SPECTROCHIM-ACTA",		"Spectrochim. Acta")

    define("j-SPECTROCHIMICA-ACTA-A",		"Spectrochimica Acta, Part A [Molecular Spectroscopy]")

    # Which one is Speech?  There are at least 3 with this name in UC Melvyl catalog.
    define("j-SPEECH",				"Speech")

    define("j-SPEECH-COMM",			"Speech Communication")
    define("j-SPEECH-COMM",			"Speech Commun.")

    define("j-SPEKTRUM-WISSENSCHAFT",		"Spektrum der Wissenschaft (German translation of Scientific American)")
    define("j-SPEKTRUM-WISSENSCHAFT",		"Spektrum der Wissenschaft")

    define("j-SPELMAN-SCI-MATH-J",		"Spelman Science and Mathematics Journal")
    define("j-SPELMAN-SCI-MATH-J",		"Spelman Sci. Math. J.")

    define("j-SPIP",				"Software Process: Improvement and Practice")
    define("j-SPIP",				"SPIP")
    define("j-SPIP",				"Softw. process improv. pract.")

    define("j-SPONT-GEN",			"Spontaneous Generations: A Journal for the History and Philosophy of Science")
    define("j-SPONT-GEN",			"Spontaneous Generations")
    define("j-SPONT-GEN",			"Spont. Gen.")

    define("j-SPRAY-TECHNOL-MARK",		"Spray technology \\& marketing")
    define("j-SPRAY-TECHNOL-MARK",		"Spray technol. mark.")

    define("j-SPRINGER-SER-CHEM-PHYS",		"Springer Series in Chemical Physics")
    define("j-SPRINGER-SER-CHEM-PHYS",		"Springer ser. chem. phys.")

    define("j-SPRINGERPLUS",			"SpringerPlus")

    define("j-ST-PETERSBG-MATH-J",		"St. Petersburg mathematical journal")
    define("j-ST-PETERSBG-MATH-J",		"St. Petersbg. math. j.")

    define("j-STAG",				"The Stag (Journal of the Society of Authors)")
    define("j-STAG",				"The Stag: Journal for Specialist Non-fiction Writers of the Society of Authors")

    define("j-STANFORD-VIDEO-J",		"The Stanford Video Journal")

    define("j-STAT-COMPUT",			"Statistics and Computing")
    define("j-STAT-COMPUT",			"Stat. Comput.")

    define("j-STAT-INTERFACE",			"Statistics and its Interface")
    define("j-STAT-INTERFACE",			"Stat. Interface")

    define("j-STAT-MED",			"Statistics in Medicine")
    define("j-STAT-MED",			"Stat. Med.")

    define("j-STAT-METHODOL",			"Statistical Methodology")
    define("j-STAT-METHODOL",			"Stat. Meth.")
    define("j-STAT-METHODOL",			"Stat. Method.")
    define("j-STAT-METHODOL",			"Stat. Methodol.")

    define("j-STAT-NEERLANDICA",		"Statistica Neerlandica. Journal of the Netherlands Society for Statistics and Operations Research")
    define("j-STAT-NEERLANDICA",		"Statistica Neerlandica")
    define("j-STAT-NEERLANDICA",		"Statist. Neerlandica")
    define("j-STAT-NEERLANDICA",		"Stat. Neerl.")

    define("j-STAT-PAPERS",			"Statistical Papers")
    define("j-STAT-PAPERS",			"Statist. Papers")
    define("j-STAT-PAPERS",			"Stat. Papers")

    define("j-STAT-PROB-LETT",			"Statistics \\& Probability Letters")
    define("j-STAT-PROB-LETT",			"Statistics {\\&} Probability Letters")
    define("j-STAT-PROB-LETT",			"Statistics and Probability Letters")
    define("j-STAT-PROB-LETT",			"Stat. Prob. Lett.")
    define("j-STAT-PROB-LETT",			"Statist. Probab. Lett.")
    define("j-STAT-PROB-LETT",			"Statist. Probab. Letters")
    define("j-STAT-PROB-LETT",			"Stat. Probab. Lett.")

    define("j-STAT-SCI",			"Statistical Science")
    define("j-STAT-SCI",			"Stat. Sci.")
    define("j-STAT-SCI",			"Statist. Sci.")

    ## http://www3.stat.sinica.edu.tw/statistica/
    define("j-STAT-SINICA",			"Statistica Sinica")
    define("j-STAT-SINICA",			"Stat. Sinica")

    define("j-STATIST-PAPERS",			"Statistical Papers = Statistische Hefte")
    define("j-STATIST-PAPERS",			"Statistical Papers")
    define("j-STATIST-PAPERS",			"Statist. Papers")

    define("j-STATISTICA-BOLOGNA",		"Statistica (Bologna)")
    define("j-STATISTICA-BOLOGNA",		"Statistica")

    define("j-STATISTICS",			"Statistics: A Journal of Theoretical and Applied Statistics")
    define("j-STATISTICS",			"Statistics: Mathematische Operationsforschung und Statistik")
    define("j-STATISTICS",			"Statistics (Berl. DDR)")
    define("j-STATISTICS",			"Statistics (Berlin, DDR)")
    define("j-STATISTICS",			"Statistics (Berlin)")
    define("j-STATISTICS",			"Statistics")

    define("j-STEREO-REV",			"Stereo review")
    define("j-STEREO-REV",			"Stereo rev.")

    define("j-STERNE-WELTRAUM",			"{Sterne und Weltraum}")
    define("j-STERNE-WELTRAUM",			"{Sterne Weltraum}")

    define("j-STOCH-ANAL-APPL",			"Stochastic Analysis and Applications")
    define("j-STOCH-ANAL-APPL",			"Stoch. anal. appl.")

    define("j-STOCH-DYNAM",			"Stochastics and Dynamics")
    define("j-STOCH-DYNAM",			"Stoch. Dyn.")
    define("j-STOCH-DYNAM",			"Stoch. Dynam.")

    define("j-STOCH-MODELS",			"Stochastic Models")
    define("j-STOCH-MODELS",			"Stoch. Models")

    define("j-STOCH-PROC-APPL",			"Stochastic Processes and Their Applications")
    define("j-STOCH-PROC-APPL",			"Stochastic Process. Appl.")
    define("j-STOCH-PROC-APPL",			"Stoch. proc. appl.")

    define("j-STOCH-STOCH-REP",			"Stochastics and Stochastic Reports")
    define("j-STOCH-STOCH-REP",			"Stoch. stoch. rep.")

    define("j-STOCH-SYS-APPL",			"Stochastic Systems and Appl.")

    define("j-STRUCT",				"Structure: form and function in modern biology")
    define("j-STRUCT",				"Structure (B31)")

    define("j-STRUCT-CHEM",			"Structural Chemistry")
    define("j-STRUCT-CHEM",			"Struct. Chem.")

    define("j-STRUCT-MULTDISCIP-0PTIM",		"Structural and Multidisciplinary Optimization")
    define("j-STRUCT-MULTDISCIP-0PTIM",		"Struct. Multidiscip. Optim.")

    define("j-STRUCT-OPTIM",			"Structural Optimization")
    define("j-STRUCT-OPTIM",			"Struct. Optim.")

    define("j-STRUCT-PROGRAM",			"Structured Programming")
    define("j-STRUCT-PROGRAM",			"Struct. program.")

    define("j-STUD-APPL-MATH",			"Studies in Applied Mathematics")
    define("j-STUD-APPL-MATH",			"Studies in Appl. Math.")
    define("j-STUD-APPL-MATH",			"Stud. Appl. Math.")

    define("j-STUD-BIOPHYS",			"Studia Biophysica")
    define("j-STUD-BIOPHYS",			"Stud. biophys.")

    define("j-STUD-CERCET-MAT",			"Studii {\\c{s}}i cercet{\\u{a}}ri Matematice")
    define("j-STUD-CERCET-MAT",			"Stud. cercet. mat.")
    define("j-STUD-CERCET-MAT",			"Stud. cerc. mat.")

    define("j-STUD-EAST-EUROPEAN-THOUGHT",	"Studies in {East European} Thought")
    define("j-STUD-EAST-EUROPEAN-THOUGHT",	"Stud. {East European} Thought")

    define("j-STUD-HIST-PHILOS-SCI",		"Studies in History and Philosophy of Science Part {A}")
    define("j-STUD-HIST-PHILOS-SCI",		"Studies in History and Philosophy of Science Part A")
    define("j-STUD-HIST-PHILOS-SCI",		"Stud. Hist. Philos. Sci. A")
    define("j-STUD-HIST-PHILOS-SCI",		"Stud. Hist. Philos. Sci.")

    define("j-STUD-HIST-PHILOS-SCI-B",		"Studies in History and Philosophy of Science Part B: Studies In History and Philosophy of Modern Physics")
    define("j-STUD-HIST-PHILOS-SCI-B",		"Studies in History and Philosophy of Science Part {B}")
    define("j-STUD-HIST-PHILOS-SCI-B",		"Studies in History and Philosophy of Science Part B")
    define("j-STUD-HIST-PHILOS-SCI-B",		"Stud. Hist. Philos. Sci. B")

    define("j-STUD-HIST-PHILOS-SCI-C",		"Studies in History and Philosophy of Science Part C: Studies in History and Philosophy of Biological and Biomedical Sciences")
    define("j-STUD-HIST-PHILOS-SCI-C",		"Studies in History and Philosophy of Science Part C")
    define("j-STUD-HIST-PHILOS-SCI-C",		"Studies in History and Philosophy of Science Part {C}")
    define("j-STUD-HIST-PHILOS-SCI-C",		"Stud. Hist. Philos. Sci. C")

    define("j-STUD-HIST-PHILOS-MOD-PHYS",	"Studies in History and Philosophy of Modern Physics")
    define("j-STUD-HIST-PHILOS-MOD-PHYS",	"Studies in History and Philosophy of Science. Part B. Studies in History and Philosophy of Modern Physics")
    define("j-STUD-HIST-PHILOS-MOD-PHYS",	"Stud. Hist. Philos. Sci. B Stud. Hist. Philos. Modern Phys.")
    define("j-STUD-HIST-PHILOS-MOD-PHYS",	"Stud. Hist. Philos. Mod. Phys.")

    define("j-STUD-LINGUIST",			"Studia Linguistica")
    define("j-STUD-LINGUIST",			"Stud. Ling.")
    define("j-STUD-LINGUIST",			"Stud. Linguist.")

    define("j-STUD-LOGICA",			"Studia Logica")
    define("j-STUD-LOGICA",			"Stud. Logica")

    define("j-STUD-SOV-THOUGHT",		"Studies in Soviet Thought")
    define("j-STUD-SOV-THOUGHT",		"Stud. Sov. Thought")

    define("j-STUD-STOR",			"Studi Storici") # "Italian: historical studies"
    define("j-STUD-STOR",			"Stud. Stor.")

    define("j-STUDIA-MATH",			"Studia Mathematica")
    define("j-STUDIA-MATH",			"Stud. Math.")
    define("j-STUDIA-MATH",			"Studia Math.")

    define("j-STUDIA-ROSE",			"Studia Rosenthaliana")

    define("j-STUDIES-COMP-SCI-ART-INTELL",	"Studies in Computer Science and Artificial Intelligence")
    define("j-STUDIES-INTEGRO-DIFF-EQ",		"Studies in Integro-Differential Equations")

    define("j-STUDIUM-GEN",			"Studium Generale")
    define("j-STUDIUM-GEN",			"{Studium Generale. Zeitschrift f{\\\"u}r Interdisziplin{\\\"a}re Studien. Journal for Interdisciplinary Studies}")
    define("j-STUDIUM-GEN",			"Stud. Gen.")
    define("j-STUDIUM-GEN",			"Studium Gen.")

    define("j-SUDHOFFS-ARCH",			"{Sudhoffs Archiv: Zeitschrift f{\\\"u}r Wissenschaftsgeschichte}")
    define("j-SUDHOFFS-ARCH",			"{Sudhoffs Archiv: Zeitschrift fuer Wissenschaftsgeschichte}")
    define("j-SUDHOFFS-ARCH",			"{Sudhoffs Archiv}")
    define("j-SUDHOFFS-ARCH",			"{Sudhoffs Arch.}")

    define("j-SUN-OBSERVER",			"Sun Observer")

    define("j-SUNEXPERT",			"SunExpert Magazine")
    define("j-SUNEXPERT",			"SunExpert")

    define("j-SUNSERVER",			"SunServer")
    define("j-SUNWORLD",			"SunWorld")

    define("j-SUNWORLD-ONLINE",			"SunWorld online")
    define("j-SUNWORLD-ONLINE",			"Sun world online")

    define("j-SUPERCOMPUTER",			"Supercomputer")
    define("j-SUPERCOMPUTING-REVIEW",		"Supercomputing Review")

    define("j-SUPERCOND-SCI-TECHNOL",		"Superconductor Science and Technology")
    define("j-SUPERCOND-SCI-TECHNOL",		"Supercond. Sci. Tech.")
    define("j-SUPERCOND-SCI-TECHNOL",		"Supercond. Sci. Technol.")

    define("j-SURF-INTERFACE-ANAL",		"Surface and Interface Analysis")
    define("j-SURF-INTERFACE-ANAL",		"Surface and Interface Analysis")
    define("j-SURF-INTERFACE-ANAL",		"SIA. surf. interface anal.")
    define("j-SURF-INTERFACE-ANAL",		"Surf. interface anal.")

    define("j-SURF-SCI",			"Surface Science")
    define("j-SURF-SCI",			"Surf. Sci.")

    define("j-SURF-SCI-LETT",			"Surface Science Letters")
    define("j-SURF-SCI-LETT",			"Surf. Sci. Lett.")

    define("j-SURVIVAL",			"Survival: Global Politics and Strategy")
    define("j-SURVIVE",				"Survive")
    define("j-SVENSK-KEMISK-TIDSKRIFT",		"Svensk kemisk tidskrift")

    define("j-SVENSK-NATURVETENSKAP",		"Svensk naturvetenskap")
    define("j-SVENSK-NATURVETENSKAP",		"Sv. Naturvetenskap")

    define("j-SWIAT-NAUKI",			"{\\'S}wiat Nauki")
    define("j-SWIAT-NAUKI",			"{\\'S}wiat Nauki [Polish edition of Scientific American]")
    define("j-SYMP-SOC-EXP-BIO",		"Symp Soc Exp Biol (VGF)")

    define("j-SYMPOSIA-MATHEMATICA",		"Symposia Mathematica")
    define("j-SYMPOSIA-MATHEMATICA",		"Symposia Mathematica, Academic Press")

    define("j-SYNTHESE",			"Synthese")

    define("j-SYS-ADMIN",			"Sys admin: the journal for UNIX system administrators")
    define("j-SYS-ADMIN",			"Sys admin")

    define("j-SYS-ANA-MODEL-SIM",		"Systems analysis, modelling, simulation")
    define("j-SYS-ANA-MODEL-SIM",		"Systems Analysis Modeling Simulation")
    define("j-SYS-ANA-MODEL-SIM",		"Syst. Anal. Mod. Sim.")

    define("j-SYS-COMP-JAPAN",			"Systems and computers in Japan")
    define("j-SYS-COMP-JAPAN",			"Systems Comput. Japan")

    define("j-SYS-INTEGRATION",			"Systems integration")

    define("j-SYST-CONTROL-INFO",		"Systems, Control and Information = Shisutemu Seigyo Joho Gakkai shi")
    define("j-SYST-CONTROL-INFO",		"Systems, Control and Information")
    define("j-SYST-CONTROL-INFO",		"Systems and Control = Shisutemu to seigyo")
    define("j-SYST-CONTROL-INFO",		"Systems and Control")

    define("j-SYST-CONTROL-LETT",		"Systems and Control Letters")

    define("j-SYST-RES",			"Systems Research")
    define("j-SYST-RES",			"Syst. Res.")

    define("j-SYST-RES-BEHAV-SCI",		"Systems Research and Behavioral Science")
    define("j-SYST-RES-BEHAV-SCI",		"Syst. Res. Behav. Sci.")

    define("j-SYSTEM",				"System")

    define("j-TAAS",				"ACM Transactions on Autonomous and Adaptive Systems (TAAS)")
    define("j-TAAS",				"ACM Transactions on Autonomous and Adaptive Systems")
    define("j-TAAS",				"ACM Trans. Auton. Adapt. Syst.")

    define("j-TACCESS",				"ACM Transactions on Accessible Computing (TACCESS)")
    define("j-TACCESS",				"ACM Trans.  Access. Comput.")

    define("j-TACO",				"ACM Transactions on Architecture and Code Optimization (TACO)")
    define("j-TACO",				"ACM Transactions on Architecture and Code Optimization")
    define("j-TACO",				"ACM Trans. Arch. Code Optim. (TACO)")
    define("j-TACO",				"ACM Trans. Arch. Code Optim.")
    define("j-TACO",				"Trans. Arch. Code Optim.")

    define("j-TAEHAN-HWAHAKHOE-CHI",		"Taehan hwahakhoe chi")

    define("j-TALG",				"ACM Transactions on Algorithms (TALG)")
    define("j-TALG",				"ACM Transactions on Algorithms")
    define("j-TALG",				"ACM Trans. Alg.")
    define("j-TALG",				"Trans. Alg.")

    define("j-TALIP",				"ACM Transactions on Asian Language Information Processing (TALIP)")
    define("j-TALIP",				"ACM Transactions on Asian Language Information Processing")
    define("j-TALIP",				"ACM Trans. Asian Lang. Info. Proc.")

    define("j-TALLIP",				"ACM Transactions on Asian and Low-Resource Language Information Processing (TALLIP)")
    define("j-TALLIP",				"ACM Transactions on Asian and Low-Resource Language Information Processing")
    define("j-TALLIP",				"ACM Trans. Asian Low-Resource Lang. Info. Proc.")

    define("j-TAMKANG-J-MATH",			"Tamkang Journal of Mathematics")
    define("j-TAMKANG-J-MATH",			"Tamkang J. Math.")

    define("j-TAP",				"ACM Transactions on Applied Perception (TAP)")
    define("j-TAP",				"ACM Transactions on Applied Perception")
    define("j-TAP",				"ACM Trans. Appl. Percept.")

    define("j-TAPPI-J",				"Tappi journal")
    define("j-TAPPI-J",				"Tappi j.")

    define("j-TAXON",				"Taxon")

    define("j-TCBB",				"IEEE/ACM Transactions on Computational Biology and Bioinformatics")
    define("j-TCBB",				"IEEE/ACM Trans. Comput. Biol. Bioinfo.")

    define("j-TCPS",				"ACM Transactions on Cyber-Physical Systems")
    define("j-TCPS",				"ACM Trans. Cyber-Physical Syst.")

    define("j-TDS",				"ACM Transactions on Data Science")
    define("j-TDS",				"Transactions on Data Science")
    define("j-TDS",				"Trans. Data Sci.")
    define("j-TDS",				"ACM Trans. Data Sci.")

    define("j-TEAC",				"ACM Transactions on Economics and Computation")
    define("j-TEAC",				"ACM Trans. Econ. Comput.")

    define("j-TEACHING-PSYCH",			"Teaching of Psychology")
    define("j-TEACHING-PSYCH",			"Teaching. Psych.")

    define("j-TECH-COMMUN",			"Technical Communication")
    define("j-TECH-COMMUN",			"Tech. Commun.")

    define("j-TECH-CULTURE",			"Technology and Culture")
    define("j-TECH-CULTURE",			"Tech. Cult.")
    define("j-TECH-CULTURE",			"Tech. Culture")
    define("j-TECH-CULTURE",			"Technol. Cult.")

    define("j-TECH-LEARNING",			"Technology and learning")

    define("j-TECH-MITT-KRUPP-ENGL-ED",		"Technische Mitteilungen Krupp (English ed.)")
    define("j-TECH-MITT-KRUPP-ENGL-ED",		"Tech. Mitt. Krupp (Engl. ed.)")

    define("j-TECH-REVIEW",			"Technology Review (M.I.T.)")
    define("j-TECH-REVIEW",			"Technology Review")
    define("j-TECH-REVIEW",			"Tech. Review")
    define("j-TECH-REVIEW",			"Tech. Rev.")
    define("j-TECH-REVIEW",			"Tech. Rev. (M.I.T.)")

    define("j-TECHNIQUE-SCI-INFORMATIQUES",	"Technique et science informatiques : TSI")
    define("j-TECHNIQUE-SCI-INFORMATIQUES",	"TSI. Tech. sci. inform.")
    define("j-TECHNIQUE-SCI-INFORMATIQUES",	"Technique et Science Informatiques")
    define("j-TECHNIQUE-SCI-INFORMATIQUES",	"Technique et Science Informatique")

    define("j-TECHNOL-FORECAST-SOC-CHANGE",	"Technological forecasting and social change")
    define("j-TECHNOL-FORECAST-SOC-CHANGE",	"Technol. forecast. soc. change.")

    define("j-TECHNOL-SOC",			"Technology in Society")
    define("j-TECHNOL-SOC",			"Technol. Soc.")

    define("j-TECHNOMETRICS",			"Technometrics")
    define("j-TECHNOVATION",			"Technovation")

    define("j-TECHTRENDS",			"TechTrends: for leaders in education and training")
    define("j-TECHTRENDS",			"TechTrends")

    define("j-TECS",				"ACM Transactions on Embedded Computing Systems")
    define("j-TECS",				"ACM Trans. Embedded Comput. Syst.")

    define("j-TELECOMM-RADIO-ENG",		"Telecommunications and Radio Engineering")
    define("j-TELECOMM-RADIO-ENG",		"Telecomm. Radio Eng.")

    define("j-TELECOMMUNICATIONS-AMERICAS-ED",	"Telecommunications (Americas Edition)")
    define("j-TELECOMMUNICATIONS-AMERICAS-ED",	"Telecommunications (Americas ed.)")
    define("j-TELECOMMUNICATIONS-AMERICAS-ED",	"Telecommunications --- America's ed")

    define("j-TELECOMMUNICATIONS-INT-ED",	"Telecommunications (International ed.)")
    define("j-TELECOMMUNICATIONS-INT-ED",	"Telecommunications (Int. ed.)")
    define("j-TELECOMMUNICATIONS-INT-ED",	"Telecommunications --- international edition")

    define("j-TELEMAT-INFORM",			"Telematics and Informatics")
    define("j-TELEMAT-INFORM",			"Telemat. inform.")

    define("j-TELEPHONY",                       "Telephony")

    define("j-TEORET-MATH-FIZ",			"Teoreticheskaya i Matematicheskaya Fizika")
    define("j-TEORET-MATH-FIZ",			"Rossi{\\u\\i}skaya Akademiya Nauk. Teoreticheskaya i Matematicheskaya Fizika")
    define("j-TEORET-MATH-FIZ",			"Teoret. Mat. Fiz.")

    define("j-TEST",				"TEST: An Official Journal of the Spanish Society of Statistics and Operations Research")
    define("j-TEST",				"TEST")

    define("j-TETRAHEDRON-COMPUT-METH",		"Tetrahedron Computer Methodology")
    define("j-TETRAHEDRON-COMPUT-METH",		"Tetrahedron comput. methodol.")

    define("j-TEX-J-SCI",			"Texas Journal of Science")
    define("j-TEX-J-SCI",			"Tex. j. sci.")

    define("j-TEX-TUG-NEWS",			"{\\TeX} and TUG News")

    define("j-TEXHAX",				"{\\TeX\\-hax}")
    define("j-TEXHAX",				"{\\TeX{}hax}")

    define("j-TEXLINE",				"{\\TeX}line")

    define("j-TEXNIQUES",			"{\\TeX}{\\-}niques, Publications for the {\\TeX} community")
    define("j-TEXNIQUES",			"{\\TeX}niques")

    define("j-TEXTURES-MICROSTRUCT",		"Textures and microstructures")
    define("j-TEXTURES-MICROSTRUCT",		"Textures microstruct.")

    define("j-THE-J",				"{T H E} journal (Technological Horizons in Education)")
    define("j-THE-J",				"{THE} journal: technological horizons in education")
    define("j-THE-J",				"The journal: technological horizons in education")
    define("j-THE-J",				"The journal: technological horizons in educatio")
    define("j-THE-J",				"The journal: technological horizons in educati")
    define("j-THE-J",				"{THE} journal")

    define("j-THEOR-BIOL-MED-MODEL",		"Theoretical Biology and Medical Modelling")
    define("j-THEOR-BIOL-MED-MODEL",		"Theor. Biol. Med. Model.")

    define("j-THEOR-CHEM-ACCOUNTS",		"Theoretical Chemistry Accounts")
    define("j-THEOR-CHEM-ACCOUNTS",		"Theor. Chem. Accounts")
    define("j-THEOR-CHEM-ACCOUNTS",		"Theor. Chem. Acc.")

    define("j-THEOR-CHEM-LONDON",		"Theoretical Chemistry (London)")
    define("j-THEOR-CHEM-LONDON",		"Theoretical Chemistry")
    define("j-THEOR-CHEM-LONDON",		"Theor. Chem. (London)")
    define("j-THEOR-CHEM-LONDON",		"Theor. Chem.")

    define("j-THEOR-CHIM-ACTA",			"Theoretica Chimica Acta")
    define("j-THEOR-CHIM-ACTA",			"Theor. Chim. Acta")

    define("j-THEOR-COMP-SCI",			"Theoretical Computer Science")
    define("j-THEOR-COMP-SCI",			"Theoret. Comput. Sci.")

    define("j-THEOR-MATH-PHYS",			"Theoretical and Mathematical Physics")
    define("j-THEOR-MATH-PHYS",			"Theor. Math. Phys.")

    define("j-THEOR-POPUL-BIOL",		"Theoretical Population Biology")
    define("j-THEOR-POPUL-BIOL",		"Theor. Popul. Biol.")
    define("j-THEOR-POPUL-BIOL",		"Theoret. Popul. Biol.")
    define("j-THEOR-POPUL-BIOL",		"Theo. Pop. Biology")

    define("j-THEOREMA",			"Teorema: Revista Internacional de Filosof{\\'\\i}a")
    define("j-THEOREMA",			"Teorema")

    define("j-THEORIA",				"Theoria")

    define("j-THEORIA-MADRID",			"Theoria: An International Journal for Theory, History and Foundations of Science")
    define("j-THEORIA-MADRID",			"Theoria (San Sebasti{\\'a}n) (2)")
    define("j-THEORIA-MADRID",			"Theoria Segunda Epoca")
    define("j-THEORIA-MADRID",			"Theoria (Madrid)")

    define("j-THEORY-COMPUT-SYST",		"Theory of Computing Systems")
    define("j-THEORY-COMPUT-SYST",		"Theory Comp. Sys.")
    define("j-THEORY-COMPUT-SYST",		"Theory Comp. Syst.")
    define("j-THEORY-COMPUT-SYST",		"Theory Comput. Sys.")
    define("j-THEORY-COMPUT-SYST",		"Theory Comput. Syst.")

    ## Journal long name changed in 1989, but CODEN and ISSN remain unchanged
    define("j-THEORY-DECISION",			"Theory and Decision: an International Journal for Philosophy and Methodology of the Social Sciences") # v1 to v25 1988
    define("j-THEORY-DECISION",			"Theory and Decision. An International Journal for Multidisciplinary Advances in Decision Science") # v26 1989 to date
    define("j-THEORY-DECISION",			"Theory and Decision")

    define("j-THEORY-PROBAB-APPL",		"Theory of Probability and its Applications")
    define("j-THEORY-PROBAB-APPL",		"Theory probab. appl.")
    define("j-THEORY-PROBAB-APPL",		"Theor. Probability Appl.")

    define("j-THEORY-PROBAB-MATH-STAT",		"Theory of Probability and Mathematical Statistics")
    define("j-THEORY-PROBAB-MATH-STAT",		"Theory Probab. Math. Stat.")

    define("j-THIN-WALLED-STRUCTURES",		"Thin-Walled Structures")

    define("j-THRI",				"ACM Transactions on Human--Robot Interaction (THRI)")
    define("j-THRI",				"ACM Trans. Hum. Robot Interact.")

    define("j-THROMB-DIATH-HAEMORRH",		"Thrombosis et diathesis haemorrhagica")
    define("j-THROMB-DIATH-HAEMORRH",		"Thromb. diath. haemorrh.")

    define("j-TIME",				"Time Magazine")
    define("j-TIME",				"Time")

    define("j-TIMES",				"The Times [London, UK]")
    define("j-TIMES",				"The Times")
    define("j-TIMES",				"Times")

    define("j-TIIS",				"ACM Transactions on Interactive Intelligent Systems  (TIIS)")
    define("j-TIIS",				"ACM Trans. Interact. Intell. Syst. (TIIS)")
    define("j-TIIS",				"ACM Trans. Interact. Intell. Syst. (TIIS)")
    define("j-TIIS",				"Trans. Interact. Intell. Syst.")
    define("j-TIIS",				"TIIS")

    define("j-TIOT",				"ACM Transactions on Internet of Things (TIOT)")
    define("j-TIOT",				"ACM Trans. Internet Things")

    define("j-TISSEC",				"ACM Transactions on Information and System Security")
    define("j-TISSEC",				"Information and system security")
    define("j-TISSEC",				"Transactions on information and system security")
    define("j-TISSEC",				"TISSEC")

    define("j-TIST",				"ACM Transactions on Intelligent Systems and Technology (TIST)")
    define("j-TIST",				"ACM trans. intell. syst. tech. (TIST)")
    define("j-TIST",				"ACM trans. intell. syst. tech.")

    define("j-TKDD",				"ACM Transactions on Knowledge Discovery from Data (TKDD)")
    define("j-TKDD",				"ACM Transactions on Knowledge Discovery from Data")
    define("j-TKDD",				"ACM Trans. Knowl. Discov. Data")

    define("j-TMIS",				"ACM Transactions on Management Information Systems (TMIS)")
    define("j-TMIS",				"ACM Transactions on Management Information Systems")
    define("j-TMIS",				"ACM Trans. Manag. Info. Syst.")

    define("j-TOCE",				"ACM Transactions on Computing Education")
    define("j-TOCE",				"ACM trans. cont. educ.")

    define("j-TOCH",				"ACM Transactions on Computing for Healthcare (HEALTH)")
    define("j-TOCH",				"ACM Transactions on Computing for Healthcare")
    define("j-TOCH",				"Trans. Comput. Healthcare")
    define("j-TOCH",				"ACM Trans. Comput. Healthcare")

    define("j-TOCHI",				"ACM Transactions on Computer-Human Interaction")
    define("j-TOCHI",				"Transactions on Computer-Human Interaction")
    define("j-TOCHI",				"ACM trans. comput.-hum. interact.")

    define("j-TOCL",				"ACM Transactions on Computational Logic")

    define("j-TOCS",				"ACM Transactions on Computer Systems")

    define("j-TOCT",				"ACM Transactions on Computation Theory (TOCT)")
    define("j-TOCT",				"ACM Transactions on Computation Theory")
    define("j-TOCT",				"ACM Trans. Comput. Theory")

    define("j-TODAES",				"ACM Transactions on Design Automation of Electronic Systems (TODAES)")
    define("j-TODAES",				"ACM Transactions on Design Automation of Electronic Systems")
    define("j-TODAES",				"ACM Trans. Des. Autom. Electron. Syst.")

    define("j-TODS",				"ACM Transactions on Database Systems")
    define("j-TODS",				"ACM Trans. Database Systems")

    define("j-TOG",				"ACM Transactions on Graphics")

    define("j-TOIS",				"ACM Transactions on Information Systems")
    define("j-TOIS",				"ACM transactions on information systems: a publication of the Association for Computing Machinery")
    define("j-TOIS",				"ACM Transactions on Information Systems")
    define("j-TOIS",				"ACM Trans. Inf. Sys.")

    define("j-TOIT",				"ACM Transactions on Internet Technology (TOIT)")
    define("j-TOIT",				"ACM Transactions on Internet Technology")
    define("j-TOIT",				"ACM Trans. Internet Tech.")

    define("j-TOKYO-J-MATH",			"Tokyo journal of mathematics")
    define("j-TOKYO-J-MATH",			"Tokyo J. Math.")

    define("j-TOMACS",				"ACM Transactions on Modeling and Computer Simulation")
    define("j-TOMACS",				"ACM Trans. Model. Comput. Simul.")

    define("j-TOMCCAP",				"ACM Transactions on Multimedia Computing, Communications, and Applications")
    define("j-TOMCCAP",				"ACM Trans. Multimedia. Comput. Comm. Appl.")

    ## From the ACM Portal Web site: ``On 23rd May 2014, ACM TOMCCAP
    ## changed its acronym to ACM TOMM. This acronym change was the
    ## result of extensive discussions between the journal Editorial
    ## Board and SIGMM constituents dating back to 2011. This name
    ## change emphasizes the continued strong collaboration with the
    ## ACM Multimedia conference (ACMMM).''

    define("j-TOMM",				"ACM Transactions on Multimedia Computing, Communications, and Applications")
    define("j-TOMM",				"ACM Trans. Multimedia. Comput. Comm. Appl.")

    define("j-TOMPECS",				"ACM Transactions on Modeling and Performance Evaluation of Computing Systems (TOMPECS)")
    define("j-TOMPECS",				"ACM Transactions on Modeling and Performance Evaluation of Computing Systems")
    define("j-TOMPECS",				"ACM trans. model. perform. eval. comput. syst.")

    define("j-TOMS",				"ACM Transactions on Mathematical Software")
    define("j-TOMS",				"ACM Trans on Math. Software")
    define("j-TOMS",				"ACM Trans. Math. Soft.")
    define("j-TOMS",				"ACM Trans. Math. Softw")
    define("j-TOMS",				"ACM Trans. Math. Softw.")
    define("j-TOMS",				"ACM Trans. Math. Software")
    define("j-TOMS",				"Trans. on Mathematical Software")

    define("j-TOOIS",				"ACM Transactions on Office Information Systems")
    define("j-TOOIS",				"ACM Trans. on Office Inf. Sys.")

    define("j-TOPC",				"ACM Transactions on Parallel Computing")
    define("j-TOPC",				"ACM Trans. Parallel Comput.")

    define("j-TOPLAS",				"ACM Transactions on Programming Languages and Systems")
    define("j-TOPLAS",				"ACM Trans. Program. Lang. Syst.")

    define("j-TOPOI",				"Topoi")
    define("j-TOPOLOGY",			"Topology")

    define("j-TOPS",				"ACM Transactions on Privacy and Security (TOPS)")
    define("j-TOPS",				"ACM Trans. Privacy Secur. (TOPS)")
    define("j-TOPS",				"ACM Trans. Privacy Secur.")

    define("j-TORS",				"ACM Transactions on Recommender Systems (TORS)")
    define("j-TORS",				"TORS")

    define("j-TOS",				"ACM Transactions on Storage")
    define("j-TOS",				"ACM trans. storage")

    define("j-TOSEM",				"ACM Transactions on Software Engineering and Methodology")
    define("j-TOSEM",				"ACM trans. softw. eng. methodol.")

    define("j-TOSN",				"ACM Transactions on Sensor Networks (TOSN)")
    define("j-TOSN",				"ACM Transactions on Sensor Networks")
    define("j-TOSN",				"ACM Trans. Sensor Networks")

    define("j-TOXICOL-APPL-PHARMACOL",		"Toxicology and applied pharmacology")
    define("j-TOXICOL-APPL-PHARMACOL",		"Toxicol Appl Pharmacol.")

    define("j-TQC",				"ACM Transactions on Quantum Computing (TQC)")
    define("j-TQC",				"ACM Transactions on Quantum Computing")
    define("j-TQC",				"ACM Trans. Quant. Comput.")

    define("j-TRAITE-SIGNAL",			"Traitement du signal")

    define("j-TRANS-AM-FISH-SOC",		"Transactions of the American Fisheries Society")
    define("j-TRANS-AM-FISH-SOC",		"Trans. Am. Fish. Soc.")

    define("j-TRANS-AM-MATH-SOC",		"Transactions of the American Mathematical Society")
    define("j-TRANS-AM-MATH-SOC",		"Trans. Amer. Math. Soc.")

    define("j-TRANS-AM-NUCL-SOC",		"Transactions of the American Nuclear Society")
    define("j-TRANS-AM-NUCL-SOC",		"Trans. Am. Nucl. Soc.")

    define("j-TRANS-AM-PHILOS-SOC-N-S",		"Transactions of the American Philosophical Society, New Series")
    define("j-TRANS-AM-PHILOS-SOC-N-S",		"Trans. Am. Philos. Soc., N.S.")

    define("j-TRANS-AMER-INST-ELEC-ENG",	"Transactions of the American Institute of Electrical Engineers")
    define("j-TRANS-AMER-INST-ELEC-ENG",	"Trans. Amer. Inst. Elec. Eng.")
    define("j-TRANS-AMER-INST-ELEC-ENG",	"Transactions of the AIEE")
    define("j-TRANS-AMER-INST-ELEC-ENG",	"AIEE Transactions")

    define("j-TRANS-ASAE",			"Transactions of the American Society of Agricultural Engineers")
    define("j-TRANS-ASAE",			"Transactions of the ASAE")
    define("j-TRANS-ASAE",			"Trans. ASAE")

    define("j-TRANS-ASME-C",			"Transactions of the ASME. Series C")
    define("j-TRANS-ASME-C",			"Trans. Amer. Soc. Mech. Engr., Series C")

    define("j-TRANS-ASME-D",			"Transactions of the ASME. Series D, Journal of basic engineering")
    define("j-TRANS-ASME-D",			"Transactions of the ASME. Series D")
    define("j-TRANS-ASME-D",			"Trans. Amer. Soc. Mech. Engr., Series D")

    define("j-TRANS-BOSE-RES-INST-CALCUTTA",	"Transactions of the {Bose Research Institute (Calcutta)}")
    define("j-TRANS-BOSE-RES-INST-CALCUTTA",	"Transactions of the {Bose Research Institute}")
    define("j-TRANS-BOSE-RES-INST-CALCUTTA",	"Trans. {Bose Res. Inst. (Calcutta)}")
    define("j-TRANS-BOSE-RES-INST-CALCUTTA",	"Trans. {Bose Res. Inst. (Calcutta)}")

    define("j-TRANS-CAMBRIDGE-PHILOS-SOC",	"Transactions of the Cambridge Philosophical Society")
    define("j-TRANS-CAMBRIDGE-PHILOS-SOC",	"Trans. Cambridge Philos. Soc.")
    define("j-TRANS-CAMBRIDGE-PHILOS-SOC",	"Trans. Camb. Phil. Soc.")
    define("j-TRANS-CAMBRIDGE-PHILOS-SOC",	"Trans. Camb. Philos. Soc.")

    define("j-TRANS-FARADAY-SOC",		"Transactions of the Faraday Society")
    define("j-TRANS-FARADAY-SOC",		"Trans. Faraday Soc.")

    define("j-TRANS-GIS",			"Transactions in {GIS}")
    define("j-TRANS-GIS",			"Trans. {GIS}")

    define("j-TRANS-IEICE-D-II",		"Transactions of the Institute of Electronics, Information and Communication Engineers D-II = Denshi Joho Tsushin Gakkai ronbunshi. D-II, Joho, shisutemu II---joho shori")
    define("j-TRANS-IEICE-D-II",		"Transactions of the Institute of Electronics, Information and Communication Engineers D-II")
    define("j-TRANS-IEICE-D-II",		"Trans. Inst. Electron. and Commun. Eng. Jpn. Part D (Japan)")
    define("j-TRANS-IEICE-D-II",		"Trans. Inst. Electron. and Commun. Jpn. Part D (Japan)")

    define("j-TRANS-INFO-PROCESSING-SOC-JAPAN", "Transactions of the Information Processing Society of Japan")
    define("j-TRANS-INFO-PROCESSING-SOC-JAPAN", "Trans. Inform. Process. Soc. Japan")

    define("j-TRANS-IRE",			"Transactions of the IRE")
    define("j-TRANS-IRE",			"Trans. IRE")

    define("j-TRANS-IRE-PROF-GROUP-INF-THEORY",	"Transaction of the {IRE} Professional Group on Information Theory {PGIT}")
    define("j-TRANS-IRE-PROF-GROUP-INF-THEORY",	"Transaction of the {IRE} Professional Group on Information Theory")
    define("j-TRANS-IRE-PROF-GROUP-INF-THEORY",	"Trans. {IRE} Prof. Group Inf. Theory {PGIT}")
    define("j-TRANS-IRE-PROF-GROUP-INF-THEORY",	"Trans. {IRE} Prof. Group Inf. Theory")

    define("j-TRANS-MATH-APPL",			"Transactions of Mathematics and its Applications")
    define("j-TRANS-MATH-APPL",			"Trans. Math. Appl.")

    define("j-TRANS-N-Y-ACAD-SCI-2",		"Transactions of the New York Academy of Sciences, Series II")
    define("j-TRANS-N-Y-ACAD-SCI-2",		"Transactions of the New York Academy of Sciences")
    define("j-TRANS-N-Y-ACAD-SCI-2",		"Trans. N. Y. Acad. Sci. II")
    define("j-TRANS-N-Y-ACAD-SCI-2",		"Trans. N. Y. Acad. Sci.")

    define("j-TRANS-PROC-N-Z-INST",		"Transactions and Proceedings of the New Zealand Institute")
    define("j-TRANS-PROC-N-Z-INST",		"Trans. Proc. N. Z. Inst.")

    define("j-TRANS-PROC-R-SOC-N-Z",		"Transactions and Proceedings of the Royal Society of New Zealand")
    define("j-TRANS-PROC-R-SOC-N-Z",		"Trans. Proc. R. Soc. N. Z.")

    define("j-TRANS-R-SOC-CAN",			"Transactions of the Royal Society of Canada")
    define("j-TRANS-R-SOC-CAN",			"Trans. R. Soc. Can.")

    define("j-TRANS-R-SOC-EDINBURGH",		"Transactions of the Royal Society of Edinburgh")
    define("j-TRANS-R-SOC-EDINBURGH",		"Trans. Roy. Soc. Edinburgh")
    define("j-TRANS-R-SOC-EDINBURGH",		"Trans. Roy. Soc. Edinb.")
    define("j-TRANS-R-SOC-EDINBURGH",		"Trans. R. Soc. Edinb.")
    define("j-TRANS-R-SOC-EDINBURGH",		"Trans. R. Soc. Edinburgh")

    define("j-TRANS-SAIEE",			"Transactions --- The South African Institute of Electrical Engineers. Handelinge --- Die Suid-Afrikaanse Instituut van Elektriese Ingenieurs")
    define("j-TRANS-SAIEE",			"Transactions --- The South African Institute of Electrical Engineers. Handelinge - Die Suid-Afrikaanse Instituut van Elektriese Ingenieurs")
    define("j-TRANS-SAIEE",			"Trans. S. Afr. Inst. Electr. Eng.")

    define("j-TRANS-SOC-COMP-SIM",		"Transactions of the Society for Computer Simulation")

    define("j-TRANS-SOC-INST-CONTROL-ENG",	"Transactions of the Society of Instrument and Control Engineers")
    define("j-TRANS-SOC-INST-CONTROL-ENG",	"Trans. Soc. Instrument and Control Engineers")

    define("j-TRANSP-DISTRIB",			"Transportation \\& distribution")
    define("j-TRANSP-DISTRIB",			"Transp. distrib.")

    define("j-TRANS-SOC-RHEOLOGY",		"Transactions of the Society of Rheology")
    define("j-TRANS-SOC-RHEOLOGY",		"Trans. Soc. Rheol.")
    define("j-TRANS-SOC-RHEOLOGY",		"Trans. Soc. Rheology")

    define("j-TRANSFUSION",			"Transfusion")

    define("j-TRANSPORT-RES",			"Transportation Research")
    define("j-TRANSPORT-RES",			"Transp. Res.")

    define("j-TRANSPORT-SCI",			"Transportation Science")
    define("j-TRANSPORT-SCI",			"Transp. Sci.")

    define("j-TRAV-HUM",			"Le Travail Humain")
    define("j-TRAV-HUM",			"Travail Humain")
    define("j-TRAV-HUM",			"Trav. Hum.")

    define("j-TRAVAUX-SCI",			"Travaux scientifiques des chercheurs du Service de sant{\\'e} des arm{\\'e}es durant l'ann{\\'e}e")
    define("j-TRAVAUX-SCI",			"Travaux scientifiques des chercheurs du Service de sante des armees durant l'annee")

    define("j-TRENDS-BIOCHEM-SCI",		"Trends in biochemical sciences")
    define("j-TRENDS-BIOCHEM-SCI",		"Trends biochem. sci. (Amst., Ref. ed.)")
    define("j-TRENDS-BIOCHEM-SCI",		"Trends biochem. sci. (Amst., Regul. ed.)")
    define("j-TRENDS-BIOCHEM-SCI",		"TIBS")
    define("j-TRENDS-BIOCHEM-SCI",		"Trends Biochem. Sci.")
    define("j-TRENDS-BIOCHEM-SCI",		"Trends Bioch. Sci.")

    define("j-TRENDS-COGN-SCI",			"Trends in Cognitive Sciences")
    define("j-TRENDS-COGN-SCI",			"Trends Cognit. Sci.")
    define("j-TRENDS-COGN-SCI",			"Trends Cogn. Sci.")

    define("j-TRENDS-ECOL-EVOL",		"Trends in ecology and evolution")
    define("j-TRENDS-ECOL-EVOL",		"Trends in ecology \\& evolution")
    define("j-TRENDS-ECOL-EVOL",		"Trends ecol. \\& evol. (Amst.)")

    define("j-TRENDS-GENET",			"Trends in Genetics (Personal edition)")
    define("j-TRENDS-GENET",			"Trends in genetics")
    define("j-TRENDS-GENET",			"Trends Genet (WEK)")
    define("j-TRENDS-GENET",			"Trends in Gen.")
    define("j-TRENDS-GENET",			"Trends Genet.")
    define("j-TRENDS-GENET",			"TIG")

    define("j-TRENDS-MICROBIOL",		"Trends in microbiology")
    define("j-TRENDS-MICROBIOL",		"Trends in microbiol.")

    define("j-TRENDS-NEUROSCI",			"Trends in neurosciences (Regular ed.)")
    define("j-TRENDS-NEUROSCI",			"Trends in neurosciences")
    define("j-TRENDS-NEUROSCI",			"Trends neurosci. (Regul. ed.)")
    define("j-TRENDS-NEUROSCI",			"Trends neurosci.")
    define("j-TRENDS-NEUROSCI",			"TINS")

    define("j-TRETS",				"ACM Transactions on Reconfigurable Technology and Systems (TRETS)")
    define("j-TRETS",				"ACM Transactions on Reconfigurable Technology and Systems")
    define("j-TRETS",				"ACM Trans. Reconfig. Tech. Syst.")

    define("j-TSAS",				"ACM Transactions on Spatial Algorithms and Systems (TSAS)")
    define("j-TSAS",				"ACM Transactions on Spatial Algorithms and Systems")
    define("j-TSAS",				"ACM Trans. Spat. Algorithms Syst.")

    define("j-TSC",				"ACM Transactions on Social Computing")
    define("j-TSC",				"Transactions on Social Computing")
    define("j-TSC",				"Trans. Social Comput.")
    define("j-TSC",				"ACM Trans. Social Comput.")

    define("j-TSI",				"Technology and Science of Informatics")

    define("j-TSLP",				"ACM Transactions on Speech and Language Processing (TSLP)")
    define("j-TSLP",				"ACM Transactions on Speech and Language Processing")
    define("j-TSLP",				"ACM Trans. Speech Lang. Proc. (TSLP)")
    define("j-TSLP",				"ACM Trans. Speech Lang. Proc.")

    define("j-TUGBOAT",				"TUGboat")
    define("j-TUGBOAT",				"{\\TUB}")
    define("j-TUGBOAT",				"{\\TUB{}}")

    define("j-TUMORI",				"Tumori")

    define("j-TURBOMACH-INT",			"Turbomachinery International")
    define("j-TURBOMACH-INT",			"Turbomach. int.")

    define("j-TWEB",				"ACM Transactions on the Web (TWEB)")
    define("j-TWEB",				"ACM Transactions on the Web")
    define("j-TWEB",				"ACM Trans. Web")

    define("j-TWIO",				"TWIOscoop")

    ## j-TWO-YEAR-COLL-MATH-J v1n1 1970 to v14n5 1983, then renamed to j-COLLEGE-MATH-J
    ## v15n1 1984 to date
    define("j-TWO-YEAR-COLL-MATH-J",		"Two-Year College Mathematics Journal")
    define("j-TWO-YEAR-COLL-MATH-J",		"Two-year Coll. Math. J.")

    define("j-U-LC",				"U \\& lc: The International Journal of Typographics")
    define("j-U-LC",				"U \\& lc")
    define("j-U-LC",				"U and lc")

    define("j-UKR-MAT-Z",			"Ukrainskii matematicheskii zhurnal")
    define("j-UKR-MAT-Z",			"Ukr. mat. z.")
    define("j-UKR-MAT-Z",			"Ukrainskij matematiceskij zurnal")
    define("j-UKR-MAT-Z",			"Ukrain. Mat. Zh.")

    define("j-ULTIM-REAL-MEAN",			"Ultimate Reality and Meaning")
    define("j-ULTIM-REAL-MEAN",			"Ultim. Real. Mean.")

    define("j-ULTRA-MIC",			"Ultramicroscopy")

    define("j-ULTRASONIC-IMAGING",		"Ultrasonic Imaging")
    define("j-ULTRASONIC-IMAGING",		"Ultrason. Imaging")

    define("j-UMAP",				"The UMAP Journal")

    define("j-UNESCO-COUR",			"UNESCO Courier")
    define("j-UNESCO-COUR",			"UNESCO Cour.")

    define("j-UNIV-COMP",			"University Computing")

    define("j-UNIVERSITAS",			"Universitas: Zeitschrift f{\\\"u}r interdisziplin{\\\"a}re Wissenschaft")
    define("j-UNIVERSITAS",			"Universitas")

    define("j-UNIX-DEVELOPER",			"UNIX Developer")
    define("j-UNIX-REVIEW",			"UNIX Review")
    define("j-UNIX-WORLD",			"UNIX/World")
    define("j-UNIXWORLD-OPEN-COMP",		"UnixWorld's Open Computing")

    define("j-US-NEWS-WORLD-REP",		"U.S. News and World Report")
    define("j-US-NEWS-WORLD-REP",		"U.S. News World Rep.")

    define("j-USENIX-SCP",			"USENIX Summer Conference Proceedings")

    define("j-USPEKHI-FIZ-NAUK",		"Uspekhi Fizicheskikh Nauk")
    define("j-USPEKHI-FIZ-NAUK",		"Uspekhi fizicheskikh nauk")
    define("j-USPEKHI-FIZ-NAUK",		"Uspehi fizicheskih nauk")
    define("j-USPEKHI-FIZ-NAUK",		"Uspechi fiziceskich nauk")
    define("j-USPEKHI-FIZ-NAUK",		"Uspehi fiz. nauk")
    define("j-USPEKHI-FIZ-NAUK",		"Uspehi fiziceskih nauk")
    define("j-USPEKHI-FIZ-NAUK",		"Uspekhi fiz. nauk")
    define("j-USPEKHI-FIZ-NAUK",		"Usp. fiz. nauk")
    define("j-USPEKHI-FIZ-NAUK",		"Fizicheskii zhurnal. Seriia D, Uspekhi fizicheskikh nauk")

    define("j-USPEHI-MAT-NAUK",			"Uspekhi matematicheskikh nauk")
    define("j-USPEHI-MAT-NAUK",			"Uspekhi matematicheskikh nauk / Vsesoiuznaia matematicheskaia assotsiatsiia")
    define("j-USPEHI-MAT-NAUK",			"Uspehi mat. nauk")

    define("j-USP-MEH",				"Uspekhi mekhaniki = Advances in mechanics")
    define("j-USP-MEH",				"Uspekhi mekhaniki. Advances in mechanics")
    define("j-USP-MEH",				"Uspehi mehaniki")
    define("j-USP-MEH",				"Usp. meh.")
    define("j-USP-MEH",				"Adv. in Mech.")

    define("j-USSR-COMP-MATH-MATH-PHYS",	"U.S.S.R. Computational Mathematics and Mathematical Physics")
    define("j-USSR-COMP-MATH-MATH-PHYS",	"USSR Computational Mathematics and Mathematical Physics")
    define("j-USSR-COMP-MATH-MATH-PHYS",	"U.S.S.R. Computational Math. and Math. Phys.")
    define("j-USSR-COMP-MATH-MATH-PHYS",	"USSR Comp. Math. and Math. Phys.")
    define("j-USSR-COMP-MATH-MATH-PHYS",	"U.S.S.R. Comput. Maths. Math. Phys.")

    define("j-UTIL-MATH",			"Utilitas Mathematica")
    define("j-UTIL-MATH",			"Utilitas Math.")
    define("j-UTIL-MATH",			"Util. Math.")
    define("j-UTIL-MATH",			"Util. math.")

    define("j-UTNE-READER",			"The Utne reader")
    define("j-UTNE-READER",			"Utne read.")

    define("j-VAX-PROF",			"The VAX professional")
    define("j-VEGETATIO",			"Vegetatio")

    ### From http://cassi.cas.org: 1 1882--v17 1898; ns n1 1899--ns v21 1919; s3 v1 1920--s3 v25 n1 1944
    define("j-VERH-DTSCH-PHYS-GES",		"{Verhandlungen der Deutschen Physikalischen Gesellschaft}")
    define("j-VERH-DTSCH-PHYS-GES",		"{Verh. Dtsch. Phys. Ges.}")
    define("j-VERH-DTSCH-PHYS-GES",		"{Verh. Deutsch. Phys. Ges.}")
    define("j-VERH-DTSCH-PHYS-GES",		"{Verhandl. Dtsch. phys. Ges.}")
    define("j-VERH-DTSCH-PHYS-GES",		"{Verh. Phys. Ges. Berlin}")
    define("j-VERH-DTSCH-PHYS-GES",		"{Verh. dt. phys. Ges.}")
    define("j-VERH-DTSCH-PHYS-GES",		"{Verh. dtsch. Phys. Ges.}")

    define("j-VERH-DTSCH-PHYS-GES-3",		"{Verhandlungen der Deutschen Physikalischen Gesellschaft. 3. Reihe}")
    define("j-VERH-DTSCH-PHYS-GES-3",		"{Verh. Dtsch. Phys. Ges. 3. Reihe}")
    define("j-VERH-DTSCH-PHYS-GES-3",		"{Verh. Deutsch. Phys. Ges. 3. Reihe}")
    define("j-VERH-DTSCH-PHYS-GES-3",		"{Verhandl. Dtsch. phys. Ges. 3. Reihe}")
    define("j-VERH-DTSCH-PHYS-GES-3",		"{Verh. Phys. Ges. Berlin. 3. Reihe}")
    define("j-VERH-DTSCH-PHYS-GES-3",		"{Verh. dtsch. Phys. Ges. 3. Reihe}")

    define("j-VERH-GES-DTSCH-NATURFORSCH-AERZTE",	"{Verhandlungen der Gesellschaft deutscher Naturforscher und {\\\"A}rzte}")
    define("j-VERH-GES-DTSCH-NATURFORSCH-AERZTE",	"{Verhandlungen der Gesellschaft Deutscher Naturforscher und {\\\"A}rzte}")
    define("j-VERH-GES-DTSCH-NATURFORSCH-AERZTE",	"{Verhandlungen der Gesellschaft deutscher Naturforscher und {\\\"A}rzte, Leipzig}")
    define("j-VERH-GES-DTSCH-NATURFORSCH-AERZTE",	"{Verhandlungen der Gesellschaft Deutscher Naturforscher und {\\\"A}rzte, Leipzig}")
    define("j-VERH-GES-DTSCH-NATURFORSCH-AERZTE",	"{Verhandlungen der Gesellschaft Deutscher Naturforscher und Aerzte}")
    define("j-VERH-GES-DTSCH-NATURFORSCH-AERZTE",	"{Verh. Ges. dtsch. Naturforsch. Aerzte, Leipzig}")
    define("j-VERH-GES-DTSCH-NATURFORSCH-AERZTE",	"{Verh. Ges. dtsch. Naturforsch. Aerzte}")
    define("j-VERH-GES-DTSCH-NATURFORSCH-AERZTE",	"{Verh. Ges. dtsch. Naturforsch. {\\\"A}rzte}")

    define("j-VERH-K-ACAD-GENEESKD-BELG",       "Verh K Acad Geneeskd Belg.")

    define("j-VERH-SCHWEIZ-NATURFORSCH-GES",	"Verhandlungen der Schweizerischen Naturforschenden Gesellschaft")
    define("j-VERH-SCHWEIZ-NATURFORSCH-GES",	"Verh. Schweiz. Naturforsch. Ges.")

    define("j-VEROFF-UNIBIB-ESSEN",		"{Veroffentlichungen der Universit{\\\"a}tsbibliothek} = Publications of Essen University Library")
    define("j-VEROFF-UNIBIB-ESSEN",		"{Veroffentlichungen der Universitatsbibliothek} = Publications of Essen University Library")

    define("j-VIC-LIT-CULT",			"Victorian Literature and Culture")
    define("j-VIC-LIT-CULT",			"Vic. Liter. Cult.")
    define("j-VIC-LIT-CULT",			"Vic. Lit. Cult.")

    define("j-VIC-STUD",			"Victorian Studies")
    define("j-VIC-STUD",			"Vic. Stud.")

    define("j-VIE-SCI",				"Comptes rendus de l'Acad{\\'e}mie des sciences. La vie des sciences")
    define("j-VIE-SCI",				"La Vie des sciences")
    define("j-VIE-SCI",				"Vie sci.")
    define("j-VIE-SCI",				"La vie des Sciences, Comptes Rendus de l'Acad{\\'e}mie des Sciences, Paris")

    define("j-VIENNA-CIRCLE-INSTITUTE-YEARBOOK",	"{Vienna Circle Institute} Yearbook")

    define("j-VIERTELJAHRESSCHR-NATURFORSCH-GES-ZURICH", "{Vierteljahrsschrift der Naturforschenden Gesellschaft in Z{\\\"u}rich}")
    define("j-VIERTELJAHRESSCHR-NATURFORSCH-GES-ZURICH", "{Vierteljahresschr. Naturforsch. Ges. Z{\\\"u}rich}")
    define("j-VIERTELJAHRESSCHR-NATURFORSCH-GES-ZURICH", "{Veirteljahrsschrift der Naturforschenden Gesellschaft in Z{\\\"u}rich}")

    define("j-VIS-COMM-IMG-PROC",		"Vision Comm. and Image Proc.")

    define("j-VIS-RES",				"Vision Research (Oxford)")
    define("j-VIS-RES",				"Vision Research")
    define("j-VIS-RES",				"Vision Res.")

    define("j-VISIBLE-LANGUAGE",		"Visible Language")
    define("j-VISIBLE-LANGUAGE",		"Visible Lang.")

    define("j-VISUAL-COMPUTER",			"Visual Computer")

    define("j-VLDB-J",				"VLDB Journal: Very Large Data Bases")
    define("j-VLDB-J",				"VLDB Journal")
    define("j-VLDB-J",				"VLDB J.")
    define("j-VLDB-J",				"VLDB Journal: Very Large Data Bases: A Publication of the VLDB Endowment")
    define("j-VLDB-J",				"VLDB Journal: The International Journal on Very Large Data Bases")

    define("j-VOPROSY-VYCHISL-PRIKL-MAT",	"Voprosy Vychisl. I Prikl. Mat.")
    define("j-VOPROSY-VYCHISL-PRIKL-MAT",	"Voprosy Vychislitel'noi i Prikladnoi Matematiki")

    define("j-WALL-ST-COMPUT-REV",		"Wall Street Computer Review")
    define("j-WALL-ST-COMPUT-REV",		"Wall St. Comput. Rev.")

    define("j-WALL-ST-J",			"Wall Street Journal")
    define("j-WALL-ST-TECH",			"Wall Street and Technology")

    define("j-WAR-HIST",			"War in History")
    define("j-WAR-HIST",			"War Hist.")

    define("j-WASH-CRIME-NEWS-SERV-CORP-SECURITY-DIGEST", "Washington Crime News Services' Corporate Security Digest")

    define("j-WASHINGTON-POST",			"Washington Post")
    define("j-WASSERWIRTSCHAFT",		"Wasserwirtschaft")

    define("j-WATER-AIR-SOIL-POLLUT",		"Water, Air and Soil Pollution")
    define("j-WATER-AIR-SOIL-POLLUT",		"Water air soil pollut.")

    define("j-WATER-RESOUR-RES",		"Water Resources Research")
    define("j-WATER-RESOUR-RES",		"Water resour. res.")

    define("j-WATER-SCI-TECHNOL",		"Water Science and Technology")
    define("j-WATER-SCI-TECHNOL",		"Water science and technology: a journal of the International Association on Water Pollution Research")
    define("j-WATER-SCI-TECHNOL",		"Water sci. technol.")

    define("j-WAVE-MOTION",			"Wave motion")

    define("j-WAVES-RANDOM-COMPLEX-MEDIA",	"Waves in Random and Complex Media. Propagation, Scattering and Imaging")
    define("j-WAVES-RANDOM-COMPLEX-MEDIA",	"Waves in Random and Complex Media")
    define("j-WAVES-RANDOM-COMPLEX-MEDIA",	"Waves Random Complex Media")

    define("j-WAVES-RANDOM-MEDIA",		"Waves in random media")
    define("j-WAVES-RANDOM-MEDIA",		"Waves in random media: an Institute of Physics journal")
    define("j-WAVES-RANDOM-MEDIA",		"Waves random media")

    define("j-WEB-APPS",			"Web Apps magazine")
    define("j-WEB-REVIEW",			"Web Review")
    define("j-WEB-WEEK",			"Web Week")
    define("j-WEB-TECHNIQUES",			"Web Techniques")

    define("j-WEBSERVER",			"WebServer Magazine: For Managers of World Wide Web Sites")
    define("j-WEBSERVER",			"WebServer Magazine")

    define("j-WESCON-CONF-REC",			"WESCON Conference Record")
    define("j-WESCON-CONF-REC",			"WESCON conf. rec.")

    define("j-WHARTON-REPORT",			"Wharton Report")
    define("j-WHOLE-EARTH-REV",			"Whole Earth Review")

    define("j-WIEN-CHEM-ZTG",			"{Wiener Chemiker-Zeitung}")
    define("j-WIEN-CHEM-ZTG",			"{Wien. Chem.-Ztg.}")

    define("j-WIRES",				"Wiley Interdisciplinary Reviews. Computational Statistics (WIREs)")
    define("j-WIRES",				"WIREs Computational Statistics")
    define("j-WIRES",				"Wiley Interdiscip. Rev. Comput. Stat.")

    define("j-WILSON-LIBR-BULL",		"Wilson library bulletin")
    define("j-WILSON-LIBR-BULL",		"Wilson libr. bull.")

    define("j-WILSON-Q",			"The Wilson Quarterly (1976--2012)") # ceased wtih v36 n3 summer 2012
    define("j-WILSON-Q",			"The Wilson Quarterly (1976--)")
    define("j-WILSON-Q",			"The Wilson Quarterly (1976-)")
    define("j-WILSON-Q",			"Wilson Q.")

    define("j-WINDOWS-MAG",			"Windows Magazine")
    define("j-WINDOWS-MAG",			"Windows Mag.")

    define("j-WIRED",				"Wired")
    define("j-WIRED",				"Wired Magazine")

    define("j-WIRTSCHAFTSINFORMATIK",		"Wirtschaftsinformatik")

    define("j-WISS-Z-PAEDAGOG-HOCHSCH-K-F-W-WANDER-DRESDEN",	"Wissenschaftliche Zeitschrift. Padagogische Hochschule `K. F. W. Wander' Dresden")
    define("j-WISS-Z-PAEDAGOG-HOCHSCH-K-F-W-WANDER-DRESDEN",	"Wiss. Z. Paedagog. Hochsch. `K. F. W. Wander' Dresden")

    define("j-WISS-Z-PAEDAGOG-HOCHSCH-KARL-LIEBKNECHT-POTSDAM",	"Wissenschaftliche Zeitschrift. Padagogische Hochschule Karl Liebknecht Potsdam")
    define("j-WISS-Z-PAEDAGOG-HOCHSCH-KARL-LIEBKNECHT-POTSDAM",	"Wiss. Z. Paedagog. Hochsch. `Karl Liebknecht' Potsdam")

    define("j-WISS-Z-TECH-HOCHSCH-KARL-MARX-STADT", "Wissenschaftliche Zeitschrift der Technischen Hochschule, Karl-Marx-Stadt")
    define("j-WISS-Z-TECH-HOCHSCH-KARL-MARX-STADT", "Wiss. Z. Techn. Hochsch. Karl-Marx-Stadt")

    define("j-WISS-Z-TECH-HOCHSCH-LEUNA-MERSEBURG",	"Wissenschaftliche Zeitschrift der Technischen Hochschule f{\\\"ur}r Chemie ``Carl Schorlemmer'' Leuna-Merseburg")
    define("j-WISS-Z-TECH-HOCHSCH-LEUNA-MERSEBURG",	"Wissenschaftliche Zeitschrift der Technischen Hochschule fur Chemie ``Carl Schorlemmer'' Leuna-Merseburg")
    define("j-WISS-Z-TECH-HOCHSCH-LEUNA-MERSEBURG",	"Wiss. Z. Tech. Hochsch. Leuna-Merseburg")
    define("j-WISS-Z-TECH-HOCHSCH-LEUNA-MERSEBURG",	"Wiss. Z. Techn. Hochsch. Leuna-Merseburg")
    define("j-WISS-Z-TECH-HOCHSCH-LEUNA-MERSEBURG",	"Wiss. Z. Tech. Hochsch. Leuna Merseburg")

    define("j-WISS-Z-TECH-UNIV-DRESDEN",	"Wissenschaftliche Zeitschrift der Technischen Universit{\\\"a}t Dresden")
    define("j-WISS-Z-TECH-UNIV-DRESDEN",	"Wiss. Z. Tech. University Dresden")
    define("j-WISS-Z-TECH-UNIV-DRESDEN",	"Wiss. Z. Techn. University Dresden")

    define("j-WISS-Z-TECH-UNIV-DRESDEN-GESELLSCHAFT",	"Wissenschaftliche Zeitschrift der Technischen Universit{\\\"a}t Dresden. Separatreihe 1, Gesellschaftswissenschaften")

    define("j-WOMENS-STUD-INT-FORUM",		"Women's Studies International Forum")
    define("j-WOMENS-STUD-INT-FORUM",		"Women's Stud. Int. Forum")

    define("j-WORD-WAYS",			"Word Ways")
    define("j-WORK-PROC-IMPROV-TODAY",		"Work Process Improvement Today")
    define("j-WORK-PUB-SYS",			"Workstations and publication systems")
    define("j-WORLD-MONIT",			"World monitor (Boston, MA)")
    define("j-WORLD-MONIT",			"World monitor")
    define("j-WORLD-MONIT",			"World monit.")
    define("j-WORLD-MONIT",			"World monitor (Boston, Mass.)")

    define("j-WORLD-WIDE-WEB-J",		"World Wide Web Journal")
    define("j-WORLD-WIDE-WEB-J",		"World Wide Web J.")

    define("j-WORLD-PRESS-REV",			"World Press Review")

    define("j-WSEAS-TRANS-MATH",		"WSEAS Transactions on Mathematics")
    define("j-WSEAS-TRANS-MATH",		"WSEAS Trans. Math.")

    define("j-X-J",				"The X Journal")
    define("j-X-RESOURCE",			"The X Resource")

    define("j-YAD-FIZ",				"Yadernaya Fizika")	# == "Nuclear Physics"
    define("j-YAD-FIZ",				"Yad. Fiz.")

    define("j-YALE-LAW-POLICY-REV",		"Yale Law and Policy Review")
    define("j-YALE-LAW-POLICY-REV",		"Yale Law Review")

    define("j-YEAST-CHICHESTER",		"Yeast (Chichester, England)")
    define("j-YEAST-CHICHESTER",		"Yeast (YEA)")
    define("j-YEAST-DAVIS",			"Yeast (Davis, CA)")

    define("j-YUGO-J-OPER-RES",			"Yugoslav Journal of Operations Research")
    define("j-YUGO-J-OPER-RES",			"Yugoslav Journal of Operations Research. An International Journal dealing with Theoretical and Computational Aspects of Operations Research, Systems Science, and Management Science")
    define("j-YUGO-J-OPER-RES",			"Yugosl. J. Oper. Res.")

    define("j-Z-ALLG-WISSENSCHAFTSTHEOR",	"{{Zeitschrift f{\\\"u}r allgemeine Wissenschaftstheorie} / Journal for General Philosophy of Science}")
    define("j-Z-ALLG-WISSENSCHAFTSTHEOR",	"{Z. allg. Wissenschaftstheor.} / J. Gen. Philos. Sci.")
    define("j-Z-ALLG-WISSENSCHAFTSTHEOR",	"{Z. allg. Wissenschaftstheor.}")

    define("j-Z-ANAL-ANWEND",			"{Zeitschrift f{\\\"u}r Analysis und ihre Anwendungen}")
    define("j-Z-ANAL-ANWEND",			"{Zeitschrift fur Analysis und ihre Anwendungen}")
    define("j-Z-ANAL-ANWEND",			"{Z. Anal. ihre Anwend.}")
    define("j-Z-ANAL-ANWEND",			"{Z. Anal. Anwendungen}")

    ## v1 1862--v127 n6 1944
    define("j-Z-ANAL-CHEM",			"{Zeitschrift f{\\\"u}r analytische Chemie}")
    define("j-Z-ANAL-CHEM",			"{Z. anal. Chem.}")

    define("j-Z-ANGE-CHEM",			"{Zeitschrift f{\\\"u}r Angewandte Chemie}")
    define("j-Z-ANGE-CHEM",			"{Zeitschrift fur Angewandte Chemie}")
    define("j-Z-ANGE-CHEM",			"{Zeitschrift fÃ¼r Angewandte Chemie}")
    define("j-Z-ANGE-CHEM",			"{Z. f. Angew. Chem.}")
    define("j-Z-ANGE-CHEM",			"{Z. Angew. Chemie}")
    define("j-Z-ANGE-CHEM",			"{Z. Angew. Chem.}")

    define("j-Z-ANGE-MATH-MECH",		"{Zeitschrift f{\\\"u}r Angewandte Mathematik und Mechanik}")
    define("j-Z-ANGE-MATH-MECH",		"{ZAMM - Journal of Applied Mathematics and Mechanics / Zeitschrift f{\\\"u}r Angewandte Mathematik und Mechanik}")
    define("j-Z-ANGE-MATH-MECH",		"{Zeitschrift fur angewandte Mathematik und Mechan}")
    define("j-Z-ANGE-MATH-MECH",		"{Z. Angew. Math. Mech}")
    define("j-Z-ANGE-MATH-MECH",		"{ZAMM Z. angew. Math. Mech.}")
    define("j-Z-ANGE-MATH-MECH",		"{ZAMM}")
    define("j-Z-ANGE-MATH-MECH",		"{ZAMM} - Zeitschrift fuer Angewandte Mathematik und Mechanik")
    define("j-Z-ANGE-MATH-MECH",		"{ZAMM} - Zeitschrift fur Angewandte Mathematik und Mechanik")
    define("j-Z-ANGE-MATH-MECH",		"{ZAMM} - Zeitschrift f{\\\"u}r Angewandte Mathematik und Mechanik")
    define("j-Z-ANGE-MATH-MECH",		"{Zeitschrift fuer Angewandte Mathematik und Mechanik (ZAMM)}")
    define("j-Z-ANGE-MATH-MECH",		"{Zeitschrift fur Angewandte Mathematik und Mechanik}")
    define("j-Z-ANGE-MATH-MECH",		"ZAMM --- Journal of Applied Mathematics and Mechanics")

    define("j-Z-ANGE-MATH-PHYS",		"{Zeitschrift f{\\\"u}r Angewandte Mathematik und Physik = Journal of Applied Mathematics and Physics}")
    define("j-Z-ANGE-MATH-PHYS",		"{Z. Angew. Math. Physik}")
    define("j-Z-ANGE-MATH-PHYS",		"{Z. Angew. Math. Phys}")
    define("j-Z-ANGE-MATH-PHYS",		"{Zeitschrift fur Angewandte Mathematik und Physik}")
    define("j-Z-ANGE-MATH-PHYS",		"{Zeitschrift fuer Angewandte Mathematik und Physik}")
    define("j-Z-ANGE-MATH-PHYS",		"{Zeitschrift f{\\\"u}r Angewandte Mathematik und Physik ZAMP}")
    define("j-Z-ANGE-MATH-PHYS",		"{Zeitschrift f{\\\"u}r Angewandte Mathematik und Physik}")
    define("j-Z-ANGE-MATH-PHYS",		"{Zeitschrift f{\\\"u}r angewandte Mathematik und Physik}")
    define("j-Z-ANGE-MATH-PHYS",		"{Zeit. Angew. Math. Physik}")

    define("j-Z-ASTROPHYSIK",			"{Zeitschrift f{\\\"u}r Astrophysik}")
    define("j-Z-ASTROPHYSIK",			"{Zeit. Astrophysik}")
    define("j-Z-ASTROPHYSIK",			"{Z. Astrophysik}")
    define("j-Z-ASTROPHYSIK",			"{Z. Astrophys.}")

    define("j-Z-BIOL",				"{Zeitschrift f{\\\"u}r Biologie, M{\\\"u}nchen}")
    define("j-Z-BIOL",				"{Zeitschrift f{\\\"u}r Biologie}")
    define("j-Z-BIOL",				"{Z. Biol.}")

    define("j-Z-CHEM-STUTTGART",		"{Zeitschrift f{\\\"u}r Chemie (Stuttgart, Germany)}")
    define("j-Z-CHEM-STUTTGART",		"{Zeitschrift f{\\\"u}r Chemie}")
    define("j-Z-CHEM-STUTTGART",		"{Z. Chem.}")

    define("j-Z-EKSP-TEOR-FIZ",			"Zhurnal eksperimental'noi i teoreticheskoi fiziki / Akademiia nauk SSSR")
    define("j-Z-EKSP-TEOR-FIZ",			"Z. eksp. teor. fiz.")
    define("j-Z-EKSP-TEOR-FIZ",			"Zh. Eksper. Teoret. Fiz.")
    define("j-Z-EKSP-TEOR-FIZ",			"Akademiya Nauk SSSR. Zhurnal Eksperimentalnoy i Teoreticheskoy Fiziki")

    define("j-Z-ELEKTROCHEM",			"Zeitschrift f{\\\"u}r Elektrochemie")
    define("j-Z-ELEKTROCHEM",			"Z. Elektrochem.")
    define("j-Z-ELEKTROCHEM",			"Z. Elektrochem")

    define("j-Z-ELEKTROCHEM-ANGEW-PHYS-CHEM",	"{Zeitschrift f{\\\"u}r Elektrochemie und angewandte physikalische Chemie}")
    define("j-Z-ELEKTROCHEM-ANGEW-PHYS-CHEM",	"{Zeitschrift fuer Elektrochemie und angewandte physikalische Chemie}")
    define("j-Z-ELEKTROCHEM-ANGEW-PHYS-CHEM",	"{Z. Elektrochem. Angew. Phys. Chem.}")

    define("j-Z-KRISTALLOGR",			"Zeitschrift f{\\\"u}r Kristallographie")
    define("j-Z-KRISTALLOGR",			"Z. Kristallogr.")
    define("j-Z-KRISTALLOGR",			"Z. f. Kristallogr")

    define("j-Z-MATH-LOGIK-GRUNDL-MATH",	"{Zeitschrift f{\\\"u}r mathematische Logik und Grundlagen der Mathematik}")
    define("j-Z-MATH-LOGIK-GRUNDL-MATH",	"{Zeitschrift fur mathematische Logik und Grundlagen der Mathematik}")
    define("j-Z-MATH-LOGIK-GRUNDL-MATH",	"{Z. math. Logik Grundl. Math.}")
    define("j-Z-MATH-LOGIK-GRUNDL-MATH",	"{Zeitschr. f. math. Logik und Grundlagen d. Math. Bd.}")

    define("j-Z-NATURFORSCH",			"{Zeitschrift f{\\\"u}r Naturforschung}")
    define("j-Z-NATURFORSCH",			"{Zeitschrift fuer Naturforschung}")
    define("j-Z-NATURFORSCH",			"{Zeits. f. Naturforschung}")
    define("j-Z-NATURFORSCH",			"{Z. Naturforschung}")
    define("j-Z-NATURFORSCH",			"{Z. Naturforsch.}")
    define("j-Z-NATURFORSCH",			"{Z. Naturf.}")

    define("j-Z-NATURFORSCH-A-ASTROPHYS-PHYS-PHYS-CHEM",	"{Zeitschrift f{\\\"u}r Naturforschung Teil A: Astrophysik, Physik, und Physikalische Chemie}")
    define("j-Z-NATURFORSCH-A-ASTROPHYS-PHYS-PHYS-CHEM",	"{Zeitschrift f{\\\"u}r Naturforschung Part A --- Astrophysik Physik und Physikalische Chemie}")
    define("j-Z-NATURFORSCH-A-ASTROPHYS-PHYS-PHYS-CHEM",	"{Zeitschrift fuer Naturforschung Teil A: Astrophysik, Physik, und Physikalische Chemie}")
    define("j-Z-NATURFORSCH-A-ASTROPHYS-PHYS-PHYS-CHEM",	"{Zeitschrift fuer Naturforschung Part A --- Astrophysik Physik und Physikalische Chemie}")
    define("j-Z-NATURFORSCH-A-ASTROPHYS-PHYS-PHYS-CHEM",	"{Z. Naturforsch., A: Astrophys., Phys. Phys. Chem.}")

    define("j-Z-NATURFORSCH-A-PHYS-SCI",	"{Zeitschrift f{\\\"u}r Naturforschung, A: Physical Sciences}")
    define("j-Z-NATURFORSCH-A-PHYS-SCI",	"{Zeitschrift fuer Naturforschung, A: Physical Sciences}")
    define("j-Z-NATURFORSCH-A-PHYS-SCI",	"{Zeitschrift fuer Naturforschung, Section A: a Journal of Physical Sciences}")
    define("j-Z-NATURFORSCH-A-PHYS-SCI",	"{Zeitschrift f{\\\"u}r Naturforschung, Section A: a Journal of Physical Sciences}")
    define("j-Z-NATURFORSCH-A-PHYS-SCI",	"{Z. Naturforsch., A: Phys. Sci.}")

    define("j-Z-NATURFORSCH-SECT-C-BIOSCI",	"{Zeitschrift fur Naturforschung. Section C, Biosciences}")
    define("j-Z-NATURFORSCH-SECT-C-BIOSCI",	"{Z Naturforsch [C] (ACL)}")

    ## Zeitschrift für Operations Research. Mathematical Methods of Operations Research
    ## Continued as ZOR—Math. Methods Oper. Res.
    ## Formerly Z. Oper. Res. Ser. A-B
    ## First Issue: 32–  1988– Last Issue: Vol. 40, no. 2 (1994)
    define("j-Z-OPER-RES",			"Zeitschrift f{\\\"u}r Operations Research. Mathematical Methods of Operations Research")
    define("j-Z-OPER-RES",			"Z. Oper. Res.")

    define("j-Z-PFLANZENKR-PFLANZENSCHUTZ",	"{Zeitschrift fur Pflanzenkrankheiten und Pflanzenschutz = Journal of plant diseases and protection}")
    define("j-Z-PFLANZENKR-PFLANZENSCHUTZ",	"{Zeitschrift fur Pflanzenkrankheiten und Pflanzenschutz}")
    define("j-Z-PFLANZENKR-PFLANZENSCHUTZ",	"{Zeitschrift fur Pflanzenkrankheiten und Pflanzen}")
    define("j-Z-PFLANZENKR-PFLANZENSCHUTZ",	"{Z. Pflanzenkr. Pflanzenschutz (1970)}")
    define("j-Z-PFLANZENKR-PFLANZENSCHUTZ",	"{Z. Pflanzenkr. Pflanzenschutz}")

    define("j-Z-PHILOS-FORSCH",			"{Zeitschrift f{\\\"u}r philosophische Forschung}")
    define("j-Z-PHILOS-FORSCH",			"{Z. philos. Forsch.}")

    ## j-Z-PHYS-CHEM-B: From CASSI description: v1 Sept. 1928-v53 n6 1943
    define("j-Z-PHYS-CHEM-B",			"Zeitschrift f{\\\"u}r Physikalische Chemie, Abteilung B: Chemie der Elementarprozesse, Aufbau der Materie")
    define("j-Z-PHYS-CHEM-B",			"Zeitschrift fuer Physikalische Chemie, Abteilung B: Chemie der Elementarprozesse, Aufbau der Materie")
    define("j-Z-PHYS-CHEM-B",			"Z. Phys. Chem., Abt. B")
    define("j-Z-PHYS-CHEM-B",			"Z. Phys. Chem., B")
    define("j-Z-PHYS-CHEM-B",			"{Zeitschrift f{\\\"u}r Physikalische Chemie, Abteilung B: Chemie der Elementarprozesse, Aufbau der Materie}")
    define("j-Z-PHYS-CHEM-B",			"{Zeitschrift fuer Physikalische Chemie, Abteilung B: Chemie der Elementarprozesse, Aufbau der Materie}")
    define("j-Z-PHYS-CHEM-B",			"{Z. Phys. Chem., Abt. B}")
    define("j-Z-PHYS-CHEM-B",			"{Z. Phys. Chem. B}")
    define("j-Z-PHYS-CHEM-B",			"{Z. Phys. Chem., B}")

    define("j-Z-PHYS-CHEM-LEIPZIG",		"{Zeitschrift f{\\\"u}r physikalische Chemie (Leipzig)}")
    define("j-Z-PHYS-CHEM-LEIPZIG",		"{Z. phys. Chem. (Leipzig)}")
    define("j-Z-PHYS-CHEM-LEIPZIG",		"{Zeits. f. Phys. Chem.}")
    define("j-Z-PHYS-CHEM-LEIPZIG",		"{Zeitschrift fuer physikalische Chemie (Leipzig)}")
    define("j-Z-PHYS-CHEM-LEIPZIG",		"{Zeitschrift fur physikalische Chemie (Leipzig)}")
    define("j-Z-PHYS-CHEM-LEIPZIG",		"{Zeitschrift fur physikalische Chemie}")

    ## v1 Feb. 15, 1887--v136 Sept. 1928
    define("j-Z-PHYS-CHEM-STOECHIOM-VERWANDTSCHAFTSL", "{Zeitschrift f{\\\"u}r Physikalische Chemie --- St{\\\"o}chiometrie und Verwandtschaftslehre}")
    define("j-Z-PHYS-CHEM-STOECHIOM-VERWANDTSCHAFTSL", "{Zeitschrift fur Physikalische Chemie, Stoechiometrie und Verwandtschaftslehre}")
    define("j-Z-PHYS-CHEM-STOECHIOM-VERWANDTSCHAFTSL", "{Zeitschrift fuer Physikalische Chemie, Stoechiometrie und Verwandtschaftslehre}")
    define("j-Z-PHYS-CHEM-STOECHIOM-VERWANDTSCHAFTSL", "{Z. Phys. Chem., Stoechiom. Verwandtschaftsl.}")
    define("j-Z-PHYS-CHEM-STOECHIOM-VERWANDTSCHAFTSL", "{Z. Phys. Chem., St{\\\"o}chiom. Verwandtschaftsl.}")

    ## j-Z-PHYSIK: From CASSI description: v1 Feb. 1920--v123 n1/2
    ## 1944; v124 1947-v271 n4 1974
    ## v1--v3 are suppl to Verh. Dtsch. Phys. Ges. (Verhandlungen der
    ## Deutschen Physikalischen Gesellschaft, Beilage)
    ## Suspended 1945--1946.  Divided into sections A and B in 1975

    define("j-Z-PHYSIK",			"{Zeitschrift f{\\\"u}r Physik}")
    define("j-Z-PHYSIK",			"Zeitschrift f{\\\"u}r Physik")
    define("j-Z-PHYSIK",			"{Zeitschrift fuer Physik}")
    define("j-Z-PHYSIK",			"{Zeitschrift fur Physik}")
    define("j-Z-PHYSIK",			"Z. Phys.")
    define("j-Z-PHYSIK",			"Z. Physik")
    define("j-Z-PHYSIK",			"Z. f. Phys.")
    define("j-Z-PHYSIK",			"Z. f. Physik")
    define("j-Z-PHYSIK",			"Zeits. f. Physik")
    define("j-Z-PHYSIK",			"{Z. Physik}")
    define("j-Z-PHYSIK",			"{Z. f. Phys.}")
    define("j-Z-PHYSIK",			"{Z. f. Physik}")
    define("j-Z-PHYSIK",			"{Zeits. f. Physik}")
    define("j-Z-PHYSIK",			"{Z. Physik}")

    define("j-Z-PHYSIK-A",			"{Zeitschrift f{\\\"u}r Physik. A, Atomic nuclei}")
    define("j-Z-PHYSIK-A",			"{Zeitschrift fur Physik. A, Atomic nuclei}")

    define("j-Z-PHYSIK-A-HADRONS-NUCL",		"{Zeitschrift f{\\\"u}r Physik A: Hadrons and Nuclei}")
    define("j-Z-PHYSIK-A-HADRONS-NUCL",		"{Zeitschrift fuer Physik A: Hadrons and Nuclei}")
    define("j-Z-PHYSIK-A-HADRONS-NUCL",		"{Z. Phys. A: Hadrons Nucl.}")
    define("j-Z-PHYSIK-A-HADRONS-NUCL",		"{Z. Physik. A: Hadrons Nucl.}")

    define("j-Z-PHYSIK-B-CM",			"{Zeitschrift f{\\\"u}r Physik. B, Condensed matter}")
    define("j-Z-PHYSIK-B-CM",			"{Zeitschrift fur Physik. B, Condensed matter}")

    define("j-Z-PHYSIK-B-CMQ",			"{Zeitschrift f{\\\"u}r Physik. B, Condensed matter and quanta}")
    define("j-Z-PHYSIK-B-CMQ",			"{Zeitschrift fur Physik. B, Condensed matter and quanta}")

    define("j-Z-PHYSIK-C",			"{Zeitschrift f{\\\"u}r Physik. C, Particles and fields}")
    define("j-Z-PHYSIK-C",			"Zeitschrift für Physik C Particles and Fields")
    define("j-Z-PHYSIK-C",			"{Zeitschrift fur Physik. C, Particles and fields}")

    define("j-Z-PHYSIK-D",			"{Zeitschrift f{\\\"u}r Physik. D, Atoms, molecules, and clusters}")
    define("j-Z-PHYSIK-D",			"{Zeitschrift fur Physik. D, Atoms, molecules, and clusters}")
    define("j-Z-PHYSIK-D",			"{Zeitschrift fur Physik D (Atoms, Molecules and Clusters)}")

    define("j-Z-TECH-PHYS",			"{Zeitschrift f{\\\"u}r technische Physik}")
    define("j-Z-TECH-PHYS",			"{Z. Tech. Phys.}")

    define("j-Z-TEH-FIZ",			"Zhurnal tekhnicheskoi fiziki")
    define("j-Z-TEH-FIZ",			"Zurnal tehniceskoj fiziki")
    define("j-Z-TEH-FIZ",			"Z. teh. fiz.")
    define("j-Z-TEH-FIZ",			"J. Tech. Phys. Acad. Sci. USSR (Zh. Tech. Fiz)")
    define("j-Z-TEH-FIZ",			"J. Techn. Phys. (Zh. Tech. Fiz.) Acad. Sci. USSR")

    define("j-Z-THEOL-KIRCHE",			"{Zeitschrift f{\\\"u}r Theologie und Kirche}")
    define("j-Z-THEOL-KIRCHE",			"{Z. Theol. Kirche}")

    define("j-Z-VERMESSUNGSWESEN",		"{Zeitschrift fur Vermessungswesen}")
    define("j-Z-VERMESSUNGSWESEN",		"{Z. Vermessungswesen}")
    define("j-Z-VERMESSUNGSWESEN",		"{Zeitschrift f{\\\"u}r Vermessungswesen}")

    define("j-Z-VYCISL-MAT-MAT-FIZ",		"Zhurnal vychislitel'noi matematiki i matematicheskoi fiziki")
    define("j-Z-VYCISL-MAT-MAT-FIZ",		"Z. vycisl. mat. mat. fiz.")
    define("j-Z-VYCISL-MAT-MAT-FIZ",		"Zh. Vychisl. Mat. i Mat. Fiz.")

    define("j-Z-WAHRSCHEINLICHKEITSTHEOR-VERW-GEB", "{Zeitschrift f{\\\"u}r Wahrscheinlichkeitstheorie und verwandte Gebiete}")
    define("j-Z-WAHRSCHEINLICHKEITSTHEOR-VERW-GEB", "{Z. Wahrscheinlichkeitstheor. verw. Geb.}")
    define("j-Z-WAHRSCHEINLICHKEITSTHEOR-VERW-GEB", "{Z. Wahrscheinlichkeitstheorie und Verw. Gebiete}")
    define("j-Z-WAHRSCHEINLICHKEITSTHEOR-VERW-GEB", "{Z. Wahrsch. Verw. Gebiete}")
    define("j-Z-WAHRSCHEINLICHKEITSTHEOR-VERW-GEB", "{Z. f{\\\"u}r Wahrscheinlichkeitstheorie}")

    define("j-ZAP-NAUC-SEMIN-LENINGR-OTD-ORDENA", "Zapiski naucnyh seminarov Leningradskogo otdelenija ordena Lenina Matematiceskogo instituta im. V.A. Steklova Akademii nauk SSSR")
    define("j-ZAP-NAUC-SEMIN-LENINGR-OTD-ORDENA", "Zap. nauc. semin. Leningr. otd. ordena")
    define("j-ZAP-NAUC-SEMIN-LENINGR-OTD-ORDENA", "Matematicheskii institut im. V.A. Steklova. Leningradskoe otdelenie")
    define("j-ZAP-NAUC-SEMIN-LENINGR-OTD-ORDENA", "Zap. Nauchn. Sem. S.-Peterburg. Otdel. Mat. Inst. Steklov. (POMI)")

    define("j-ZASTOS-MAT",			"Zastosowania Matematyki")
    define("j-ZASTOS-MAT",			"Zastos. Mat.")

    define("j-ZH-RUSS-FIZ-KHIM-OBSHCH-CHAST-FIZ", "Zhurnal Russkogo Fiziko-Khimicheskogo Obshchestva, Chast Fizicheskaya")
    define("j-ZH-RUSS-FIZ-KHIM-OBSHCH-CHAST-FIZ", "Zhurnal Russkogo Fiziko-Khimicheskogo Obschchestva pri Leningradskom Universitete, Chast' Fizicheskaya")
    define("j-ZH-RUSS-FIZ-KHIM-OBSHCH-CHAST-FIZ", "Zhurnal Russkogo Fiziko-Khimicheskogo Obshchestva pri Leningradskom Universitete: Chast' Fizicheskaia")
    define("j-ZH-RUSS-FIZ-KHIM-OBSHCH-CHAST-FIZ", "Zhurnal Russkogo Fiziko-Khimicheskogo Obschchestva")
    define("j-ZH-RUSS-FIZ-KHIM-OBSHCH-CHAST-FIZ", "Zhurnal Russkogo Fiziko-Khimicheskogo Obshchestva pri Leningradskom Universitete, Chast Fizicheskaya")
    define("j-ZH-RUSS-FIZ-KHIM-OBSHCH-CHAST-FIZ", "Zhurnal Russkogo Fiziko-Khimicheskogo Obshchestva pri Leningradskom Universitete, Chast' Fizicheskaya")
    define("j-ZH-RUSS-FIZ-KHIM-OBSHCH-CHAST-FIZ", "Zhurnal Russkogo Fiziko-Khimicheskogo Obshchestva")
    define("j-ZH-RUSS-FIZ-KHIM-OBSHCH-CHAST-FIZ", "Zh. Russ. Fiz.-Khim. O-va., Chast Fiz.")
    define("j-ZH-RUSS-FIZ-KHIM-OBSHCH-CHAST-FIZ", "Zh. Russ. Fiz.-Khim. Obshch, Chast Fiz.")

    # j-ZH-VYCHISL-MAT-MAT-FIZ in English: Journal of Computational Mathematics and Mathematical Physics
    define("j-ZH-VYCHISL-MAT-MAT-FIZ",		"Zhurnal Vychislitel'no{\\u{\\i}} Matematiki i Matematichesko{\\u{\\i}} Fiziki")
    define("j-ZH-VYCHISL-MAT-MAT-FIZ",		"Zhurnal Vychislitel'no{\\u{\\i}} Matematiki i Matematichesko{\\u{\\i}} Fiziki. Rossi{\\u{\\i}}skaya Akademiya Nauk")
    define("j-ZH-VYCHISL-MAT-MAT-FIZ",		"Zh. Vychisl. Mat. Mat. Fiz.")

    define("j-ZOO-SCI",				"Zoological Science: the Official Journal of the Zoological Society of Japan")
    define("j-ZOO-SCI",				"Zoo. Sci.")
    define("j-ZOO-SCI",				"Zoological Science")
    define("j-ZOO-SCI",				"Zoolog Sci (BMX)")

    define("j-ZOR-MATH-METHODS-OPER-RES",	"ZOR --- Mathematical Methods of Operations Research")
    define("j-ZOR-MATH-METHODS-OPER-RES",	"{ZOR, Zeitschrift fur Operations Research}. {Mathematical} Methods of Operations Research")
    define("j-ZOR-MATH-METHODS-OPER-RES",	"{ZOR, Zeitschrift f{\\\"u}r Operations Research}. {Mathematical} Methods of Operations Research")
    define("j-ZOR-MATH-METHODS-OPER-RES",	"ZOR --- Methods and Models of Operations Research")
    define("j-ZOR-MATH-METHODS-OPER-RES",	"ZOR --- Math. Methods Oper. Res.")

    define("j-ZYGON-J-RELIG-SCI",		"Zygon Journal of Religion and Science")
    define("j-ZYGON-J-RELIG-SCI",		"Zygon J. Relig. Sci.")
}


function initialize_URL()
{
    ## Extract these pairs from bibsql with
    ##
    ##     select distinct journal, journalURL from bibtab
    ##            where (journal like 'j-%')
    ##              and (journalURL is not NULL)
    ##            order by journal;
    ##
    ## Then manually edit into a list of unique pairs sorted by journal name.

    ## Retired definitions:
    ##
    ## Journal_URL["j-ARCH-HIST-EXACT-SCI"]		= "http://www.springerlink.com/content/0003-9519/"
    ##
    ## Journal_URL["j-MATH-COMPUT-SCI"]			= "http://www.springerlink.com/content/1661-8270/"
    ##
    ## Journal_URL["j-NUOVO-SAGGIATORE"]		= "http://www.sif.it/nuovosag-en.shtml" # in Library of Congress, but invalid
    ##
    ## NB: Both QAM archives are needed to locate issues from 1994 to date
    ## WORKS, BUT LONGER: Journal_URL["j-RELIABLE-COMPUTING"]			= "http://www.springerlink.com/content/1385-3139"
    ##
    ## WORKS: Journal_URL["j-ANN-INST-HENRI-POINCARE-PROBAB-STATIST"] = "http://projecteuclid.org/all/euclid.aihp/; http://www.numdam.org/numdam-bin/feuilleter?j=AIHPB"
    ##
    ## Works, but apparently unrelated to ISSN:
    ##
    ## journal out of copyright: archives in one zip file at http://archive.org/details/archivesnerland00wetegoog"
    ##
    ## WORKS, BUT OTHER PREFERRED: Journal_URL["j-SIAM-J-SCI"]		= "http://epubs.siam.org/loi/sjoce3"
    ##
    ## WORKS, BUT OTHER PREFERRED: Journal_URL["j-SIAM-J-SCI-STAT-COMP"]		= "http://epubs.siam.org/sisc"
    ##
    ## WORKS, BUT OTHER PREFERRED: Journal_URL["j-TOMS"]				= "http://portal.acm.org/toc.cfm?idx=J782"

    ## Retired definitions

   ##	Journal_URL["j-ACTA-INFO"]				= "http://www.springerlink.com/content/0001-5903"
   ##	Journal_URL["j-ACCOUNT-HIST-J"]			= "http://www.jstor.org/action/showPublication?journalCode=accohistjour"
   ##	Journal_URL["j-AM-PROSPECT"]			= "http://www.prospect.org; http://prospect.org/magazine"
   ##	Journal_URL["j-AMER-MATH-MONTHLY"]			= "http://www.jstor.org/page/journal/amermathmont/about.html"
   ##	Journal_URL["j-AMER-STAT"]				= "http://amstat.tandfonline.com/loi/utas20"
   ##	Journal_URL["j-ANN-INST-HENRI-POINCARE-PROBAB-STATIST"] = "http://projecteuclid.org/all/euclid.aihp/; http://www.numdam.org/numdam-bin/feuilleter?j=AIHPB"
   ##	Journal_URL["j-ANN-MATH-2"]				= "http://annals.math.princeton.edu/"
   ##	Journal_URL["j-APPL-STAT"]				= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1467-9876/issues; http://www.blackwellpublishers.co.uk/asp/journal.asp?ref=0035-9254&src=arc"
   ##	Journal_URL["j-APPL-STAT"]				= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1467-9876/issues; http://www.blackwellpublishing.com/journal.asp?ref=0035-9254"
   ##	Journal_URL["j-ARCH-HIST-EXACT-SCI"]		= "http://www.springerlink.com/content/0003-9519/"
   ##	Journal_URL["j-BELL-LABS-TECH-J"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1538-7305/issues/"
   ##	Journal_URL["j-BELL-SYST-TECH-J"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1538-7305/issues/"
   ##	Journal_URL["j-BIOMETRIKA"]				= "http://biomet.oxfordjournals.org/content/by/year"
   ##	Journal_URL["j-BIOMETRIKA"]				= "http://www.jstor.org/journals/00063444.html"
   ##	Journal_URL["j-BRITISH-J-PHILOS-SCI"]		= "http://www.jstor.org/journals/00070882.html"
   ##	Journal_URL["j-C-R-BIOL"]				= "http://sciencedirect.com/science/journal/16310691"
   ##	Journal_URL["j-C-R-MEC"]				= "http://www.sciencedirect.com/science/article/pii/S1631072112000393"
   ##	Journal_URL["j-C-R-PHYS"]				= "http://www.sciencedirect.com/science/journal/16310705"
   ##	Journal_URL["j-CACM"]				= "http://portal.acm.org/browse_dl.cfm?idx=J79"
   ##	Journal_URL["j-CALC-VAR-PARTIAL-DIFFER-EQU"]	= "http://www.springer.com/mathematics/analysis/journal/526"
   ##	Journal_URL["j-CHEM-PHYS"]				= "http://www.sciencedirect.com/science/journal/03010104/"
   ##	Journal_URL["j-CHEM-PHYS-LETT"]			= "http://www.sciencedirect.com/science/journal/00092614/"
   ##	Journal_URL["j-COMBIN-PROBAB-COMPUT"]		= "http://journals.cambridge.org/action/displayBackIssues?jid=CPC"
   ##	Journal_URL["j-COMP-LANGS-SYS-STRUCT"]		= "http://www.sciencedirect.com/science/journal/14778424/"
   ##	Journal_URL["j-COMP-NET-AMSTERDAM"]			= "http://www.sciencedirect.com/science/journal/13891286/"
   ##	Journal_URL["j-COMP-PHYS-COMM"]			= "http://chance.amstat.org/; http://link.springer.com/journal/144; http://www.tandfonline.com/loi/ucha20"
   ##	Journal_URL["j-COMP-PHYS-COMM"]			= "http://www.sciencedirect.com/science/journal/00104655/"
   ##	Journal_URL["j-COMP-VIS-IMAGE-UNDERSTANDING"]	= "http://www.sciencedirect.com/science/journal/10773142/"
   ##	Journal_URL["j-COMPLEX-SYSTEMS"]			= "http://www.nature.com/scientificamerican"
   ##	Journal_URL["j-COMPUT-MATER-SCI"]			= "http://www.sciencedirect.com/science/journal/09270256/"
   ##	Journal_URL["j-COMPUTERS-AND-GRAPHICS"]		= "http://www.sciencedirect.com/science/journal/00978493/"
   ##	Journal_URL["j-COMPUTER"]				= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=2"
   ##	Journal_URL["j-COMPUTER"]				= "http://www.computer.org/portal/web/csdl/magazines/computer; http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=2"
   ##	Journal_URL["j-FUT-GEN-COMP-SYS"]			= "http://www.sciencedirect.com/science/journal/0167739X/"
   ##	Journal_URL["j-GRAPH-MODELS"]			= "http://www.sciencedirect.com/science/journal/15240703/"
   ##	Journal_URL["j-GRAPH-MODELS-IMAGE-PROC"]		= "http://www.sciencedirect.com/science/journal/10773169/"
   ##	Journal_URL["j-HIST-MATH"]				= "http://www.sciencedirect.com/science/journal/03150860/"
   ##	Journal_URL["j-IEEE-TRANS-VIS-COMPUT-GRAPH"]	= "http://www.computer.org/csdl/trans/tg/index.html"
   ##	Journal_URL["j-IEEE-TRANS-VIS-COMPUT-GRAPH"]	= "http://www.computer.org/csdl/trans/tg/index.html; http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=2945"
   ##	Journal_URL["j-INFO-PROC-LETT"]			= "http://www.sciencedirect.com/science/journal/00200190/"
   ##	Journal_URL["j-INT-AFF"]				= "http://www.jstor.org/journals/00205850.html; http://www.ingenta.com/journals/browse/bpl/inta; http://www.blackwell-synergy.com/rd.asp?goto=journal&code=inta"
   ##	Journal_URL["j-INT-J-COMPUT-GEOM-APPL"]		= "http://www.worldscientific.com/worldscinet/ijcga"
   ##	Journal_URL["j-ISIS"]				= "http://www.jstor.org/page/journal/isis/about.html"
   ##	Journal_URL["j-J-APPL-PHYS"]			= "http://scitation.aip.org/content/aip/journal/jap/browse"
   ##	Journal_URL["j-J-COMPUT-APPL-MATH"]			= "http://www.sciencedirect.com/science/journal/03770427"
   ##	Journal_URL["j-J-COMPUT-CHEM"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1096-987X"
   ##	Journal_URL["j-J-COMPUT-PHYS"]			= "http://www.sciencedirect.com/science/journal/00219991/"
   ##	Journal_URL["j-J-INFORMETRICS"]			= "http://www.sciencedirect.com/science/journal/17511577/"
   ##	Journal_URL["j-J-MATH-PHYS"]			= "http://scitation.aip.org/content/aip/journal/jmp/browse"
   ##	Journal_URL["j-J-MATH-PURES-APPL"]			= "http://www.sciencedirect.com/science/journal/00217824"
   ##	Journal_URL["j-J-MOL-STRUCT"]			= "http://www.sciencedirect.com/science/journal/00222860/"
   ##	Journal_URL["j-J-PAR-DIST-COMP"]			= "http://www.sciencedirect.com/science/journal/07437315/"
   ##	Journal_URL["j-J-PHYS-A"]				= "http://iopscience.iop.org/0305-4470/"
   ##	Journal_URL["j-J-PHYS-CHEM-SOLIDS"]			= "http://www.sciencedirect.com/science/journal/00223697/"
   ##	Journal_URL["j-J-R-STAT-SOC-SER-A-STAT-SOC"]	= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1467-985X"
   ##	Journal_URL["j-J-R-STAT-SOC-SER-B-METHODOL"]	= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1467-9868"
   ##	Journal_URL["j-J-R-STAT-SOC-SER-B-METHODOL"]	= "http://projecteuclid.org/all/euclid.aos/"
   ##	Journal_URL["j-J-R-STAT-SOC-SER-B-STAT-METHODOL"]	= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1467-9868"
   ##	Journal_URL["j-J-SYMBOLIC-COMP"]			= "http://www.sciencedirect.com/science/journal/07477171/"
   ##	Journal_URL["j-J-SYST-SOFTW"]			= "http://www.sciencedirect.com/science/journal/01641212/"
   ##	Journal_URL["j-J-THEOR-BIOL"]			= "http://www.sciencedirect.com/science/journal/00225193/"
   ##	Journal_URL["j-LINEAR-ALGEBRA-APPL"]		= "http://www.sciencedirect.com/science/journal/00243795/"
   ##	Journal_URL["j-MAGN-MAGN-MATER"]			= "http://www.sciencedirect.com/science/journal/03048853/"
   ##	Journal_URL["j-MATH-COMPUT-SCI"]			= "http://www.springerlink.com/content/1661-8270/"
   ##	Journal_URL["j-MATH-MECH-SOLIDS"]			= "http://mms.sagepub.com/content/4/4/407.short"
   ##	Journal_URL["j-NATURWISS-RUNDSCH"]			= "http://www.digizeitschriften.de/dms/toc/?PPN=PPN385489110"
   ##	Journal_URL["j-NUOVO-CIMENTO-1955-1965"]		= "http://link.springer.com/journal/volumesAndIssues/11539"
   ##	Journal_URL["j-OPT-LET"]				= "http://www.opticsinfobase.org/ol/home.cfm"
   ##	Journal_URL["j-PARALLEL-COMPUTING"]			= "http://www.sciencedirect.com/science/journal/01678191/"
   ##	Journal_URL["j-PERSPECT-SCI"]			= "http://muse.jhu.edu/journals/perspectives_on_science"
   ##	Journal_URL["j-PHILOS-SCI"]				= "http://www.jstor.org/journals/00318248.html"
   ##	Journal_URL["j-PHYS-LET-A"]				= "http://www.sciencedirect.com/science/journal/03759601/"
   ##	Journal_URL["j-PHYS-REV"]				= "http://journals.aps.org/pr/issues"
   ##	Journal_URL["j-PHYS-REV-2"]				= "http://journals.aps.org/archive/"
   ##	Journal_URL["j-PHYS-REV-2"]				= "http://journals.aps.org/archive/"
   ##	Journal_URL["j-PROC-PHYS-SOC"]			= "http://iopscience.iop.org/0959-5309/"
   ##	Journal_URL["j-PROC-PHYS-SOC"]			= "http://iopscience.iop.org/0959-5309"
   ##	Journal_URL["j-PROC-PHYS-SOC"]			= "http://iopscience.iop.org/1478-7814"
   ##	Journal_URL["j-PROC-R-SOC-EDINB"]			= "http://journals.cambridge.org/action/displayJournal?jid=PRM"
   ##	Journal_URL["j-PROC-R-SOC-LOND-SER-A-MATH-PHYS-ENG-SCI"] = "http://rspa.royalsocietypublishing.org/content/current"
   ##	Journal_URL["j-PROC-VLDB-ENDOWMENT"]		= "http://portal.acm.org/citation.cfm?id=J1174"
   ##	Journal_URL["j-QUART-APPL-MATH"]			= "http://www.ams.org/journals/qam"
   ##	Journal_URL["j-REV-HIST-SCI"]			= "http://www.jstor.org/journals/00487996.html; http://www.persee.fr/web/revues/home/prescript/revue/rhs"
   ##	Journal_URL["j-REV-HIST-SCI"]			= "http://www.persee.fr/web/revues/home/prescript/revue/rhs; http://www.jstor.org/action/showPublication?journalCode=revuhistscie"
   ##	Journal_URL["j-S-B-PREUSS-AKAD-WISS-PHYS-MATH-KL"]	= "http://www.biodiversitylibrary.org/bibliography/42231"
   ##	Journal_URL["j-S-B-PREUSS-AKAD-WISS-PHYS-MATH-KL"]	= "http://www.biodiversitylibrary.org/bibliography/42308"
   ##	Journal_URL["j-S-B-PREUSS-AKAD-WISS-PHYS-MATH-KL"]	= "http://www.biodiversitylibrary.org/bibliography/42324"
   ##	Journal_URL["j-SCI-COMPUT-PROGRAM"]			= "http://www.sciencedirect.com/science/journal/01676423/"
   ##	Journal_URL["j-SIAM-J-COMPUT"]			= "http://epubs.siam.org/sicomp/"
   ##	Journal_URL["j-SIAM-J-SCI-COMP"]			= "http://epubs.siam.org/sisc/"
   ##	Journal_URL["j-SOLID-STATE-COMMUN"]			= "http://www.sciencedirect.com/science/journal/00381098/"
   ##	Journal_URL["j-STAT-METHODOL"]			= "http://www.sciencedirect.com/science/journal/15723127/"
   ##	Journal_URL["j-STUD-HIST-PHILOS-MOD-PHYS"]		= "http://www.sciencedirect.com/science/journal/13552198/"
   ##	Journal_URL["j-STUD-HIST-PHILOS-SCI"]		= "http://www.sciencedirect.com/science/journal/00393681/"
   ##	Journal_URL["j-STUD-HIST-PHILOS-SCI-C"]		= "http://www.sciencedirect.com/science/journal/13698486/"
   ##	Journal_URL["j-TECHNOMETRICS"]			= "http://www.jstor.org/journals/00401706.html"
   ##	Journal_URL["j-TECHNOMETRICS"]			= "http://www.tandfonline.com/loi/utch20"
   ##	Journal_URL["j-THEOR-CHEM-ACCOUNTS"]		= "http://www.springerlink.com/content/1432-2234"
   ##	Journal_URL["j-THEOR-COMP-SCI"]			= "http://www.sciencedirect.com/science/journal/03043975/"
   ##	Journal_URL["j-TOMS"]				= "http://portal.acm.org/toc.cfm?idx=J782"
   ##	Journal_URL["j-VERH-DTSCH-PHYS-GES"]		= "http://catalog.hathitrust.org/Record/012306260"
   ##	Journal_URL["j-VERH-DTSCH-PHYS-GES"]		= "http://hdl.handle.net/2027/chi.105146030"
   ##	Journal_URL["j-VERH-DTSCH-PHYS-GES"]		= "http://hdl.handle.net/2027/chi.21403652"
   ##	Journal_URL["j-VERH-DTSCH-PHYS-GES"]		= "http://hdl.handle.net/2027/coo.31924056107224"
   ##	Journal_URL["j-VERH-DTSCH-PHYS-GES"]		= "http://hdl.handle.net/2027/coo.31924056112125"
   ##	Journal_URL["j-VERH-DTSCH-PHYS-GES"]		= "http://hdl.handle.net/2027/coo.31924056112240"
   ##	Journal_URL["j-VERH-DTSCH-PHYS-GES"]		= "http://hdl.handle.net/2027/coo.31924056113289"
   ##	Journal_URL["j-VERH-DTSCH-PHYS-GES"]		= "http://hdl.handle.net/2027/coo.31924056113297"
   ##	Journal_URL["j-Z-ALLG-WISSENSCHAFTSTHEOR"]		= "http://www.jstor.org/journals/00442216.html"

    ## =================================================================
    ## Current definitions

    Journal_URL["j-AAUP-BULL"]				= "http://www.jstor.org/journal/aaupbulletin"
    Journal_URL["j-ABERDEEN-UNIV-REV"]			= ""
    Journal_URL["j-ABSTR-PAP-AM-CHEM-SOC"]		= "http://www.acs.org/content/acs/en/meetings/nationalmeetings/programarchive.html"
    Journal_URL["j-ACCOUNT-HIST-J"]			= "http://www.jstor.org/action/showPublication?journalCode=accohistjour; http://www.aahhq.org/"
    Journal_URL["j-ACCOUNT-RES"]			= "http://www.tandfonline.com/loi/gacr20"
    Journal_URL["j-ACM-COMM-COMP-ALGEBRA"]		= "http://portal.acm.org/browse_dl.cfm?idx=J1000"
    Journal_URL["j-ACM-J-EXP-ALGORITHMICS"]		= "http://portal.acm.org/browse_dl.cfm?idx=J430"
    Journal_URL["j-ACM-SIGCAS-COMPUT-SOC"]		= "http://dl.acm.org/citation.cfm?id=J198"
    Journal_URL["j-ACM-SIGMOBILE-MOBILE-COMPUT-COMMUN-REV"] = "http://dl.acm.org/citation.cfm?id=J548"
    Journal_URL["j-ACTA-APPL-MATH"]			= "http://link.springer.com/journal/10440"
    Journal_URL["j-ACTA-ARITHMETICA"]			= "https://www.impan.pl/en/publishing-house/journals-and-series/acta-arithmetica/all"
    Journal_URL["j-ACTA-BIOTHEOR"]			= "http://link.springer.com/journal/10441"
    Journal_URL["j-ACTA-CRYSTAL-A"]			= "http://journals.iucr.org/a/services/archive.html"
    Journal_URL["j-ACTA-CRYSTALLOGR"]			= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)0365-110X"
    Journal_URL["j-ACTA-GEOD-GEOPHYS-HU"]		= "http://www.akademiai.com/loi/074"
    Journal_URL["j-ACTA-INFO"]				= "http://link.springer.com/journal/236"
    Journal_URL["j-ACTA-MATER"]				= "http://www.sciencedirect.com/science/journal/13596454"
    Journal_URL["j-ACTA-MATH"]				= "http://link.springer.com/journal/11511"
    Journal_URL["j-ACTA-MECH"]				= "http://link.springer.com/journal/707"
    Journal_URL["j-ACTA-MED-SCAND"]			= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)0954-6820a"
    Journal_URL["j-ACTA-NUMERICA"]			= "http://journals.cambridge.org/action/displayJournal?jid=ANU"
    Journal_URL["j-ACTA-ONCOL"]				= "http://www.tandfonline.com/loi/ionc20"
    Journal_URL["j-ACTA-OPHTHALMOL"]			= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1755-3768"
    Journal_URL["j-ACTA-PHYS-ACAD-SCI-HUNG"]		= "http://link.springer.com/journal/12658"
    Journal_URL["j-ACTA-PHYS-HUNG-NEW-SERIES-HEAVY-ION-PHYS"] = "http://link.springer.com/journal/12656"
    Journal_URL["j-ACTA-PHYS-HUNG-A"]			= "http://link.springer.com/journal/12656"
    Journal_URL["j-ACTA-PHYS-POL-A"]			= "http://przyrbwn.icm.edu.pl/APP/apphome.html"
    Journal_URL["j-ACTA-PHYS-POL-B"]			= "http://www.actaphys.uj.edu.pl/pl/acta_physica_polonica_b"
    Journal_URL["j-ACTA-SCI-MATH-SZEGED"]		= "http://acta.fyx.hu/acta/"
    Journal_URL["j-ACTA-SOCIOL"]			= "https://journals.sagepub.com/loi/asja; https://www.jstor.org/journal/actasoci"
    Journal_URL["j-ADA-USER-J"]				= "http://www.ada-europe.org/auj/archive"
    Journal_URL["j-ADV-APPL-MECH"]			= "http://www.sciencedirect.com/science/bookseries/00652156"
    Journal_URL["j-ADV-APPL-MATH"]			= "http://www.sciencedirect.com/science/journal/01968858"
    Journal_URL["j-ADV-APPL-PROB"]			= "http://www.jstor.org/journals/00018678.html; https://www.cambridge.org/core/journals/advances-in-applied-probability; http://projecteuclid.org/euclid.aap/"
    Journal_URL["j-ADV-APPL-STAT"]			= "http://www.pphmj.com/journals/contents/adas.htm"
    Journal_URL["j-ADV-APPL-STAT-SCI"]			= "http://www.mililink.com/journals_content.php?id=58"
    Journal_URL["j-ADV-COMPLEX-SYST"]			= "http://www.worldscinet.com/acs/acs.shtml"
    Journal_URL["j-ADV-COMPUT-MATH"]			= "http://link.springer.com/journal/10444"
    Journal_URL["j-ADV-DIFFERENCE-EQU"]			= "http://www.advancesindifferenceequations.com/"
    Journal_URL["j-ADV-ENG-SOFTWARE"]			= "http://www.sciencedirect.com/science/journal/01411195"
    Journal_URL["j-ADV-GEOPHYS"]			= "http://www.sciencedirect.com/science/bookseries/00652687"
    Journal_URL["j-ADV-HIST-STUD"]			= "http://www.scirp.org/journal/ahs"
    Journal_URL["j-ADV-MATER"]				= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1521-4095"
    Journal_URL["j-ADV-MATH"]				= "http://www.sciencedirect.com/science/journal/00018708"
    Journal_URL["j-ADV-NONLINEAR-ANAL"]			= "http://www.degruyter.com/view/j/anona"
    Journal_URL["j-ADV-PHYS"]				= "http://www.tandfonline.com/loi/tadp20"
    Journal_URL["j-ADV-PURE-APPL-MATH"]			= "https://www.scirp.org/journal/apm"
    Journal_URL["j-ADV-QUANTUM-CHEM"]			= "http://www.sciencedirect.com/science/bookseries/00653276"
    Journal_URL["j-ADV-THEORY-SIMUL"]			= "https://onlinelibrary.wiley.com/journal/25130390"
    Journal_URL["j-ADV-WATER-RESOURCES"]		= "http://www.sciencedirect.com/science/journal/03091708"
    Journal_URL["j-AEQUATIONES-MATHEMATICAE"]		= "http://link.springer.com/journal/10"
    Journal_URL["j-AI-MAGAZINE"]			= "http://www.aaai.org/ojs/index.php/aimagazine/issue/archive"
    Journal_URL["j-AI-SOC"]				= "http://link.springer.com/journal/146"
    Journal_URL["j-AIP-ADV"]				= "http://scitation.aip.org/content/aip/journal/adva"
    Journal_URL["j-AIP-CONF-PROC"]			= "http://scitation.aip.org/content/aip/proceeding/aipcp"
    Journal_URL["j-ALGEBRA-LOGIC"]			= "http://link.springer.com/journal/10469"
    Journal_URL["j-ALGOL-BULLETIN"]			= "http://portal.acm.org/affiliated/ALGOL"
    Journal_URL["j-ALGORITHMICA"]			= "http://link.springer.com/journal/453"
    Journal_URL["j-ALGORITHMS-BASEL"]			= "https://www.mdpi.com/journal/algorithms"
    Journal_URL["j-ALMAGEST"]				= "https://www.brepolsonline.net/loi/almagest"
    Journal_URL["j-AM-BIOL-TEACH"]			= "http://abt.ucpress.edu/content/by/year"
    Journal_URL["j-AM-DOC"]				= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)2330-1643/"
    Journal_URL["j-AM-HIST-REV"]			= "http://ahr.oxfordjournals.org/; http://www.journals.uchicago.edu/toc/ahr/current; http://www.jstor.org/journals/00028762.html"
    Journal_URL["j-AM-J-APPL-SCI"]			= "https://thescipub.com/journals/ajas/archive"
    Journal_URL["j-AM-J-ARCHAEOL"]			= "http://www.jstor.org/journal/amerjarch"
    Journal_URL["j-AM-J-HUM-GENET"]			= "http://www.cell.com/ajhg/archive"
    Journal_URL["j-AM-J-PHYS-ANTHROPOL"]		= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1096-8644"
    Journal_URL["j-AM-J-PHYSIOL"]			= "https://www.physiology.org/"
    Journal_URL["j-AM-J-PSYCHIATRY"]			= "http://ajp.psychiatryonline.org/loi/ajp"
    Journal_URL["j-AM-J-SCI"]				= "http://www.ajsonline.org/content/by/year"
    Journal_URL["j-AM-NAT"]				= "http://www.jstor.org/journals/00030147.html"
    Journal_URL["j-AM-PROSPECT"]			= "http://prospect.org/magazine"
    Journal_URL["j-AM-SCH"]				= "http://www.theamericanscholar.org/archives"
    Journal_URL["j-AM-SCH"]				= "http://www.theamericanscholar.org/archives; http://www.jstor.org/action/showPublication?journalCode=americanscholar"
    Journal_URL["j-AM-SCI"]				= "http://www.americanscientist.org/issues/past.aspx"
    Journal_URL["j-AM-STUD"]				= "http://muse.jhu.edu/journals/american_studies"
    Journal_URL["j-AMBIX"]				= "http://www.tandfonline.com/loi/yamb20"
    Journal_URL["j-AMER-J-PHYSICS"]			= "http://scitation.aip.org/content/aapt/journal/ajp"
    Journal_URL["j-AMER-MATH-MONTHLY"]			= "http://www.jstor.org/journals/00029890.html"
    Journal_URL["j-AMER-PSYCHOLOGIST"]			= "http://psycnet.apa.org/PsycARTICLES/journal/amp/"
    Journal_URL["j-AMER-STAT"]				= "http://www.tandfonline.com/loi/utas20"
    Journal_URL["j-ANAESTHESIA"]			= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1365-2044"
    Journal_URL["j-ANAL-CHEM"]				= "http://pubs.acs.org/journal/ancham"
    Journal_URL["j-ANAL-MATH-PHYS"]			= "http://link.springer.com/journal/13324"
    Journal_URL["j-ANALYST"]				= "http://pubs.rsc.org/en/journals/journalissues/an"
    Journal_URL["j-ANESTHESIOL-HAGERSTOWN"]		= "http://anesthesiology.pubs.asahq.org/issue.aspx"
    Journal_URL["j-ANGEW-CHEM"]				= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1521-3757"
    Journal_URL["j-ANGEW-CHEM-INT-ED"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1521-3773/issues"
    Journal_URL["j-ANGEW-CHEM-INT-ED-ENGL"]		= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1521-3773a"
    Journal_URL["j-ANIM-BEHAV"]				= "http://www.sciencedirect.com/science/journal/00033472"
    ## UNKNOWN: Journal_URL["j-ANN-ACAD-REGIAE-SCI-UPS"]		= ""
    Journal_URL["j-ANN-APPL-BIOL"]			= "https://onlinelibrary.wiley.com/loi/17447348"
    Journal_URL["j-ANN-APPL-PROBAB"]			= "http://projecteuclid.org/all/euclid.aoap/; http://www.jstor.org/journals/10505164.html"
    Journal_URL["j-ANN-APPL-STAT"]			= "http://projecteuclid.org/all/euclid.aoas/; http://www.jstor.org/journals/19326157.html"
    Journal_URL["j-ANN-EUGENICS"]			= "https://onlinelibrary.wiley.com/journal/14691809"
    Journal_URL["j-ANN-FINANCE"]			= "http://link.springer.com/journal/10436"
    Journal_URL["j-ANN-FOND-LOUIS-DE-BROGLIE"]		= "http://aflb.ensmp.fr/AFLB-Web/fldb-annales-index.htm"
    Journal_URL["j-ANN-FUNCT-ANAL"]			= "http://projecteuclid.org/afa"
    Journal_URL["j-ANN-HIST-COMPUT"]			= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=5488650"
    Journal_URL["j-ANN-HUM-GENET"]			= "https://onlinelibrary.wiley.com/journal/14691809"
    Journal_URL["j-ANN-INST-HENRI-POINCARE-A"]		= "http://eudml.org/journal/10197"

    Journal_URL["j-ANN-INST-HENRI-POINCARE-ANAL-NON-LINEAIRE"] = "http://www.numdam.org/numdam-bin/feuilleter?j=AIHPC"
    Journal_URL["j-ANN-INST-HENRI-POINCARE-B-PROBAB-STAT"] = "http://www.numdam.org/numdam-bin/feuilleter?j=AIHPB"
    Journal_URL["j-ANN-INST-HENRI-POINCARE-PROBAB-STATIST"] = "http://projecteuclid.org/all/euclid.aihp; http://www.sciencedirect.com/science/journal/02460203/"
    Journal_URL["j-ANN-INST-STAT-MATH-TOKYO"]		= "http://link.springer.com/journal/10463"
    Journal_URL["j-ANN-MATH"]				= "http://annals.math.princeton.edu/"
    Journal_URL["j-ANN-MATH-2"]				= "http://www.jstor.org/action/showPublication?journalCode=annamath"
    Journal_URL["j-ANN-MATH-ARTIF-INTELL"]		= "http://link.springer.com/journal/10472"
    Journal_URL["j-ANN-MATH-STAT"]			= "http://projecteuclid.org/all/euclid.aoms/"
    Journal_URL["j-ANN-NUCL-ENERGY"]			= "http://www.sciencedirect.com/science/journal/03064549"
    Journal_URL["j-ANN-NY-ACAD-SCI"]			= "http://www.nyas.org/Publications/Archive.aspx"
    Journal_URL["j-ANN-OPER-RESEARCH"]			= "http://link.springer.com/journal/10479"
    Journal_URL["j-ANN-PHYS"]				= "http://www.sciencedirect.com/science/journal/00034916"
    Journal_URL["j-ANN-PHYS-1900"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1521-3889"
    Journal_URL["j-ANN-PHYS-1900-4"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1521-3889"
    Journal_URL["j-ANN-PHYS-5"]				= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1521-3889"
    Journal_URL["j-ANN-PHYS-6"]				= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1521-3889"
    Journal_URL["j-ANN-PHYS-7"]				= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1521-3889"
    Journal_URL["j-ANN-PHYS-8"]				= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1521-3889"
    Journal_URL["j-ANN-PHYS-BERLIN"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1521-3889"
    Journal_URL["j-ANN-PHYS-CHEM"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1521-3889"
    Journal_URL["j-ANN-PHYS-PHYS-CHEM"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1521-3889"
    Journal_URL["j-ANN-PROBAB"]				= "http://projecteuclid.org/all/euclid.aop"
    Journal_URL["j-ANN-REV-FLUID-MECH"]			= "http://www.annualreviews.org/journal/fluid"
    Journal_URL["j-ANNU-REV-NUCL-PART-SCI"]		= "http://www.annualreviews.org/loi/nucl"
    Journal_URL["j-ANN-REV-PHYS-CHEM"]			= "http://www.annualreviews.org/journal/physchem"
    Journal_URL["j-ANN-SC-NORM-SUPER-PISA-CL-SCI-4"]	= "http://www.numdam.org/numdam-bin/browse?j=ASNSP"
    Journal_URL["j-ANN-SCIENCE"]			= "http://www.tandfonline.com/loi/tasc20"
    Journal_URL["j-ANN-STAT"]				= "http://projecteuclid.org/all/euclid.aos/"
    Journal_URL["j-ANN-THEOR-PSYCHOL"]			= "http://link.springer.com/bookseries/5627"
    Journal_URL["j-ANNU-REP-PROG-CHEM"]			= "http://pubs.rsc.org/en/journals/journalissues/ar"
    Journal_URL["j-ANNU-REV-ASTRON-ASTROPHYS"]		= "http://www.annualreviews.org/journal/astro"
    Journal_URL["j-ANNU-REV-AUTOM-PROGRAM"]		= "http://www.sciencedirect.com/science/journal/00664138"
    Journal_URL["j-ANNU-REV-NUCL-SCI"]			= "http://www.annualreviews.org/loi/nucl"
    Journal_URL["j-ANTIOCH-REV"]			= "http://www.jstor.org/journals/00035769.html"
    Journal_URL["j-ANZIAM-J"]				= "http://journals.cambridge.org/action/displayJournal?jid=ANZ"
    Journal_URL["j-ANZJS"]				= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1467-842X/issues"
    Journal_URL["j-APPL-COMPUT-HARMON-ANAL"]		= "http://www.sciencedirect.com/science/journal/10635203"
    Journal_URL["j-APPL-ECON-LETT"]			= "http://www.tandfonline.com/loi/rael20"
    Journal_URL["j-APPL-MATH-COMP"]			= "http://www.sciencedirect.com/science/journal/00963003"
    Journal_URL["j-APPL-MATH-LETT"]			= "http://www.sciencedirect.com/science/journal/08939659"
    Journal_URL["j-APPL-MATH-MODEL"]			= "http://www.sciencedirect.com/journal/applied-mathematical-modelling"
    Journal_URL["j-APPL-MATH-OPTIM"]			= "http://link.springer.com/journal/245"
    Journal_URL["j-APPL-MATH-SCI-RUSE"]			= "http://www.m-hikari.com/ams/"
    Journal_URL["j-APPL-MECH-REV"]			= "http://appliedmechanicsreviews.asmedigitalcollection.asme.org/issues.aspx"
    Journal_URL["j-APPL-NUM-MATH"]			= "http://www.sciencedirect.com/science/journal/01689274"
    Journal_URL["j-APPL-OPTICS"]			= "http://www.osapublishing.org/ao/browse.cfm"
    Journal_URL["j-APPL-PHYS"]				= "http://link.springer.com/journal/339"
    Journal_URL["j-APPL-PHYS-A"]			= "http://link.springer.com/journal/339"
    Journal_URL["j-APPL-PHYS-A"]			= "http://link.springer.com/journal/volumesAndIssues/339"
    Journal_URL["j-APPL-PHYS-EXPRESS"]			= "http://apex.ipap.jp/"
    Journal_URL["j-APPL-PHYS-LET"]			= "http://scitation.aip.org/content/aip/journal/apl"
    Journal_URL["j-APPL-SCI-RES-SECT-B"]		= "http://link.springer.com/journal/volumesAndIssues/12380"
    Journal_URL["j-APPL-STAT"]				= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1467-9876/issues"
    Journal_URL["j-APPL-SURF-SCI"]			= "http://www.sciencedirect.com/science/journal/01694332"
    Journal_URL["j-APPL-SURF-SCI-1977-1985"]		= "http://www.sciencedirect.com/science/journal/03785963"
    Journal_URL["j-AQUAC-FISH-FISH"]			= "https://onlinelibrary.wiley.com/loi/26938847"
    Journal_URL["j-ARCH-APPL-MECH"]			= "http://link.springer.com/journal/419"
    Journal_URL["j-ARCH-HIST-EXACT-SCI"]		= "http://link.springer.com/journal/407"
    Journal_URL["j-ARCH-MATH"]				= "http://link.springer.com/journal/volumesAndIssues/13"
    Journal_URL["j-ARCH-MECH"]				= "http://am.ippt.pan.pl/index.php/am"
    Journal_URL["j-ARCH-NEERL-SCI-EXACTES-NAT"]		= "http://www.biodiversitylibrary.org/bibliography/82374"
    Journal_URL["j-ARCH-NUM-SOFT"]			= "https://journals.ub.uni-heidelberg.de/index.php/ans/"
    Journal_URL["j-ARCH-PHILOS"]			= "http://www.jstor.org/journal/archphil"
    Journal_URL["j-ARCH-RAT-MECH-ANAL"]			= "http://link.springer.com/journal/205"
    Journal_URL["j-ARCH-SCI-PHYS-NAT"]			= "http://biodiversitylibrary.org/bibliography/5919"
    Journal_URL["j-ARKIV-FYSIK"]			= "http://www.speciation.net/Database/Journals/Arkiv-foer-Fysik-;i771"
    Journal_URL["j-ARM-J-PHYS"]				= "http://www.flib.sci.am/eng/journal/Phys/"
    Journal_URL["j-ARMS"]				= "http://armsnet.info/archive-arms"
    Journal_URL["j-ARMS-CONTROL-TODAY"]			= "http://www.armscontrol.org/act/"
    Journal_URL["j-ARS-COMB"]				= "http://www.combinatorialmath.ca/arscombinatoria/"
    Journal_URL["j-ARSP-ARCH-RECHTS-SOZIALPHILOS"]	= "http://www.jstor.org/journal/arsparchrechsozi"
    Journal_URL["j-ART-LIFE-ROBOT"]			= "http://link.springer.com/journal/10015"
    Journal_URL["j-ARTIF-LIFE"]				= "https://direct.mit.edu/artl/issue"
    Journal_URL["j-ASTA-ADV-STAT-ANAL"]			= "http://link.springer.com/journal/10182"
    Journal_URL["j-ASTRO-NACHR"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1521-3994/issues"
    Journal_URL["j-ASTROBIOLOGY"]			= "http://online.liebertpub.com/loi/AST"
    Journal_URL["j-ASTRON-ASTROPHYS"]			= "https://www.aanda.org/component/issues/"
    Journal_URL["j-ASTRON-ASTROPHYS-TRANS"]		= "http://www.tandfonline.com/loi/gaat20"
    Journal_URL["j-ASTRON-GEOPHYS"]			= "http://astrogeo.oxfordjournals.org/"
    Journal_URL["j-ASTRON-J"]				= "http://iopscience.iop.org/1538-3881"
    Journal_URL["j-ASTROPART-PHYS"]			= "http://www.sciencedirect.com/science/journal/09276505"
    Journal_URL["j-ASTROPHYS-SPACE-SCI"]		= "http://link.springer.com/journal/10509"
    Journal_URL["j-ASTROPHYSICAL-J"]			= "http://iopscience.iop.org/0004-637X/"
    Journal_URL["j-ASYMPTOT-ANAL"]			= "http://content.iospress.com/journals/asymptotic-analysis"
    Journal_URL["j-AT-DATA-NUCL-DATA-TABLES"]		= "https://www.sciencedirect.com/journal/atomic-data-and-nuclear-data-tables"
    Journal_URL["j-ATLANTIC-MONTHLY"]			= "http://www.theatlantic.com/magazine/backissues/"
    Journal_URL["j-ATMOS-SCI-LETT"]			= "http://www.sciencedirect.com/science/journal/1530261X"
    Journal_URL["j-ATOMS"]				= "https://www.mdpi.com/journal/atoms"
    Journal_URL["j-ATT-TECH-J"]				= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1538-7305/issues/"
    Journal_URL["j-ATTEN-PERCEPT-PSYCHOPHYS"]		= "http://link.springer.com/journal/13414"
    Journal_URL["j-AUST-J-AGRIC-RES"]			= "http://www.publish.csiro.au/nid/43/aid/34.htm"
    Journal_URL["j-AUST-J-MATH-ANAL-APPL"]		= "http://ajmaa.org/volumes.php"
    Journal_URL["j-AUST-J-STAT"]			= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1467-842X/issues"
    Journal_URL["j-AUSTRALIAN-J-PHYS"]			= "http://www.publish.csiro.au/ph/content/allissues"
    Journal_URL["j-AUSTRALIAN-MATH-SOC-GAZ"]		= "http://www.austms.org.au/gazette"
    Journal_URL["j-AUSTRALIAN-MATH-SOC-SERIES-A"]	= "http://journals.cambridge.org/action/displayBackIssues?jid=JAZ"
    Journal_URL["j-AUTOM-REMOTE-CONTROL"]		= "http://link.springer.com/journal/10513"
    Journal_URL["j-AXIOMS-BASEL"]			= "https://www.mdpi.com/journal/axioms"
    Journal_URL["j-BAYESIAN-ANAL"]			= "http://ba.stat.cmu.edu/; http://projecteuclid.org/all/euclid.ba/"
    Journal_URL["j-BEHAV-BRAIN-SCI"]			= "https://www.cambridge.org/core/journals/behavioral-and-brain-sciences/all-issues"
    Journal_URL["j-BEHAV-RES-METH-INSTR-COMP"]		= "http://link.springer.com/journal/13428"
    Journal_URL["j-BEHAV-SCI"]				= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1099-1743"
    Journal_URL["j-BEHAVIOUR"]				= "http://booksandjournals.brillonline.com/content/journals/1568539x"
    Journal_URL["j-BEIBL-ANN-PHYS"]			= "http://de.wikisource.org/wiki/Annalen_der_Physik#Beibl.C3.A4tter"
    Journal_URL["j-BELL-LABS-TECH-J"]			= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=6731002"
    Journal_URL["j-BER-BUNSENGES-PHYS-CHEM"]		= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)0005-9021e"
    Journal_URL["j-BER-DTSCH-CHEM-GES"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1099-0682c"
    Journal_URL["j-BER-DTSCH-CHEM-GES-A"]		= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1099-0682a"
    Journal_URL["j-BER-DTSCH-CHEM-GES-ABT-A-B"]		= "https://onlinelibrary.wiley.com/journal/10990682c"
    Journal_URL["j-BER-WISSENSCHAFTGESCH"]		= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1522-2365/"
    Journal_URL["j-BERNOULLI"]				= "http://www.jstor.org/journal/bernoulli"
    Journal_URL["j-BIOCHEM-BIOPHYS-RES-COMMUN"]		= "http://www.sciencedirect.com/science/journal/0006291X"
    Journal_URL["j-BIOGRAPH-MEMOIRS-FELLOWS-ROY-SOC"]	= "http://www.jstor.org/journals/00804606.html; https://royalsocietypublishing.org/journal/rsbm"
    Journal_URL["j-BIOGRAPHY-HONOLULU"]			= "http://muse.jhu.edu/journals/biography/"
    Journal_URL["j-BIOINFORMATICS"]			= "http://bioinformatics.oxfordjournals.org/"
    Journal_URL["j-BIOL-CYBERN"]			= "http://link.springer.com/journal/422"
    Journal_URL["j-BIOMETRICAL-J"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1521-4036"
    Journal_URL["j-BIOMETRICS"]				= "http://www.jstor.org/journal/biometrics"
    Journal_URL["j-BIOMETRIKA"]				= "http://biomet.oxfordjournals.org/content/by/year; http://www.jstor.org/journals/00063444.html"
    Journal_URL["j-BIOPHYS-CHEM"]			= "http://www.sciencedirect.com/science/journal/03014622"
    Journal_URL["j-BIOPHYS-J"]				= "http://www.cell.com/biophysj/archive"
    Journal_URL["j-BIOPHYS-STRUCT-MECH"]		= "http://link.springer.com/journal/249"
    Journal_URL["j-BIOSYSTEMS"]				= "http://www.sciencedirect.com/science/journal/03032647"
    Journal_URL["j-BIOTECH"]				= "http://www.nature.com/nbt/archive"
    Journal_URL["j-BIT"]				= "http://link.springer.com/journal/10543"
    Journal_URL["j-BIT-NUM-MATH"]			= "http://link.springer.com/journal/10543"
    Journal_URL["j-BMC-BIOINFORMATICS"]			= "http://www.biomedcentral.com/bmcbioinformatics/"
    Journal_URL["j-BOUND-VALUE-PROBL"]			= "http://boundaryvalueproblems.springeropen.com/"
    Journal_URL["j-BOUNDARY-LAYER-METEOROL"]		= "http://link.springer.com/journal/10546"
    Journal_URL["j-BR-ASSOC-ADV-SCI-REP"]		= "http://www.biodiversitylibrary.org/bibliography/2276"
    Journal_URL["j-BR-J-APPL-PHYS"]			= "http://iopscience.iop.org/0508-3443"
    Journal_URL["j-BR-MED-J"]				= "http://www.jstor.org/journal/britmedj"
    Journal_URL["j-BRAZ-J-PHYS"]			= "http://link.springer.com/journal/13538"
    Journal_URL["j-BRITISH-J-HIST-MATH"]		= "http://www.tandfonline.com/loi/tbsh21"
    Journal_URL["j-BRITISH-J-HIST-SCI"]			= "http://journals.cambridge.org/action/displayJournal?jid=BJH"
    Journal_URL["j-BRITISH-J-PHILOS-SCI"]		= "http://bjps.oxfordjournals.org/content/by/year"
    Journal_URL["j-BSHM-BULL"]				= "http://www.tandfonline.com/loi/tbsh20"
    Journal_URL["j-BSHM-NEWSLETTER"]			= "http://www.tandfonline.com/loi/tbsh20"
    Journal_URL["j-BULL-AMS"]				= "http://www.ams.org/journals/bull/"
    Journal_URL["j-BULL-AMS"]				= "http://www.ams.org/journals/bull/all_issues.html"
    Journal_URL["j-BULL-AMS-N-S"]			= "http://www.ams.org/journals/bull/all_issues.html"
    Journal_URL["j-BULL-APPL-STAT"]			= "http://www.tandfonline.com/loi/cjas20"
    Journal_URL["j-BULL-AT-SCI"]			= "http://bos.sagepub.com/"
    Journal_URL["j-BULL-AUSTRAL-MATH-SOC"]		= "http://journals.cambridge.org/action/displayJournal?jid=BAZ"
    Journal_URL["j-BULL-CALCUTTA-MATH-SOC"]		= "http://bulletin.calmathsoc.org/database.php"
    Journal_URL["j-BULL-GEODESIQUE"]			= "http://link.springer.com/journal/190"
    Journal_URL["j-BULL-HIST-CHEM"]			= "http://www.scs.illinois.edu/~mainzv/HIST/bulletin_open_access/bull-index.php"
    Journal_URL["j-BULL-LOND-MATH-SOC"]			= "http://blms.oxfordjournals.org/content/by/year"
    Journal_URL["j-BULL-MATH-BIOL"]			= "http://link.springer.com/journal/11538"
    Journal_URL["j-BULL-MATH-BIOPHYS"]			= "http://link.springer.com/journal/11538"
    Journal_URL["j-BULL-SOC-MATH-FRANCE"]		= "http://www.numdam.org/numdam-bin/browse?sl=0&j=BSMF"
    Journal_URL["j-BULL-SYMB-LOG"]			= "http://projecteuclid.org/all/euclid.bsl"
    Journal_URL["j-C-R-ACAD-SCI-PARIS"]			= "http://gallica.bnf.fr/ark:/12148/cb343481087/date"
    Journal_URL["j-C-R-ACAD-SCI-PARIS-SER-I-MATH"]	= "http://www.sciencedirect.com/science/journal/1631073X"
    Journal_URL["j-C-R-BIOL"]				= "http://www.sciencedirect.com/science/journal/16310691"
    Journal_URL["j-C-R-HEBD-SEANCES-ACAD-SCI"]		= "http://gallica.bnf.fr/ark:/12148/cb343481087/date"
    Journal_URL["j-CACM"]				= "http://dl.acm.org/pub.cfm?id=J782"
    Journal_URL["j-CAGD"]				= "http://www.sciencedirect.com/science/journal/01678396"
    Journal_URL["j-CALC-VAR-PARTIAL-DIFFER-EQU"]	= "http://link.springer.com/journal/volumesAndIssues/526"
    Journal_URL["j-CALCOLO"]				= "http://link.springer.com/journal/10092"
    Journal_URL["j-CAN-APPL-MATH-Q"]			= "http://www.math.ualberta.ca/ami/camq.html"
    Journal_URL["j-CAN-J-ARCHAEO"]			= "https://canadianarchaeology.com/caa/publications/canadian-journal-archaeology/archives"
    Journal_URL["j-CAN-J-CHEM"]				= "http://www.nrcresearchpress.com/journal/cjc"
    Journal_URL["j-CAN-J-EARTH-SCI"]			= "http://dx.doi.org/10.1139/e01-003"
    Journal_URL["j-CAN-J-FOR-RES"]			= "http://www.nrcresearchpress.com/loi/cjfr"
    Journal_URL["j-CAN-J-FISH-AQUAT-SCI"]		= "https://cdnsciencepub.com/journal/cjfas"
    Journal_URL["j-CAN-J-HIGHER-ED"]			= "http://journals.sfu.ca/cjhe"
    Journal_URL["j-CAN-J-MATH"]				= "http://cms.math.ca/cjm/"
    Journal_URL["j-CAN-J-PHYS"]				= "http://www.nrcresearchpress.com/journal/cjp"
    Journal_URL["j-CAN-J-RES-SECT-A"]			= "http://www.nrcresearchpress.com/loi/cjr"
    Journal_URL["j-CAN-J-STAT"]				= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1708-945X/"
    Journal_URL["j-CAN-MATH-BULL"]			= "http://cms.math.ca/cmb/"
    Journal_URL["j-CARBON"]				= "http://www.sciencedirect.com/science/journal/00086223"
    Journal_URL["j-CCPE"]				= "http://www.interscience.wiley.com/jpages/1532-0626"
    Journal_URL["j-CELEST-MECH"]			= "https://www.springer.com/journal/10569"
    Journal_URL["j-CELL-SYST"]				= "http://www.sciencedirect.com/science/journal/24054712"
    Journal_URL["j-CENTAURUS"]				= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1600-0498/"
    Journal_URL["j-CERN-COURIER"]			= "http://www.cerncourier.com/; https://cds.cern.ch/collection/CERN%20Courier%20Issues"
    Journal_URL["j-CESK-CAS-FYZ"]			= "http://link.springer.com/journal/10582"
    Journal_URL["j-CGF"]				= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1467-8659/"
    Journal_URL["j-CGIP"]				= "http://www.sciencedirect.com/science/journal/0146664X"
    Journal_URL["j-CHANCE"]				= "http://chance.amstat.org/; http://link.springer.com/journal/144; http://www.tandfonline.com/loi/ucha20"
    Journal_URL["j-CHAOS"]				= "http://scitation.aip.org/content/aip/journal/chaos"
    Journal_URL["j-CHEM-ENG-COMMUN"]			= "http://www.tandfonline.com/loi/gcec20"
    Journal_URL["j-CHEM-ENG-NEWS"]			= "http://pubs.acs.org/loi/cenear"
    Journal_URL["j-CHEM-ENG-NEWS-ARCHIVE"]		= "http://pubs.acs.org/loi/cenear"
    Journal_URL["j-CHEM-IND-CHICHESTER-UK"]		= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)2047-6329"
    Journal_URL["j-CHEM-MATER"]				= "http://pubs.acs.org/journal/cmatex"
    Journal_URL["j-CHEM-NEWS-J-PHYS-SCI"]		= "http://catalog.hathitrust.org/Record/007085562"
    Journal_URL["j-CHEM-PHYS"]				= "http://www.sciencedirect.com/science/journal/03010104"
    Journal_URL["j-CHEM-PHYS-LETT"]			= "http://www.sciencedirect.com/science/journal/00092614"
    Journal_URL["j-CHEM-REV"]				= "http://pubs.acs.org/loi/chreay"
    Journal_URL["j-CHEM-UNSERER-ZEIT"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1521-3781"
    Journal_URL["j-CHEMINFORM"]				= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1522-2667"
    Journal_URL["j-CHEMOSPHERE"]			= "http://www.sciencedirect.com/science/journal/00456535"
    Journal_URL["j-CHEMPHYSCHEM"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1439-7641"
    Journal_URL["j-CHIC-REV"]				= "http://www.jstor.org/journal/chicagorev"
    Journal_URL["j-CHR-SCI-MON"]			= "https://www.csmonitor.com/"
    Journal_URL["j-CHRON-HIGHER-ED"]			= "https://www.chronicle.com/issue/current"
    Journal_URL["j-CHYMIA"]				= "http://www.jstor.org/journals/00959367.html"
    Journal_URL["j-CIRC-ARRHYTHM-ELECTROPHYSIOL"]	= "http://circep.ahajournals.org/content/by/year"
    Journal_URL["j-CLIN-PHARMACOL-THER"]		= "http://onlinelibrary.wiley.com/subject/code/MDM1/titles"
    Journal_URL["j-CMS-NOTES"]				= "https://cms.math.ca/notes"
    Journal_URL["j-COLL-ENGL"]				= "http://www.ncte.org/journals/ce"
    Journal_URL["j-COLLECT-CZECH-CHEM-COMMUN"]		= "http://cccc.uochb.cas.cz/archive/"
    Journal_URL["j-COLLEGE-MATH-J"]			= "https://maa.tandfonline.com/loi/ucmj20; https://www.jstor.org/journal/collmathj"
    Journal_URL["j-COLLNET-J-SCIENTOMETRICS-INF-MANAGE"] = "http://www.tandfonline.com/loi/tsim20"
    Journal_URL["j-COLLOQ-GER"]				= "http://www.jstor.org/journal/collogerm"
    Journal_URL["j-COMBIN-PROBAB-COMPUT"]		= "http://journals.cambridge.org/action/displayJournal?jid=CPC"
    Journal_URL["j-COMBINATORICA"]			= "http://link.springer.com/journal/volumesAndIssues/493"
    Journal_URL["j-COMM-APPL-ANAL"]			= "http://www.dynamicpublishers.com/CAA/caacontent.htm"
    Journal_URL["j-COMM-NONLIN-SCI-NUM-SIM"]		= "http://www.sciencedirect.com/science/journal/10075704"
    Journal_URL["j-COMM-NUMER-METHODS-ENGRG"]		= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1099-0887"
    Journal_URL["j-COMM-PARTIAL-DIFF-EQNS"]		= "http://www.tandfonline.com/loi/lpde20"
    Journal_URL["j-COMM-PURE-APPL-MATH"]		= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1097-0312"
    Journal_URL["j-COMMENT-MATH-HELV"]			= "https://link.springer.com/journal/14"
    Journal_URL["j-COMMUN-BOOKNOTES-Q"]			= "http://www.tandfonline.com/loi/hcbq20"
    Journal_URL["j-COMMUN-COMPUT-PHYS"]			= "http://www.global-sci.com/"
    Journal_URL["j-COMMUN-CONTEMP-MATH"]		= "http://www.worldscientific.com/worldscinet/ccm"
    Journal_URL["j-COMMUN-DESIGN-Q-REVIEW"]		= "http://dl.acm.org/citation.cfm?id=J1351"
    Journal_URL["j-COMMUN-KOREAN-MATH-SOC"]		= "http://ckms.kms.or.kr/"
    Journal_URL["j-COMMUN-MATH-PHYS"]			= "http://link.springer.com/journal/220"
    Journal_URL["j-COMMUN-MATH-SCI"]			= "http://ProjectEuclid.org/cms"
    Journal_URL["j-COMMUN-MATH-STAT"]			= "http://link.springer.com/journal/40304"
    Journal_URL["j-COMMUN-STAT"]			= "http://www.tandfonline.com/loi/lsta19"
    Journal_URL["j-COMMUN-STAT-SIMUL-COMPUT"]		= "http://www.tandfonline.com/loi/lssp20"
    Journal_URL["j-COMMUN-STAT-THEORY-METH"]		= "http://www.tandfonline.com/loi/lsta20"
    Journal_URL["j-COMP-ARCH-NEWS"]			= "http://portal.acm.org/browse_dl.cfm?idx=J89"
    Journal_URL["j-COMP-EDU"]				= "http://www.sciencedirect.com/science/journal/03601315"
    Journal_URL["j-COMP-GRAPHICS"]			= "http://portal.acm.org/browse_dl.cfm?idx=J166"
    Journal_URL["j-COMP-J"]				= "http://comjnl.oxfordjournals.org/"
    Journal_URL["j-COMP-LANGS"]				= "http://www.sciencedirect.com/science/journal/00960551"
    Journal_URL["j-COMP-LANGS-SYS-STRUCT"]		= "http://www.sciencedirect.com/science/journal/14778424"
    Journal_URL["j-COMP-MATH-APPL"]			= "http://www.sciencedirect.com/science/journal/08981221"
    Journal_URL["j-COMP-MATH-APPL-B"]			= "http://www.sciencedirect.com/science/journal/08981221"
    Journal_URL["j-COMP-NET-AMSTERDAM"]			= "http://www.sciencedirect.com/science/journal/13891286"
    Journal_URL["j-COMP-NET-ISDN"]			= "http://www.sciencedirect.com/science/journal/01697552"
    Journal_URL["j-COMP-OP-RES"]			= "http://www.sciencedirect.com/science/journal/03050548"
    Journal_URL["j-COMP-OPTIM-APPL"]			= "http://link.springer.com/journal/10589"
    Journal_URL["j-COMP-PHYS"]				= "http://www.sciencedirect.com/science/journal/00219991"
    # Journal_URL["j-COMP-PHYSICS"]			= "http://scitation.aip.org/content/aip/journal/cip"
    Journal_URL["j-COMP-PHYS-COMM"]			= "http://www.sciencedirect.com/science/journal/00104655"
    Journal_URL["j-COMP-PHYS-REP"]			= "http://www.sciencedirect.com/science/journal/01677977"
    Journal_URL["j-COMP-SCI-REV"]			= "http://www.sciencedirect.com/science/journal/15740137"
    Journal_URL["j-COMP-STAT"]				= "https://www.springer.com/journal/180"
    Journal_URL["j-COMP-STRUCTURES"]			= "http://www.sciencedirect.com/science/journal/00457949"
    Journal_URL["j-COMP-SURV"]				= "http://portal.acm.org/browse_dl.cfm?idx=J204"
    Journal_URL["j-COMP-VIS-IMAGE-UNDERSTANDING"]	= "http://www.sciencedirect.com/science/journal/10773142"
    Journal_URL["j-COMPLEX-VAR-ELLIPTIC-EQU"]		= "http://www.tandfonline.com/loi/gcov20"
    Journal_URL["j-COMPLEX-VARIABLES-THEORY-APPL"]	= "https://www.tandfonline.com/journals/gcov19"
    Journal_URL["j-COMPLEXITY"]				= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1099-0526"
    Journal_URL["j-COMPOS-SCI-TECH"]			= "http://www.sciencedirect.com/science/journal/02663538"
    Journal_URL["j-COMPUT-AIDED-CIVIL-INFRASTRUCT-ENG"]	= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1467-8667"
    Journal_URL["j-COMPUT-AIDED-DES"]			= "http://www.sciencedirect.com/science/journal/00104485"
    Journal_URL["j-COMPUT-ANIM-VIRTUAL-WORLDS"]		= "http://www3.interscience.wiley.com/cgi-bin/jhome/106562739"
    Journal_URL["j-COMPUT-CHEM"]			= "http://www.sciencedirect.com/science/journal/00978485"
    Journal_URL["j-COMPUT-EDGE"]			= "http://www.computer.org/web/computingedge"
    Journal_URL["j-COMPUT-GEOSCI"]			= "http://link.springer.com/journal/10596"
    Journal_URL["j-COMPUT-INTELL"]			= "https://onlinelibrary.wiley.com/journal/14678640"
    Journal_URL["j-COMPUT-MATER-SCI"]			= "http://www.sciencedirect.com/science/journal/09270256"
    Journal_URL["j-COMPUT-MATH-APPL"]			= "http://www.sciencedirect.com/science/journal/08981221"
    Journal_URL["j-COMPUT-MATH-APPL-B"]			= "http://www.sciencedirect.com/science/journal/08981221"
    Journal_URL["j-COMPUT-METH-APPL-MECH-ENG"]		= "http://www.sciencedirect.com/science/journal/00457825"
    Journal_URL["j-COMPUT-METH-FUNCT-THEORY"]		= "https://www.springer.com/journal/40315"
    ## Journal_URL["j-COMPUT-PHYS"]			= "http://scitation.aip.org/content/aip/journal/cip"
    ## Journal_URL["j-COMPUT-PHYS"]			= "http://www.aip.org/cip/"
    Journal_URL["j-COMPUT-PHYS"]			= "https://aip.scitation.org/journal/cip"
    Journal_URL["j-COMPUT-SCI-ENG"]			= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=5992"
    Journal_URL["j-COMPUT-SECUR"]			= "http://www.sciencedirect.com/science/journal/01674048"
    Journal_URL["j-COMPUT-SOFTW-BIG-SCI"]		= "https://www.springer.com/journal/41781"
    Journal_URL["j-COMPUT-STAND"]			= "http://www.sciencedirect.com/science/journal/01678051"
    Journal_URL["j-COMPUT-STAT-DATA-ANAL"]		= "http://www.sciencedirect.com/science/journal/01679473"
    Journal_URL["j-COMPUT-SYST-SCI-ENG"]		= "http://www.crlpublishing.co.uk/csse"
    Journal_URL["j-COMPUT-THEOR-CHEM"]			= "http://www.sciencedirect.com/science/journal/2210271X"
    Journal_URL["j-COMPUTABILITY"]			= "http://iospress.metapress.com/content/122520/"
    # Journal_URL["j-COMPUTER"]				= "http://www.computer.org/portal/web/csdl/magazines/computer"
    Journal_URL["j-COMPUTER"]				= "https://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=2"
    Journal_URL["j-COMPUTER-PROC-CHINESE-ORIENTAL-LANG"] = "http://www.worldscientific.com/worldscinet/ijcpol"
    Journal_URL["j-COMPUTERS-AND-GRAPHICS"]		= "http://www.sciencedirect.com/science/journal/00978493"
    Journal_URL["j-COMPUTING"]				= "http://link.springer.com/journal/607"
    Journal_URL["j-CONSERV-BIOL"]			= "https://conbio.onlinelibrary.wiley.com/loi/15231739; http://www.jstor.org/journals/08888892.html"
    Journal_URL["j-CONST-APPROX"]			= "http://link.springer.com/journal/365"
    Journal_URL["j-CONTEMP-BR-HIST"]			= "http://www.tandfonline.com/loi/fcbh20"
    Journal_URL["j-CONTEMP-PHYS"]			= "http://www.tandfonline.com/loi/tcph20"
    Journal_URL["j-CONTEMP-SOCIOL"]			= "http://www.jstor.org/journal/contsoci"
    Journal_URL["j-CONTIN-MECH-THERMODYN"]		= "http://link.springer.com/journal/161"
    Journal_URL["j-CONTROL-CYBERN"]			= "http://control.ibspan.waw.pl:3000/mainpage"
    Journal_URL["j-CONTROLLED-CLIN-TRIALS"]		= "http://www.sciencedirect.com/science/journal/01972456"
    Journal_URL["j-CPE"]				= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1532-0634/issues"
    Journal_URL["j-CRIT-CARE-MED"]			= "http://journals.lww.com/ccmjournal/pages/issuelist.aspx"
    Journal_URL["j-CRITICA-MEXICO"]			= "http://critica.filosoficas.unam.mx/; http://www.jstor.org/journals/00111503.html"
    Journal_URL["j-CROAT-CHEM-ACTA"]			= "http://public.carnet.hr/ccacaa/"
    Journal_URL["j-CRYPTOGR-COMMUN"]			= "http://link.springer.com/journal/12095"
    Journal_URL["j-CRYPTOLOGIA"]			= "http://www.tandfonline.com/loi/ucry20"
    Journal_URL["j-CRYST-RES-TECHNOL"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1521-4079"
    Journal_URL["j-CSSP"]				= "http://link.springer.com/journal/34"
    Journal_URL["j-CURR-SCI"]				= "https://www.jstor.org/journal/currentscience"
    Journal_URL["j-CVGIP"]				= "http://www.sciencedirect.com/science/journal/0734189X"
    Journal_URL["j-CVGIP-GMIP"]				= "http://www.sciencedirect.com/science/journal/10499652"
    Journal_URL["j-CVGIP-IU"]				= "http://www.sciencedirect.com/science/journal/10499660"
    Journal_URL["j-CYBER"]				= "http://link.springer.com/journal/10559"
    Journal_URL["j-CYBERNETICS-SYSTEMS"]		= "http://www.tandfonline.com/loi/ucbs20"
    Journal_URL["j-CZECH-J-PHYS"]			= "http://link.springer.com/journal/10582"
    Journal_URL["j-DAEDALUS"]				= "http://www.jstor.org/journals/00115266.html; http://www.mitpressjournals.org/loi/daed"
    Journal_URL["j-DATA-PROCESS"]			= "http://www.sciencedirect.com/science/journal/0011684X"
    Journal_URL["j-DEEP-SEA-RES-PART-2-TOP-STUD-OCEANOGR"] = "https://www.sciencedirect.com/journal/deep-sea-research-part-ii-topical-studies-in-oceanography"
    Journal_URL["j-DESIGNS-CODES-CRYPTOGR"]		= "http://link.springer.com/journal/10623"
    Journal_URL["j-DEV-CELL"]				= "https://www.cell.com/cell/archive"
    Journal_URL["j-DGOV"]				= "https://dl.acm.org/loi/dgov"
    Journal_URL["j-DIALECTICA"]				= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1746-8361"
    Journal_URL["j-DIALOGUE"]				= "http://journals.cambridge.org/jid_DIA"
    Journal_URL["j-DIPL-HIST"]				= "http://dh.oxfordjournals.org/content/by/year"
    Journal_URL["j-DISCRETE-COMPUT-GEOM"]		= "http://link.springer.com/journal/454"
    Journal_URL["j-DISCRETE-APPL-MATH"]			= "http://www.sciencedirect.com/science/journal/0166218X"
    Journal_URL["j-DISTRIB-COMPUT"]			= "https://link.springer.com/journal/446"
    Journal_URL["j-DLT"]				= "https://dl.acm.org/loi/dlt"
    Journal_URL["j-DOC-MATH"]				= "http://www.math.uiuc.edu/documenta/"
    Journal_URL["j-DOKL-MATH"]				= "http://link.springer.com/journal/11472"
    Journal_URL["j-DOKL-AKAD-NAUK"]			= "http://istina.msu.ru/journals/366838/"
    Journal_URL["j-DTRAP"]				= "https://dl.acm.org/loi/dtrap"
    Journal_URL["j-DUKE-MATH-J"]			= "http://projecteuclid.org/info/euclid.dmj"
    Journal_URL["j-EARTH-SURF-PROCESSES"]		= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1931-8065"
    Journal_URL["j-EARTH-SURF-PROCESSES-LANDFORMS"]	= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1096-9837"
    Journal_URL["j-EARTHQUAKE-ENG-STRUCT-DYN"]		= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1096-9845"
    Journal_URL["j-ECOL-MODELL"]			= "https://www.sciencedirect.com/journal/ecological-modelling"
#    j-ECONOM-J moved from Wiley to Oxford Academic effective 1-Jan-2019
#    Journal_URL["j-ECONOM-J"]				= "https://onlinelibrary.wiley.com/journal/1368423x"
    Journal_URL["j-ECONOM-J"]				= "https://academic.oup.com/ectj"
    Journal_URL["j-ECONOM-LETT"]			= "http://www.sciencedirect.com/science/journal/01651765"
    Journal_URL["j-ECONOM-STAT"]			= "https://www.sciencedirect.com/journal/econometrics-and-statistics"
    Journal_URL["j-ECON-QUAL-CONTROL"]			= "http://degruyter.com/eqc"
    Journal_URL["j-ECONOMETRICA"]			= "http://www.jstor.org/journal/econometrica"
    Journal_URL["j-EDU-CHEM"]				= "http://www.rsc.org/eic/e-magazine"
    Journal_URL["j-EDUC-STUD-MATH"]			= "http://link.springer.com/journal/10649"
    Journal_URL["j-EDUCOM-REV"]				= "http://www.educause.edu/pub/er/"
    Journal_URL["j-ELECT-LETTERS"]			= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=2220"
    Journal_URL["j-ELECT-NOTES-THEOR-COMP-SCI"]		= "http://www.sciencedirect.com/science/journal/15710661"
    Journal_URL["j-ELECTR-ENG"]				= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=6413714"
    Journal_URL["j-ELECTR-REV"]				= "http://catalog.hathitrust.org/Record/008614749"
    Journal_URL["j-ELECTROMAGNETICS"]			= "http://www.tandfonline.com/loi/uemg20"
    Journal_URL["j-ELECTRON-COMMUN-JPN-PART-1-COMMUN"]	= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1520-6424"
    Journal_URL["j-ELECTRON-COMMUN-PROBAB"]		= "http://ecp.ejpecp.org/"
    Journal_URL["j-ELECTRON-J-LINEAR-ALGEBRA"]		= "http://repository.uwyo.edu/ela/"
    Journal_URL["j-ELECTRON-J-PROBAB"]			= "http://ejp.ejpecp.org/"
    Journal_URL["j-ELECTRON-J-THEOR-PHYS"]		= "http://www.ejtp.com/"
    Journal_URL["j-ELECTRON-TRANS-NUMER-ANAL"]		= "http://etna.mcs.kent.edu/"
    Journal_URL["j-ELECTROPHORESIS"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1522-2683"
    Journal_URL["j-EMBO-J"]				= "http://emboj.embopress.org/"
    Journal_URL["j-EMPIR-SOFTWARE-ENG"]			= "http://link.springer.com/journal/10664"
    Journal_URL["j-ENDEAVOUR"]				= "http://www.sciencedirect.com/science/journal/01609327"
    Journal_URL["j-ENSEIGN-MATH-2"]			= "http://www.e-periodica.ch/digbib/vollist?var=true&UID=ens-001"
    Journal_URL["j-ENTROPY"]				= "https://www.mdpi.com/journal/entropy/"
    Journal_URL["j-ENVIRON-MONIT-ASSESS"]		= "http://www.springerlink.com/content/0167-6369"
    Journal_URL["j-EPJ-APPL-PHYS"]			= "http://www.epjap.org/"
    Journal_URL["j-ERKENNTNIS"]				= "http://www.jstor.org/stable/20011824"
    Journal_URL["j-ERKENNTNIS-1975"]			= "http://link.springer.com/journal/10670"
    Journal_URL["j-ESAIM-PROBAB-STATIST"]		= "http://www.esaim-ps.org/"
    Journal_URL["j-EUGEN-REV"]				= "https://www.ncbi.nlm.nih.gov/pmc/issues/191964/"
    Journal_URL["j-EULERIANA"]				= "https://scholarlycommons.pacific.edu/euleriana/"
    Journal_URL["j-EUR-J-APPL-MATH"]			= "http://journals.cambridge.org/action/displayJournal?jid=EJM"
    Journal_URL["j-EUR-J-INORG-CHEM"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1099-0682c"
    Journal_URL["j-EUR-J-MECH-A-SOLIDS"]		= "http://www.sciencedirect.com/science/journal/09977538"
    Journal_URL["j-EUR-J-OPER-RES"]			= "http://www.sciencedirect.com/science/journal/03772217"
    Journal_URL["j-EUR-J-PHYS"]				= "http://iopscience.iop.org/0143-0807/"
    Journal_URL["j-EUR-PHYS-J-A"]			= "http://www.springerlink.com/content/1434-6001"
    Journal_URL["j-EUR-PHYS-J-B"]			= "http://link.springer.com/journal/10051"
    Journal_URL["j-EUR-PHYS-J-C"]			= "http://www.springerlink.com/content/1434-6044"
    Journal_URL["j-EUR-PHYS-J-D"]			= "http://link.springer.com/journal/10053"
    Journal_URL["j-EUR-PHYS-J-E"]			= "http://www.springerlink.com/content/1292-8941"
    Journal_URL["j-EUR-PHYS-J-H"]			= "http://www.springerlink.com/content/2102-6459"
    Journal_URL["j-EUR-SCI-EDIT"]			= "http://europeanscienceediting.eu/issues"
    Journal_URL["j-EUROPHYS-LETT"]			= "http://iopscience.iop.org/0295-5075"
    Journal_URL["j-EUR-PHYS-J-PLUS"]			= "http://link.springer.com/journal/13360"
    Journal_URL["j-EUR-PHYS-J-SPEC-TOP"]		= "http://link.springer.com/journal/11734"
    Journal_URL["j-EUR-REV-HIST"]			= "http://www.tandfonline.com/loi/cerh20"
    Journal_URL["j-EURASIP-J-ADV-SIGNAL-PROCESS"]	= "http://asp.eurasipjournals.springeropen.com/"

    Journal_URL["j-EUROPHYS-NEWS"]			= "http://www.europhysicsnews.org"
    Journal_URL["j-EVOL-INTEL"]				= "http://link.springer.com/journal/12065"
    Journal_URL["j-EXP-MATH"]				= "http://www.tandfonline.com/loi/uexm20"
    Journal_URL["j-EXP-NEUROL"]				= "http://www.sciencedirect.com/science/journal/00144886"
    Journal_URL["j-EXP-PARASITOL"]			= "http://www.sciencedirect.com/science/journal/00144894"
    Journal_URL["j-EXPEDITION"]				= "http://www.penn.museum/sites/expedition/"
    Journal_URL["j-EXPERT-SYST-APPL"]			= "http://www.sciencedirect.com/science/journal/09574174"
    Journal_URL["j-EXPO-MATH"]				= "http://www.sciencedirect.com/science/journal/07230869"
    Journal_URL["j-EYE"]				= "http://www.nature.com/eye/archive/"
    Journal_URL["j-FAR-EAST-J-THEOR-STAT"]		= "http://www.pphmj.com/journals/fjts.htm"
    Journal_URL["j-FED-REGIST"]				= "https://www.archives.gov/federal-register"
    Journal_URL["j-FERROELECTRICS"]			= "http://www.tandfonline.com/loi/gfer20"
    Journal_URL["j-FIB-QUART"]				= "http://www.fq.math.ca/"
    Journal_URL["j-FINITE-ELEMENTS-ANAL-DESIGN"]	= "http://www.sciencedirect.com/journal/finite-elements-in-analysis-and-design"
    Journal_URL["j-FINITE-FIELDS-APPL"]			= "http://www.sciencedirect.com/science/journal/10715797"
    Journal_URL["j-FISH-AQUACULT-J"]			= "https://www.longdom.org/fisheries-and-aquaculture-journal/archive.html"
    Journal_URL["j-FISH-BULL"]				= "https://spo.nmfs.noaa.gov/fb.htm"
    Journal_URL["j-FISH-FISH"]				= "https://onlinelibrary.wiley.com/journal/14672979"
    Journal_URL["j-FISH-PHYSIOL-BIOCHEM"]		= "https://www.springer.com/journal/10695"
    Journal_URL["j-FISH-OCEANOGR"]			= "https://onlinelibrary.wiley.com/journal/13652419"
    Journal_URL["j-FISH-RES"]				= "https://www.sciencedirect.com/journal/fisheries-research"
    Journal_URL["j-FISHERIES"]				= "https://www.tandfonline.com/loi/ufsh20"
    Journal_URL["j-FISHES"]				= "https://www.mdpi.com/journal/fishes"
    Journal_URL["j-FIZ-SZ"]				= "http://www.kfki.hu/fszemle/archivum"
    Journal_URL["j-FLUCT-NOISE-LETT"]			= "http://www.worldscientific.com/loi/fnl"
    Journal_URL["j-FOREIGN-AFFAIRS"]			= "http://www.jstor.org/journals/00157120.html http://www.foreignaffairs.org/backissues/"
    Journal_URL["j-FORM-ASP-COMPUT"]			= "http://link.springer.com/journal/165"
    Journal_URL["j-FORM-METHODS-SYST-DES"]		= "https://dl.acm.org/loi/fmsd"
    Journal_URL["j-FORTRAN-FORUM"]			= "http://portal.acm.org/toc.cfm?id=J286"
    Journal_URL["j-FORTSCHR-PHYS"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1521-3978"
    Journal_URL["j-FORTUNE"]				= "http://archive.fortune.com/magazines/fortune/fortune_archive/"
    Journal_URL["j-FOUND-CHEM"]				= "http://link.springer.com/journal/10698"
    Journal_URL["j-FOUND-COMPUT-MATH"]			= "http://link.springer.com/journal/10208"
    Journal_URL["j-FOUND-PHYS"]				= "http://link.springer.com/journal/10701"
    Journal_URL["j-FOUND-PHYS-LETT"]			= "http://link.springer.com/journal/10702"
    Journal_URL["j-FOUND-SCI"]				= "http://link.springer.com/journal/10699"
    Journal_URL["j-FRACTALS"]				= "http://www.worldscientific.com/loi/fractals"
    Journal_URL["j-FREE-INQUIRY"]			= "https://secularhumanism.org/archive/"
    Journal_URL["j-FRONTIERS-MAR-SCI"]			= "https://www.frontiersin.org/journals/655"
    Journal_URL["j-FUNCT-ANAL-APPL"]			= "http://link.springer.com/journal/10688"
    Journal_URL["j-FUNCT-SPACES"]			= "https://www.hindawi.com/journals/jfs/"
    Journal_URL["j-FUND-INFO"]				= "http://content.iospress.com/journals/fundamenta-informaticae"
    Journal_URL["j-FUND-SCI"]				= ""
    Journal_URL["j-FUNKCIAL-EKVAC"]			= "http://www.math.kobe-u.ac.jp/~fe/"
    Journal_URL["j-FUSION-SCI-TECHNOL"]			= "http://www.ans.org/pubs/journals/fst/"
    Journal_URL["j-FUT-GEN-COMP-SYS"]			= "http://www.sciencedirect.com/science/journal/0167739X"
    Journal_URL["j-FUTURE-INTERNET"]			= "https://www.mdpi.com/journal/futureinternet"
    Journal_URL["j-FUTURES"]				= "http://www.sciencedirect.com/science/journal/00163287"
    Journal_URL["j-FUZZY-SETS-SYSTEMS"]			= "http://www.sciencedirect.com/science/journal/01650114"
    Journal_URL["j-G-FIS"]				= "http://www.sif.it/riviste/gdf"
    Journal_URL["j-GAMES"]				= "https://www.mdpi.com/journal/games"
    Journal_URL["j-GEN"]				= "http://www.genetics.org/content/by/year"
    Journal_URL["j-GEN-RELATIVITY-GRAV"]		= "http://link.springer.com/journal/10714"
    Journal_URL["j-GENOME-BIOL"]			= "http://genomebiology.biomedcentral.com/articles"
    Journal_URL["j-GENOME-RES"]				= "http://genome.cshlp.org/content/by/year"
    Journal_URL["j-GEODERMA"]				= "http://www.sciencedirect.com/science/journal/00167061"
    Journal_URL["j-GEOPHYS-J-INT"]			= "http://gji.oxfordjournals.org/content/by/year"
    Journal_URL["j-GEOPHYS-J-R-ASTRON-SOC"]		= "http://gji.oxfordjournals.org/"
    Journal_URL["j-GEOPHYSICS"]				= "http://library.seg.org/loi/gpysa7"
    Journal_URL["j-GEOSCI-MODEL-DEV"]			= "http://www.geosci-model-dev.net"
    Journal_URL["j-GER-STUD-REV"]			= "http://www.jstor.org/journal/germstudrevi"
    Journal_URL["j-GLOB-ECOL-BIOGEOGRAPHY"]		= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1466-8238"
    Journal_URL["j-GRAPH-MODELS"]			= "http://www.sciencedirect.com/science/journal/15240703"
    Journal_URL["j-GRAPH-MODELS-IMAGE-PROC"]		= "http://www.sciencedirect.com/science/journal/10773169"
    Journal_URL["j-GROUPS-COMPLEX-CRYPTOL"]		= "http://www.degruyter.com/view/j/gcc"
    Journal_URL["j-GSA-TODAY"]				= "http://www.geosociety.org/gsatoday/archive/"
    Journal_URL["j-HARPERS-MAG"]			= "http://harpers.org/archive/"
    Journal_URL["j-HELV-CHIM-ACTA"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1522-2675"
    Journal_URL["j-HELV-PHYS-ACTA"]			= "http://retro.seals.ch/digbib/vollist?UID=hpa-001"
    Journal_URL["j-HEREDITY"]				= "https://www.nature.com/hdy/"
    Journal_URL["j-HEXAGON"]				= "https://www.alphachisigma.org/about-us/hexagon-and-news"
    Journal_URL["j-HEYTHROP-J"]				= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1468-2265"
    Journal_URL["j-HIGH-PRESSURE-RES"]			= "http://www.tandfonline.com/loi/ghpr20"
    Journal_URL["j-HIGHER-ORDER-SYMB-COMPUT"]		= "http://link.springer.com/journal/10990"
    Journal_URL["j-HIST-GEO-SPACE-SCI"]			= "https://www.hist-geo-space-sci.net/volumes.html"
    Journal_URL["j-HIST-MATH"]				= "http://www.sciencedirect.com/science/journal/03150860"
    Journal_URL["j-HIST-REC-AUSTRAL-SCI"]		= "http://www.publish.csiro.au/nid/108/aid/2411.htm"
    Journal_URL["j-HIST-SCI"]				= "http://historyofscience.jp/HS/"
    Journal_URL["j-HIST-SCI-2"]				= "http://hssj.info/"
    Journal_URL["j-HIST-SCI-UK"]			= "http://hos.sagepub.com/content/by/year"
    Journal_URL["j-HIST-STUD-NAT-SCI"]			= "http://www.jstor.org/journals/19391811.html"
    Journal_URL["j-HIST-STUD-PHYS-BIOL-SCI"]		= "http://www.jstor.org/journals/08909997.html"
    Journal_URL["j-HIST-STUD-PHYS-SCI"]			= "http://www.jstor.org/journals/00732672.html"
    Journal_URL["j-HIST-TECHNOL"]			= "http://www.tandfonline.com/loi/ghat20"
    Journal_URL["j-HISTORIAN"]				= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1540-6563"
    Journal_URL["j-HOKKAIDO-MATH-J"]			= "http://projecteuclid.org/hokmj"
    Journal_URL["j-HOOVER-DIG"]				= "http://www.hoover.org/publications/hoover-digest/by-date"
    Journal_URL["j-HOPOS"]				= "http://www.jstor.org/journals/21525188.html"
    Journal_URL["j-HOUSTON-J-MATH"]			= "https://www.math.uh.edu/~hjm/"
    Journal_URL["j-HYDROBIOLOGIA"]			= "http://link.springer.com/journal/10750"
    Journal_URL["j-IAEA-BULL"]				= "https://www.iaea.org/publications/magazines/bulletin"
    Journal_URL["j-IBM-JRD"]				= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=5288520"
    Journal_URL["j-ICARUS-IJSSS"]			= "http://www.sciencedirect.com/science/journal/00191035"
    Journal_URL["j-ICES-J-MAR-SCI"]			= "https://academic.oup.com/icesjms"
    Journal_URL["j-IEEE-ACCESS"]			= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=6287639"
    Journal_URL["j-IEEE-ACM-TASLP"]			= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=6570655"
    Journal_URL["j-IEEE-ANN-HIST-COMPUT"]		= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=85"
    Journal_URL["j-IEEE-ANTENNAS-WIREL-PROPAG-LETT"]	= "http://ieeexplore.ieee.org/servlet/opac?punumber=7727"
    Journal_URL["j-IEEE-ASSP-MAG"]			= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=53"
    Journal_URL["j-IEEE-CGA"]				= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=38"
    Journal_URL["j-IEEE-COMMUN-LET"]			= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=4234"
    Journal_URL["j-IEEE-COMM-MAG"]			= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=35"
    Journal_URL["j-IEEE-COMPUT-ARCHIT-LETT"]		= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=10208"
    Journal_URL["j-IEEE-COMPUT-SCI-ENG"]		= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=99"
    Journal_URL["j-IEEE-ENG-MED-BIOL-MAG"]		= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=51"
    Journal_URL["j-IEEE-INTELL-SYST"]			= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=9670"
    Journal_URL["j-IEEE-INTERNET-COMPUT"]		= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=4236"
    Journal_URL["j-IEEE-MICRO"]				= "https://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=40"
    Journal_URL["j-IEEE-MICROW-WIREL-COMPON-LETT"]	= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=7260"
    Journal_URL["j-IEEE-MULTIMEDIA"]			= "http://www.computer.org/multimedia/"
    # Journal_URL["j-IEEE-SEC-PRIV"]			= "http://www.computer.org/portal/web/csdl/magazines/security"
    Journal_URL["j-IEEE-SEC-PRIV"]			= "https://publications.computer.org/security-and-privacy/"
    Journal_URL["j-IEEE-SIGNAL-PROCESS-LETT"]		= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=97"
    Journal_URL["j-IEEE-SOFTWARE"]			= "https://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=52"
    Journal_URL["j-IEEE-SPECTRUM"]			= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=6"
    Journal_URL["j-IEEE-TRANS-ACOUST-SPEECH"]		= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=29"
    Journal_URL["j-IEEE-TRANS-ANTENNAS-PROPAG"]		= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=8"
    Journal_URL["j-IEEE-TRANS-AUDIO-ELECTROACOUST"]	= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=8337"
    Journal_URL["j-IEEE-TRANS-AUTOMAT-CONTR"]		= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=9"
    Journal_URL["j-IEEE-TRANS-BIG-DATA"]		= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=6687317"
    Journal_URL["j-IEEE-TRANS-BIOMED-ENG"]		= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=10"
    Journal_URL["j-IEEE-TRANS-CAD-ICS"]			= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=43"
    Journal_URL["j-IEEE-TRANS-CIRCUITS-SYST-1"]		= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=8919"
    Journal_URL["j-IEEE-TRANS-CIRCUITS-SYST-2"]		= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=82"
    Journal_URL["j-IEEE-TRANS-CIRCUITS-SYST-II-EXPRESS-BRIEFS"] = "https://ieeexplore.ieee.org/xpl/issues?punumber=8920"
    Journal_URL["j-IEEE-TRANS-CIRCUITS-SYST-VIDEO-TECH"]	= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=76"
    Journal_URL["j-IEEE-TRANS-COMMUN-TECHNOL"]		= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=4547467"
    Journal_URL["j-IEEE-TRANS-COMPUT"]			= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=12"
    Journal_URL["j-IEEE-TRANS-EMERG-TOP-COMPUT"]	= "https://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=6245516"
    Journal_URL["j-IEEE-TRANS-ENG-WRIT-SPEECH"]		= "https://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=4322293"
    Journal_URL["j-IEEE-TRANS-GEOSCI-REMOTE-SENSING"]	= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=36"
    Journal_URL["j-IEEE-TRANS-IMAGE-PROCESS"]		= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=83"
    Journal_URL["j-IEEE-TRANS-INF-THEORY"]		= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=18"
    Journal_URL["j-IEEE-TRANS-INSTRUM-MEAS"]		= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=19"
    Journal_URL["j-IEEE-TRANS-KNOWL-DATA-ENG"]		= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=69"
    Journal_URL["j-IEEE-TRANS-MAGNETICS"]		= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=20"
    Journal_URL["j-IEEE-TRANS-MED-IMAG"]		= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=42"
    Journal_URL["j-IEEE-TRANS-MICROWAVE-THEORY-TECH"]	= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=22"
    Journal_URL["j-IEEE-TRANS-NETWORKING"]		= "http://portal.acm.org/browse_dl.cfm?idx=J771"
    Journal_URL["j-IEEE-TRANS-NEURAL-NETW"]		= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=72"
    Journal_URL["j-IEEE-TRANS-NUCL-SCI"]		= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=23"
    Journal_URL["j-IEEE-TRANS-PAR-DIST-SYS"]		= "https://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=71"
    Journal_URL["j-IEEE-TRANS-PATT-ANAL-MACH-INTEL"]	= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=34"
    Journal_URL["j-IEEE-TRANS-PLASMA-SCI"]		= "https://ieeexplore.ieee.org/xpl/issues?punumber=27"
    Journal_URL["j-IEEE-TRANS-PROF-COMMUN"]		= "https://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=47"
    Journal_URL["j-IEEE-TRANS-SIG-PROC"]		= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=78"
    Journal_URL["j-IEEE-TRANS-SOFTW-ENG"]		= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=32"
    Journal_URL["j-IEEE-TRANS-VEH-TECHNOL"]		= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=25"
    Journal_URL["j-IEEE-TRANS-VIS-COMPUT-GRAPH"]	= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=2945"
    Journal_URL["j-IEEE-TRANS-WIREL-COMMUN"]		= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=7693"
    Journal_URL["j-IJHPCA"]				= "http://hpc.sagepub.com/content/by/year"
    Journal_URL["j-IJQC"]				= "http://www.interscience.wiley.com/jpages/0020-7608/"
    Journal_URL["j-IJQC-QC-SYMP"]			= "http://www.interscience.wiley.com/jpages/0020-7608/"
    Journal_URL["j-IJQC-SYMP"]				= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1097-461X"
    Journal_URL["j-IJSA"]				= "http://hpc.sagepub.com/content/by/year"
    Journal_URL["j-IJSAHPC"]				= "http://hpc.sagepub.com/content/by/year"
    Journal_URL["j-IMA-J-APPL-MATH"]			= "http://imamat.oxfordjournals.org/content/by/year"
    Journal_URL["j-IMA-J-NUMER-ANAL"]			= "http://imajna.oxfordjournals.org/content/by/year"
    Journal_URL["j-IMWUT"]				= "http://dl.acm.org/citation.cfm?id=J1566"
    Journal_URL["j-INC-STAT"]				= "http://www.jstor.org/journals/14669404.html"
    Journal_URL["j-INDAG-MATH-PROC"]			= "http://www.sciencedirect.com/science/journal/13857258"
    Journal_URL["j-INDIAN-J-HIST-SCI"]			= "https://insaindia.res.in/ijhs.php"
    Journal_URL["j-INDIAN-J-MATH"]			= "http://www.amsallahabad.org/ijm.html"
    Journal_URL["j-INDIANA-U-MATH"]			= "http://www.iumj.indiana.edu/"
    Journal_URL["j-INF-COMPUT"]				= "http://www.sciencedirect.com/science/journal/08905401"
    Journal_URL["j-INF-CONTROL"]			= "http://www.sciencedirect.com/science/journal/00199958"
    Journal_URL["j-INFO-PROC-LETT"]			= "http://www.sciencedirect.com/science/journal/00200190"
    Journal_URL["j-INFO-PROC-MAN"]			= "http://www.sciencedirect.com/science/journal/03064573"
    Journal_URL["j-INFO-SCI"]				= "http://www.sciencedirect.com/science/journal/00200255"
    Journal_URL["j-INFO-SEC-TECH-REP"]			= "https://www.sciencedirect.com/journal/information-security-technical-report"
    Journal_URL["j-INFORMATIK-SPEKTRUM"]		= "http://link.springer.com/journal/287"
    Journal_URL["j-INFORMS-J-COMPUT"]			= "http://pubsonline.informs.org/journal/ijoc"
    Journal_URL["j-INORG-CHEM"]				= "http://pubs.acs.org/loi/inocaj"
    Journal_URL["j-INT-AFF"]				= "http://www.jstor.org/journals/00205850.html"
    Journal_URL["j-INT-COMMUN-HEAT-MASS-TRANSF"]	= "http://www.sciencedirect.com/science/journal/07351933"
    Journal_URL["j-INT-ECON-REV"]			= "http://www.jstor.org/journal/inteeconrevi"
    Journal_URL["j-INT-EQN-OP-TH"]			= "http://link.springer.com/journal/20"
    Journal_URL["j-INT-J-APPL-CRYPTOGR"]		= "http://www.inderscienceonline.com/loi/ijact"
    Journal_URL["j-INT-J-APPL-ELECTROMAGN-MATER"]	= "http://www.iospress.nl/journal/international-journal-of-applied-electromagnetics-and-mechanics/"
    Journal_URL["j-INT-J-APPL-MATH"]			= "http://www.diogenes.bg/ijam/"
    Journal_URL["j-INT-J-APPL-MATH-STAT"]		= "http://www.ceser.in/ijamas.html"
    Journal_URL["j-INT-J-ASTROBIOL"]			= "http://journals.cambridge.org/action/displayJournal?jid=IJA"
    Journal_URL["j-INT-J-CIRCUIT-THEORY-APPL"]		= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1097-007X"
    Journal_URL["j-INT-J-COMP-PROC-LANG"]		= "http://www.worldscientific.com/worldscinet/ijcpol"
    Journal_URL["j-INT-J-COMPUT-APPL"]			= "https://www.tandfonline.com/loi/tjca20"
    Journal_URL["j-INT-J-COMPUT-GEOM-APPL"]		= "http://www.worldscientific.com/loi/ijcga"
    Journal_URL["j-INT-J-COMPUT-INF-SCI"]		= "http://link.springer.com/journal/10766"
    Journal_URL["j-INT-J-COMPUT-MATH"]			= "http://www.tandfonline.com/loi/gcom20"
    Journal_URL["j-INT-J-COMPUT-SYST-SCI-ENG"]		= "http://www.crlpublishing.co.uk/csse"
    Journal_URL["j-INT-J-COMPUT-METHODS-ENG-SCI-MECH"]	= "https://www.tandfonline.com/loi/ucme20"
    Journal_URL["j-INT-J-CONTROL"]			= "http://www.tandfonline.com/loi/tcon20"
    Journal_URL["j-INT-J-DAMAGE-MECH"]			= "https://journals.sagepub.com/loi/ijd"
    Journal_URL["j-INT-J-ENG-SCI"]			= "http://www.sciencedirect.com/science/journal/00207225"
    Journal_URL["j-INT-J-EPIDEMIOL"]			= "http://ije.oxfordjournals.org/content/by/year"
    Journal_URL["j-INT-J-FOUND-COMP-SCI"]		= "http://www.worldscientific.com/loi/ijfcs"
    Journal_URL["j-INT-J-FRACTURE"]			= "http://link.springer.com/journal/10704"
    Journal_URL["j-INT-J-GEN-SYST"]			= "https://www.tandfonline.com/loi/ggen20"
    Journal_URL["j-INT-J-HEALTH-SERV"]			= "https://journals.sagepub.com/loi/joha"
    Journal_URL["j-INT-J-HEAT-MASS-TRANSFER"]		= "http://www.sciencedirect.com/science/journal/00179310"
    Journal_URL["j-INT-J-HIGH-SPEED-COMPUTING"]		= "http://www.worldscientific.com/worldscinet/ijhsc"
    Journal_URL["j-INT-J-IMAGE-GRAPHICS"]		= "http://www.worldscientific.com/worldscinet/ijig"
    Journal_URL["j-INT-J-INFO-SEC"]			= "http://link.springer.com/journal/10207"
    Journal_URL["j-INT-J-MATH"]				= "http://www.worldscientific.com/worldscinet/ijm"
    Journal_URL["j-INT-J-MATH-EDU-SCI-TECH"]		= "http://www.tandfonline.com/loi/tmes20"
    Journal_URL["j-INT-J-MATH-MATH-SCI"]		= "https://www.hindawi.com/journals/ijmms/"
    Journal_URL["j-INT-J-MECH-SCI"]			= "http://www.sciencedirect.com/science/journal/00207403"
    Journal_URL["j-INT-J-MOD-PHYS-A"]			= "http://www.worldscientific.com/worldscinet/ijmpa"
    Journal_URL["j-INT-J-MOD-PHYS-B"]			= "http://www.worldscientific.com/worldscinet/ijmpb"
    Journal_URL["j-INT-J-MOD-PHYS-C"]			= "http://www.worldscientific.com/loi/ijmpc"
    Journal_URL["j-INT-J-MOD-PHYS-D"]			= "http://www.worldscientific.com/loi/ijmpd"
    Journal_URL["j-INT-J-NUM-METH-FLUIDS"]		= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1097-0363"
    Journal_URL["j-INT-J-NUMBER-THEORY"]		= "http://www.worldscientific.com/worldscinet/ijnt"
    Journal_URL["j-INT-J-NUMER-ANAL-METHODS-GEOMECH"]	= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1096-9853"
    Journal_URL["j-INT-J-NUMER-METHODS-BIOMED-ENG"]	= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)2040-7947"
    Journal_URL["j-INT-J-NUMER-METHODS-ENG"]		= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1097-0207"
    Journal_URL["j-INT-J-NUMER-METHODS-FLUIDS"]		= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1097-0363"
    Journal_URL["j-INT-J-PAR-EMER-DIST-SYS"]		= "http://www.tandfonline.com/loi/gpaa20"
    Journal_URL["j-INT-J-PARALLEL-PROG"]		= "http://link.springer.com/journal/10766"
    Journal_URL["j-INT-J-PLAST"]			= "http://www.sciencedirect.com/science/journal/07496419"
    Journal_URL["j-INT-J-PURE-APPL-MATH"]		= "http://ijpam.eu/"
    Journal_URL["j-INT-J-RADIAT-ONCOL-BIOL-PHYS"]	= "http://www.sciencedirect.com/science/journal/03603016"
    Journal_URL["j-INT-J-ROCK-MECH-MINING-SCI-GEOMECH-ABS"] = "http://www.sciencedirect.com/science/journal/01489062"
    Journal_URL["j-INT-J-SCI-ENG-RESEARCH"]		= "http://www.ijser.org/"
    Journal_URL["j-INT-J-SCI-MATH-EDUC"]		= "http://link.springer.com/journal/10763"
    Journal_URL["j-INT-J-SOFTW-TOOLS-TECHNOL-TRANSFER"]	= "http://link.springer.com/journal/10009"
    Journal_URL["j-INT-J-SOLIDS-STRUCT"]		= "http://www.sciencedirect.com/science/journal/00207683"
    Journal_URL["j-INT-J-STAT-PROBAB"]			= "http://www.ccsenet.org/journal/index.php/ijsp/issue/archive"
    Journal_URL["j-INT-J-SYST-SCI"]			= "http://www.tandfonline.com/loi/tsys20"
    Journal_URL["j-INT-J-THEOR-PHYS"]			= "http://link.springer.com/journal/10773"
    Journal_URL["j-INT-J-THERMOPHYS"]			= "http://www.springerlink.com/content/0195-928X; http://link.springer.com/journal/10765"
    Journal_URL["j-INT-J-WAVELETS-MULTIRESOLUT-INF-PROCESS"] = "https://www.worldscientific.com/worldscinet/ijwmip"
    Journal_URL["j-INT-PHILOS-Q"]			= "http://www.pdcnet.org/ipq/International-Philosophical-Quarterly"
    Journal_URL["j-INT-REV-VICTIM"]			= "https://journals.sagepub.com/loi/irva"
    Journal_URL["j-INT-SECUR"]				= "http://muse.jhu.edu/journals/ins/; http://www.jstor.org/journals/01622889.html"
    Journal_URL["j-INT-STAT-REV"]			= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1751-5823; http://www.jstor.org/journals/03067734.html"
    Journal_URL["j-INT-STAT-REV"]			= "http://www.jstor.org/journals/03067734.html"
    Journal_URL["j-INT-STUD-PHILOS-SCI"]		= "https://www.tandfonline.com/loi/cisp20"
    Journal_URL["j-INT-TRANS-OPL-RES"]			= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1475-3995"
    Journal_URL["j-INTELL-NATL-SECUR"]			= "http://www.tandfonline.com/loi/fint20"
    Journal_URL["j-INTEGERS"]				= "http://www.degruyter.com/view/j/integ"
    Journal_URL["j-INTEGR-ENVIRON-ASSES-MANAG"]		= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1551-3793"
    Journal_URL["j-INTEGRAL-TRANSFORMS-SPEC-FUNCT"]	= "http://www.tandfonline.com/loi/gitr20"
    Journal_URL["j-INTERDISCIP-INFORM-SCI"]		= "https://www.jstage.jst.go.jp/browse/iis"
    Journal_URL["j-INTERFACE-SCI"]			= "http://link.springer.com/journal/10793"
    Journal_URL["j-INTERNET-HIST"]			= "https://www.tandfonline.com/loi/rint20"
    Journal_URL["j-INTERNET-MATH"]			= "http://projecteuclid.org/info/euclid.im"
    Journal_URL["j-INVENT-MATH"]			= "http://link.springer.com/journal/222"
    Journal_URL["j-INVERSE-PROBL-IMAGING"]		= "http://www.aimsciences.org/journals/homeAllIssue.jsp?journalID=11"
    Journal_URL["j-INVERSE-PROBL-SCI-ENG"]		= "http://www.tandfonline.com/loi/gipe20"
    Journal_URL["j-INVERSE-PROBLEMS"]			= "http://iopscience.iop.org/0266-5611/"
    Journal_URL["j-IR-J-PSYCHOL-MED"]			= "http://journals.cambridge.org/action/displayJournal?jid=IPM"
    Journal_URL["j-IRE-TRANS-ELEC-COMPUT"]		= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=5407885"
    Journal_URL["j-IRE-TRANS-ENG-WRIT-SPEECH"]		= "https://ieeexplore.ieee.org/servlet/opac?punumber=4322631"
    Journal_URL["j-IRE-TRANS-INF-THEORY"]		= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=4547527"
    Journal_URL["j-IRISH-MATH-SOC-BULL"]		= "https://www.maths.tcd.ie/pub/ims/bulletin/"
    Journal_URL["j-ISIS"]				= "http://www.jstor.org/journal/isis"
    Journal_URL["j-ISRAEL-J-CHEM"]			= "https://onlinelibrary.wiley.com/journal/18695868"
    Journal_URL["j-ISRAEL-J-MATH"]			= "http://link.springer.com/journal/11856"
    Journal_URL["j-ISSUES-SCI-TECHNOL"]			= "http://www.issues.org/backissues.html"
    Journal_URL["j-IT-PRO"]				= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=6294"
    Journal_URL["j-ITAL-J-PURE-APPL-MATH"]		= "http://ijpam.uniud.it/journal/"
    Journal_URL["j-J-ACCOUNTANCY"]			= "http://www.journalofaccountancy.com/"
    Journal_URL["j-J-ACM"]				= "http://portal.acm.org/browse_dl.cfm?idx=J401"
    Journal_URL["j-J-ACOUST-SOC-AM"]			= "http://scitation.aip.org/content/asa/journal/jasa"
    Journal_URL["j-J-AEROSOL-SCI"]			= "http://www.sciencedirect.com/science/journal/00218502"
    Journal_URL["j-J-AGRIC-SCI"]			= "https://www.cambridge.org/core/journals/journal-of-agricultural-science"
    Journal_URL["j-J-ALG"]				= "http://www.sciencedirect.com/science/journal/01966774"
    Journal_URL["j-J-ALGEBRA"]				= "http://www.sciencedirect.com/science/journal/00218693"
    Journal_URL["j-J-AM-CERAM-SOC"]			= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1551-2916"
    Journal_URL["j-J-AM-HIST"]				= "http://jah.oxfordjournals.org/"
    Journal_URL["j-J-AM-SOC-INF-SCI"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)2330-1643"
    Journal_URL["j-J-AM-SOC-INF-SCI-TECHNOL"]		= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1532-2890"
    Journal_URL["j-J-AM-STAT-ASSOC"]			= "http://www.tandfonline.com/loi/uasa20"
    Journal_URL["j-J-ANAL-MATH"]			= "http://link.springer.com/journal/11854"
    Journal_URL["j-J-APPL-ECONOMETRICS"]		= "https://onlinelibrary.wiley.com/journal/10991255; https://www.jstor.org/journal/japplecon"
    Journal_URL["j-J-APPL-MATH"]			= "http://www.hindawi.com/journals/jam/"
    Journal_URL["j-J-APPL-MATH-MECH"]			= "http://www.sciencedirect.com/science/journal/00218928"
    Journal_URL["j-J-APPL-MECH"]			= "http://appliedmechanics.asmedigitalcollection.asme.org/issues.aspx"
    Journal_URL["j-J-APPL-MECH-TECH-PHYS"]		= "http://link.springer.com/journal/10808"
    ## Journal_URL["j-J-APPL-PHYS"]			= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=4915369"
    Journal_URL["j-J-APPL-PHYS"]			= "http://aip.scitation.org/toc/jap/current"
    Journal_URL["j-J-APPL-PROBAB"]			= "http://www.jstor.org/journals/00219002.html"
    Journal_URL["j-J-APPL-PROBAB"]			= "http://www.jstor.org/journals/00219002.html; http://projecteuclid.org/euclid.jap/"
    Journal_URL["j-J-APPL-STAT"]			= "http://www.tandfonline.com/loi/cjas20"
    Journal_URL["j-J-APPROX-THEORY"]			= "http://www.sciencedirect.com/science/journal/00219045"
    Journal_URL["j-J-AQUACULT-RES-DEV"]			= "https://www.walshmedicalmedia.com/aquaculture-research-development/archive.html"
    Journal_URL["j-J-ASSOC-INF-SCI-TECHNOL"]		= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)2330-1643"
    Journal_URL["j-J-ASTROPHYS-ASTRON"]			= "http://www.springerlink.com/content/0250-6335"
    Journal_URL["j-J-ATMOS-SCI"]			= "http://journals.ametsoc.org/toc/atsc/current"
    Journal_URL["j-J-ATMOS-SOL-TERR-PHYS"]		= "http://www.sciencedirect.com/science/journal/13646826"
    journal_URL["j-J-AUSTRAL-MATH-SOC"]			= ""
    journal_URL["j-J-AUSTRAL-MATH-SOC-SER-A"]		= "http://journals.cambridge.org/action/displayJournal?jid=JAZ"
    journal_URL["j-J-AUSTRAL-MATH-SOC-SER-B"]		= "http://journals.cambridge.org/action/displayJournal?jid=ANZ"
    Journal_URL["j-J-AUTOM-REASON"]			= "http://link.springer.com/journal/10817"
    Journal_URL["j-J-BIOINF-COMPUT-BIOL"]		= "http://www.worldscientific.com/loi/jbcb"
    Journal_URL["j-J-BIOMECH"]				= "http://www.sciencedirect.com/science/journal/00219290"
    Journal_URL["j-J-BIOMED-MATER-RES"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1552-4965"
    Journal_URL["j-J-BR-ASTRON-ASSOC"]			= "http://www.britastro.org/journal"
    Journal_URL["j-J-BR-INTERPLANET-SOC"]		= "https://www.jbis.org.uk/"
    Journal_URL["j-J-BUS-ECON-STAT"]			= "https://amstat.tandfonline.com/loi/ubes20"
    Journal_URL["j-J-CELL-BIOL"]			= "http://jcb.rupress.org/content/by/year"
    Journal_URL["j-J-CELL-COMP-PHYSIOL"]		= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1097-4652"
    Journal_URL["j-J-CEREB-BLOOD-FLOW-METAB"]		= "http://jcb.sagepub.com/content/by/year"
    Journal_URL["j-J-CHEM-EDUC"]			= "http://pubs.acs.org/journal/jceda8"
    Journal_URL["j-J-CHEM-INFO-COMP-SCI"]		= "http://pubs.acs.org/loi/jcisd8"
    Journal_URL["j-J-CHEM-INFO-MODEL"]			= "http://pubs.acs.org/loi/jcisd8"
    Journal_URL["j-J-CHEM-PHYS"]			= "http://scitation.aip.org/content/aip/journal/jcp/browse"
    Journal_URL["j-J-CHEM-SOC"]				= "http://pubs.rsc.org/en/journals/journalissues/jr"
    Journal_URL["j-J-CHEM-SOC-FARADAY-TRANS"]		= "http://pubs.rsc.org/en/journals/journalissues/ft"
    Journal_URL["j-J-CHEM-SOC-FARADAY-TRANS-2"]		= "http://pubs.rsc.org/en/journals/journalissues/f2"
    Journal_URL["j-J-CHEM-SOC-TRANS"]			= "http://pubs.rsc.org/en/journals/journalissues/ct"
    Journal_URL["j-J-CHEM-THEORY-COMPUT"]		= "http://pubs.acs.org/loi/jctcce"
    Journal_URL["j-J-CHEMOM"]				= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1099-128X"
    Journal_URL["j-J-CHROMATOGR-A"]			= "http://www.sciencedirect.com/science/journal/00219673"
    Journal_URL["j-J-CLIN-INVEST"]			= "http://www.jci.org/archive"
    Journal_URL["j-J-CLIN-PATHOL"]			= "http://jcp.bmj.com/content/by/year"
    Journal_URL["j-J-COLD-REG-ENG"]			= "http://ascelibrary.org/journal/jcrgei"
    Journal_URL["j-J-COLD-WAR-STUD"]			= "http://muse.jhu.edu/journals/43"
    Journal_URL["j-J-COLL-SCI-TEACH"]			= "http://www.jstor.org/action/showPublication?journalCode=jcollscieteac"
    Journal_URL["j-J-COMB-OPTIM"]			= "http://link.springer.com/journal/10878"
    Journal_URL["j-J-COMP-PHYSIOL-A"]			= "https://www.springer.com/journal/359"
    Journal_URL["j-J-COMB-THEORY"]			= "http://www.sciencedirect.com/science/journal/00219800"
    Journal_URL["j-J-COMB-THEORY-A"]			= "http://www.sciencedirect.com/science/journal/00973165"
    Journal_URL["j-J-COMP-SECUR"]			= "http://content.iospress.com/journals/journal-of-computer-security"
    Journal_URL["j-J-COMP-SYS-SCI"]			= "http://www.sciencedirect.com/science/journal/00220000"
    Journal_URL["j-J-COMPLEX-NETWORKS"]			= "http://www.comnet.oxfordjournals.org"
    Journal_URL["j-J-COMPLEXITY"]			= "http://www.sciencedirect.com/science/journal/0885064X"
    Journal_URL["j-J-COMPOS-MATER"]			= "http://jcm.sagepub.com/"
    Journal_URL["j-J-COMPUT-AIDED-MATER-DES"]		= "http://link.springer.com/journal/10820"
    Journal_URL["j-J-COMPUT-APPL-MATH"]			= "http://www.sciencedirect.com/science/journal/03770427"
    Journal_URL["j-J-COMPUT-BIOL"]			= "http://online.liebertpub.com/cmb"
    Journal_URL["j-J-COMPUT-CHEM"]			= "http://www.interscience.wiley.com/jpages/0192-8651"
    Journal_URL["j-J-COMPUT-FINANCE"]			= "https://www.risk.net/journal-of-computational-finance"
    Journal_URL["j-J-COMPUT-GEOM"]			= "http://jocg.org/"
    Journal_URL["j-J-COMPUT-GRAPH-STAT"]		= "http://www.tandfonline.com/loi/ucgs20"
    Journal_URL["j-J-COMPUT-PHYS"]			= "http://www.sciencedirect.com/science/journal/00219991"
    Journal_URL["j-J-COMPUT-SCI"]			= "https://www.sciencedirect.com/journal/journal-of-computational-science"
    Journal_URL["j-J-CONTEMP-HIST"]			= "http://www.jstor.org/journals/00220094.html; http://online.sagepub.com/00220094"
    ## OLD: Journal_URL["j-J-CONVEX-ANAL"]			= "http://www.emis.ams.org/journals/JCA/"
    Journal_URL["j-J-CONVEX-ANAL"]			= "http://www.heldermann.de/JCA/jcacon.htm"
    Journal_URL["j-J-CRYPTO-ENG"]			= "http://link.springer.com/journal/13389"
    Journal_URL["j-J-CRYPTOLOGY"]			= "http://link.springer.com/journal/145"
    Journal_URL["j-J-DIFFERENCE-EQU-APPL"]		= "http://www.informaworld.com/1023-6198"
    Journal_URL["j-J-DISCRETE-ALGORITHMS"]		= "http://www.sciencedirect.com/science/journal/15708667"
    Journal_URL["j-J-DOC"]				= "http://www.emeraldinsight.com/loi/jd"
    Journal_URL["j-J-ECON-LIT"]				= "https://www.aeaweb.org/journals/jel/issues"
    Journal_URL["j-J-ECONOMETRICS"]			= "http://www.sciencedirect.com/science/journal/03044076"
    Journal_URL["j-J-EDUC-BEHAV-STAT"]			= "http://www.jstor.org/journal/jeducbehastat"
    Journal_URL["j-J-EDUC-SOCIOL-NEW-YORK"]		= "http://www.jstor.org/journal/jeducsoci"
    Journal_URL["j-J-ELAST"]				= "http://link.springer.com/journal/10659"
    Journal_URL["j-J-ELECTROCHEM-SOC"]			= "http://jes.ecsdl.org/content/by/year"
    Journal_URL["j-J-ELECTROMAGN-WAVES-APPL"]		= "http://www.tandfonline.com/loi/tewa20"
    Journal_URL["j-J-ELECTRON-SPECTROSC-RELAT-PHENOM"]	= "https://www.sciencedirect.com/journal/journal-of-electron-spectroscopy-and-related-phenomena"
    Journal_URL["j-J-ELECTROST"]			= "http://www.sciencedirect.com/science/journal/03043886"
    Journal_URL["j-J-ENG-MATER-TECHNOL"]		= "http://materialstechnology.asmedigitalcollection.asme.org/issues.aspx"
    Journal_URL["j-J-ENG-MATH"]				= "http://www.springerlink.com/content/0022-0833"
    Journal_URL["j-J-FINANC-ECON"]			= "http://www.sciencedirect.com/science/journal/0304405X"
    Journal_URL["j-J-FISH-BIOL"]			= "https://onlinelibrary.wiley.com/journal/10958649"
    Journal_URL["j-J-FISH-DIS"]				= "https://onlinelibrary.wiley.com/journal/13652761"
    Journal_URL["j-J-FISH-RES-BOARD-CAN"]		= "https://cdnsciencepub.com/journal/cjfas"
    Journal_URL["j-J-FISHERIESCIENCES-COM"]		= "https://www.fisheriessciences.com/archive.php"
    Journal_URL["j-J-FLUID-MECH"]			= "http://journals.cambridge.org/action/displayJournal?jid=FLM"
    Journal_URL["j-J-FRANKLIN-INST"]			= "http://www.sciencedirect.com/science/journal/00160032"
    Journal_URL["j-J-FUNCT-ANAL"]			= "http://www.sciencedirect.com/science/journal/00221236"
    Journal_URL["j-J-FUNCT-PROGRAM"]			= "http://journals.cambridge.org/action/displayJournal?jid=JFP"
    Journal_URL["j-J-GEN-PHILOS-SCI"]			= "http://www.jstor.org/journal/jgenphilscience; http://link.springer.com/journal/10838"
    Journal_URL["j-J-GEN-PHYSIOL"]			= "http://jgp.rupress.org/content/by/year/"
    Journal_URL["j-J-GEOM-PHYS"]			= "http://www.sciencedirect.com/science/journal/03930440"
    Journal_URL["j-J-GEOPHYS-RES"]			= "http://agupubs.onlinelibrary.wiley.com/agu/journal/10.1002/(ISSN)2156-2202/"
    Journal_URL["j-J-GEOPHYS-RES-OCEAN"]		= "http://agupubs.onlinelibrary.wiley.com/agu/jgr/journal/10.1002/(ISSN)2169-9291/"
    Journal_URL["j-J-GEOPHYS-RES-SOLID-EARTH"]		= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)2169-9356"
    Journal_URL["j-J-GLOBAL-OPT"]			= "http://link.springer.com/journal/10898"
    Journal_URL["j-J-GRAPHICS-GPU-GAME-TOOLS"]		= "http://www.tandfonline.com/loi/ujgt20"
    Journal_URL["j-J-GRAPHICS-TOOLS"]			= "http://www.tandfonline.com/loi/ujgt20"
    Journal_URL["j-J-GRID-COMP"]			= "http://link.springer.com/journal/10723"
    Journal_URL["j-J-HIST-ASTRON"]			= "http://jha.sagepub.com/"
    Journal_URL["j-J-HIST-BIOL"]			= "https://link.springer.com/journal/10739"
    Journal_URL["j-J-HIST-IDEAS"]			= "http://muse.jhu.edu/journals/jhi/; http://www.jstor.org/journals/00225037.html"
    Journal_URL["j-J-HUM-HYPERTENS"]			= "http://www.nature.com/jhh/archive"
    Journal_URL["j-J-HUMANIST-MATH"]			= "http://scholarship.claremont.edu/jhm/"
    Journal_URL["j-J-HYDROL"]				= "http://www.sciencedirect.com/science/journal/00221694"
    Journal_URL["j-J-INEQUAL-APPL"]			= "http://journalofinequalitiesandapplications.springeropen.com/"
    Journal_URL["j-J-INFO-ORG-SCI"]			= "http://jios.foi.hr/index.php/jios/index"
    Journal_URL["j-J-INFO-SCI-PRINCIPLES-PRACTICE"]	= "http://jis.sagepub.com/"
    Journal_URL["j-J-INFO-SEC-APPL"]			= "http://www.sciencedirect.com/science/journal/22142126"
    Journal_URL["j-J-INFORMETRICS"]			= "http://www.sciencedirect.com/science/journal/17511577"
    Journal_URL["j-J-INST-ELECTR-ENG"]			= "http://ieeexplore.ieee.org/servlet/opac?punumber=5308791"
    Journal_URL["j-J-INST-MATH-APPL"]			= "http://imamat.oxfordjournals.org/content/by/year"
    Journal_URL["j-J-INT-ASSOC-MATH-GEOL"]		= "http://link.springer.com/journal/11004"
    Journal_URL["j-J-INT-ECON"]				= "http://www.sciencedirect.com/science/journal/09247963"
    Journal_URL["j-J-INTEGER-SEQ"]			= "https://cs.uwaterloo.ca/journals/JIS/"
    Journal_URL["j-J-INTEGRAL-EQU-APPL"]		= "http://projecteuclid.org/euclid.jiea"
    Journal_URL["j-J-INTELL-MATER-SYST-STRUCT"]		= "http://jim.sagepub.com/content/by/year"
    Journal_URL["j-J-INTERDISCIP-HIST"]			= "http://www.jstor.org/journals/00221953.html; http://muse.jhu.edu/journals/jih/"
    Journal_URL["j-J-INVERSE-ILL-POSED-PROBL"]		= "http://www.degruyter.com/view/j/jiip"
    Journal_URL["j-J-INVESTMENT-MANAGE"]		= "https://www.joim.com/library-archives/"
    Journal_URL["j-J-IRREPROD-RESULTS"]			= "http://www.jir.com/"
    Journal_URL["j-J-KOREAN-PHYS-SOC"]			= "http://www.springerlink.com/content/0374-4884/"
    Journal_URL["j-J-LOGIC-ALG-PROG"]			= "http://www.sciencedirect.com/science/journal/15678326"
    Journal_URL["j-J-LOGIC-LANGUAGE-INFO"]		= "http://link.springer.com/journal/10849"
    Journal_URL["j-J-LOND-MATH-SOC"]			= "http://jlms.oxfordjournals.org/content/by/year"
    Journal_URL["j-J-LOND-MATH-SOC-2"]			= "http://jlms.oxfordjournals.org/content/by/year"
    Journal_URL["j-J-MACH-LEARN-RES"]			= "http://jmlr.csail.mit.edu/"
    Journal_URL["j-J-MATER-RES"]			= "http://journals.cambridge.org/action/displayJournal?jid=JMR"
    Journal_URL["j-J-MATER-SCI"]			= "http://link.springer.com/journal/volumesAndIssues/10853"
    Journal_URL["j-J-MATER-SCI-LETT"]			= "http://link.springer.com/journal/10855"
    Journal_URL["j-J-MATH-ANAL-APPL"]			= "http://www.sciencedirect.com/science/journal/0022247X"
    Journal_URL["j-J-MATH-ARTS"]			= "http://www.tandfonline.com/loi/tmaa20"
    Journal_URL["j-J-MATH-BIOL"]			= "http://link.springer.com/journal/285"
    Journal_URL["j-J-MATH-CHEM"]			= "http://link.springer.com/journal/10910"
    Journal_URL["j-J-MATH-CRYPTOL"]			= "http://www.degruyter.com/view/j/jmc"
    Journal_URL["j-J-MATH-INEQUAL"]			= "http://jmi.ele-math.com/"
    Journal_URL["j-J-MATH-PHYS"]			= "http://jmp.aip.org/"
    Journal_URL["j-J-MATH-PHYS-MIT"]			= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1467-9590"
    Journal_URL["j-J-MATH-PSYCHOL"]			= "http://www.sciencedirect.com/science/journal/00222496"
    Journal_URL["j-J-MATH-PURES-APPL"]			= "http://www.sciencedirect.com/science/journal/00217824"
    Journal_URL["j-J-MATH-RES-APPL"]			= "http://jmre.dlut.edu.cn/en/ch/index.aspx"
    Journal_URL["j-J-MATH-SCI-ADV-APPL"]		= "http://www.scientificadvances.co.in/about-this-journal/1"
    Journal_URL["j-J-MATH-SCI-NY-NY"]			= "http://link.springer.com/journal/10958"
    Journal_URL["j-J-MECH-MATER-STRUCT"]		= "http://msp.org/jomms/"
    Journal_URL["j-J-MECH-PHYS-SOLIDS"]			= "http://www.sciencedirect.com/science/journal/00225096"
    Journal_URL["j-J-MED-SYST"]				= "http://link.springer.com/journal/10916"
    Journal_URL["j-J-MICROELECTROMECHANICAL-SYSTEMS"]	= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=84"
    Journal_URL["j-J-MIL-HIST"]				= "http://muse.jhu.edu/journals/journal_of_military_history/"
    Journal_URL["j-J-MOD-ITAL-STUD"]			= "http://www.tandfonline.com/loi/rmis20"
    Journal_URL["j-J-MOD-OPT"]				= "http://www.tandfonline.com/loi/tmop20"
    Journal_URL["j-J-MOL-EVOL"]				= "http://link.springer.com/journal/239"
    Journal_URL["j-J-MOL-MODEL"]			= "http://link.springer.com/journal/894"
    Journal_URL["j-J-MOL-SPECTROSC"]			= "http://www.sciencedirect.com/science/journal/00222852"
    Journal_URL["j-J-MOL-STRUCT"]			= "http://www.sciencedirect.com/science/journal/00222860"
    Journal_URL["j-J-MOL-STRUCT-THEOCHEM"]		= "http://www.sciencedirect.com/science/journal/01661280"
    Journal_URL["j-J-NANOMATER"]			= "http://www.hindawi.com/GetJournal.aspx?journal=JNM"
    Journal_URL["j-J-NANOSCI-NANOTECHNOL"]		= "http://www.aspbs.com/jnn/"
    Journal_URL["j-J-NETW-COMPUT-APPL"]			= "http://www.sciencedirect.com/science/journal/10848045"
    Journal_URL["j-J-NEUROSCI-METHODS"]			= "http://www.sciencedirect.com/science/journal/01650270"
    Journal_URL["j-J-NON-CRYST-SOLIDS"]			= "http://www.sciencedirect.com/science/journal/00223093"
    Journal_URL["j-J-NONLINEAR-CONVEX-ANAL"]		= "http://www.ybook.co.jp/jnca.html"
    Journal_URL["j-J-NUCL-ENERGY-1954"]			= "http://www.sciencedirect.com/science/journal/08913919"
    Journal_URL["j-J-NUCL-MATER"]			= "http://www.sciencedirect.com/science/journal/00223115"
    Journal_URL["j-J-NUMBER-THEORY"]			= "http://www.sciencedirect.com/science/journal/0022314X"
    Journal_URL["j-J-OPEN-RES-SOFT"]			= "https://openresearchsoftware.metajnl.com/issue/archive/"
    Journal_URL["j-J-OPT-A"]				= "http://iopscience.iop.org/1464-4258"
    Journal_URL["j-J-OPT-B"]				= "http://iopscience.iop.org/1464-4266"
    Journal_URL["j-J-OPT-SOC-AM"]			= "http://www.osapublishing.org/josa/browse.cfm"
    Journal_URL["j-J-OPT-SOC-AM-A"]			= "http://www.osapublishing.org/josaa/"
    Journal_URL["j-J-OPT-SOC-AM-B"]			= "http://www.osapublishing.org/josab/"
    Journal_URL["j-J-OPT-SOC-AM-REV-SCI-INSTRUM"]	= "https://www.osapublishing.org/josa/browse.cfm"
    Journal_URL["j-J-OPT-THEORY-APPL"]			= "http://link.springer.com/journal/volumesAndIssues/10957"
    Journal_URL["j-J-PAR-DIST-COMP"]			= "http://www.sciencedirect.com/science/journal/07437315"
    Journal_URL["j-J-PATHOL"]				= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1096-9896"
    Journal_URL["j-J-PHILOS"]				= "http://www.jstor.org/journal/jphilosophy"
    Journal_URL["j-J-PHYS-A"]				= "http://iopscience.iop.org/0305-4470"
    Journal_URL["j-J-PHYS-A"]				= "http://iopscience.iop.org/1751-8121"
    Journal_URL["j-J-PHYS-A-MATH-THEOR"]		= "http://iopscience.iop.org/1751-8121"
    Journal_URL["j-J-PHYS-B"]				= "http://iopscience.iop.org/0022-3700/"
    Journal_URL["j-J-PHYS-B-AT-MOL-OPT-PHYS"]		= "http://iopscience.iop.org/0953-4075"
    Journal_URL["j-J-PHYS-C"]				= "http://iopscience.iop.org/0022-3719"
    Journal_URL["j-J-PHYS-CHEM"]			= "http://pubs.acs.org/journal/jpchax"
    Journal_URL["j-J-PHYS-CHEM-A"]			= "http://pubs.acs.org/journal/jpcafh"
    Journal_URL["j-J-PHYS-CHEM-B"]			= "http://pubs.acs.org/loi/jpcbfk"
    Journal_URL["j-J-PHYS-CHEM-SOLIDS"]			= "http://www.sciencedirect.com/science/journal/00223697"
    Journal_URL["j-J-PHYS-COLLOQ"]			= "http://jphyscol.journaldephysique.org/"
    Journal_URL["j-J-PHYS-CONDENS-MATTER"]		= "http://iopscience.iop.org/0953-8984"
    Journal_URL["j-J-PHYS-CONF-SER"]			= "http://www.iop.org/EJ/journal/conf"
    Journal_URL["j-J-PHYS-D"]				= "http://iopscience.iop.org/0022-3727/"
    Journal_URL["j-J-PHYS-E"]				= "http://iopscience.iop.org/0022-3735/"
    Journal_URL["j-J-PHYS-F"]				= "http://iopscience.iop.org/0305-4608/"
    Journal_URL["j-J-PHYS-LETT"]			= "http://jphyslet.journaldephysique.org/"
    Journal_URL["j-J-PHYS-RADIUM"]			= "http://jphysrad.journaldephysique.org/"
    Journal_URL["j-J-PHYS-THEOR-APPL"]			= "http://jphystap.journaldephysique.org/"
    Journal_URL["j-J-PHYSIQUE"]				= "http://www.journaldephysique.org/"
    Journal_URL["j-J-PLANKTON-RES"]			= "http://plankt.oxfordjournals.org/content/by/year"
    Journal_URL["j-J-PLASMA-PHYS"]			= "http://journals.cambridge.org/action/displayJournal?jid=PLA"
    Journal_URL["j-J-POLYM-SCI"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1542-6238"
    Journal_URL["j-J-POLYM-SCI-C-POLYM-LETT"]		= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1543-0472"
    Journal_URL["j-J-POP-CULT"]				= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1540-5931"
    Journal_URL["j-J-R-ASTRON-SOC-CAN"]			= "https://www.rasc.ca/journal"
    Journal_URL["j-J-R-SOC-ARTS"]			= "http://www.jstor.org/journal/jroysocart"
    Journal_URL["j-J-R-STAT-SOC"]			= "http://www.jstor.org/journals/09528385.html"
    Journal_URL["j-J-R-STAT-SOC-SER-A-GENERAL"]		= "http://www.jstor.org/journals/00359238.html"
    Journal_URL["j-J-R-STAT-SOC-SER-A-STAT-SOC"]	= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1467-985X; http://www.jstor.org/journals/09641998.html"
    Journal_URL["j-J-R-STAT-SOC-SER-B-METHODOL"]	= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1467-9868; http://www.jstor.org/journals/00359246.html"
    Journal_URL["j-J-R-STAT-SOC-SER-B-METHODOL"]	= "http://www.jstor.org/journals/00359246.html"
    Journal_URL["j-J-R-STAT-SOC-SER-B-STAT-METHODOL"]	= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1467-9868; http://www.jstor.org/journals/13697412.html"
    Journal_URL["j-J-R-STAT-SOC-SER-B-STAT-METHODOL"]	= "http://www.jstor.org/journals/13697412.html"
    Journal_URL["j-J-R-STAT-SOC-SER-D-STATISTICIAN"]	= "http://www.jstor.org/journals/00390526.html"
    Journal_URL["j-J-R-STAT-SOC-SUPPL"]			= "http://www.jstor.org/journals/00401706.html"
    Journal_URL["j-J-RADIOANAL-NUCL-CHEM"]		= "http://link.springer.com/journal/10967"
    Journal_URL["j-J-REINE-ANGEW-MATH"]			= "https://www.degruyter.com/view/j/crll"
    Journal_URL["j-J-RELIG-HEALTH"]			= "http://link.springer.com/journal/10943"
    Journal_URL["j-J-RES-COMMUN-STUD"]			= ""
    Journal_URL["j-J-RES-NATL-BUR-STAND-1934"]		= "https://www.nist.gov/nist-research-library/journal-research-nist/past-papers"
    Journal_URL["j-J-RES-NATL-BUR-STAND-A"]		= "http://www.nist.gov/nvl/jrespastpapers.cfm"
    Journal_URL["j-J-RES-NATL-BUR-STAND-B"]		= "http://www.nist.gov/nvl/jrespastpapers.cfm"
    Journal_URL["j-J-RES-NATL-BUR-STAND-C"]		= "http://www.nist.gov/nvl/jrespastpapers.cfm"
    Journal_URL["j-J-RES-NATL-BUR-STAND-D"]		= "http://www.nist.gov/nvl/jrespastpapers.cfm"
    Journal_URL["j-J-RES-NATL-INST-STAND-TECHNOL"]	= "http://www.nist.gov/nvl/jres.cfm"
    Journal_URL["j-J-RES-SCI-TEACH"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1098-2736"
    Journal_URL["j-J-RISK-UNCERT"]			= "http://link.springer.com/journal/11166"
    Journal_URL["j-J-SCI-COMPUT"]			= "http://link.springer.com/journal/10915"
    Journal_URL["j-J-SCI-EDUC-TECHNOL"]			= "http://www.jstor.org/journal/jsciedutech"
    Journal_URL["j-J-SCIENT-INSTR"]			= "https://iopscience.iop.org/journal/0950-7671"
    Journal_URL["j-J-SIAM"]				= "http://epubs.siam.org/loi/smjmap.1"
    Journal_URL["j-J-SIMUL"]				= "http://www.palgrave-journals.com/jos"
    Journal_URL["j-J-SOC-BIOL-STRUCT"]			= "http://www.sciencedirect.com/science/journal/01401750"
    Journal_URL["j-J-SOC-CHEM-IND-LONDON"]		= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1097-4660"
    Journal_URL["j-J-SOC-IND-APPL-MATH-A-ON-CONTROL"]	= "http://epubs.siam.org/journal/sjcodc"
    Journal_URL["j-J-SOFTW-EVOL-PROC"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)2047-7481"
    Journal_URL["j-J-SOFTW-MAINT"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)2047-7481"
    Journal_URL["j-J-SOFTW-MAINT-EVOL"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)2047-7481"
    Journal_URL["j-J-SOFTWARE-ALGEBRA-GEOM"]		= "http://j-sag.org/"
    Journal_URL["j-J-SOV-MATH"]				= "http://link.springer.com/journal/10958"
    Journal_URL["j-J-STAT-COMPUT-SIMUL"]		= "http://www.tandfonline.com/loi/gscs20"
    Journal_URL["j-J-STAT-MECH-THEORY-EXP"]		= "http://iopscience.iop.org/1742-5468/"
    Journal_URL["j-J-STAT-PHYS"]			= "http://link.springer.com/journal/10955"
    Journal_URL["j-J-STAT-PLANN-INFERENCE"]		= "http://www.sciencedirect.com/science/journal/03783758"
    Journal_URL["j-J-STAT-SOC"]				= "http://www.jstor.org/journals/09595341.html"
    Journal_URL["j-J-STAT-SOC-LONDON"]			= "http://www.jstor.org/journals/09595341.html"
    Journal_URL["j-J-STAT-SOFT"]			= "http://www.jstatsoft.org/"
    Journal_URL["j-J-STAT-THEORY-PRACT"]		= "https://link.springer.com/journal/42519"
    Journal_URL["j-J-STRATEG-STUD"]			= "http://www.tandfonline.com/loi/fjss20"
    Journal_URL["j-J-STRUCT-ENG"]			= "http://ascelibrary.org/journal/jsendh"
    Journal_URL["j-J-STRUCT-MECH"]			= "http://www.tandfonline.com/loi/lmbd18"
    Journal_URL["j-J-SUPERCOMPUTING"]			= "http://link.springer.com/journal/11227"
    Journal_URL["j-J-SUPERCOND-NOVEL-MAGN"]		= "http://link.springer.com/journal/10948"
    Journal_URL["j-J-SYMBOLIC-COMP"]			= "http://www.sciencedirect.com/science/journal/07477171"
    Journal_URL["j-J-SYMBOLIC-LOGIC"]			= "http://projecteuclid.org/euclid.jsl; http://www.jstor.org/journal/jsymboliclogic"
    Journal_URL["j-J-SYST-SOFTW"]			= "http://www.sciencedirect.com/science/journal/01641212"
    Journal_URL["j-J-THEOR-BIOL"]			= "http://www.sciencedirect.com/science/journal/00225193"
    Journal_URL["j-J-THEOR-PROBAB"]			= "http://link.springer.com/journal/10959"
    Journal_URL["j-J-TIME-SER-ANAL"]			= "https://onlinelibrary.wiley.com/journal/14679892"
    Journal_URL["j-J-TIME-SER-ECONOM"]			= "https://www.degruyter.com/view/j/jtse"
    Journal_URL["j-J-UCS"]				= "http://www.jucs.org/jucs"
    Journal_URL["j-J-URBAN-ECON"]			= "http://www.sciencedirect.com/science/journal/00941190"
    Journal_URL["j-J-VAC-SCI-TECHNOL"]			= "http://scitation.aip.org/content/avs/journal/jvst"
    Journal_URL["j-J-VAC-SCI-TECHNOL-A"]		= "http://scitation.aip.org/content/avs/journal/jvsta"
    Journal_URL["j-J-VAC-SCI-TECHNOL-B"]		= "http://scitation.aip.org/content/avs/journal/jvstb"
    Journal_URL["j-J-WASH-ACAD-SCI"]			= "http://www.jstor.org/journal/jwashacadscie"
    Journal_URL["j-JABES"]				= "https://www.springer.com/journal/13253"
    Journal_URL["j-JACS"]				= "http://pubs.acs.org/journal/jacsat"
    Journal_URL["j-JAMA"]				= "http://jama.jamanetwork.com/issues.aspx"
    Journal_URL["j-JDIQ"]				= "http://portal.acm.org/browse_dl.cfm?idx=J1191"
    Journal_URL["j-JETC"]				= "http://portal.acm.org/browse_dl.cfm?idx=J967"
    Journal_URL["j-JIPAM-J-INEQUAL-PURE-APPL-MATH"]	= "http://www.emis.de/journals/JIPAM/"
    Journal_URL["j-JOCCH"]				= "http://portal.acm.org/browse_dl.cfm?idx=J1157"
    Journal_URL["j-JOHN-HOPKINS-MAG"]			= "http://hub.jhu.edu/magazine/past-issues"
    Journal_URL["j-JPN-STUD-HIST-SCI"]			= "http://hssj.info/"
    Journal_URL["j-KVANT"]				= "http://www.kvant.dk/gallery.php"
    Journal_URL["j-LANCET"]				= "http://www.sciencedirect.com/science/journal/01406736"
    Journal_URL["j-LANG-SCI"]				= "http://www.sciencedirect.com/science/journal/03880001"
    Journal_URL["j-LANGMUIR"]				= "http://pubs.acs.org/journal/langd5"
    Journal_URL["j-LASER-PHYS-LETT"]			= "http://iopscience.iop.org/1612-202X"
    Journal_URL["j-LEARN-PUBL"]				= "https://onlinelibrary.wiley.com/journal/17414857"
    Journal_URL["j-LECT-NOTES-COMP-SCI"]		= "http://link.springer.com/bookseries/558"
    Journal_URL["j-LECT-NOTES-MATH"]			= "http://link.springer.com/bookseries/304"
    Journal_URL["j-LECT-NOTES-PHYSICS"]			= "http://link.springer.com/bookseries/5304"
    ## Journal_URL["j-LECT-SER-COMPUT-COMPUT-SCI"]		= ""
    Journal_URL["j-LEONARDO"]				= "http://www.jstor.org/journal/leonardo"
    Journal_URL["j-LET-MATH-PHYS"]			= "http://link.springer.com/journal/11005"
    Journal_URL["j-LETT-NUOVO-CIMENTO"]			= "http://link.springer.com/journal/11545"
    Journal_URL["j-LETT-NUOVO-CIMENTO-2"]		= "http://link.springer.com/journal/11545"
    Journal_URL["j-LIGHT-SCI-APPL"]			= "http://www.nature.com/lsa/"
    Journal_URL["j-LIMNOL-OCEANOGR"]			= "https://aslopubs.onlinelibrary.wiley.com/loi/19395590"
    Journal_URL["j-LIMNOL-OCEANOGR-LETT"]		= "https://aslopubs.onlinelibrary.wiley.com/loi/23782242"
    Journal_URL["j-LIN-AND-MULT-ALGEBRA"]		= "http://www.tandfonline.com/loi/glma20"
    Journal_URL["j-LIN-MULT-ALGEBRA"]			= "http://www.tandfonline.com/loi/glma20"
    Journal_URL["j-LINEAR-ALGEBRA-APPL"]		= "http://www.sciencedirect.com/science/journal/00243795"
    Journal_URL["j-LINUX-J"]				= "http://portal.acm.org/citation.cfm?id=J508"
    Journal_URL["j-LISP-SYMB-COMPUT"]			= "http://link.springer.com/journal/10990"
    Journal_URL["j-LMS-J-COMPUT-MATH"]			= "http://journals.cambridge.org/action/displayJournal?jid=JCM"
    Journal_URL["j-LONDON-REV-BOOKS"]			= "https://www.lrb.co.uk/"
    Journal_URL["j-MACH-INTELL"]			= "http://www.doc.ic.ac.uk/~shm/MI/mi.html"
    Journal_URL["j-MACROMOLECULES"]			= "http://pubs.acs.org/loi/mamobx"
    Journal_URL["j-MAGN-MAGN-MATER"]			= "http://www.sciencedirect.com/science/journal/03048853"
    Journal_URL["j-MAGN-RESON"]				= "http://www.sciencedirect.com/science/journal/00222364"
    Journal_URL["j-MAGY-TUDOMANY"]			= "http://www.matud.iif.hu/archive.htm"
    Journal_URL["j-MANAGEMENT-SCIENCE"]			= "http://pubsonline.informs.org/loi/mnsc"
    Journal_URL["j-MANCHESTER-GUARDIAN"]		= "http://pqasb.pqarchiver.com/guardian/"
    Journal_URL["j-MAR-BIOL-RES"]			= "https://www.tandfonline.com/loi/smar20"
    Journal_URL["j-MAR-BIOTECHNOL"]			= "https://www.springer.com/journal/10126"
    Journal_URL["j-MAR-ECOL-PROG-SER"]			= "https://www.int-res.com/journals/meps/meps-home/"
    Journal_URL["j-MAR-POLICY"]				= "https://www.sciencedirect.com/journal/marine-policy"
    Journal_URL["j-MARIN-RESOURC-ECON"]			= "https://www.journals.uchicago.edu/loi/mre"
    Journal_URL["j-MAT-SB"]				= "http://iopscience.iop.org/1064-5616"
    Journal_URL["j-MAT-ZAMETKI"]			= "http://link.springer.com/journal/11006"
    Journal_URL["j-MATER-RES-SOC-SYMP-PROC"]		= "http://journals.cambridge.org/action/displayJournal?jid=OPL"
    Journal_URL["j-MATER-SCI-ENG-A"]			= "http://www.sciencedirect.com/science/journal/09215093"
    Journal_URL["j-MATER-TODAY"]			= "http://www.sciencedirect.com/science/journal/13697021"
    Journal_URL["j-MATH-ANN"]				= "http://link.springer.com/journal/208"
    Journal_URL["j-MATH-BIOSCI"]			= "http://www.sciencedirect.com/science/journal/00255564"
    Journal_URL["j-MATH-COMP-SIM"]			= "http://www.sciencedirect.com/science/journal/03784754"
    Journal_URL["j-MATH-COMPUT"]			= "http://www.ams.org/mcom/"
    Journal_URL["j-MATH-COMPUT-SCI"]			= "http://link.springer.com/journal/11786"
    Journal_URL["j-MATH-GAZ"]				= "http://journals.cambridge.org/action/displayBackIssues?jid=MAG"
    Journal_URL["j-MATH-GAZ"]				= "http://www.m-a.org.uk/jsp/index.jsp?lnk=620"
    Journal_URL["j-MATH-GAZ"]				= "http://www.jstor.org/journal/mathgaze"
    Journal_URL["j-MATH-GEOSCI"]			= "http://link.springer.com/journal/11004"
    Journal_URL["j-MATH-INEQUAL-APPL"]			= "http://mia.ele-math.com/"
    Journal_URL["j-MATH-INTEL"]				= "http://link.springer.com/journal/283"
    Journal_URL["j-MATH-MAG"]				= "http://www.maa.org/pubs/mathmag.html"
    Journal_URL["j-MATH-MECH-COMPLEX-SYST"]		= "https://msp.org/memocs/"
    Journal_URL["j-MATH-MECH-SOLIDS"]			= "http://mms.sagepub.com/"
    Journal_URL["j-MATH-MED-BIOL"]			= "https://academic.oup.com/imammb/issue"
    Journal_URL["j-MATH-METHODS-APPL-SCI"]		= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1099-1476"
    Journal_URL["j-MATH-METHODS-STAT"]			= "http://link.springer.com/journal/12004"
    Journal_URL["j-MATH-MODEL-NUM-ANA"]			= "http://journals.cambridge.org/action/displayJournal?jid=MZA"
    Journal_URL["j-MATH-MODELS-METHODS-APPL-SCI"]	= "http://www.worldscientific.com/worldscinet/m3as"
    Journal_URL["j-MATH-NACHR"]				= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1522-2616"
    Journal_URL["j-MATH-OP-RES"]			= "http://pubsonline.informs.org/loi/moor"
    Journal_URL["j-MATH-OPERATIONSFORSCH-STAT"]		= "http://www.tandfonline.com/loi/gsta18"
    Journal_URL["j-MATH-PROC-CAMB-PHILOS-SOC"]		= "http://journals.cambridge.org/action/displayJournal?jid=PSP"
    Journal_URL["j-MATH-PROG"]				= "http://link.springer.com/journal/10107"
    Journal_URL["j-MATH-PROGRAM-COMPUT"]		= "http://link.springer.com/journal/12532"
    Journal_URL["j-MATH-RES-LETT"]			= "http://intlpress.com/site/pub/pages/journals/items/mrl/content/vols/"
    Journal_URL["j-MATH-SCAND"]				= "http://www.mscand.dk/issue/archive"
    Journal_URL["j-MATH-SCI"]				= "http://www.appliedprobability.org/content.aspx?Group=tms&Page=allissues"
    Journal_URL["j-MATH-SOC-SCI"]			= "http://www.sciencedirect.com/science/journal/01654896"
    Journal_URL["j-MATH-SYS-THEORY"]			= "http://link.springer.com/journal/224"
    Journal_URL["j-MATH-TABLES-AIDS-COMPUT"]		= "http://www.ams.org/mcom/"
    Journal_URL["j-MATH-TABLES-OTHER-AIDS-COMPUT"]	= "http://www.ams.org/mcom/"
    Journal_URL["j-MATH-TODAY"]				= "http://ima.org.uk/activities/publications/mathematics_today.cfm.html"
    Journal_URL["j-MATH-USSR-IZV"]			= "http://iopscience.iop.org/0025-5726"
    Journal_URL["j-MATH-Z"]				= "http://link.springer.com/journal/209"
    Journal_URL["j-MATHEMATIKA"]			= "https://www.cambridge.org/core/journals/mathematika/all-issues"
    Journal_URL["j-MATHEMATICA-J"]			= "http://www.mathematica-journal.com/"
    Journal_URL["j-MDMV"]				= "http://www.degruyter.com/view/j/dmvm"
    Journal_URL["j-MECH-MATER"]				= "http://www.sciencedirect.com/science/journal/01676636"
    Journal_URL["j-MECH-RESEARCH-COMM"]			= "http://www.sciencedirect.com/science/journal/00936413"
    Journal_URL["j-MED-DECIS-MAKING"]			= "http://mdm.sagepub.com/content/by/year"
    Journal_URL["j-MED-J-AUST"]				= "http://www.mja.com.au/journal"
    Journal_URL["j-MED-PHYS"]				= "http://scitation.aip.org/content/aapm/journal/medphys"
    Journal_URL["j-MED-WAR"]				= "http://www.tandfonline.com/loi/fmcs20"
    Journal_URL["j-MEDIA-HIST"]				= "http://www.tandfonline.com/loi/cmeh20"
    Journal_URL["j-MEM-PROC-MANCHESTER-LIT-PHILOS-SOC"]	= "http://www.manlitphil.ac.uk/pages/?page_id=20"
    Journal_URL["j-METALL-MATER-TRANS-A"]		= "http://link.springer.com/journal/11661"
    Journal_URL["j-METALL-TRANS-A-PHYS-METALL-MATER-SCI"] = "http://link.springer.com/journal/11661"
    Journal_URL["j-METHODS-APPL-ANAL"]			= "http://www.intlpress.com/MAA/"
    Journal_URL["j-METRIKA"]				= "http://link.springer.com/journal/184"
    Journal_URL["j-METRON"]				= "https://www.springer.com/journal/40300"
    Journal_URL["j-MICH-MATH-J"]			= "https://projecteuclid.org/all/euclid.mmj"
    Journal_URL["j-MICROCHIM-ACTA"]			= "http://www.springerlink.com/content/0026-3672"
    Journal_URL["j-MICROELECT-J"]			= "http://www.sciencedirect.com/science/journal/00262692"
    Journal_URL["j-MICROSC-RES-TECH"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1097-0029"
    Journal_URL["j-MICROW-OPT-TECHNOL-LETT"]		= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1098-2760"
    Journal_URL["j-MIDWEST-STUD-PHILOS"]		= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1475-4975"
    Journal_URL["j-MIENTRAS-TANTO"]			= "https://www.jstor.org/journal/mientrastanto"
    Journal_URL["j-MIND"]				= "https://academic.oup.com/mind/issue"
    Journal_URL["j-MINDS-MACH"]				= "http://link.springer.com/journal/11023"
    Journal_URL["j-MINERALS-BASEL"]			= "http://www.mdpi.com/journal/minerals"
    Journal_URL["j-MINERVA-WASHINGTON"]			= "http://link.springer.com/journal/11024"
    Journal_URL["j-MINI-REV-MED-CHEM"]			= "http://benthamscience.com/journal/index.php?journalID=mrmc"
    Journal_URL["j-MOD-INTELL-HIST"]			= "http://journals.cambridge.org/action/displayJournal?jid=MIH"
    Journal_URL["j-MOD-ITALY"]				= "http://www.tandfonline.com/loi/cmit20"
    Journal_URL["j-MOD-PHYS-LETT-A"]			= "http://www.worldscientific.com/loi/mpla"
    Journal_URL["j-MOD-PHYS-LETT-B"]			= "http://www.worldscientific.com/loi/mplb"
    Journal_URL["j-MODEL-SIMUL-SCI-ENG"]		= "http://iopscience.iop.org/0965-0393"
    Journal_URL["j-MOL-BIOSYST"]			= "http://pubs.rsc.org/en/journals/journalissues/mb"
    Journal_URL["j-MOL-INF"]				= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1868-1751"
    Journal_URL["j-MOL-PHYS"]				= "http://www.tandfonline.com/loi/tmph20"
    Journal_URL["j-MOLECULES"]				= "https://www.mdpi.com/journal/molecules"
    Journal_URL["j-MONAT-MATH"]				= "http://link.springer.com/journal/605"
    Journal_URL["j-MONAT-MATH-PHYSIK"]			= "http://link.springer.com/journal/605"
    Journal_URL["j-MONTE-CARLO-METHODS-APPL"]		= "http://www.degruyter.com/view/j/mcma"
    Journal_URL["j-MONTHLY-NOT-ROY-ASTRON-SOC"]		= "https://academic.oup.com/mnras"
    Journal_URL["j-MOSCOW-UNIV-MECH-BULL"]		= "http://link.springer.com/journal/11971"
    Journal_URL["j-MULTIBODY-SYST-DYN"]			= "http://link.springer.com/journal/11044"
    Journal_URL["j-MULTISCALE-MODELING-SIMUL"]		= "http://epubs.siam.org/mms"
    Journal_URL["j-MUTAT-RES"]				= "http://www.sciencedirect.com/science/journal/00275107"
    Journal_URL["j-N-AM-J-FISH-MANAG"]			= "https://afspubs.onlinelibrary.wiley.com/journal/15488675"
    Journal_URL["j-NACHR-CHEM"]				= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1868-0054"
    Journal_URL["j-NACHR-CHEM-TECH"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1868-0054a"
    Journal_URL["j-NACHR-CHEM-TECH-LAB"]		= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1868-0054b"
    Journal_URL["j-NAMS"]				= "http://www.ams.org/notices/"
    Journal_URL["j-NANO-LETT"]				= "http://pubs.acs.org/journal/nalefd"
    Journal_URL["j-NAT-COMPUT"]				= "http://link.springer.com/journal/11047"
    Journal_URL["j-NAT-RESOUR-MODEL"]			= "https://onlinelibrary.wiley.com/journal/19397445"
    Journal_URL["j-NAT-REV"]				= "http://www.nationalreview.com/search"
    Journal_URL["j-NATION"]				= "http://catalog.hathitrust.org/api/volumes/oclc/1643268.html; http://www.ebscohost.com/archives/magazine-archives/the-nation"
    Journal_URL["j-NATL-SCI-REV"]			= "http://www.nsr.oxfordjournals.org/content/by/year"
    Journal_URL["j-NATURE"]				= "http://www.nature.com/nature/archive/"
    Journal_URL["j-NATURE-BIOTECH"]			= "http://www.nature.com/nbt"
    Journal_URL["j-NATURE-COMMUN"]			= "http://www.nature.com/ncomms"
    Journal_URL["j-NATURE-GEOSCI"]			= "http://www.nature.com/ngeo/"
    Journal_URL["j-NATURE-MATER"]			= "http://www.nature.com/nmat/"
    Journal_URL["j-NATURE-NANOTECHNOL"]			= "http://www.nature.com/nnano/archive/"
    Journal_URL["j-NATURE-NEWS"]			= "http://www.nature.com/nature/archive/category.html?code=archive_news"
    Journal_URL["j-NATURE-PHOTONICS"]			= "http://www.nature.com/nphoton/archive/"
    Journal_URL["j-NATURE-PHYS-SCI"]			= "http://www.nature.com/"
    Journal_URL["j-NATURE-PHYSICS"]			= "http://www.nature.com/nphys/archive/"
    Journal_URL["j-NATURE-REV-PHYS"]			= "https://www.nature.com/natrevphys/archive"
    Journal_URL["j-NATURWISS-RUNDSCH"]			= "http://www.digizeitschriften.de/dms/toc/?PPN=PPN385489110; http://www.naturwissenschaftliche-rundschau.de/"
    Journal_URL["j-NATURWISSENSCHAFTEN"]		= "http://link.springer.com/journal/114"
    Journal_URL["j-NED-TIJDSCHR-NATUURKD"]		= "https://www.ntvn.nl/archief/"
    Journal_URL["j-NETW-HETEROG-MEDIA"]			= "http://aimsciences.org/journals/home.jsp?journalID=9"
    Journal_URL["j-NETWORK-SECURITY"]			= "http://www.sciencedirect.com/journal/network-security"
    Journal_URL["j-NEURAL-COMP"]			= "http://www.mitpressjournals.org/loi/neco"
    Journal_URL["j-NEUROCOMPUTING"]			= "http://www.sciencedirect.com/science/journal/09252312"
    Journal_URL["j-NEUROIMAGE"]				= "http://www.sciencedirect.com/science/journal/10538119"
    Journal_URL["j-NEUROSCIENCE"]			= "http://www.sciencedirect.com/journal/neuroscience"
    Journal_URL["j-NEW-ASTRON"]				= "http://www.sciencedirect.com/science/journal/13841076"
    Journal_URL["j-NEW-BLACKFRIARS"]			= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1741-2005"
    Journal_URL["j-NEW-ENGLAND-J-MED"]			= "http://www.nejm.org/medical-index"
    Journal_URL["j-NEW-HUNG-Q"]				= "http://www.hungarianquarterly.com/"
    Journal_URL["j-NEW-IDEAS-PSYCHOL"]			= "http://www.sciencedirect.com/journal/new-ideas-in-psychology/issues"
    Journal_URL["j-NEW-J-PHYS"]				= "http://iopscience.iop.org/1367-2630"
    Journal_URL["j-NEW-PERSPECT-Q"]			= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1540-5842"
    Journal_URL["j-NEW-SCIENTIST"]			= "http://www.sciencedirect.com/science/journal/02624079"
    Journal_URL["j-NEW-YORK-REV-BOOKS"]			= "http://www.nybooks.com/issues/"
    Journal_URL["j-NEW-YORKER"]				= "http://www.newyorker.com/archive/"
    Journal_URL["j-NEW-ZEALAND-SCI-REV"]		= "http://scientists.org.nz/journal"
    Journal_URL["j-NEWS-PHYSIOL-SCI"]			= "http://nips.physiology.org/ "
    Journal_URL["j-NEWSL-SCI-TECHNOL-HUMAN-VALUES"]	= "http://www.jstor.org/journals/07382618.html"
    Journal_URL["j-NIEUW-ARCHIEF-WISKUNDE"]		= "http://www.nieuwarchief.nl/"
    Journal_URL["j-NONLINEAR-ANAL"]			= "http://www.sciencedirect.com/journal/nonlinear-analysis"
    Journal_URL["j-NONLINEAR-DYN"]			= "http://link.springer.com/journal/11071"
    Journal_URL["j-NONLINEAR-THEORY-APPL"]		= "https://www.jstage.jst.go.jp/browse/nolta/"
    Journal_URL["j-NONLINEARITY"]			= "http://iopscience.iop.org/0951-7715"
    Journal_URL["j-NORDISK-MATH-TIDSKR"]		= "http://www.jstor.org/journal/nordmatetids"
    Journal_URL["j-NORDISK-TIDSKR-INFORM-BEHAND"]	= "http://link.springer.com/journal/10543"
    Journal_URL["j-NORMAT"]				= "http://www.jstor.org/journal/nordmatetids"
    # Journal_URL["j-NORSK-MAT-TIDSSKR"]			= "????"
    Journal_URL["j-NOTES-REC-R-SOC-LOND"]		= "http://rsnr.royalsocietypublishing.org/"
    Journal_URL["j-NOTRE-DAME-J-FORM-LOG"]		= "http://projecteuclid.org/all/euclid.ndjfl"
    Journal_URL["j-NOUS"]				= "http://www.jstor.org/journal/nous"
    Journal_URL["j-NTM"]				= "http://link.springer.com/journal/48"
    Journal_URL["j-NUCL-ENERGY"]			= "http://www.sciencedirect.com/science/journal/08913919"
    Journal_URL["j-NUCL-ENERGY-PART-A"]			= "http://www.sciencedirect.com/science/journal/03683265"
    Journal_URL["j-NUCL-INSTR-METH"]			= "http://www.sciencedirect.com/science/journal/0029554X"
    Journal_URL["j-NUCL-INSTRUM-METHODS-PHYS-RES-SECT-A"] = "https://www.sciencedirect.com/journal/nuclear-instruments-and-methods-in-physics-research-section-a-accelerators-spectrometers-detectors-and-associated-equipment"
    Journal_URL["j-NUCL-INSTRUM-METHODS-PHYS-RES-SECT-B"] = "https://www.sciencedirect.com/journal/nuclear-instruments-and-methods-in-physics-research-section-b-beam-interactions-with-materials-and-atoms/issues"
    Journal_URL["j-NUCL-MED"]				= "http://jnm.snmjournals.org/content/by/year"
    Journal_URL["j-NUCL-PHYS"]				= "http://www.sciencedirect.com/science/journal/00295582"
    Journal_URL["j-NUCL-PHYS-A"]			= "http://www.sciencedirect.com/science/journal/03759474"
    Journal_URL["j-NUCL-PHYS-B"]			= "http://www.sciencedirect.com/science/journal/05503213"
    Journal_URL["j-NUCL-PHYS-B-PROC-SUPPL"]		= "http://www.sciencedirect.com/science/journal/09205632"
    Journal_URL["j-NUCL-SCI-ENG"]			= "http://www.ans.org/pubs/journals/nse/"
    Journal_URL["j-NUCL-TECHNOL"]			= "http://www.ans.org/pubs/journals/nt/"
    Journal_URL["j-NUM-LIN-ALG-APPL"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1099-1506"
    Journal_URL["j-NUM-MATH"]				= "http://link.springer.com/journal/211"
    Journal_URL["j-NUMER-ALGEBRA-CONTROL-OPTIM"]	= "http://aimsciences.org/journal/2155-3289"
    Journal_URL["j-NUMER-ALGORITHMS"]			= "http://link.springer.com/journal/11075"
    Journal_URL["j-NUMER-FUNCT-ANAL-OPTIM"]		= "http://www.tandfonline.com/loi/lnfa20"
    Journal_URL["j-NUMER-HEAT-TRANSFER-B"]		= "http://www.tandfonline.com/loi/unhb20"
    Journal_URL["j-NUMER-METHODS-PARTIAL-DIFFER-EQU"]	= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1098-2426"
    Journal_URL["j-NUNCIUS"]				= "http://booksandjournals.brillonline.com/content/18253911"
    Journal_URL["j-NUNCIUS"]				= "http://booksandjournals.brillonline.com/content/journals/18253911"
    Journal_URL["j-NUOVO-CIMENTO-1"]			= "http://link.springer.com/journal/11583"
    Journal_URL["j-NUOVO-CIMENTO-2"]			= "http://link.springer.com/journal/40754"
    Journal_URL["j-NUOVO-CIMENTO-3"]			= "http://link.springer.com/journal/40755"
    Journal_URL["j-NUOVO-CIMENTO-4"]			= "http://link.springer.com/journal/40756"
    Journal_URL["j-NUOVO-CIMENTO-5"]			= "http://link.springer.com/journal/40757"
    Journal_URL["j-NUOVO-CIMENTO-6"]			= "http://link.springer.com/journal/40758"
    Journal_URL["j-NUOVO-CIMENTO-7"]			= "http://link.springer.com/journal/40758"
    Journal_URL["j-NUOVO-CIMENTO-8"]			= "http://link.springer.com/journal/40760"
    Journal_URL["j-NUOVO-CIMENTO-9"]			= "http://link.springer.com/journal/40761"
    Journal_URL["j-NUOVO-CIMENTO-10"]			= "http://link.springer.com/journal/11583"
    Journal_URL["j-NUOVO-CIMENTO-1955-1965"]		= "http://link.springer.com/journal/40762"
    Journal_URL["j-NUOVO-CIMENTO-A"]			= "http://link.springer.com/journal/11539"
    Journal_URL["j-NUOVO-CIMENTO-B"]			= "http://link.springer.com/journal/11542"
    Journal_URL["j-NUOVO-CIMENTO-B-11"]			= "http://link.springer.com/journal/40764"
    Journal_URL["j-NUOVO-CIMENTO-D"]			= "http://link.springer.com/journal/11544"
    Journal_URL["j-NUOVO-CIMENTO-SOC-ITAL-FIS-B"]	= "http://link.springer.com/journal/11542"
    Journal_URL["j-NUOVO-SAGGIATORE"]			= "http://www.sif.it/attivita/saggiatore/econtents"
    Journal_URL["j-NY-TIMES"]				= "http://www.nytimes.com/"
    Journal_URL["j-OBIT-NOTICES-FELLOWS-ROY-SOC"]	= "http://rsbm.royalsocietypublishing.org/content/royobits"
    Journal_URL["j-OIKOS"]				= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1600-0706"
    Journal_URL["j-OPEN-J-DISCRETE-MATH"]		= "http://www.scirp.org/journal/OJDM/"
    Journal_URL["j-OPER-MATRICES"]			= "http://oam.ele-math.com/"
    Journal_URL["j-OPER-RES"]				= "http://pubsonline.informs.org/loi/opre"
    Journal_URL["j-OPER-SYS-REV"]			= "http://portal.acm.org/browse_dl.cfm?idx=J597"
    Journal_URL["j-OPT-COMM"]				= "http://www.sciencedirect.com/science/journal/00304018"
    Journal_URL["j-OPT-CTL-APPL-METH"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1099-1514"
    Journal_URL["j-OPT-EXPRESS"]			= "http://opticsexpress.org/Issue.cfm"
    Journal_URL["j-OPT-LET"]				= "http://www.opticsinfobase.org/ol/"
    Journal_URL["j-OPTICA"]				= "https://www.osapublishing.org/optica/"
    Journal_URL["j-OPTICS-NEWS"]			= "http://www.osa-opn.org/home/archive/"
    Journal_URL["j-OPTICS-PHOTONICS-NEWS"]		= "http://www.osa-opn.org/home/archive/"
    Journal_URL["j-OPTIK"]				= "http://www.sciencedirect.com/science/journal/00304026"
    Journal_URL["j-OPTIM-ENG"]				= "http://link.springer.com/journal/11081"
    Journal_URL["j-OPTIM-LETT"]				= "http://link.springer.com/journal/11590"
    Journal_URL["j-OPTIM-METHODS-SOFTW"]		= "http://www.tandfonline.com/loi/goms20"
    Journal_URL["j-OPTIMIZATION"]			= "http://www.tandfonline.com/loi/gopt20"
    Journal_URL["j-ORDER-DORDRECHT"]			= "http://link.springer.com/journal/11083"
    Journal_URL["j-ORIG-LIFE-EVOL-BIOSPH"]		= "http://www.springerlink.com/openurl.asp?genre=journal&issn=0169-6149"
    Journal_URL["j-ORSA-J-COMPUT"]			= "http://pubsonline.informs.org/loi/ojoc"
    Journal_URL["j-OSIRIS"]				= "http://www.jstor.org/page/journal/osiris/about.html"
    Journal_URL["j-OSIRIS-2"]				= "http://www.jstor.org/page/journal/osiris/about.html"
    Journal_URL["j-PAC-HIST-REV"]			= "http://phr.ucpress.edu/content/by/year"
    Journal_URL["j-PAC-J-MATH"]				= "http://msp.org/pjm"
    Journal_URL["j-PAC-J-APPL-MATH"]			= "http://www.novapublishers.com/catalog/product_info.php?products_id=6697"
    Journal_URL["j-PACMPL"]				= "http://pacmpl.acm.org/"
    Journal_URL["j-PAMM"]				= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1617-7061"
    Journal_URL["j-PARALLEL-ALGORITHMS-APPL"]		= "http://www.tandfonline.com/loi/gpaa20"
    Journal_URL["j-PARALLEL-COMPUTING"]			= "http://www.sciencedirect.com/science/journal/01678191"
    Journal_URL["j-PARALLEL-PROCESS-LETT"]		= "http://www.worldscientific.com/loi/ppl"
    Journal_URL["j-PEDIATRIC-RES"]			= "http://www.nature.com/pr/archive"
    Journal_URL["j-PERFORM-INSTR"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1932-0166"
    Journal_URL["j-PERSPECT-SCI"]			= "http://muse.jhu.edu/journals/perspectives_on_science/; http://www.mitpressjournals.org/loi/posc/"
    Journal_URL["j-PERSPECT-SCI-CHRIST-FAITH"]		= "http://network.asa3.org/?page=PSCF"
    Journal_URL["j-PHASE-TRANSIT"]			= "http://www.tandfonline.com/loi/gpht20"
    Journal_URL["j-PHILOS-MAG"]				= "http://www.tandfonline.com/loi/tphm19"
    Journal_URL["j-PHILOS-MAG-4"]			= "http://www.tandfonline.com/toc/tphm15"
    Journal_URL["j-PHILOS-MAG-5"]			= "http://www.tandfonline.com/loi/tphm16"
    Journal_URL["j-PHILOS-MAG-6"]			= "http://www.tandfonline.com/loi/tphm17"
    Journal_URL["j-PHILOS-MAG-7"]			= "http://www.tandfonline.com/loi/tphm20"
    Journal_URL["j-PHILOS-MAG-8"]			= "http://www.tandf.co.uk/journals/titles/14786435.asp"
    Journal_URL["j-PHILOS-MAG-A"]			= "http://www.tandfonline.com/loi/tpha20"
    Journal_URL["j-PHILOS-MAG-B"]			= "http://www.tandfonline.com/loi/tphb20"
    Journal_URL["j-PHILOS-MAG-LETT"]			= "http://www.tandfonline.com/loi/tphl20"
    Journal_URL["j-PHILOS-NATUR"]			= "http://philnat.klostermann.de/"
    Journal_URL["j-PHILOS-PHENOMENOL-RES"]		= "https://onlinelibrary.wiley.com/loi/19331592"
    Journal_URL["j-PHILOS-SCI"]				= "http://www.jstor.org/journal/philscie"
    Journal_URL["j-PHILOS-SOC-SCI"]			= "https://journals.sagepub.com/loi/posa"
    Journal_URL["j-PHILOS-STUD"]			= "https://www.jstor.org/journal/philstudies"
    Journal_URL["j-PHILOS-TOP"]				= "http://www.jstor.org/journal/philtopics"
    Journal_URL["j-PHILOS-TRANS-R-SOC-LOND"]		= "http://rsta.royalsocietypublishing.org/"
    Journal_URL["j-PHILOS-TRANS-R-SOC-LOND-A-CONTAIN-PAP-MATH-PHYS-CHARACTER"]	= "https://royalsocietypublishing.org/loi/rsta"
    Journal_URL["j-PHILOS-TRANS-R-SOC-LOND-PHYS-SCI-ENG"] = "http://www.jstor.org/journals/09628428.html"
    Journal_URL["j-PHILOS-TRANS-R-SOC-LOND-SER-A"]	= "http://rsta.royalsocietypublishing.org/"
    Journal_URL["j-PHILOS-TRANS-R-SOC-LOND-SER-A-MATH-PHYS-SCI"]	= "http://www.jstor.org/journals/00804614.html"
    Journal_URL["j-PHILOS-TRANS-R-SOC-LOND-SER-B-BIO-SCI"] = "https://royalsocietypublishing.org/loi/rstb"
    Journal_URL["j-PHOTONICS-NANOSTRUCT"]		= "http://www.sciencedirect.com/science/journal/15694410"
    Journal_URL["j-PHOTONIQUES"]			= "http://www.photoniques.com/"
    Journal_URL["j-PHYS-AT-NUCL"]			= "http://link.springer.com/journal/11450"
    Journal_URL["j-PHYS-BL"]				= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1521-3722"
    Journal_URL["j-PHYS-BULL"]				= "http://iopscience.iop.org/0031-9112"
    Journal_URL["j-PHYS-CHEM-CHEM-PHYS"]		= "http://pubs.rsc.org/en/journals/journal/cp"
    Journal_URL["j-PHYS-CHEM-LIQ"]			= "http://www.tandfonline.com/loi/gpch20"
    Journal_URL["j-PHYS-CHEM-MINERALS"]			= "http://www.springerlink.com/content/0342-1791"
    Journal_URL["j-PHYS-EARTH-PLANET-INTER"]		= "http://www.sciencedirect.com/science/journal/00319201"
    Journal_URL["j-PHYS-EDUC"]				= "http://iopscience.iop.org/0031-9120/"
    Journal_URL["j-PHYS-FLUIDS"]			= "http://scitation.aip.org/content/aip/journal/pof1"
    Journal_URL["j-PHYS-FLUIDS-A"]			= "http://scitation.aip.org/content/aip/journal/pofa"
    Journal_URL["j-PHYS-J"]				= "http://www.pro-physik.de/phy/physik/archiv.html"
    Journal_URL["j-PHYS-LET"]				= "http://www.sciencedirect.com/science/journal/00319163"
    Journal_URL["j-PHYS-LET-A"]				= "http://www.sciencedirect.com/science/journal/03759601"
    Journal_URL["j-PHYS-LET-B"]				= "http://www.sciencedirect.com/science/journal/03702693"
    Journal_URL["j-PHYS-MED-BIOL"]			= "http://iopscience.iop.org/0031-9155"
    Journal_URL["j-PHYS-PART-NUCL"]			= "http://scitation.aip.org/content/aip/journal/ppn; http://link.springer.com/journal/11496"
    Journal_URL["j-PHYS-PERSPECT"]			= "http://link.springer.com/journal/16"
    Journal_URL["j-PHYS-PLASMAS"]			= "http://scitation.aip.org/content/aip/journal/pop"
    Journal_URL["j-PHYS-PROCEDIA"]			= "http://www.sciencedirect.com/science/journal/18753892"
    Journal_URL["j-PHYS-REP"]				= "http://www.sciencedirect.com/science/journal/03701573"
    Journal_URL["j-PHYS-REV"]				= "http://journals.aps.org/pr/issues"
    Journal_URL["j-PHYS-REV-1"]				= "http://journals.aps.org/archive/browse"
    Journal_URL["j-PHYS-REV-2"]				= "http://journals.aps.org/archive/browse"
    Journal_URL["j-PHYS-REV-A"]				= "http://pra.aps.org/browse"
    Journal_URL["j-PHYS-REV-A-3"]			= "http://pra.aps.org/browse"
    Journal_URL["j-PHYS-REV-B"]				= "http://journals.aps.org/prb/"
    Journal_URL["j-PHYS-REV-B-CMMP"]			= "http://prb.aps.org/browse"
    Journal_URL["j-PHYS-REV-B-SS"]			= "http://prb.aps.org/browse"
    Journal_URL["j-PHYS-REV-C"]				= "http://prc.aps.org/browse"
    Journal_URL["j-PHYS-REV-D"]				= "http://prd.aps.org/browse"
    Journal_URL["j-PHYS-REV-E"]				= "http://pre.aps.org/browse"
    Journal_URL["j-PHYS-REV-FOCUS"]			= "http://focus.aps.org/"
    Journal_URL["j-PHYS-REV-LET"]			= "http://prl.aps.org/browse"
    Journal_URL["j-PHYS-REV-X"]				= "http://prx.aps.org/browse"
    Journal_URL["j-PHYS-STATUS-SOLIDI"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1521-3951"
    Journal_URL["j-PHYS-STATUS-SOLIDI-B-BASIC-RES"]	= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1521-3951/"
    Journal_URL["j-PHYS-STATUS-SOLIDI-RAPID-RES-LETT"]	= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1862-6270"
    Journal_URL["j-PHYS-TEACHER"]			= "http://scitation.aip.org/content/aapt/journal/tpt"
    Journal_URL["j-PHYS-TODAY"]				= "http://www.physicstoday.org/"
    Journal_URL["j-PHYS-UNSERER-ZEIT"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1521-3943"
    Journal_URL["j-PHYS-USPEKHI"]			= "http://iopscience.iop.org/0038-5670"
    Journal_URL["j-PHYS-WORLD"]				= "http://physicsworldarchive.iop.org/"
    Journal_URL["j-PHYSICA"]				= "http://www.sciencedirect.com/science/journal/00318914"
    Journal_URL["j-PHYSICA"]				= "http://www.sciencedirect.com/science/journal/00318914/"
    Journal_URL["j-PHYSICA-A"]				= "http://www.sciencedirect.com/science/journal/03784371"
    Journal_URL["j-PHYSICA-B"]				= "http://www.sciencedirect.com/science/journal/09214526"
    Journal_URL["j-PHYSICA-D"]				= "http://www.sciencedirect.com/science/journal/01672789"
    Journal_URL["j-PHYSICA-SCRIPTA"]			= "http://iopscience.iop.org/1402-4896/"
    Journal_URL["j-PHYSICS"]				= "http://physics.aps.org/"
    Journal_URL["j-PHYSIKAL-Z"]				= "http://catalog.hathitrust.org/Record/000541302"
    Journal_URL["j-PHYSIS"]				= "http://www.olschki.it/riviste/17"
    Journal_URL["j-PHYSIS-NS"]				= "http://www.olschki.it/riviste/17"
    Journal_URL["j-PLANET-SPACE-SCI"]			= "http://www.sciencedirect.com/science/journal/00320633"
    Journal_URL["j-PLASMA-PHYS-CONTROL-FUSION"]		= "http://iopscience.iop.org/0741-3335"
    Journal_URL["j-PLASMA-IONS"]			= "http://www.elsevier.fr/plasmas/"
    Journal_URL["j-PLASMA-PHYS"]			= "http://iopscience.iop.org/0032-1028"
    Journal_URL["j-PLATIN-MET-REV"]			= "http://www.technology.matthey.com/journal-archive/; http://www.platinummetalsreview.com/"
    Journal_URL["j-PLOS-COMPUT-BIOL"]			= "http://compbiol.plosjournals.org/"
    Journal_URL["j-PLOS-MED"]				= "http://medicine.plosjournals.org/"
    Journal_URL["j-PLOS-ONE"]				= "http://www.plosone.org/"
    Journal_URL["j-POLIT-ANAL"]				= "https://www.cambridge.org/core/journals/political-analysis/all-issues"
    Journal_URL["j-POLITY"]				= "http://www.jstor.org/journals/00323497.html; http://www.palgrave-journals.com/polity/"
    Journal_URL["j-POLYMER"]				= "http://www.sciencedirect.com/science/journal/00323861"
    Journal_URL["j-POLYMER-J-TOKYO"]			= "http://www.nature.com/pj/archive"
    Journal_URL["j-POMACS"]				= "http://dl.acm.org/pub.cfm?id=J1567"
    Journal_URL["j-PORT-MATH"]				= "http://www.ems-ph.org/journals/journal.php?jrn=pm"
    Journal_URL["j-POSITIVITY"]				= "http://link.springer.com/journal/11117"
    Journal_URL["j-PRAMANA"]				= "http://www.springerlink.com/content/0304-4289"
    Journal_URL["j-PRIKL-MAT-MEH"]			= "http://www.sciencedirect.com/science/journal/00218928"
    Journal_URL["j-PROBAB-SURV"]			= "http://projecteuclid.org/all/euclid.ps"
    Journal_URL["j-PROBAB-ENGRG-INFORM-SCI"]		= "http://www.journals.cambridge.org/jid_PES"
    Journal_URL["j-PROBAB-THEORY-RELAT-FIELDS"]		= "http://link.springer.com/journal/440"
    Journal_URL["j-PROC-AM-MATH-SOC"]			= "http://www.ams.org/journals/proc"
    Journal_URL["j-PROC-AMER-PHIL-SOC"]			= "http://www.jstor.org/journal/procamerphilsoci"
    Journal_URL["j-PROC-CAMBRIDGE-PHIL-SOC"]		= "http://journals.cambridge.org/action/displayJournal?jid=PSP"
    Journal_URL["j-PROC-CHEM-SOC-LONDON"]		= "http://pubs.rsc.org/en/journals/journalissues/ps"
    Journal_URL["j-PROC-EDINBURGH-MATH-SOC"]		= "http://journals.cambridge.org/action/displayJournal?jid=PEM"
    Journal_URL["j-PROC-EDINBURGH-MATH-SOC-2"]		= "http://journals.cambridge.org/action/displayJournal?jid=PEM"
    Journal_URL["j-PROC-IEE"]				= "https://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=5247218"
    Journal_URL["j-PROC-IEEE"]				= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=5"
    Journal_URL["j-PROC-IRE"]				= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=10933"
    Journal_URL["j-PROC-LONDON-MATH-SOC"]		= "http://plms.oxfordjournals.org/content/by/year"
    Journal_URL["j-PROC-LONDON-MATH-SOC-3"]		= "http://londmathsoc.onlinelibrary.wiley.com/hub/journal/10.1112/(ISSN)1460-244X/"
    Journal_URL["j-PROC-JAPAN-ACAD-SER-A-MATH-SCI"]	= "http://projecteuclid.org/pja"
    Journal_URL["j-PROC-LINN-SOC-LONDON"]		= "https://academic.oup.com/proceedingslinnean"
    Journal_URL["j-PROC-LONDON-MATH-SOC-1"]		= "http://plms.oxfordjournals.org/content/by/year"
    Journal_URL["j-PROC-MANCHESTER-LIT-PHILOS-SOC"]	= "http://www.manlitphil.ac.uk/pages/?page_id=20"
    Journal_URL["j-PROC-NATL-ACAD-SCI-USA"]		= "http://www.pnas.org/content/by/year"
    Journal_URL["j-PROC-PHYS-SOC"]			= "http://iopscience.iop.org/0370-1328"
    Journal_URL["j-PROC-PHYS-SOC-LONDON-SECT-A"]	= "http://iopscience.iop.org/0370-1298"
    Journal_URL["j-PROC-PHYS-SOC-LONDON-SECT-B"]	= "http://iopscience.iop.org/0370-1301"
    Journal_URL["j-PROC-R-INST-G-B"]			= "http://catalog.hathitrust.org/Record/008307565"
    Journal_URL["j-PROC-R-SOC-B"]			= "http://rspb.royalsocietypublishing.org/"
    Journal_URL["j-PROC-R-SOC-EDINB"]			= "http://journals.cambridge.org/action/displayJournal?jid=PRE"
    Journal_URL["j-PROC-R-SOC-EDINB-SECT-A-MATH"]	= "http://journals.cambridge.org/action/displayJournal?jid=PRE"
    Journal_URL["j-PROC-R-SOC-EDINB-SECT-A-MATH"]	= "http://journals.cambridge.org/action/displayJournal?jid=PRM"
    Journal_URL["j-PROC-R-SOC-EDINB-SECT-A-MATH-PHYS-SCI"] = "http://journals.cambridge.org/action/displayJournal?jid=PRM"
    Journal_URL["j-PROC-R-SOC-LOND"]			= "http://rspa.royalsocietypublishing.org/content/by/year"
    Journal_URL["j-PROC-R-SOC-LOND-SER-A"]		= "http://rspa.royalsocietypublishing.org/"
    Journal_URL["j-PROC-R-SOC-LOND-SER-B"]		= "http://rspb.royalsocietypublishing.org/content/by/year"
    Journal_URL["j-PROC-R-SOC-LOND-SER-A-MATH-PHYS"]	= "http://rspa.royalsocietypublishing.org/"
    Journal_URL["j-PROC-R-SOC-LOND-SER-A-MATH-PHYS-ENG-SCI"] = "http://rspa.royalsocietypublishing.org/"
    Journal_URL["j-PROC-R-SOC-LOND-SER-A-MATH-PHYS-SCI"] = "http://rspa.royalsocietypublishing.org/"
    Journal_URL["j-PROC-R-SOC-LOND-SER-B-BIO-SCI"]	= "https://royalsocietypublishing.org/loi/rspb"
    ## Journal_URL["j-PROC-SOC-PSYCH-RES"]			= ""
    Journal_URL["j-PROC-STAT-SOC-LONDON"]		= "http://www.jstor.org/journals/20465890.html"
    Journal_URL["j-PROC-VLDB-ENDOWMENT"]		= "http://portal.acm.org/toc.cfm?id=J869"
    Journal_URL["j-PROCEDIA-SOC-BEHAV-SCI"]		= "http://www.sciencedirect.com/science/journal/18770428"
    Journal_URL["j-PROG-BIOPHYS-MOL-BIOL"]		= "http://www.sciencedirect.com/science/journal/00796107"
    Journal_URL["j-PROG-COMP-SOFT"]			= "http://link.springer.com/journal/11086"
    Journal_URL["j-PROG-ELECTROMAGN-RES"]		= "http://www.jpier.org/PIER/"
    Journal_URL["j-PROGR-OCEANOGR"]			= "https://www.sciencedirect.com/science/journal/00796611"
    Journal_URL["j-PROG-THEOR-PHYS"]			= "http://ptp.oxfordjournals.org/content/by/year"
    Journal_URL["j-PROTEIN-STRUCT-FUNCT-BIOINF"]	= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1097-0134"
    Journal_URL["j-PSYCHOL-METHODS"]			= "http://psycnet.apa.org/journals/met/"
    Journal_URL["j-PSYCHOL-REV"]			= "https://www.apa.org/pubs/journals/rev/"
    Journal_URL["j-PUBL-ASTRON-SOC-PAC"]		= "http://iopscience.iop.org/journal/1538-3873"
    Journal_URL["j-PUBL-MATH-DEBRECEN"]			= "http://publi.math.unideb.hu/"
    Journal_URL["j-PURE-APPL-CHEM"]			= "http://www.degruyter.com/view/j/pac"
    Journal_URL["j-PURE-APPL-GEOPHYS"]			= "http://link.springer.com/journal/24"
    Journal_URL["j-QJM"]				= "https://academic.oup.com/qjmed/issue"
    Journal_URL["j-QUAD-STORIA-FISICA"]			= "http://www.sif.it/riviste/qsf/econtents"
    Journal_URL["j-QUANT-FINANCE"]			= "http://www.tandfonline.com/loi/rquf20"
    Journal_URL["j-QUANTUM-INF-PROCESS"]		= "http://link.springer.com/journal/11128"
    Journal_URL["j-QUART-APPL-MATH"]			= "http://dl.acm.org/citation.cfm?id=J641; http://www.ams.org/journals/qam"
    Journal_URL["j-QUART-J-MATH"]			= "https://academic.oup.com/qjmath/issue"
    Journal_URL["j-QUART-J-MATH-OXFORD"]		= "https://academic.oup.com/qjmath/issue"
    Journal_URL["j-QUART-J-MECH-APPLIED-MATH"]		= "http://qjmam.oxfordjournals.org/content/by/year"
    Journal_URL["j-QUART-J-ROY-METEOROL-SOC"]		= "http://rmets.onlinelibrary.wiley.com/hub/journal/10.1002/(ISSN)1477-870X/issues/"
    Journal_URL["j-QUEUE"]				= "http://portal.acm.org/browse_dl.cfm?idx=J882"
    Journal_URL["j-R-JOURNAL"]				= "http://journal.r-project.org/"
    Journal_URL["j-R-NEWS"]				= "http://journal.r-project.org/"
    Journal_URL["j-R-SOC-OPEN-SCI"]			= "http://rsos.royalsocietypublishing.org/"
    Journal_URL["j-RADIAT-PHYS-CHEM"]			= "https://www.sciencedirect.com/journal/radiation-physics-and-chemistry"
    Journal_URL["j-RADIAT-RES"]				= "http://www.jstor.org/journal/radirese"
    Journal_URL["j-RADIOCHIM-ACTA"]			= "http://www.oldenbourg-link.com/loi/ract"
    Journal_URL["j-RADIUM-PARIS"]			= "http://radium.journaldephysique.org/"
    Journal_URL["j-RAMANUJAN-J"]			= "http://link.springer.com/journal/11139"
    Journal_URL["j-RECHERCHE"]				= "http://www.larecherche.fr/"
    Journal_URL["j-REG-SCI-URBAN-ECON"]			= "http://www.sciencedirect.com/science/journal/01660462"
    Journal_URL["j-REGISTER"]				= "https://www.theregister.co.uk/"
    Journal_URL["j-RELIABLE-COMPUTING"]			= "http://link.springer.com/journal/11155"
    Journal_URL["j-REP-BRIT-ASSOC-ADV-SCI"]		= "https://catalog.hathitrust.org/Record/008891242"
    Journal_URL["j-REP-PROG-PHYS"]			= "http://iopscience.iop.org/0034-4885"
    Journal_URL["j-RES-MATH-SCI"]			= "https://www.springer.com/journal/40687"
    Journal_URL["j-RES-POLICY"]				= "http://www.sciencedirect.com/science/journal/00487333"
    Journal_URL["j-RESONANCE"]				= "http://link.springer.com/journal/12045"
    Journal_URL["j-REV-AM-HIST"]			= "http://www.jstor.org/journals/00487511.html"
    Journal_URL["j-REV-BRAS-FIS"]			= "http://www.sbfisica.org.br/bjp/"
    Journal_URL["j-REV-ECON-STAT"]			= "http://www.jstor.org/journal/revieconstat; http://www.mitpressjournals.org/loi/rest"
    Journal_URL["j-REV-ECON-STUD"]			= "http://restud.oxfordjournals.org/content/by/year"
    Journal_URL["j-REV-FINANCE"]			= "https://academic.oup.com/rof/issue"
    Journal_URL["j-REV-FISH-BIOL-FISH"]			= "https://www.springer.com/journal/11160"
    Journal_URL["j-REV-FISH-SCI-AQUAC"]			= "https://www.tandfonline.com/loi/brfs21"
    Journal_URL["j-REV-GEOPHYS-SPACE-PHYS"]		= "http://agupubs.onlinelibrary.wiley.com/agu/journal/10.1002/(ISSN)1944-9208"
    Journal_URL["j-REV-HIST-MATH"]			= "http://smf4.emath.fr/Publications/RevueHistoireMath/"
    Journal_URL["j-REV-HIST-SCI"]			= "http://www.jstor.org/journals/00487996.html; http://www.persee.fr/collection/rhs; http://www.jstor.org/action/showPublication?journalCode=revuhistscie"
    Journal_URL["j-REV-HIST-SCI"]			= "http://www.jstor.org/journals/00487996.html; http://www.persee.fr/collection/rhs; http://www.persee.fr/collection/rhs; http://www.jstor.org/action/showPublication?journalCode=revuhistscie"
    Journal_URL["j-REV-HIST-SCI-LEURS-APPL"]		= "http://www.jstor.org/journals/00487996.html; http://www.persee.fr/collection/rhs"
    Journal_URL["j-REV-HIST-SCI-LEURS-APPL"]		= "http://www.olschki.it/riviste/17"
    Journal_URL["j-REV-MATH-PHYS"]			= "https://www.worldscientific.com/worldscinet/rmp"
    Journal_URL["j-REV-METAPHYS-MORALE"]		= "http://www.jstor.org/journal/revumetamora"
    Journal_URL["j-REV-MOD-PHYS"]			= "http://rmp.aps.org/browse"
    Journal_URL["j-REV-NETW-ECON"]			= "http://www.degruyter.com/view/j/rne"
    Journal_URL["j-REV-PHILOS-FR-ETRANG"]		= "http://www.jstor.org/journal/revuphilfranetra"
    Journal_URL["j-REV-PORT-PHILOS"]			= "http://www.jstor.org/journals/08705283.html"
    Journal_URL["j-REV-QUEST-SCI"]			= "http://www.unamur.be/sciences/philosoc/revueqs"
    Journal_URL["j-REV-SCI-INSTRUM"]			= "http://rsi.aip.org/"
    Journal_URL["j-REV-SYMB-LOG"]			= "https://www.cambridge.org/core/journals/review-of-symbolic-logic"
    Journal_URL["j-REV-SYNTH"]				= "http://link.springer.com/journal/11873"
    Journal_URL["j-RHEOL-ACTA"]				= "http://link.springer.com/journal/397"
    Journal_URL["j-RHET-SOC-Q"]				= "http://www.jstor.org/journal/rhetsociquar"
    Journal_URL["j-RIC-MAT"]				= "http://link.springer.com/journal/11587"
    Journal_URL["j-RISK-ANAL"]				= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1539-6924"
    Journal_URL["j-RISK-MANAGEMENT"]			= "https://link.springer.com/journal/41283/volumes-and-issues; https://www.jstor.org/journal/riskmanagement; http://www.palgrave.com/gp/journal/41283"
    Journal_URL["j-RISKNEWS"]				= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1616-0045"
    Journal_URL["j-RIV-NUOVO-CIMENTO"]			= "http://www.sif.it/riviste/ncr/econtents"
    Journal_URL["j-ROCKY-MOUNTAIN-J-MATH"]		= "http://projecteuclid.org/euclid.rmjm"
    Journal_URL["j-RUSS-J-PHYS-CHEM-A"]			= "http://www.springerlink.com/content/0036-0244"
    Journal_URL["j-RUSS-J-PHYS-CHEM-B"]			= "http://link.springer.com/journal/11826"
    Journal_URL["j-RUSS-LIT"]				= "http://www.sciencedirect.com/science/journal/03043479"
    Journal_URL["j-RUSS-MATH"]				= "http://link.springer.com/journal/11982"
    Journal_URL["j-RUSS-MATH-SURV"]			= "http://iopscience.iop.org/0036-0279"
    Journal_URL["j-S-B-KAISERL-AKAD-WISS"]		= "http://catalog.hathitrust.org/Record/003086676"
    Journal_URL["j-S-B-KONIG-PREUSS-AKAD-WISS"]		= "http://www.biodiversitylibrary.org/bibliography/42231"
    Journal_URL["j-S-B-KONIG-PREUSS-AKAD-WISS-BERLIN"]	= "http://www.biodiversitylibrary.org/bibliography/42231"
    Journal_URL["j-S-B-MATH-NATURWISS-KL-KAISERL-AKAD-WISS"] = "http://catalog.hathitrust.org/Record/003086685"
    Journal_URL["j-S-B-PREUSS-AKAD-WISS-PHYS-MATH-KL"]	= "http://www.biodiversitylibrary.org/bibliography/92710"
    Journal_URL["j-SAMPL-THEORY-SIGNAL-IMAGE-PROCESS"]	= "http://stsip.org/"
    Journal_URL["j-SANKHYA"]				= "https://www.jstor.org/journal/sankhya"
    Journal_URL["j-SCAND-J-STAT"]			= "https://onlinelibrary.wiley.com/loi/14679469"
    Journal_URL["j-SCHOOL-SCI-MATH"]			= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1949-8594"
    Journal_URL["j-SCI-ADV"]				= "http://advances.sciencemag.org/content/by/year"
    Journal_URL["j-SCI-AMER"]				= "http://www.nature.com/scientificamerican"
    Journal_URL["j-SCI-CHINA-MATH"]			= "http://link.springer.com/journal/11425"
    Journal_URL["j-SCI-CITIZEN"]			= "http://www.tandfonline.com/loi/vzsc20"
    Journal_URL["j-SCI-COMPUT"]				= "http://digital.scientificcomputing.com/scientificcomputing/"
    Journal_URL["j-SCI-COMPUT-PROGRAM"]			= "http://www.sciencedirect.com/science/journal/01676423"
    Journal_URL["j-SCI-CONTEXT"]			= "http://journals.cambridge.org/action/displayJournal?jid=SIC"
    Journal_URL["j-SCI-EDUC"]				= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1098-237X"
    Journal_URL["j-SCI-EDUC-SPRINGER"]			= "http://link.springer.com/journal/11191"
    Journal_URL["j-SCI-MATH-JPN"]			= "http://www.jams.or.jp/notice/scmj/smj.html"
    Journal_URL["j-SCI-MONTHLY"]			= "http://www.jstor.org/journal/sciemont"
    Journal_URL["j-SCI-NEWS"]				= "http://www.jstor.org/journals/00368423.html"
    Journal_URL["j-SCI-NEWS-LETT"]			= "http://www.jstor.org/journal/scienewslett"
    Journal_URL["j-SCI-PROG"]				= "http://iospress.metapress.com/content/1058-9244"
    Journal_URL["j-SCI-PROG-RUSHDEN-UK"]		= "http://www.jstor.org/journal/scienceprogress"
    Journal_URL["j-SCI-PUBLIC-POL"]			= "http://spp.oxfordjournals.org/content/by/year"
    Journal_URL["j-SCI-REP"]				= "http://www.nature.com/srep/"
    Journal_URL["j-SCI-REV-MENT-HEALTH-PRAC"]		= "https://www.srmhp.org/online-articles.html"
    Journal_URL["j-SCI-SOC"]				= "http://guilfordjournals.com/loi/siso"
    Journal_URL["j-SCI-STUD"]				= "http://www.jstor.org/journals/00368539.html"
    Journal_URL["j-SCI-TECHNOL-LIB"]			= "http://www.tandfonline.com/loi/wstl20"
    Journal_URL["j-SCIENCE"]				= "http://www.sciencemag.org/archive/"
    Journal_URL["j-SCIENCE-NEW-SERIES"]			= "http://www.sciencemag.org/archive/"
    Journal_URL["j-SCIENCE-NEWS"]			= "http://www.jstor.org/journals/00368423.html; http://www.sciencenews.org/view/archives; http://www3.interscience.wiley.com/journal/122396840/home"
    Journal_URL["j-SCIENCES"]				= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)2326-1951"
    Journal_URL["j-SCIENTIA-MILAN"]			= "http://amshistorica.unibo.it/6"
    Journal_URL["j-SCIENTIST"]				= "http://www.the-scientist.com/"
    Journal_URL["j-SCIENTOMETRICS"]			= "http://link.springer.com/journal/11192"
    Journal_URL["j-SCPE"]				= "http://www.scpe.org/"
    Journal_URL["j-SEMIOTICA"]				= "https://www.degruyter.com/view/j/semi.2016.2016.issue-209/issue-files/semi.2016.2016.issue-209.xml"
    Journal_URL["j-SENSORS-BASEL"]			= "https://www.mdpi.com/journal/sensorsb"
    Journal_URL["j-SERB-ASTRON-J"]			= "http://doiserbia.nb.rs/journal.aspx?issn=1450-698X"
    Journal_URL["j-SET-VALUED-ANAL"]			= "http://link.springer.com/journal/11228"
    Journal_URL["j-SET-VALUED-VAR-ANAL"]		= "http://link.springer.com/journal/11228"
    Journal_URL["j-SIAM-ASA-J-UNCERTAIN-QUANTIF"]	= "http://epubs.siam.org/loi/sjuqa3"
    Journal_URL["j-SIAM-J-ALG-DISC-METH"]		= "http://epubs.siam.org/loi/sjamdu"
    Journal_URL["j-SIAM-J-APPL-ALGEBR-GEOM"]		= "http://epubs.siam.org/loi/sjaabq"
    Journal_URL["j-SIAM-J-APPL-DYN-SYST"]		= "http://epubs.siam.org/siads"
    Journal_URL["j-SIAM-J-APPL-MATH"]			= "http://epubs.siam.org/siap"
    Journal_URL["j-SIAM-J-COMPUT"]			= "http://epubs.siam.org/sicomp"
    Journal_URL["j-SIAM-J-CONTROL"]			= "http://epubs.siam.org/journal/sjcodc"
    Journal_URL["j-SIAM-J-CONTROL-OPTIM"]		= "http://epubs.siam.org/sicon"
    Journal_URL["j-SIAM-J-DISCR-MATH"]			= "http://epubs.siam.org/sidma"
    Journal_URL["j-SIAM-J-FINANCIAL-MATH"]		= "http://epubs.siam.org/sifin"
    Journal_URL["j-SIAM-J-IMAGING-SCI"]			= "http://epubs.siam.org/siims"
    Journal_URL["j-SIAM-J-MAT-ANA-APPL"]		= "http://epubs.siam.org/simax"
    Journal_URL["j-SIAM-J-MATH-ANA"]			= "http://epubs.siam.org/sima"
    Journal_URL["j-SIAM-J-NUM-ANALYSIS-B"]		= "http://epubs.siam.org/loi/sjnaam.1"
    Journal_URL["j-SIAM-J-NUMER-ANAL"]			= "http://epubs.siam.org/sinum"
    Journal_URL["j-SIAM-J-OPT"]				= "http://epubs.siam.org/siopt"
    Journal_URL["j-SIAM-J-SCI-COMP"]			= "http://epubs.siam.org/sisc"
    Journal_URL["j-SIAM-J-SCI-STAT-COMP"]		= "http://epubs.siam.org/loi/sijcd4"
    Journal_URL["j-SIAM-NEWS"]				= "http://www.siam.org/news/"
    Journal_URL["j-SIAM-REVIEW"]			= "http://epubs.siam.org/sirev"
    Journal_URL["j-SIB-MATH-J"]				= "http://link.springer.com/journal/11202"
    Journal_URL["j-SIG-PROC"]				= "http://www.sciencedirect.com/science/journal/01651684"
    Journal_URL["j-SIGACT"]				= "http://dl.acm.org/citation.cfm?id=J697"
    Journal_URL["j-SIGADA-LETTERS"]			= "http://portal.acm.org/citation.cfm?id=J32"
    Journal_URL["j-SIGAPP"]				= "https://dl.acm.org/loi/sigapp"
    Journal_URL["j-SIGCSE"]				= "http://portal.acm.org/browse_dl.cfm?idx=J688"
    Journal_URL["j-SIGMA-CHI-Q"]			= "http://www.jstor.org/journal/sigmxiquar"
    Journal_URL["j-SIGMETRICS"]				= "http://portal.acm.org/toc.cfm?id=J618"
    Journal_URL["j-SIGMOD"]				= "http://portal.acm.org/browse_dl.cfm?idx=J689"
    # Journal_URL["j-SIGNIF"]				= "https://rss.onlinelibrary.wiley.com/journal/17409713"
    Journal_URL["j-SIGNIF"]				= "https://academic.oup.com/jrssig/issue"
    Journal_URL["j-SIGNUM"]				= "http://portal.acm.org/browse_dl.cfm?idx=J690"
    Journal_URL["j-SIGPLAN"]				= "https://dl.acm.org/loi/sigplan"
    Journal_URL["j-SIGSAM"]				= "http://portal.acm.org/browse_dl.cfm?idx=J1000"
    Journal_URL["j-SIGSOFT"]				= "https://dl.acm.org/citation.cfm?id=J728"
    Journal_URL["j-SIMULATION"]				= "http://sim.sagepub.com/content/by/year"
    Journal_URL["j-SKEPT-INQ"]				= "https://www.csicop.org/si/archive"
    Journal_URL["j-SKY-TELESC"]				= "https://skyandtelescope.org/magazine_categories/sky-and-telescope-magazine/"
    Journal_URL["j-SOC-INDIC-RES"]			= "http://link.springer.com/journal/11205"
    Journal_URL["j-SOC-SCI-INFO"]			= "http://ssi.sagepub.com/content/by/year"
    Journal_URL["j-STUD-EAST-EUROPEAN-THOUGHT"]		= "http://link.springer.com/journal/11212"
    Journal_URL["j-SOC-STUD-SCI"]			= "http://sss.sagepub.com/content/by/year"
    Journal_URL["j-SOCIO-ECON"]				= "http://www.sciencedirect.com/science/journal/10535357"
    Journal_URL["j-SOCIOL-METHODS-RES"]			= "http://smr.sagepub.com/content"
    Journal_URL["j-SOFTWARE-SYST-MODEL"]		= "http://link.springer.com/journal/10270"
    Journal_URL["j-SOLID-STATE-COMMUN"]			= "http://www.sciencedirect.com/science/journal/00381098"
    Journal_URL["j-SOLID-STATE-PHYS-N-Y-1955"]		= "http://www.sciencedirect.com/science/bookseries/00811947"
    Journal_URL["j-SOV-J-QUANTUM-ELECTRON"]		= "http://iopscience.iop.org/0049-1748"
    Journal_URL["j-SOV-PHYS-USP"]			= "http://iopscience.iop.org/0038-5670"
    Journal_URL["j-SPACE-SCI-REV"]			= "http://link.springer.com/journal/11214"
    Journal_URL["j-SPE"]				= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1097-024X"
    Journal_URL["j-SPIP"]				= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1099-1670"
    Journal_URL["j-SPEKTRUM-WISSENSCHAFT"]		= "http://www.spektrum.de/shop/spektrum-der-wissenschaft/archiv/"
    Journal_URL["j-SPONT-GEN"]				= "https://spontaneousgenerations.library.utoronto.ca/"
    Journal_URL["j-SPRINGERPLUS"]			= "http://link.springer.com/journal/40064"
    Journal_URL["j-STAT-COMPUT"]			= "http://link.springer.com/journal/11222"
    Journal_URL["j-STAT-MED"]				= "https://onlinelibrary.wiley.com/journal/10970258"
    Journal_URL["j-STAT-METHODOL"]			= "http://www.sciencedirect.com/science/journal/15723127"
    Journal_URL["j-STAT-NEERLANDICA"]			= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1467-9574"
    Journal_URL["j-STAT-PAPERS"]			= "http://link.springer.com/journal/362"
    Journal_URL["j-STAT-PROB-LETT"]			= "http://www.sciencedirect.com/science/journal/01677152"
    Journal_URL["j-STAT-SCI"]				= "http://projecteuclid.org/all/euclid.ss"
    Journal_URL["j-STATIST-PAPERS"]			= "http://link.springer.com/journal/362"
    Journal_URL["j-STATISTICS"]				= "http://www.tandfonline.com/loi/gsta20"
    Journal_URL["j-STATISTICS-BERLIN"]			= "http://www.tandfonline.com/loi/gsta19"
    Journal_URL["j-STERNE-WELTRAUM"]			= "https://www.spektrum.de/shop/sterne-und-weltraum/archiv/"
    Journal_URL["j-STOCH-MODELS"]			= "http://www.tandfonline.com/loi/lstm19"
    Journal_URL["j-STOCH-PROC-APPL"]			= "http://www.sciencedirect.com/science/journal/03044149"
    Journal_URL["j-STRUCT-CHEM"]			= "http://www.springerlink.com/content/1040-0400"
    Journal_URL["j-STRUCT-MULTDISCIP-0PTIM"]		= "http://link.springer.com/journal/158"
    Journal_URL["j-STRUCT-OPTIM"]			= "http://link.springer.com/journal/158"
    Journal_URL["j-STUD-APPL-MATH"]			= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1467-9590"
    Journal_URL["j-STUD-HIST-PHILOS-MOD-PHYS"]		= "http://www.sciencedirect.com/science/journal/13552198"
    Journal_URL["j-STUD-HIST-PHILOS-SCI"]		= "http://www.sciencedirect.com/science/journal/00393681"
    Journal_URL["j-STUD-HIST-PHILOS-SCI-B"]		= "http://www.sciencedirect.com/science/journal/13552198"
    Journal_URL["j-STUD-HIST-PHILOS-SCI-C"]		= "http://www.sciencedirect.com/science/journal/13698486"
    Journal_URL["j-STUD-LOGICA"]			= "http://dx.doi.org/10.1007/s11225-010-9254-6"
    Journal_URL["j-STUD-SOV-THOUGHT"]			= "http://link.springer.com/journal/11212"
    ## Journal_URL["j-STUDIUM-GEN"]			= "????"
    Journal_URL["j-SUDHOFFS-ARCH"]			= "http://www.jstor.org/journal/sudharch"
    Journal_URL["j-SUPERCOND-SCI-TECHNOL"]		= "http://iopscience.iop.org/0953-2048"
    Journal_URL["j-SURF-INTERFACE-ANAL"]		= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1096-9918"
    Journal_URL["j-SURF-SCI-LETT"]			= "http://www.sciencedirect.com/science/journal/01672584"
    Journal_URL["j-SURVIVAL"]				= "http://www.tandfonline.com/loi/tsur20"
    Journal_URL["j-SWIAT-NAUKI"]			= "http://www.swiatnauki.pl"
    Journal_URL["j-SYNTHESE"]				= "https://link.springer.com/journal/11229"
    Journal_URL["j-SYST-CONTROL-LETT"]			= "http://www.sciencedirect.com/science/journal/01676911"
    Journal_URL["j-SYST-RES"]				= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1099-1735"
    Journal_URL["j-SYSTEM"]				= "http://www.sciencedirect.com/science/journal/0346251X"
    Journal_URL["j-TAAS"]				= "http://portal.acm.org/browse_dl.cfm?idx=J1010"
    Journal_URL["j-TACCESS"]				= "http://portal.acm.org/browse_dl.cfm?idx=J1156"
    Journal_URL["j-TACO"]				= "http://portal.acm.org/browse_dl.cfm?idx=J924"
    Journal_URL["j-TALG"]				= "http://portal.acm.org/browse_dl.cfm?idx=J982"
    Journal_URL["j-TALIP"]				= "http://portal.acm.org/browse_dl.cfm?idx=J820"
    Journal_URL["j-TALLIP"]				= "http://portal.acm.org/browse_dl.cfm?idx=J1521"
    Journal_URL["j-TAMKANG-J-MATH"]			= "http://journals.math.tku.edu.tw/index.php/TKJM"
    Journal_URL["j-TAP"]				= "http://portal.acm.org/browse_dl.cfm?idx=J932"
    Journal_URL["j-TCBB"]				= "https://dl.acm.org/loi/tcbb"
    Journal_URL["j-TCPS"]				= "http://dl.acm.org/pub.cfm?id=J1536"
    Journal_URL["j-TDS"]				= "https://dl.acm.org/loi/tds"
    Journal_URL["j-TEAC"]				= "http://dl.acm.org/citation.cfm?id=2542174"
    Journal_URL["j-TEAC"]				= "https://dl.acm.org/loi/teac"
    # Journal_URL["j-TECH-CULTURE"]			= "http://www.press.jhu.edu/journals/technology_and_culture/"
    # [29-Sep-2023] old value no longer works: this one does:
    Journal_URL["j-TECH-CULTURE"]			= "https://muse.jhu.edu/journal/194"
    Journal_URL["j-TECH-REVIEW"]			= "http://www.technologyreview.com/magazine/archive/"
    Journal_URL["j-TECHNOL-SOC"]			= "http://www.sciencedirect.com/science/journal/0160791X"
    Journal_URL["j-TECHNOMETRICS"]			= "http://www.jstor.org/journals/00401706.html; http://www.tandfonline.com/loi/utch20"
    Journal_URL["j-TECHNOVATION"]			= "http://www.sciencedirect.com/science/journal/01664972"
    Journal_URL["j-TECS"]				= "http://portal.acm.org/browse_dl.cfm?&idx=J840"
    Journal_URL["j-TECS"]				= "http://portal.acm.org/browse_dl.cfm?idx=J840"
    Journal_URL["j-TEORET-MATH-FIZ"]			= "http://link.springer.com/journal/11232"
    Journal_URL["j-TEST"]				= "http://link.springer.com/journal/11749"
    Journal_URL["j-TEXTURES-MICROSTRUCT"]		= "http://www.tandfonline.com/loi/gtam20"
    Journal_URL["j-THEOR-BIOL-MED-MODEL"]		= "http://tbiomed.biomedcentral.com/articles"
    Journal_URL["j-THEOR-CHEM-ACCOUNTS"]		= "http://link.springer.com/journal/214"
    Journal_URL["j-THEOR-CHIM-ACTA"]			= "http://link.springer.com/journal/214"
    Journal_URL["j-THEOR-COMP-SCI"]			= "http://www.sciencedirect.com/science/journal/03043975"
    Journal_URL["j-THEOR-MATH-PHYS"]			= "http://link.springer.com/journal/11232"
    Journal_URL["j-THEOR-POPUL-BIOL"]			= "http://www.sciencedirect.com/science/journal/00405809"
    Journal_URL["j-THEOREMA"]				= "http://www.jstor.org/journal/teorreviintefilo; http://www.unioviedo.es/Teorema/"
    Journal_URL["j-THEORIA"]				= "http://www3.interscience.wiley.com/journal/118902497"
    Journal_URL["j-THEORIA-MADRID"]			= "http://www.ehu.eus/ojs/index.php/THEORIA/issue/archive"
    Journal_URL["j-THEORY-DECISION"]			= "http://link.springer.com/journal/11238"
    Journal_URL["j-THEORY-PROBAB-APPL"]			= "http://epubs.siam.org/tvp"
    Journal_URL["j-THEORY-PROBAB-MATH-STAT"]		= "http://www.ams.org/publications/journals/journalsframework/tpms"
    Journal_URL["j-THRI"]				= "https://dl.acm.org/loi/thri"
    Journal_URL["j-TIIS"]				= "http://portal.acm.org/browse_dl.cfm?idx=J1341"
    Journal_URL["j-TIME"]				= "http://time.com/vault/"
    Journal_URL["j-TIMES"]				= "http://www.thetimes.co.uk/tto/archive/"
    Journal_URL["j-TIOT"]				= "https://dl.acm.org/loi/tiot"
    Journal_URL["j-TISSEC"]				= "http://portal.acm.org/browse_dl.cfm?idx=J789"
    Journal_URL["j-TIST"]				= "http://portal.acm.org/citation.cfm?id=J1318"
    Journal_URL["j-TKDD"]				= "http://portal.acm.org/browse_dl.cfm?idx=J1054"
    Journal_URL["j-TMIS"]				= "http://portal.acm.org/browse_dl.cfm?idx=J1320"
    Journal_URL["j-TOCE"]				= "http://portal.acm.org/browse_dl.cfm?idx=J1193"
    Journal_URL["j-TOCH"]				= "https://dl.acm.org/loi/health"
    Journal_URL["j-TOCHI"]				= "http://portal.acm.org/browse_dl.cfm?idx=J756"
    Journal_URL["j-TOCL"]				= "http://portal.acm.org/browse_dl.cfm?idx=J773"
    Journal_URL["j-TOCS"]				= "http://portal.acm.org/browse_dl.cfm?idx=J774"
    Journal_URL["j-TOCT"]				= "http://portal.acm.org/browse_dl.cfm?idx=J1190"
    Journal_URL["j-TODAES"]				= "http://portal.acm.org/browse_dl.cfm?idx=J776"
    Journal_URL["j-TODS"]				= "http://portal.acm.org/browse_dl.cfm?idx=J777"
    Journal_URL["j-TOG"]				= "http://portal.acm.org/browse_dl.cfm?idx=J778"
    Journal_URL["j-TOIS"]				= "http://portal.acm.org/browse_dl.cfm?idx=J779"
    Journal_URL["j-TOIT"]				= "http://portal.acm.org/browse_dl.cfm?idx=J780"
    Journal_URL["j-TOMACS"]				= "http://portal.acm.org/browse_dl.cfm?idx=J781"
    Journal_URL["j-TOMCCAP"]				= "http://portal.acm.org/browse_dl.cfm?idx=J961"
    Journal_URL["j-TOMM"]				= "http://portal.acm.org/browse_dl.cfm?idx=J961"
    Journal_URL["j-TOMPECS"]				= "http://dl.acm.org/pub.cfm?id=J1525"
    Journal_URL["j-TOMS"]				= "http://dl.acm.org/pub.cfm?id=J782"
    Journal_URL["j-TOPC"]				= "http://dl.acm.org/citation.cfm?id=2632163"
    Journal_URL["j-TOPLAS"]				= "http://portal.acm.org/browse_dl.cfm?idx=J783"
    Journal_URL["j-TOPOI"]				= "http://link.springer.com/journal/11245"
    Journal_URL["j-TOPOLOGY"]				= "http://www.sciencedirect.com/science/journal/00409383"
    Journal_URL["j-TOPS"]				= "http://dl.acm.org/citation.cfm?id=J1547"
    Journal_URL["j-TORS"]				= "https://dl.acm.org/loi/tors"
    Journal_URL["j-TOS"]				= "http://portal.acm.org/browse_dl.cfm?idx=J960"
    Journal_URL["j-TOSEM"]				= "http://portal.acm.org/browse_dl.cfm?idx=J790"
    Journal_URL["j-TOSN"]				= "http://portal.acm.org/browse_dl.cfm?idx=J981"
    Journal_URL["j-TQC"]				= "https://dl.acm.org/citation.cfm?id=J1620"
    Journal_URL["j-TRANS-AM-FISH-SOC"]			= "https://afspubs.onlinelibrary.wiley.com/journal/15488659"
    Journal_URL["j-TRANS-AM-MATH-SOC"]			= "http://www.ams.org/journals/tran/"
    Journal_URL["j-TRANS-AMER-INST-ELEC-ENG"]		= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=6413714"
    Journal_URL["j-TRANS-CAMBRIDGE-PHILOS-SOC"]		= ""
    Journal_URL["j-TRANS-FARADAY-SOC"]			= "http://pubs.rsc.org/en/journals/journalissues/tf"
    Journal_URL["j-TRANS-GIS"]				= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1467-9671"
    Journal_URL["j-TRANS-IRE-PROF-GROUP-INF-THEORY"]	= "http://ieeexplore.ieee.org/xpl/RecentIssue.jsp?punumber=4547596"
    Journal_URL["j-TRANS-MATH-APPL"]			= "https://academic.oup.com/imatrm/issue"
    Journal_URL["j-TRANS-N-Y-ACAD-SCI-2"]		= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)2164-0947"
    Journal_URL["j-TRANS-PROC-N-Z-INST"]		= "http://rsnz.natlib.govt.nz/"
    Journal_URL["j-TRANS-PROC-R-SOC-N-Z"]		= "http://rsnz.natlib.govt.nz/"
    Journal_URL["j-TRANS-R-SOC-CAN"]			= "http://www.rsc-src.ca/en/publications-resources/transactions-and-proceedings"
    Journal_URL["j-TRANS-R-SOC-EDINBURGH"]		= "https://catalog.hathitrust.org/Record/000505377"
    Journal_URL["j-TRANS-SOC-RHEOLOGY"]			= "http://scitation.aip.org/content/sor/journal/tsor"
    Journal_URL["j-TRANSFUSION"]			= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1537-2995"
    Journal_URL["j-TRENDS-COGN-SCI"]			= "http://www.sciencedirect.com/science/journal/13646613"
    Journal_URL["j-TRETS"]				= "http://portal.acm.org/toc.cfm?id=J1151"
    Journal_URL["j-TSAS"]				= "http://dl.acm.org/pub.cfm?id=J1514"
    Journal_URL["j-TSC"]				= "http://dl.acm.org/pub.cfm?id=J1546"
    Journal_URL["j-TSLP"]				= "http://portal.acm.org/browse_dl.cfm?&idx=J957"
    Journal_URL["j-TWO-YEAR-COLL-MATH-J"]		= "https://maa.tandfonline.com/loi/ucmj20; https://www.jstor.org/journal/twoyearcollmathj"
    Journal_URL["j-TUGboat"]				= "https://tug.org/TUGboat/"
    Journal_URL["j-TWEB"]				= "http://portal.acm.org/browse_dl.cfm?idx=J1062"
    Journal_URL["j-ULTRASONIC-IMAGING"]			= "http://www.sciencedirect.com/science/journal/01617346"
    Journal_URL["j-USPEHI-FIZ-NAUK"]			= "http://iopscience.iop.org/0038-5670"
    Journal_URL["j-USPEKHI-FIZ-NAUK"]			= "http://ufn.ru/en/articles/"
    Journal_URL["j-USSR-COMP-MATH-MATH-PHYS"]		= "http://www.sciencedirect.com/science/journal/00415553"
    Journal_URL["j-VERH-DTSCH-PHYS-GES"]		= "http://hdl.handle.net/2027/coo.31924056113495"
    Journal_URL["j-VERH-DTSCH-PHYS-GES-3"]		= "http://catalog.hathitrust.org/Record/012306260"
    Journal_URL["j-VERH-SCHWEIZ-NATURFORSCH-GES"]	= "http://retro.seals.ch/digbib/vollist?UID=sng-005"
    Journal_URL["j-VIENNA-CIRCLE-INSTITUTE-YEARBOOK"]	= "http://link.springer.com/bookseries/6669"
    Journal_URL["j-VLDB-J"]				= "http://portal.acm.org/toc.cfm?id=J869"
    Journal_URL["j-WAR-HIST"]				= "http://wih.sagepub.com/content/by/year"
    Journal_URL["j-WASHINGTON-POST"]			= "http://www.washingtonpost.com/"
    Journal_URL["j-WAVE-MOTION"]			= "http://www.sciencedirect.com/science/journal/01652125"
    Journal_URL["j-WAVES-RANDOM-COMPLEX-MEDIA"]		= "http://www.tandfonline.com/loi/twrm20"
    Journal_URL["j-WAVES-RANDOM-MEDIA"]			= "http://www.tandfonline.com/loi/twrm19"
    Journal_URL["j-WIRES"]				= "https://onlinelibrary.wiley.com/journal/19390068"
    Journal_URL["j-WILSON-Q"]				= "https://www.wilsonquarterly.com/"
    Journal_URL["j-WIRED"]				= "http://www.wired.com"
    Journal_URL["j-WOMENS-STUD-INT-FORUM"]		= "https://www.sciencedirect.com/science/journal/02775395"
    Journal_URL["j-YUGO-J-OPER-RES"]			= "http://www.doiserbia.nb.rs/journal.aspx?issn=0354-0243"
    Journal_URL["j-Z-ALLG-WISSENSCHAFTSTHEOR"]		= "http://www.jstor.org/journals/00442216.html; http://link.springer.com/journal/10838"
    Journal_URL["j-Z-ANAL-CHEM"]			= "http://link.springer.com/journal/216"
    Journal_URL["j-Z-ANGE-CHEM"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1521-3757"
    Journal_URL["j-Z-ANGE-MATH-MECH"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1521-4001"
    Journal_URL["j-Z-ANGE-MATH-PHYS"]			= "http://link.springer.com/journal/33"
    Journal_URL["j-Z-ANORG-ALLG-CHEM"]			= "https://onlinelibrary.wiley.com/journal/15213749"
    Journal_URL["j-Z-CHEM-STUTTGART"]			= "https://onlinelibrary.wiley.com/journal/00442402"
    Journal_URL["j-Z-EKSP-TEOR-FIZ"]			= "http://jetp.ac.ru/cgi-bin/e/index"
    Journal_URL["j-Z-ELEKTROCHEM"]			= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)0005-9021b"
    Journal_URL["j-Z-ELEKTROCHEM-ANGEW-PHYS-CHEM"]	= "http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)0005-9021c"
    Journal_URL["j-Z-NATURFORSCH"]			= "http://www.degruyter.com/view/j/zna; http://www.znaturforsch.com/conts.htm"
    Journal_URL["j-Z-NATURFORSCH-A-ASTROPHYS-PHYS-PHYS-CHEM"] = "https://www.degruyter.com/journal/key/zna/html"
    Journal_URL["j-Z-OPER-RES"]				= "http://link.springer.com/journal/186"
    Journal_URL["j-Z-PHILOS-FORSCH"]			= "http://www.jstor.org/journal/zeitphilfors"
    Journal_URL["j-Z-PHYSIK"]				= "http://link.springer.com/journal/218"
    Journal_URL["j-Z-PHYSIK-A-HADRONS-NUCL"]		= "http://link.springer.com/journal/218"
    Journal_URL["j-Z-PHYSIK-B-CM"]			= "http://link.springer.com/journal/257"
    Journal_URL["j-Z-PHYSIK-C"]				= "http://link.springer.com/journal/288"
    Journal_URL["j-Z-TEH-FIZ"]				= "http://istina.msu.ru/journals/437021/"
    Journal_URL["j-Z-THEOL-KIRCHE"]			= "http://www.jstor.org/journal/zeittheokirc"
    Journal_URL["j-Z-WAHRSCHEINLICHKEITSTHEOR-VERW-GEB"] = "http://link.springer.com/journal/440"
    Journal_URL["j-ZH-VYCHISL-MAT-MAT-FIZ"]		= "http://www.mathnet.ru/zvmmf"
    Journal_URL["j-ZOR-MATH-METHODS-OPER-RES"]		= "http://link.springer.com/journal/186"
    Journal_URL["j-ZYGON-J-RELIG-SCI"]			= "http://onlinelibrary.wiley.com/journal/10.1111/(ISSN)1467-9744"
}


function ISSN_Digit(the_ISSN,n)
{
    return (index("0123456789X", substr(the_ISSN, n, 1)) - 1)
}


function ISSN_to_Journal(the_ISSN)
{
    the_ISSN = tolower(the_ISSN)	# ensure array index is always single case
    return ((the_ISSN in ISSN_to_journal) ? ISSN_to_journal[the_ISSN] : "")
}


function Journal_to_CODEN(journal)
{
    journal = tolower(journal)	# ensure array index is always single case
    return ((journal in journal_to_CODEN) ? journal_to_CODEN[journal] : "")
}


function Journal_to_ISSN(journal)
{
    journal = tolower(journal)	# ensure array index is always single case
    return ((journal in journal_to_ISSN) ? journal_to_ISSN[journal] : "")
}


function new_entry()
{
    Citation_Tag = tag($0)
    # warning("DEBUG: tag = <" Citation_Tag ">")
    CODEN = ""
    Have_Full_Journal = 0
    Have_ISSN = 0
    Have_ISSN_L = 0
    Have_Journal_URL = 0
    ISSN = ""
    ISSN_L = ""
    Journal = ""
}


function pad_to_length(s,n)
{
    # Return a copy of s blank-padded (or truncated) to length n

    s = substr(s,1,n)
    while (length(s) < n)
	s = s "                                        "

    return (substr(s,1,n))
}


function print_abbrevs( sortpipe,the_abbrev)
{
   # We select a sort pipe that keeps only lines that match in the
   # first 32 characters (8 from "@String{" and 24 from the journal
   # key), because several journals appear multiple times with variant
   # spellings.
   sortpipe =  "sort +0.0 -0.32 -f -u " \
	"| nawk -f /u/sy/beebe/tex/bib/wrap.awk PREFIX='                                            ' "

   sortpipe =  "sort +0.0 -0.32 -f -u "

   for (the_abbrev in Used)
	printf("@String{%-23s = \"%s\"}\n",the_abbrev,Expansion[the_abbrev]) | sortpipe
   close(sortpipe)
   print ""
}


function print_CODEN(line,    old_coden, new_coden)
{
    if (match(line, "\"[^\"][^\"][^\"][^\"][^\"]\","))
    {
	old_coden = substr(line, RSTART + 1, 5)
	new_coden = fix_CODEN(old_coden)
	line = (substr(line, 1, RSTART) new_coden substr(line, RSTART + RLENGTH - 2))
	warning("replaced old 5-digit CODEN [" old_coden \
		"] with new checksummed 6-digit CODEN [" new_coden "]")
    }

    write_tmp(line)
    CODEN = value(line)
}


function print_ISSN(line,    issn)
{
    issn = toupper(value(line))
    ## print "%% DEBUG: print_ISSN(): issn = [" issn "]"

    # check for expansion, e.g., "0009-3696" to "0009-3696 (print), 2327-5804 (electronic)"
    if ( (length(issn) == 9) && (issn in Full_ISSN) )
	sub(issn, Full_ISSN[issn], line)

    write_tmp(line)
    ISSN = value(line)
    ## print "%% DEBUG: print_ISSN(): ISSN = [" ISSN "]"
}


function print_journal(line,    squeezed_journal,the_journal)
{
    the_journal = value(line)

    if (Value_Type != TYPE_QUOTED)
	write_tmp(line)		# output non-quoted strings verbatim
    else
    {
	squeezed_journal = squeeze(the_journal)

	if ((squeezed_journal ~ /[?]/) || (squeezed_journal == ""))
	    write_tmp(line)	# NEVER replace an uncertain/empty value with an abbrev!
	else if (squeezed_journal in Squeezed_Abbrev)
	{
	    write_tmp("  journal =      " Squeezed_Abbrev[squeezed_journal] ",")
	    Journal = Squeezed_Abbrev[squeezed_journal] # remember globally
	    Used[Squeezed_Abbrev[squeezed_journal]] = 1

	    if (Journal in Journal_URL)
		write_tmp("  journal-URL =  \"" Journal_URL[Journal] "\",")
	}
	else
	{
	    warning("no journal abbreviation for [" the_journal "]")
	    write_tmp(line)
	}
    }
}


function print_missing_CODEN( short,the_ISSN)
{
    for (short in Expansion)
    {
	if (Journal_to_CODEN(short) == "") # then CODEN is missing
	{
	    printf("    set_CODEN(\"%s\",%s \"\")\n", short, \
		   substr("                                        ",1,38-length(short))) | SORTPIPE
	    the_ISSN = Journal_to_ISSN(short)
	    if (the_ISSN != "")
		print "find_ISSN " the_ISSN | SORTPIPE
	    print "find\t______\t" ((the_ISSN == "") ? "____-____" : the_ISSN) "\t" pad_to_length(short,31) "\t" Expansion[short] | SORTPIPE2
	}
    }
}


function print_missing_ISSN( short,the_CODEN)
{
    for (short in Expansion)
    {
	if (Journal_to_ISSN(short) == "") # then ISSN is missing
	{
	    printf("    set_ISSN(\"%s\",%s \"\")\n", short, \
		   substr("                                        ",1,39-length(short))) | SORTPIPE
	    the_CODEN = Journal_to_CODEN(short)
	    if (the_CODEN != "")
		print "find_CODEN " the_CODEN | SORTPIPE
	    print "find_TITLE \"" Expansion[short] "\"" | SORTPIPE
	    print "find\t" ((the_CODEN == "") ? "______" : the_CODEN) "\t____-____\t" pad_to_length(short,31) "\t" Expansion[short] | SORTPIPE2
	}
    }
}


function print_saved_data(line,    k,n,parts,the_CODEN,the_ISSN,the_journal)
{
    if (Journal != "")
    {
	the_CODEN = Journal_to_CODEN(Journal)
	if ((CODEN != "") && (CODEN != "????"))	# then compare bibliography CODEN with CODEN matching journal name
	{
	    if (CODEN != the_CODEN) # error: CODENs mismatch
	    {
		if (the_CODEN == "")
		    warning("Journal mismatch:\texpected " CODEN_to_Journal(CODEN) " : found " Journal " for CODEN " CODEN)
		else if ((length(the_CODEN) == 6) && (length(CODEN) == 5) && (substr(the_CODEN,1,5) == CODEN))
		{		# have old check-digit-less CODEN, which we can repair
		    warning("CODEN mismatch:\texpected " the_CODEN ": found " CODEN ": fix by: sed -f " SED_File)
		    print "s/\"" CODEN "\"/\"" the_CODEN "\"/" | ("sort -u >" SED_File)
		}
		else if ((index(the_CODEN,CODEN) == 0) || (length(CODEN) != 6)) # NB: the_CODEN may have list of CODENs
		    warning("CODEN mismatch:\texpected " the_CODEN ": found " CODEN)
	    }
	    else		# CODENs match, so check that journals do too
	    {
		the_journal = CODEN_to_Journal(CODEN)
		if (the_journal != Journal)
		   warning("Journal mismatch:\texpected " the_journal " : found " Journal " for CODEN " CODEN)
	    }
	}
	else			# empty CODEN, so to try to supply CODEN that matches journal name
	{
	    CODEN = the_CODEN
	    if ((CODEN != "") && (CODEN != "????"))
		write_tmp("  CODEN =        \"" CODEN "\",")
	}

	the_ISSN = Journal_to_ISSN(Journal)
	if ((ISSN != "") && (ISSN != "????"))	# then compare bibliography ISSN with ISSN matching journal name
	{
	    if (ISSN != the_ISSN) # error: ISSNs mismatch
	    {
		if (the_ISSN == "")
		    warning("Journal mismatch:\texpected " ISSN_to_Journal(ISSN) " : found " Journal " for ISSN " ISSN)
		else if ((index(the_ISSN,ISSN) == 0) || (length(ISSN) != 9)) # NB: the_ISSN may have list of ISSNs
		    warning("ISSN mismatch:\texpected " the_ISSN ": found " ISSN)
	    }
	    else		# ISSNs match, so check that journals do too
	    {
		the_journal = ISSN_to_Journal(ISSN)
		if (the_journal != Journal)
		   warning("Journal mismatch:\texpected " the_journal " : found " Journal " for ISSN " ISSN)
	    }
	}
	else			# empty ISSN, so try to supply ISSN that matches journal name
	{
	    ISSN = the_ISSN

	    if (!Have_ISSN && (ISSN != "") && (ISSN != "????"))
		write_tmp("  ISSN =         \"" ISSN "\",")
	}

	## Output a single ISSN-L value if any of the
	## internally-provided ISSN values are in the
	## ISSN_to_ISSN_L[] map.

	if (the_ISSN != "")
	{
	    n = split(the_ISSN, parts, "[^-0-9X]+")

	    for (k = 1; k <= n; ++k)
	    {
		## print "%%% DEBUG: parts[" k "] = [" parts[k] "]  n =", n

		if (!Have_ISSN_L && (parts[k] in ISSN_to_ISSN_L))
		{
		    ## print "%%% DEBUG: matched ISSN-L!"

		    write_tmp("  ISSN-L =       \"" ISSN_to_ISSN_L[parts[k]] "\",")
		    break
		}
	    }
	}

	if (!Have_Full_Journal && (Journal in Expansion))
	    write_tmp("  fjournal =     \"" Expansion[Journal] "\",")

	if (!Have_Journal_URL && (Journal in Journal_URL))	# added [08-Dec-2013]
	    write_tmp("  journal-URL =  \"" Journal_URL[Journal] "\",")
    }

    write_tmp(line)
}


function print_and_save_journal(line)
{
    write_tmp(line)

    if (NF == 3)		# Looks like ``journal = j-xyz,''.  We
    {				# must avoid catching more complex cases,
				# like ``journal = j-abc # " or " # j-xyz''
	Journal = $NF
	sub(/, *$/, "", Journal)
    }
}


function set_CODEN(the_journal,the_CODEN,silent, old_CODEN,old_journal)
{
    if (the_CODEN == "")
	return
    else if (the_CODEN == "????")
	return
    old_journal = CODEN_to_Journal(the_CODEN)
    if (old_journal != "")
    {
	if ((old_journal != the_journal) && !silent)
	    warning("Duplicate CODEN " the_CODEN " for " the_journal " and " old_journal)
    }
    else			 # NB: this is the ONLY place this array is set!
	CODEN_to_journal[tolower(the_CODEN)] = the_journal # NB: index in single lettercase

    old_CODEN = Journal_to_CODEN(the_journal)
    if (old_CODEN != "")
    {
	if ((old_CODEN != the_CODEN) && !silent)
	    warning("Duplicate journal " the_journal " for " the_CODEN " and " old_CODEN)
    }
    else			# NB: this is the ONLY place this array is set!
	journal_to_CODEN[tolower(the_journal)] = the_CODEN # NB: index in single lettercase
}


function set_ISSN(the_journal,the_ISSN,silent, old_ISSN,old_journal)
{
    if (the_ISSN == "")
	return
    else if (the_ISSN == "????")
	return
    old_journal = ISSN_to_Journal(the_ISSN)
    if (old_journal != "")
    {
	if ((old_journal != the_journal) && !silent)
	    warning("Duplicate ISSN " the_ISSN " for " the_journal " and " old_journal)
    }
    else			# NB: this is the ONLY place this array is set!
	ISSN_to_journal[tolower(the_ISSN)] = the_journal # NB: index in single lettercase

    old_ISSN = Journal_to_ISSN(the_journal)
    if (old_ISSN != "")
    {
	if ((old_ISSN != the_ISSN) && !silent)
	    warning("Duplicate journal " the_journal " for " the_ISSN " and " old_ISSN)
    }
    else			# NB: this is the ONLY place this array is set!
	journal_to_ISSN[tolower(the_journal)] = the_ISSN # NB: index in single lettercase
}


function set_quad(the_CODEN, the_ISSN, the_journal, abbrev, full)
{
    if (the_CODEN in CODEN_to_journal)
	warning("set_quad(): CODEN " the_CODEN " already defined: arguments ignored")
    else if (the_ISSN in ISSN_to_journal)
	warning("set_quad(): ISSN " the_ISSN " already defined: arguments ignored")
    else if (the_journal in journal_to_ISSN)
	warning("set_quad(): journal " the_journal " already defined: arguments ignored")
    else if (the_journal in journal_to_CODEN)
	warning("set_quad(): journal " the_journal " already defined: arguments ignored")
    else
    {
	CODEN_to_journal[the_CODEN] = the_journal
	ISSN_to_journal[tolower(the_ISSN)] = the_journal
	journal_to_ISSN[tolower(the_journal)] = the_ISSN
	journal_to_CODEN[tolower(the_journal)] = the_CODEN
    }
}


function squeeze(s, t)
{
    # Reduce s to lower case, and remove selected punctuation and
    # TeX control sequences, plus a few short English words
    t = tolower(s)

    gsub(/ a /, " ", t)		# removed embedded ignorable words
    gsub(/ an /, " ", t)
    gsub(/ and /, " ", t)
    gsub(/ de /, " ", t)
    gsub(/ der /, " ", t)
    gsub(/ fur /, " ", t)
    gsub(/ of /, " ", t)
    gsub(/ on /, " ", t)
    gsub(/ und /, " ", t)
    gsub(/ \\& /, " ", t)
    gsub(/ for /, " ", t)
    gsub(/ of /, " ", t)
    gsub(/ on /, " ", t)
    gsub(/ the /, " ", t)
    gsub(/ to /, " ", t)

    gsub(/^a /, "", t)		# removed initial ignorable words
    gsub(/^an /, "", t)
    gsub(/^the /, "", t)

    gsub(/^journal /, "j ", t)	# reduce some rather common names
    gsub(/ journal /, " j ", t)

    gsub(/^journ[.] /, "j ", t)
    gsub(/ journ[.] /, " j ", t)

    gsub(/^zeitschrift /, "z ", t)
    gsub(/ zeitschrift /, " z ", t)

    gsub(/---/, "", t)		# remove emdash
    gsub(/\\emdash/, "", t)	# remove emdash
    gsub(/\\-/, "", t)		# remove discretionary hyphen
    gsub(/[\-\\{}()\[\].,;:~ \t\n]/, "", t)	# remove selected punctuation

    # print "DEBUG: [" s "] -> [" t "]" >"/dev/stderr"

    return (t)
}


function tag(s, k1,k2)
{
    # Return the citation tag from a `@EntryType{tag,' line
    k1 = index(s,"{") + 1
    k2 = index(s,",")
    return (substr(s,k1,k2-k1))
}


function trim(s)
{
    gsub(/^[ \t]+/,"",s)
    gsub(/[ \t]+$/,"",s)
    return (s)
}


function value(s, k,t)
{
    # Return the value string from a key = value assignment, and set
    # the GLOBAL variable Value_Type to one of the TYPE_xxx values to
    # indicate the value type.  In the case of TYPE_QUOTED values, the
    # surrounding quotes are stripped, for convenience of table
    # lookups.

    k = index(s,"=")
    if (k == 0)
    {	# This can NEVER happen, but check anyway
	warning("no key=value assignment found [" s "]")
	t = s
	Value_Type = TYPE_UNKNOWN
    }
    else
    {
	t = trim(substr(s,k+1))	# trim text on RHS of assignment

	if (index(t,"#") > 0)	# looks like concatenation operator
	    Value_Type = TYPE_COMPLEX
	else if ((substr(t,1,1) == "\"") && (substr(t,length(t)-1) == "\","))
	{
	    Value_Type = TYPE_QUOTED
	    t = substr(t,2,length(t)-3)
	}
	else if (t ~ /["]/)
	{		# This can happen if a comma is missing after a quoted value
	    warning("unexpected quote, or missing final comma, in value string [" t "]")
	    Value_Type = TYPE_COMPLEX
	}
	else if (substr(t,length(t)) == ",")	# matches <abbrev,>
	    Value_Type = TYPE_ABBREV
	else			# don't know what this is
	    Value_Type = TYPE_COMPLEX
    }
    return (t)
}


function warning(s)
{
    print FILENAME ":" FNR "\t[" Citation_Tag "] " s > "/dev/stderr"
}


function write_tmp(s)
{
    print s > Temp_File
}
